#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a > r && b > r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && ((a ^ b >= 0 && a > std::numeric_limits<T>::max() / b) || (a ^ b < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _151,    std::shared_ptr< monty::ndarray< long long,1 > > _152,    int _153,    int _154,    int _155,    std::shared_ptr< monty::ndarray< long long,1 > > _156) { mosek::fusion::p_Sort::argTransposeSort(_151,_152,_153,_154,_155,_156); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156){
  _checked_ptr_1<long long> _ptr__151(_151 ? _151->raw() : nullptr, _151 ? _151->size(0) : 0);
  _checked_ptr_1<long long> _ptr__152(_152 ? _152->raw() : nullptr, _152 ? _152->size(0) : 0);
  _checked_ptr_1<long long> _ptr__156(_156 ? _156->raw() : nullptr, _156 ? _156->size(0) : 0);
  int _6615 = (int)0;
  int _6616 = safe_add( safe_mul( _153,_155 ),(int)1 );
  for (int _157 = _6615; _157 < _6616; ++_157)
  {
    {
      _ptr__152[_157] = (int)0;
    }
  }
  int _6617 = (int)0;
  int _6618 = (int)((_156)->size(0));
  for (int _158 = _6617; _158 < _6618; ++_158)
  {
    {
      ++ _ptr__152[safe_add( safe_add( safe_mul( (_ptr__156[_ptr__151[_158]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__151[_158]] % _155) ),(int)1 )];
    }
  }
  int _6619 = (int)0;
  int _6620 = safe_mul( _153,_155 );
  for (int _159 = _6619; _159 < _6620; ++_159)
  {
    {
      _ptr__152[safe_add( _159,(int)1 )] = safe_add( _ptr__152[safe_add( _159,(int)1 )],_ptr__152[_159] );
    }
  }
  std::vector<long long> _6621;
  for (int _161 = (int)0, _6622 = (int)((_151)->size(0)); _161 < _6622 ; ++_161)
  {
    _6621.push_back(_ptr__151[_161]);
  }
  auto _6623 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6621.size()),_6621.begin(),_6621.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _160 = _6623;
  _checked_ptr_1<long long> _ptr__160(_160 ? _160->raw() : nullptr,_160 ? _160->size(0) : 0);
  long long _6624 = (long long)0;
  long long _6625 = (long long)((_156)->size(0));
  for (long long _162 = _6624; _162 < _6625; ++_162)
  {
    {
      long long _163 = safe_add( safe_mul( (_ptr__156[_ptr__160[_162]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__160[_162]] % _155) );
      _ptr__151[_ptr__152[_163]] = _ptr__160[_162];
      ++ _ptr__152[_163];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _164,    std::shared_ptr< monty::ndarray< long long,1 > > _165) { mosek::fusion::p_Sort::argsort(_164,_165); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165){
  _checked_ptr_1<long long> _ptr__164(_164 ? _164->raw() : nullptr, _164 ? _164->size(0) : 0);
  _checked_ptr_1<long long> _ptr__165(_165 ? _165->raw() : nullptr, _165 ? _165->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_164,_165,(long long)((int)0),(long long)((int)((_164)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _166,    std::shared_ptr< monty::ndarray< int,1 > > _167) { mosek::fusion::p_Sort::argsort(_166,_167); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167){
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr, _166 ? _166->size(0) : 0);
  _checked_ptr_1<int> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_166,_167,(long long)((int)0),(long long)((int)((_166)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _168,    std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< long long,1 > > _170) { mosek::fusion::p_Sort::argsort(_168,_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170){
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_168,_169,_170,(long long)((int)0),(long long)((int)((_168)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< int,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<int> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    long long _176,    long long _177) { mosek::fusion::p_Sort::argsort(_174,_175,_176,_177); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,_177,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179,    long long _180,    long long _181) { mosek::fusion::p_Sort::argsort(_178,_179,_180,_181); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181){
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_178,_179,_180,_181,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _182,    std::shared_ptr< monty::ndarray< long long,1 > > _183,    std::shared_ptr< monty::ndarray< long long,1 > > _184,    long long _185,    long long _186) { mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186){
  _checked_ptr_1<long long> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  _checked_ptr_1<long long> _ptr__183(_183 ? _183->raw() : nullptr, _183 ? _183->size(0) : 0);
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _187,    std::shared_ptr< monty::ndarray< int,1 > > _188,    std::shared_ptr< monty::ndarray< int,1 > > _189,    long long _190,    long long _191) { mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191){
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  _checked_ptr_1<int> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<int> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _192,    std::shared_ptr< monty::ndarray< long long,1 > > _193,    long long _194,    long long _195,    bool _196) { mosek::fusion::p_Sort::argsort(_192,_193,_194,_195,_196); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196){
  _checked_ptr_1<long long> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  if (((!_196) || ((_195 - _194) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_192,_193,_194,_195,_196)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _197 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__197(_197 ? _197->raw() : nullptr,_197 ? _197->size(0) : 0);
      int _198 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_192,_193,nullptr,_194,_195,_197);
      if (((_ptr__197[(int)1] - _ptr__197[(int)0]) < safe_mul( _198,(_195 - _194) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_192,_193,_194,_195,_ptr__197[(int)0],_ptr__197[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _199,    std::shared_ptr< monty::ndarray< int,1 > > _200,    long long _201,    long long _202,    bool _203) { mosek::fusion::p_Sort::argsort(_199,_200,_201,_202,_203); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203){
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  _checked_ptr_1<int> _ptr__200(_200 ? _200->raw() : nullptr, _200 ? _200->size(0) : 0);
  if (((!_203) || ((_202 - _201) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_199,_200,_201,_202,_203)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__204(_204 ? _204->raw() : nullptr,_204 ? _204->size(0) : 0);
      int _205 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_199,_200,nullptr,_201,_202,_204);
      if (((_ptr__204[(int)1] - _ptr__204[(int)0]) < safe_mul( _205,(_202 - _201) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_199,_200,_201,_202,_ptr__204[(int)0],_ptr__204[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _206,    std::shared_ptr< monty::ndarray< long long,1 > > _207,    std::shared_ptr< monty::ndarray< long long,1 > > _208,    long long _209,    long long _210,    bool _211) { mosek::fusion::p_Sort::argsort(_206,_207,_208,_209,_210,_211); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211){
  _checked_ptr_1<long long> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  _checked_ptr_1<long long> _ptr__207(_207 ? _207->raw() : nullptr, _207 ? _207->size(0) : 0);
  _checked_ptr_1<long long> _ptr__208(_208 ? _208->raw() : nullptr, _208 ? _208->size(0) : 0);
  if (((!_211) || ((_210 - _209) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_206,_207,_208,_209,_210,_211)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _212 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr,_212 ? _212->size(0) : 0);
      int _213 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_206,_207,_208,_209,_210,_212);
      if ((((_ptr__212[(int)1] - _ptr__212[(int)0]) < safe_mul( _213,(_210 - _209) )) && ((_ptr__212[(int)3] - _ptr__212[(int)2]) < safe_mul( _213,(_210 - _209) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_206,_208,_209,_210,_ptr__212[(int)2],_ptr__212[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_206,_207,_209,_210,_ptr__212[(int)0],_ptr__212[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _214,    std::shared_ptr< monty::ndarray< int,1 > > _215,    std::shared_ptr< monty::ndarray< int,1 > > _216,    long long _217,    long long _218,    bool _219) { mosek::fusion::p_Sort::argsort(_214,_215,_216,_217,_218,_219); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219){
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  _checked_ptr_1<int> _ptr__215(_215 ? _215->raw() : nullptr, _215 ? _215->size(0) : 0);
  _checked_ptr_1<int> _ptr__216(_216 ? _216->raw() : nullptr, _216 ? _216->size(0) : 0);
  if (((!_219) || ((_218 - _217) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_214,_215,_216,_217,_218,_219)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__220(_220 ? _220->raw() : nullptr,_220 ? _220->size(0) : 0);
      int _221 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_214,_215,_216,_217,_218,_220);
      if ((((_ptr__220[(int)1] - _ptr__220[(int)0]) < safe_mul( _221,(_218 - _217) )) && ((_ptr__220[(int)3] - _ptr__220[(int)2]) < safe_mul( _221,(_218 - _217) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_214,_216,_217,_218,_ptr__220[(int)2],_ptr__220[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_214,_215,_217,_218,_ptr__220[(int)0],_ptr__220[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _222,    std::shared_ptr< monty::ndarray< long long,1 > > _223,    long long _224,    long long _225,    long long _226,    long long _227) { mosek::fusion::p_Sort::argbucketsort(_222,_223,_224,_225,_226,_227); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227){
  _checked_ptr_1<long long> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  _checked_ptr_1<long long> _ptr__223(_223 ? _223->raw() : nullptr, _223 ? _223->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_222,_224,_225,_223,_226,_227);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< int,1 > > _229,    long long _230,    long long _231,    int _232,    int _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<int> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< long long,1 > > _235,    std::shared_ptr< monty::ndarray< long long,1 > > _236,    long long _237,    long long _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239) { mosek::fusion::p_Sort::getminmax(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<long long> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  _checked_ptr_1<long long> _ptr__236(_236 ? _236->raw() : nullptr, _236 ? _236->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _ptr__239[(int)0] = _ptr__235[_ptr__234[_237]];
  _ptr__239[(int)1] = _ptr__235[_ptr__234[_237]];
  long long _6626 = safe_add( _237,(int)1 );
  long long _6627 = _238;
  for (long long _240 = _6626; _240 < _6627; ++_240)
  {
    {
      if ((_ptr__239[(int)0] > _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)0] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
      if ((_ptr__239[(int)1] < _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)1] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
    }
  }
  if ((NULL != _236.get()))
  {
    {
      _ptr__239[(int)2] = _ptr__236[_ptr__234[_237]];
      _ptr__239[(int)3] = _ptr__236[_ptr__234[_237]];
      long long _6628 = safe_add( _237,(int)1 );
      long long _6629 = _238;
      for (long long _241 = _6628; _241 < _6629; ++_241)
      {
        {
          if ((_ptr__239[(int)2] > _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)2] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
          if ((_ptr__239[(int)3] < _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)3] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _242,    std::shared_ptr< monty::ndarray< int,1 > > _243,    std::shared_ptr< monty::ndarray< int,1 > > _244,    long long _245,    long long _246,    std::shared_ptr< monty::ndarray< int,1 > > _247) { mosek::fusion::p_Sort::getminmax(_242,_243,_244,_245,_246,_247); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247){
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<int> _ptr__243(_243 ? _243->raw() : nullptr, _243 ? _243->size(0) : 0);
  _checked_ptr_1<int> _ptr__244(_244 ? _244->raw() : nullptr, _244 ? _244->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _ptr__247[(int)0] = _ptr__243[_ptr__242[_245]];
  _ptr__247[(int)1] = _ptr__243[_ptr__242[_245]];
  long long _6630 = safe_add( _245,(int)1 );
  long long _6631 = _246;
  for (long long _248 = _6630; _248 < _6631; ++_248)
  {
    {
      if ((_ptr__247[(int)0] > _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)0] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
      if ((_ptr__247[(int)1] < _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)1] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
    }
  }
  if ((NULL != _244.get()))
  {
    {
      _ptr__247[(int)2] = _ptr__244[_ptr__242[_245]];
      _ptr__247[(int)3] = _ptr__244[_ptr__242[_245]];
      long long _6632 = safe_add( _245,(int)1 );
      long long _6633 = _246;
      for (long long _249 = _6632; _249 < _6633; ++_249)
      {
        {
          if ((_ptr__247[(int)2] > _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)2] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
          if ((_ptr__247[(int)3] < _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)3] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _250,    std::shared_ptr< monty::ndarray< long long,1 > > _251,    long long _252,    long long _253,    bool _254) { return mosek::fusion::p_Sort::issorted(_250,_251,_252,_253,_254); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254){
  _checked_ptr_1<long long> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<long long> _ptr__251(_251 ? _251->raw() : nullptr, _251 ? _251->size(0) : 0);
  long long _6634 = _252;
  long long _6635 = (_253 - (int)1);
  for (long long _255 = _6634; _255 < _6635; ++_255)
  {
    {
      if ((_ptr__251[_ptr__250[_255]] > _ptr__251[_ptr__250[safe_add( _255,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< int,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<int> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _6636 = _258;
  long long _6637 = (_259 - (int)1);
  for (long long _261 = _6636; _261 < _6637; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< long long,1 > > _263,    std::shared_ptr< monty::ndarray< long long,1 > > _264,    long long _265,    long long _266,    bool _267) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266,_267); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<long long> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  _checked_ptr_1<long long> _ptr__264(_264 ? _264->raw() : nullptr, _264 ? _264->size(0) : 0);
  long long _6638 = _265;
  long long _6639 = (_266 - (int)1);
  for (long long _268 = _6638; _268 < _6639; ++_268)
  {
    {
      if (((_ptr__263[_ptr__262[_268]] > _ptr__263[_ptr__262[safe_add( _268,(int)1 )]]) || ((_ptr__263[_ptr__262[safe_add( _268,(int)1 )]] == _ptr__263[_ptr__262[_268]]) && (_ptr__264[_ptr__262[_268]] > _ptr__264[_ptr__262[safe_add( _268,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< int,1 > > _270,    std::shared_ptr< monty::ndarray< int,1 > > _271,    long long _272,    long long _273,    bool _274) { return mosek::fusion::p_Sort::issorted(_269,_270,_271,_272,_273,_274); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274){
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<int> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  _checked_ptr_1<int> _ptr__271(_271 ? _271->raw() : nullptr, _271 ? _271->size(0) : 0);
  long long _6640 = _272;
  long long _6641 = (_273 - (int)1);
  for (long long _275 = _6640; _275 < _6641; ++_275)
  {
    {
      if (((_ptr__270[_ptr__269[_275]] > _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) || ((_ptr__270[_ptr__269[_275]] == _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) && (_ptr__271[_ptr__269[_275]] > _ptr__271[_ptr__269[safe_add( _275,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276){ return new mosek::fusion::IndexCounter(_276); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_276); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
    n = (int)((_276)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_276);
    std::vector<int> _6642;
    for (int _277 = (int)0, _6643 = (int)((_276)->size(0)); _277 < _6643 ; ++_277)
    {
      _6642.push_back(_ptr__276[_277]);
    }
    auto _6644 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6642.size()),_6642.begin(),_6642.end()));
    dims = _6644;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){ return new mosek::fusion::IndexCounter(_278,_279,_280); }mosek::fusion::IndexCounter::IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_278,_279,_280); }void mosek::fusion::p_IndexCounter::_initialize  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    _checked_ptr_1<int> _ptr__280(_280 ? _280->raw() : nullptr, _280 ? _280->size(0) : 0);
    int _281 = (int)((_280)->size(0));
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6645 = (int)0;
    int _6646 = n;
    for (int _282 = _6645; _282 < _6646; ++_282)
    {
      {
        ((*st)(_282)) = _278;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_280);
    dims = _279;
    start = _278;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){ return new mosek::fusion::IndexCounter(_283,_284,_285); }mosek::fusion::IndexCounter::IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_283,_284,_285); }void mosek::fusion::p_IndexCounter::_initialize  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__284(_284 ? _284->raw() : nullptr, _284 ? _284->size(0) : 0);
    _checked_ptr_1<long long> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    n = (int)((_284)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6647 = (int)0;
    int _6648 = n;
    for (int _286 = _6647; _286 < _6648; ++_286)
    {
      {
        ((*st)(_286)) = _283;
      }
    }
    strides = _285;
    dims = _284;
    start = _283;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _287 = _pubthis->get();
  _pubthis->inc();
  return _287;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _288;
  {
    _288 = (int)0;
    for(;((_288 < (n - (int)1)) && (((*ii)(_288)) == ((*dims)(((n - _288) - (int)1)))));++ _288)
    {
      {
        ((*ii)(_288)) = (int)0;
        ++ ((*ii)(safe_add( _288,(int)1 )));
        ((*st)(safe_add( _288,(int)1 ))) = safe_add( ((*st)(safe_add( _288,(int)1 ))),((*strides)(((n - _288) - (int)2))) );
      }
    }
  }
  int _6649 = (int)0;
  int _6650 = _288;
  for (int _289 = _6649; _289 < _6650; ++_289)
  {
    {
      ((*st)(_289)) = ((*st)(_288));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6651 = (int)0;
  int _6652 = n;
  for (int _290 = _6651; _290 < _6652; ++_290)
  {
    {
      ((*st)(_290)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _291,    int _292) { return mosek::fusion::p_CommonTools::resize(_291,_292); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292){
  _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
  if ((_292 == (int)((_291)->size(0))))
  {
    {
      return _291;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_292)));
      _checked_ptr_1<long long> _ptr__293(_293 ? _293->raw() : nullptr,_293 ? _293->size(0) : 0);
      if ((_292 > (int)((_291)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,(int)((_291)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,_292);
        }
      }
      return _293;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295){
  _checked_ptr_1<int> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_295)));
      _checked_ptr_1<int> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298){
  _checked_ptr_1<double> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _299 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_298)));
      _checked_ptr_1<double> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::binarySearch(_300,_301); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  int _302 = (int)0;
  int _303 = (int)((_300)->size(0));
  if ((_ptr__300[_302] == _301))
  {
    {
      return _302;
    }
  }
  else if((_ptr__300[(_303 - (int)1)] == _301))
  {
    {
      return (_303 - (int)1);
    }
  }
  {}
  while ( (_302 < (_303 - (int)1)) )
  {
    {
      int _304 = ((_303 - _302) / (int)2);
      if ((_301 < _ptr__300[_304]))
      {
        {
          _302 = safe_add( _304,(int)1 );
        }
      }
      else if((_301 > _ptr__300[_304]))
      {
        {
          _303 = _304;
        }
      }
      else
      {
        {
          return _304;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _305,    long long _306) { return mosek::fusion::p_CommonTools::binarySearch(_305,_306); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306){
  _checked_ptr_1<long long> _ptr__305(_305 ? _305->raw() : nullptr, _305 ? _305->size(0) : 0);
  int _307 = ::mosek::fusion::p_CommonTools::binarySearchL(_305,_306);
  if (((_307 < (int)((_305)->size(0))) && (_ptr__305[_307] == _306)))
  {
    {
      return _307;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearchR(_308,_309); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = (int)0;
  int _311 = (int)((_308)->size(0));
  if ((_ptr__308[_310] > _309))
  {
    {
      return _310;
    }
  }
  {}
  while ( (_310 < (_311 - (int)1)) )
  {
    {
      int _312 = (safe_add( _311,_310 ) / (int)2);
      if ((_309 >= _ptr__308[_312]))
      {
        {
          _310 = _312;
        }
      }
      else
      {
        {
          _311 = _312;
        }
      }
    }
  }
  return _311;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _313,    long long _314) { return mosek::fusion::p_CommonTools::binarySearchL(_313,_314); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314){
  _checked_ptr_1<long long> _ptr__313(_313 ? _313->raw() : nullptr, _313 ? _313->size(0) : 0);
  int _315 = (int)0;
  int _316 = (int)((_313)->size(0));
  if ((_314 <= _ptr__313[_315]))
  {
    {
      return _315;
    }
  }
  {}
  while ( (_315 < (_316 - (int)1)) )
  {
    {
      int _317 = (safe_add( _316,_315 ) / (int)2);
      if ((_ptr__313[_317] < _314))
      {
        {
          _315 = _317;
        }
      }
      else
      {
        {
          _316 = _317;
        }
      }
    }
  }
  return _316;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _318,    std::shared_ptr< monty::ndarray< int,1 > > _319,    std::shared_ptr< monty::ndarray< int,1 > > _320) { mosek::fusion::p_CommonTools::ndIncr(_318,_319,_320); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320){
  _checked_ptr_1<int> _ptr__318(_318 ? _318->raw() : nullptr, _318 ? _318->size(0) : 0);
  _checked_ptr_1<int> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  _checked_ptr_1<int> _ptr__320(_320 ? _320->raw() : nullptr, _320 ? _320->size(0) : 0);
  int _321 = ((int)((_318)->size(0)) - (int)1);
  ++ _ptr__318[_321];
  while ( ((_321 > (int)0) && (_ptr__318[_321] >= _ptr__320[_321])) )
  {
    {
      _ptr__318[_321] = _ptr__319[_321];
      ++ _ptr__318[(_321 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323,    std::shared_ptr< monty::ndarray< double,1 > > _324,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,    long long _328,    int _329,    int _330) { mosek::fusion::p_CommonTools::transposeTriplets(_322,_323,_324,_325,_326,_327,_328,_329,_330); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330){
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  _checked_ptr_1<double> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _329,(int)2 ))));
  _checked_ptr_1<long long> _ptr__331(_331 ? _331->raw() : nullptr,_331 ? _331->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _330,(int)2 ))));
  _checked_ptr_1<long long> _ptr__332(_332 ? _332->raw() : nullptr,_332 ? _332->size(0) : 0);
  {
    long long _333 = (long long)0;
    for(;(_333 < _328);++ _333)
    {
      {
        _ptr__332[safe_add( _ptr__323[_333],(int)2 )] = safe_add( _ptr__332[safe_add( _ptr__323[_333],(int)2 )],(int)1 );
        _ptr__331[safe_add( _ptr__322[_333],(int)2 )] = safe_add( _ptr__331[safe_add( _ptr__322[_333],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _334 = (int)1;
    for(;(_334 < _329);++ _334)
    {
      {
        _ptr__331[safe_add( _334,(int)1 )] = safe_add( _ptr__331[safe_add( _334,(int)1 )],_ptr__331[_334] );
      }
    }
  }
  {
    int _335 = (int)1;
    for(;(_335 < _330);++ _335)
    {
      {
        _ptr__332[safe_add( _335,(int)1 )] = safe_add( _ptr__332[safe_add( _335,(int)1 )],_ptr__332[_335] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__336(_336 ? _336->raw() : nullptr,_336 ? _336->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_328)));
  _checked_ptr_1<double> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  int _6653 = (int)0;
  int _6654 = _329;
  for (int _339 = _6653; _339 < _6654; ++_339)
  {
    {
      {
        long long _340 = _ptr__331[_339];
        for(;(_340 < _ptr__331[safe_add( _339,(int)1 )]);++ _340)
        {
          {
            int _341 = _ptr__323[_340];
            long long _342 = _ptr__332[_341];
            _ptr__336[_342] = _339;
            _ptr__337[_342] = _341;
            _ptr__338[_342] = _ptr__324[_340];
            _ptr__332[_341] = safe_add( _342,(int)1 );
          }
        }
      }
    }
  }
  ((*_325)((int)0)) = _337;
  ((*_326)((int)0)) = _336;
  ((*_327)((int)0)) = _338;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _343,    std::shared_ptr< monty::ndarray< int,1 > > _344,    std::shared_ptr< monty::ndarray< double,1 > > _345,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,    long long _349,    int _350,    int _351) { mosek::fusion::p_CommonTools::transposeTriplets(_343,_344,_345,_346,_347,_348,_349,_350,_351); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351){
  _checked_ptr_1<int> _ptr__343(_343 ? _343->raw() : nullptr, _343 ? _343->size(0) : 0);
  _checked_ptr_1<int> _ptr__344(_344 ? _344->raw() : nullptr, _344 ? _344->size(0) : 0);
  _checked_ptr_1<double> _ptr__345(_345 ? _345->raw() : nullptr, _345 ? _345->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _352 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _350,(int)2 ))));
  _checked_ptr_1<long long> _ptr__352(_352 ? _352->raw() : nullptr,_352 ? _352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _353 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _351,(int)2 ))));
  _checked_ptr_1<long long> _ptr__353(_353 ? _353->raw() : nullptr,_353 ? _353->size(0) : 0);
  {
    long long _354 = (long long)0;
    for(;(_354 < _349);++ _354)
    {
      {
        _ptr__353[safe_add( _ptr__344[_354],(int)2 )] = safe_add( _ptr__353[safe_add( _ptr__344[_354],(int)2 )],(int)1 );
        _ptr__352[safe_add( _ptr__343[_354],(int)2 )] = safe_add( _ptr__352[safe_add( _ptr__343[_354],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _355 = (int)1;
    for(;(_355 < _350);++ _355)
    {
      {
        _ptr__352[safe_add( _355,(int)1 )] = safe_add( _ptr__352[safe_add( _355,(int)1 )],_ptr__352[_355] );
      }
    }
  }
  {
    int _356 = (int)1;
    for(;(_356 < _351);++ _356)
    {
      {
        _ptr__353[safe_add( _356,(int)1 )] = safe_add( _ptr__353[safe_add( _356,(int)1 )],_ptr__353[_356] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _357 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__357(_357 ? _357->raw() : nullptr,_357 ? _357->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_349)));
  _checked_ptr_1<double> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    int _360 = (int)0;
    for(;(_360 < _350);++ _360)
    {
      {
        long long _6655 = _ptr__352[_360];
        long long _6656 = _ptr__352[safe_add( _360,(int)1 )];
        for (long long _361 = _6655; _361 < _6656; ++_361)
        {
          {
            int _362 = _ptr__344[_361];
            long long _363 = _ptr__353[_362];
            _ptr__357[_363] = _360;
            _ptr__358[_363] = _362;
            _ptr__359[_363] = _ptr__345[_361];
            _ptr__353[_362] = safe_add( _363,(int)1 );
          }
        }
      }
    }
  }
  ((*_346)((int)0)) = _358;
  ((*_347)((int)0)) = _357;
  ((*_348)((int)0)) = _359;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _364,    std::shared_ptr< monty::ndarray< int,1 > > _365,    std::shared_ptr< monty::ndarray< double,1 > > _366,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,    long long _370,    int _371,    int _372) { mosek::fusion::p_CommonTools::tripletSort(_364,_365,_366,_367,_368,_369,_370,_371,_372); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372){
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr, _364 ? _364->size(0) : 0);
  _checked_ptr_1<int> _ptr__365(_365 ? _365->raw() : nullptr, _365 ? _365->size(0) : 0);
  _checked_ptr_1<double> _ptr__366(_366 ? _366->raw() : nullptr, _366 ? _366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__373(_373 ? _373->raw() : nullptr,_373 ? _373->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _372,(int)2 ))));
  _checked_ptr_1<long long> _ptr__374(_374 ? _374->raw() : nullptr,_374 ? _374->size(0) : 0);
  long long _6657 = (long long)0;
  long long _6658 = _370;
  for (long long _375 = _6657; _375 < _6658; ++_375)
  {
    {
      _ptr__374[safe_add( _ptr__365[_375],(int)2 )] = safe_add( _ptr__374[safe_add( _ptr__365[_375],(int)2 )],(int)1 );
    }
  }
  int _6659 = (int)1;
  int _6660 = _372;
  for (int _376 = _6659; _376 < _6660; ++_376)
  {
    {
      _ptr__374[safe_add( _376,(int)1 )] = safe_add( _ptr__374[safe_add( _376,(int)1 )],_ptr__374[_376] );
    }
  }
  int _6661 = (int)0;
  int _6662 = (int)_370;
  for (int _377 = _6661; _377 < _6662; ++_377)
  {
    {
      int _378 = _ptr__365[_377];
      _ptr__373[_ptr__374[safe_add( _378,(int)1 )]] = _377;
      _ptr__374[safe_add( _378,(int)1 )] = safe_add( _ptr__374[safe_add( _378,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _371,(int)2 ))));
  _checked_ptr_1<long long> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  {
    int _381 = (int)0;
    for(;(_381 < _370);++ _381)
    {
      {
        _ptr__379[safe_add( _ptr__364[_381],(int)2 )] = safe_add( _ptr__379[safe_add( _ptr__364[_381],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _382 = (int)1;
    for(;(_382 < _371);++ _382)
    {
      {
        _ptr__379[safe_add( _382,(int)1 )] = safe_add( _ptr__379[safe_add( _382,(int)1 )],_ptr__379[_382] );
      }
    }
  }
  {
    int _383 = (int)0;
    for(;(_383 < _372);++ _383)
    {
      {
        {
          long long _384 = _ptr__374[_383];
          for(;(_384 < _ptr__374[safe_add( _383,(int)1 )]);++ _384)
          {
            {
              int _385 = _ptr__364[_ptr__373[_384]];
              _ptr__380[_ptr__379[safe_add( _385,(int)1 )]] = _ptr__373[_384];
              _ptr__379[safe_add( _385,(int)1 )] = safe_add( _ptr__379[safe_add( _385,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _386 = (int)1;
  {
    int _387 = _ptr__364[_ptr__380[(int)0]];
    int _388 = _ptr__365[_ptr__380[(int)0]];
    {
      int _389 = (int)1;
      for(;(_389 < _370);++ _389)
      {
        {
          int _390 = _ptr__380[_389];
          if (((_387 != _ptr__364[_390]) || (_388 != _ptr__365[_390])))
          {
            {
              _387 = _ptr__364[_390];
              _388 = _ptr__365[_390];
              ++ _386;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__391(_391 ? _391->raw() : nullptr,_391 ? _391->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__392(_392 ? _392->raw() : nullptr,_392 ? _392->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_386)));
  _checked_ptr_1<double> _ptr__393(_393 ? _393->raw() : nullptr,_393 ? _393->size(0) : 0);
  {
    int _394 = _ptr__380[(int)0];
    _ptr__391[(int)0] = _ptr__364[_394];
    _ptr__392[(int)0] = _ptr__365[_394];
    _ptr__393[(int)0] = _ptr__366[_394];
  }
  int _395 = (int)1;
  int _6663 = (int)1;
  long long _6664 = _370;
  for (long long _396 = _6663; _396 < _6664; ++_396)
  {
    {
      int _397 = _ptr__380[_396];
      if (((_ptr__391[(_395 - (int)1)] == _ptr__364[_397]) && (_ptr__392[(_395 - (int)1)] == _ptr__365[_397])))
      {
        {
          _ptr__393[(_395 - (int)1)] = (_ptr__393[(_395 - (int)1)] + _ptr__366[_397]);
        }
      }
      else
      {
        {
          _ptr__391[_395] = _ptr__364[_397];
          _ptr__392[_395] = _ptr__365[_397];
          _ptr__393[_395] = _ptr__366[_397];
          ++ _395;
        }
      }
    }
  }
  ((*_367)((int)0)) = _391;
  ((*_368)((int)0)) = _392;
  ((*_369)((int)0)) = _393;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _398,    std::shared_ptr< monty::ndarray< int,1 > > _399) { mosek::fusion::p_CommonTools::argMSort(_398,_399); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399){
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr, _398 ? _398->size(0) : 0);
  _checked_ptr_1<int> _ptr__399(_399 ? _399->raw() : nullptr, _399 ? _399->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_398)->size(0)))));
  _checked_ptr_1<int> _ptr__400(_400 ? _400->raw() : nullptr,_400 ? _400->size(0) : 0);
  bool _401 = false;
  {
    int _402 = (int)1;
    for(;(_402 < (int)((_398)->size(0)));_402 *= (int)2)
    {
      {
        _401 = (!_401);
        int _6665 = (int)0;
        int _6666 = (int)((_398)->size(0));
        int _6667 = safe_mul( _402,(int)2 );
        for (int _403 = _6665; _403 < _6666; _403 += _6667)
        {
          {
            if (_401)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_398,_400,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_400,_398,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_401)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_400,(int)0,_398,(int)0,(int)((_398)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr, _406 ? _406->size(0) : 0);
  int _6668;
  bool _6669 = (_409 > (int)((_404)->size(0)));
  if (_6669)
  {
    _6668 = (int)((_404)->size(0));
  }
  else
  {
    _6668 = _409;
  }
  int _410 = _6668;
  int _6670;
  bool _6671 = (_408 > _410);
  if (_6671)
  {
    _6670 = _410;
  }
  else
  {
    _6670 = _408;
  }
  int _411 = _6670;
  if ((_411 == _410))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_404,_407,_405,_407,(_411 - _407));
    }
  }
  else
  {
    {
      int _412 = _407;
      int _413 = _411;
      int _414;
      {
        _414 = _407;
        for(;((_412 < _411) && (_413 < _410));++ _414)
        {
          {
            if ((_ptr__406[_ptr__404[_412]] < _ptr__406[_ptr__404[_413]]))
            {
              {
                _ptr__405[_414] = _ptr__404[_412];
                ++ _412;
              }
            }
            else
            {
              {
                _ptr__405[_414] = _ptr__404[_413];
                ++ _413;
              }
            }
          }
        }
      }
      while ( (_412 < _411) )
      {
        {
          _ptr__405[_414] = _ptr__404[_412];
          ++ _412;
          ++ _414;
        }
      }
      while ( (_413 < _410) )
      {
        {
          _ptr__405[_414] = _ptr__404[_413];
          ++ _413;
          ++ _414;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _415,    std::shared_ptr< monty::ndarray< long long,1 > > _416,    std::shared_ptr< monty::ndarray< long long,1 > > _417,    long long _418,    long long _419) { mosek::fusion::p_CommonTools::argQsort(_415,_416,_417,_418,_419); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419){
  _checked_ptr_1<long long> _ptr__415(_415 ? _415->raw() : nullptr, _415 ? _415->size(0) : 0);
  _checked_ptr_1<long long> _ptr__416(_416 ? _416->raw() : nullptr, _416 ? _416->size(0) : 0);
  _checked_ptr_1<long long> _ptr__417(_417 ? _417->raw() : nullptr, _417 ? _417->size(0) : 0);
  if ((NULL == _417.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_418,_419);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_417,_418,_419);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _420,    std::shared_ptr< monty::ndarray< int,1 > > _421,    std::shared_ptr< monty::ndarray< int,1 > > _422,    long long _423,    long long _424) { mosek::fusion::p_CommonTools::argQsort(_420,_421,_422,_423,_424); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424){
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  _checked_ptr_1<int> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<int> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  if ((NULL == _422.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_423,_424);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_422,_423,_424);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _425,    int _426,    int _427,    int _428){ return new mosek::fusion::SolutionStruct(_425,_426,_427,_428); }mosek::fusion::SolutionStruct::SolutionStruct  (int _425,    int _426,    int _427,    int _428) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_425,_426,_427,_428); }void mosek::fusion::p_SolutionStruct::_initialize  (int _425,    int _426,    int _427,    int _428){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _425;
    sol_numcon = _426;
    sol_numcone = _427;
    sol_numbarvar = _428;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_425 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
    if ((_428 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_426 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
      }
    }
    {}
    if ((_427 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){ return new mosek::fusion::SolutionStruct(_429); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_429); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6672;
    bool _6673 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc.get());
    if (_6673)
    {
      _6672 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc);
    }
    else
    {
      _6672 = nullptr;
    }
    xc = _6672;
    std::shared_ptr< monty::ndarray< double,1 > > _6674;
    bool _6675 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx.get());
    if (_6675)
    {
      _6674 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx);
    }
    else
    {
      _6674 = nullptr;
    }
    xx = _6674;
    std::shared_ptr< monty::ndarray< double,1 > > _6676;
    bool _6677 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx.get());
    if (_6677)
    {
      _6676 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx);
    }
    else
    {
      _6676 = nullptr;
    }
    yx = _6676;
    std::shared_ptr< monty::ndarray< double,1 > > _6678;
    bool _6679 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slc.get());
    if (_6679)
    {
      _6678 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6678 = nullptr;
    }
    slc = _6678;
    std::shared_ptr< monty::ndarray< double,1 > > _6680;
    bool _6681 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->suc.get());
    if (_6681)
    {
      _6680 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6680 = nullptr;
    }
    suc = _6680;
    std::shared_ptr< monty::ndarray< double,1 > > _6682;
    bool _6683 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->y.get());
    if (_6683)
    {
      _6682 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->y);
    }
    else
    {
      _6682 = nullptr;
    }
    y = _6682;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6684;
    bool _6685 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx.get());
    if (_6685)
    {
      _6684 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6684 = nullptr;
    }
    slx = _6684;
    std::shared_ptr< monty::ndarray< double,1 > > _6686;
    bool _6687 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux.get());
    if (_6687)
    {
      _6686 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6686 = nullptr;
    }
    sux = _6686;
    std::shared_ptr< monty::ndarray< double,1 > > _6688;
    bool _6689 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx.get());
    if (_6689)
    {
      _6688 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx);
    }
    else
    {
      _6688 = nullptr;
    }
    snx = _6688;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _430,int _431,int _432,int _433) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_430,_431,_432,_433); }void mosek::fusion::p_SolutionStruct::resize(int _430,int _431,int _432,int _433){
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _433;
    }
  }
  else if((_433 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _434;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _434 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _434 = safe_add( _433,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_434);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_434);
      sol_numbarvar = _434;
    }
  }
  if ((_430 < (int)0))
  {
    {
    }
  }
  else if((_430 <= sol_numvar))
  {
    {
      sol_numvar = _430;
    }
  }
  else if((_430 <= (int)((xx)->size(0))))
  {
    {
      int _6690 = sol_numvar;
      int _6691 = _430;
      for (int _435 = _6690; _435 < _6691; ++_435)
      {
        {
          ((*slx)(_435)) = 0.0;
          ((*sux)(_435)) = 0.0;
          ((*xx)(_435)) = 0.0;
          ((*yx)(_435)) = 0.0;
        }
      }
      sol_numvar = _430;
    }
  }
  else
  {
    {
      int _436;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _430,(int)100 )))
      {
        {
          _436 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _436 = safe_add( _430,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _437 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__437(_437 ? _437->raw() : nullptr,_437 ? _437->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_437,(int)0,(int)((slx)->size(0)));
      slx = _437;
      std::shared_ptr< monty::ndarray< double,1 > > _438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__438(_438 ? _438->raw() : nullptr,_438 ? _438->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_438,(int)0,(int)((sux)->size(0)));
      sux = _438;
      std::shared_ptr< monty::ndarray< double,1 > > _439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__439(_439 ? _439->raw() : nullptr,_439 ? _439->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_439,(int)0,(int)((xx)->size(0)));
      xx = _439;
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_440,(int)0,(int)((yx)->size(0)));
      yx = _440;
      {
        int _441 = sol_numvar;
        for(;(_441 < _430);++ _441)
        {
          {
            ((*slx)(_441)) = 0.0;
            ((*sux)(_441)) = 0.0;
            ((*xx)(_441)) = 0.0;
          }
        }
      }
      sol_numvar = _430;
    }
  }
  if ((_431 < (int)0))
  {
    {
    }
  }
  else if((_431 <= sol_numcon))
  {
    {
      sol_numcon = _431;
    }
  }
  else if((_431 <= (int)((xx)->size(0))))
  {
    {
      int _6692 = sol_numcon;
      int _6693 = _431;
      for (int _442 = _6692; _442 < _6693; ++_442)
      {
        {
          ((*slc)(_442)) = 0.0;
          ((*suc)(_442)) = 0.0;
          ((*xc)(_442)) = 0.0;
          ((*y)(_442)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  else
  {
    {
      int _443;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _431,(int)100 )))
      {
        {
          _443 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _443 = safe_add( _431,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_444,(int)0,(int)((slc)->size(0)));
      slc = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_445,(int)0,(int)((suc)->size(0)));
      suc = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_446,(int)0,(int)((xc)->size(0)));
      xc = _446;
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_447,(int)0,(int)((y)->size(0)));
      y = _447;
      int _6694 = sol_numcon;
      int _6695 = _431;
      for (int _448 = _6694; _448 < _6695; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  if ((_432 < (int)0))
  {
    {
    }
  }
  else if((_432 <= sol_numcone))
  {
    {
      sol_numcone = _432;
    }
  }
  else if((_432 <= (int)((xx)->size(0))))
  {
    {
      int _6696 = sol_numcone;
      int _6697 = _432;
      for (int _449 = _6696; _449 < _6697; ++_449)
      {
        {
          ((*snx)(_449)) = 0.0;
        }
      }
      sol_numcone = _432;
    }
  }
  else
  {
    {
      int _450;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _432,(int)100 )))
      {
        {
          _450 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _450 = safe_add( _432,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_450)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_451,(int)0,(int)((snx)->size(0)));
      snx = _451;
      {
        int _452 = sol_numcone;
        for(;(_452 < _432);++ _452)
        {
          {
            ((*snx)(_452)) = 0.0;
          }
        }
      }
      sol_numcone = _432;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _453) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_453); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _453){
  return isAcceptable(dstatus,_453);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_454); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454){
  return isAcceptable(pstatus,_454);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456){
  if ((_456 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_455 == ::mosek::fusion::SolutionStatus::Optimal) || (_455 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){ return new mosek::fusion::ConNZStruct(_457,_458,_459,_460,_461,_462,_463); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_457,_458,_459,_460,_461,_462,_463); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__457(_457 ? _457->raw() : nullptr, _457 ? _457->size(0) : 0);
    _checked_ptr_1<int> _ptr__458(_458 ? _458->raw() : nullptr, _458 ? _458->size(0) : 0);
    _checked_ptr_1<double> _ptr__459(_459 ? _459->raw() : nullptr, _459 ? _459->size(0) : 0);
    _checked_ptr_1<double> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<int> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<int> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    ptrb = _457;
    subj = _458;
    cof = _459;
    bfix = _460;
    barsubi = _461;
    barsubj = _462;
    barmidx = _463;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _464){ return new mosek::fusion::Model(_464); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _464) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_464); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_464);
    monty::rc_ptr< ::mosek::fusion::Model > _465 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_464)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_464)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_464)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6698;
    for (int _466 = (int)0, _6699 = (int)((mosek::fusion::p_Model::_get_impl(_464)->vars)->size(0)); _466 < _6699 ; ++_466)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6700;
      bool _6701 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get());
      if (_6701)
      {
        _6700 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6700 = nullptr;
      }
      _6698.push_back(_6700);
    }
    auto _6702 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6698.size()),_6698.begin(),_6698.end()));
    vars = _6702;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_464)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6703;
    for (int _467 = (int)0, _6704 = (int)((mosek::fusion::p_Model::_get_impl(_464)->barvars)->size(0)); _467 < _6704 ; ++_467)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6705;
      bool _6706 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get());
      if (_6706)
      {
        _6705 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6705 = nullptr;
      }
      _6703.push_back(_6705);
    }
    auto _6707 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6703.size()),_6703.begin(),_6703.end()));
    barvars = _6707;
    var_map = mosek::fusion::p_Model::_get_impl(_464)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6708;
    for (int _468 = (int)0, _6709 = (int)((mosek::fusion::p_Model::_get_impl(_464)->cons)->size(0)); _468 < _6709 ; ++_468)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6710;
      bool _6711 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get());
      if (_6711)
      {
        _6710 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get())->__mosek_2fusion_2ModelConstraint__clone(_465);
      }
      else
      {
        _6710 = nullptr;
      }
      _6708.push_back(_6710);
    }
    auto _6712 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6708.size()),_6708.begin(),_6708.end()));
    cons = _6712;
    con_map = mosek::fusion::p_Model::_get_impl(_464)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _469){ return new mosek::fusion::Model(_469); }mosek::fusion::Model::Model  (const std::string &  _469) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_469); }void mosek::fusion::p_Model::_initialize  (const std::string &  _469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_469,std::string (""));
    model_name = _469;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6713;
    for (int _470 = (int)0, _6714 = (int)1024; _470 < _6714 ; ++_470)
    {
      _6713.push_back(nullptr);
    }
    auto _6715 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6713.size()),_6713.begin(),_6713.end()));
    vars = _6715;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6716;
    for (int _471 = (int)0, _6717 = (int)1024; _471 < _6717 ; ++_471)
    {
      _6716.push_back(nullptr);
    }
    auto _6718 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6716.size()),_6716.begin(),_6716.end()));
    cons = _6718;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474){
  _checked_ptr_1<int> _ptr__473(_473 ? _473->raw() : nullptr, _473 ? _473->size(0) : 0);
  _checked_ptr_1<int> _ptr__474(_474 ? _474->raw() : nullptr, _474 ? _474->size(0) : 0);
  return _472;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string & _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478){
  _checked_ptr_1<int> _ptr__475(_475 ? _475->raw() : nullptr, _475 ? _475->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  _checked_ptr_1<long long> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  task_format_con_names(_475,_476,_477,_478);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string & _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482){
  _checked_ptr_1<int> _ptr__479(_479 ? _479->raw() : nullptr, _479 ? _479->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  _checked_ptr_1<long long> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  task_format_var_names(_479,_480,_481,_482);
}
void mosek::fusion::p_Model::varname(int _483,const std::string & _484){
  task_var_name(_483,_484);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  int _487 = ((*natbarvarmap_ptr)(_485));
  int _488 = ((*natbarvarmap_num)(_485));
  int _6719 = (int)0;
  int _6720 = _488;
  for (int _489 = _6719; _489 < _6720; ++_489)
  {
    {
      _ptr__486[_489] = safe_add( _487,_489 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491){
  _checked_ptr_1<long long> _ptr__491(_491 ? _491->raw() : nullptr, _491 ? _491->size(0) : 0);
  int _492 = ((*natbarvarmap_ptr)(_490));
  int _493 = ((*natbarvarmap_num)(_490));
  int _494 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_490))));
  int _495 = (safe_mul( safe_mul( _493,_494 ),safe_add( _494,(int)1 ) ) / (int)2);
  long long _496 = ((*natbarvar_ptr)(_492));
  int _6721 = (int)0;
  int _6722 = _495;
  for (int _497 = _6721; _497 < _6722; ++_497)
  {
    {
      _ptr__491[_497] = safe_add( _496,_497 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _498,int _499){
  int _500 = (int)((natbarvar_idx)->size(0));
  int _501 = task_numbarvar();
  int _502 = (safe_mul( _499,safe_add( _499,(int)1 ) ) / (int)2);
  int _503 = safe_mul( _498,_502 );
  if ((safe_add( natbarvar_numbarvarelm,_503 ) >= _500))
  {
    {
      if ((_503 < _500))
      {
        {
          _503 = _500;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _500,_503 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _500,_503 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _500,_503 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6723;
      bool _6724 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6724)
      {
        _6723 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6723 = (int)32;
      }
      int _504 = _6723;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_504);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _504,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _505 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_504)));
      int _6725 = (int)0;
      int _6726 = (int)((barvars)->size(0));
      for (int _506 = _6725; _506 < _6726; ++_506)
      {
        {
          ((*_505)(_506)) = ((*barvars)(_506));
        }
      }
      barvars = _505;
    }
  }
  {}
  if ((safe_add( _501,_498 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6727;
      bool _6728 = (safe_add( _501,_498 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6728)
      {
        _6727 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6727 = safe_add( _501,_498 );
      }
      int _507 = _6727;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_507);
    }
  }
  {}
  if ((safe_add( _501,_498 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6729;
      bool _6730 = (_498 > (int)((natbarvar_ptr)->size(0)));
      if (_6730)
      {
        _6729 = _498;
      }
      else
      {
        _6729 = (int)((natbarvar_ptr)->size(0));
      }
      int _508 = _6729;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_508 ),(int)1 ));
    }
  }
  {}
  int _6731 = (int)0;
  int _6732 = _498;
  for (int _509 = _6731; _509 < _6732; ++_509)
  {
    {
      ((*natbarvar_dim)(safe_add( _501,_509 ))) = _499;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _498;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_498 );
  int _510 = task_append_barvar(_499,_498);
  int _511 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _512 = ((*natbarvar_ptr)(_501));
    int _6733 = (int)0;
    int _6734 = _499;
    for (int _513 = _6733; _513 < _6734; ++_513)
    {
      {
        int _6735 = _513;
        int _6736 = _499;
        for (int _514 = _6735; _514 < _6736; ++_514)
        {
          {
            int _6737 = (int)0;
            int _6738 = _498;
            for (int _515 = _6737; _515 < _6738; ++_515)
            {
              {
                ((*natbarvar_idx)(safe_add( _512,safe_mul( _515,_502 ) ))) = safe_add( _511,_515 );
                ((*natbarvar_i)(safe_add( _512,safe_mul( _515,_502 ) ))) = _514;
                ((*natbarvar_j)(safe_add( _512,safe_mul( _515,_502 ) ))) = _513;
              }
            }
            ++ _512;
          }
        }
      }
    }
    int _6739 = (int)0;
    int _6740 = _498;
    for (int _516 = _6739; _516 < _6740; ++_516)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _511,_516 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _511,_516 ))),_502 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _498,_502 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _517){
  int _518 = natvarmap->alloc(_517);
  int _519 = safe_add( natvarmap->maxidx(_518),(int)1 );
  int _520 = natvarmap->capacity();
  int _521 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _520))
  {
    {
      int _522 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_520);
      int _6741 = _522;
      int _6742 = _520;
      for (int _523 = _6741; _523 < _6742; ++_523)
      {
        {
          ((*natvarmap_idx)(_523)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_520);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _521))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_521);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _524 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_521)));
      int _6743 = (int)0;
      int _6744 = (int)((vars)->size(0));
      for (int _525 = _6743; _525 < _6744; ++_525)
      {
        {
          ((*_524)(_525)) = ((*vars)(_525));
        }
      }
      int _6745 = (int)((vars)->size(0));
      int _6746 = (int)((_524)->size(0));
      for (int _526 = _6745; _526 < _6746; ++_526)
      {
        {
          ((*_524)(_526)) = nullptr;
        }
      }
      vars = _524;
    }
  }
  {}
  if ((task_numvar() < _519))
  {
    {
      task_append_var((_519 - task_numvar()));
    }
  }
  {}
  return _518;
}
int mosek::fusion::p_Model::natconmap_alloc(int _527){
  int _528 = natconmap->alloc(_527);
  int _529 = safe_add( natconmap->maxidx(_528),(int)1 );
  int _530 = natconmap->capacity();
  int _531 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _530))
  {
    {
      int _532 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_530);
      int _6747 = _532;
      int _6748 = _530;
      for (int _533 = _6747; _533 < _6748; ++_533)
      {
        {
          ((*natconmap_idx)(_533)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_530);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_530);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_530);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_530);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_530);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _531))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_531);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _534 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_531)));
      int _6749 = (int)0;
      int _6750 = (int)((cons)->size(0));
      for (int _535 = _6749; _535 < _6750; ++_535)
      {
        {
          ((*_534)(_535)) = ((*cons)(_535));
        }
      }
      int _6751 = (int)((cons)->size(0));
      int _6752 = _531;
      for (int _536 = _6751; _536 < _6752; ++_536)
      {
        {
          ((*_534)(_536)) = nullptr;
        }
      }
      cons = _534;
    }
  }
  {}
  if ((_529 > task_numcon()))
  {
    {
      task_append_con((_529 - task_numcon()));
    }
  }
  {}
  return _528;
}
int mosek::fusion::p_Model::natconemap_alloc(int _537){
  int _538 = natconemap->alloc(_537);
  int _539 = safe_add( natconemap->maxidx(_538),(int)1 );
  if ((_539 > task_numcone()))
  {
    {
      task_append_zerocones((_539 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _538;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540){
  _checked_ptr_1<long long> _ptr__540(_540 ? _540->raw() : nullptr, _540 ? _540->size(0) : 0);
  int _541 = (int)0;
  int _6753 = (int)0;
  int _6754 = (int)((_540)->size(0));
  for (int _542 = _6753; _542 < _6754; ++_542)
  {
    {
      if ((_ptr__540[_542] > (int)0))
      {
        {
          ++ _541;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _543 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_541)));
  _checked_ptr_1<int> _ptr__543(_543 ? _543->raw() : nullptr,_543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6755 = (int)0;
  int _6756 = (int)((_540)->size(0));
  for (int _545 = _6755; _545 < _6756; ++_545)
  {
    {
      if ((_ptr__540[_545] > (int)0))
      {
        {
          _ptr__543[_544] = (int)(_ptr__540[_545] - (int)1);
          ++ _544;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_543);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546){
  _checked_ptr_1<long long> _ptr__546(_546 ? _546->raw() : nullptr, _546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6757 = (int)0;
  int _6758 = (int)((_546)->size(0));
  for (int _548 = _6757; _548 < _6758; ++_548)
  {
    {
      if ((_ptr__546[_548] > (int)0))
      {
        {
          ++ _547;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_547)));
  _checked_ptr_1<int> _ptr__549(_549 ? _549->raw() : nullptr,_549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6759 = (int)0;
  int _6760 = (int)((_546)->size(0));
  for (int _551 = _6759; _551 < _6760; ++_551)
  {
    {
      if ((_ptr__546[_551] > (int)0))
      {
        {
          _ptr__549[_550] = (int)(_ptr__546[_551] - (int)1);
          ++ _550;
        }
      }
      {}
    }
  }
  task_var_putintlist(_549);
}
void mosek::fusion::Model::putlicensewait  ( bool _552) { mosek::fusion::p_Model::putlicensewait(_552); }void mosek::fusion::p_Model::putlicensewait(bool _552){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_552);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _553) { mosek::fusion::p_Model::putlicensepath(_553); }void mosek::fusion::p_Model::putlicensepath(const std::string & _553){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_553);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _554) { mosek::fusion::p_Model::putlicensecode(_554); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554){
  _checked_ptr_1<int> _ptr__554(_554 ? _554->raw() : nullptr, _554 ? _554->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_554);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6761 = (int)0;
  int _6762 = (int)((vars)->size(0));
  for (int _555 = _6761; _555 < _6762; ++_555)
  {
    {
      ((*vars)(_555)) = nullptr;
    }
  }
  int _6763 = (int)0;
  int _6764 = (int)((cons)->size(0));
  for (int _556 = _6763; _556 < _6764; ++_556)
  {
    {
      ((*cons)(_556)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558){
  if (((_557 < (int)0) || ((_557 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_557)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_557))))->elementName((long long)(((*natvarmap_idx)(_557))),_558);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_559,_560,_561,_562); }void mosek::fusion::p_Model::getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562){
  _checked_ptr_1<int> _ptr__560(_560 ? _560->raw() : nullptr, _560 ? _560->size(0) : 0);
  _checked_ptr_1<double> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _563 = (int)((_560)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6765;
  bool _6766 = _559;
  if (_6766)
  {
    _6765 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6765 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _564 = _6765;
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6767;
  bool _6768 = _559;
  if (_6768)
  {
    _6767 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6767 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _565 = _6767;
  _checked_ptr_1<double> _ptr__565(_565 ? _565->raw() : nullptr,_565 ? _565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6769;
  bool _6770 = _559;
  if (_6770)
  {
    _6769 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6769 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _566 = _6769;
  _checked_ptr_1<double> _ptr__566(_566 ? _566->raw() : nullptr,_566 ? _566->size(0) : 0);
  int _6771 = (int)0;
  int _6772 = _563;
  for (int _567 = _6771; _567 < _6772; ++_567)
  {
    {
      long long _568 = ((*natconmap_slackidx)(_ptr__560[_567]));
      if ((_568 < (int)0))
      {
        {
          long long _569 = (-safe_add( _568,(int)1 ));
          _ptr__561[safe_add( _562,_567 )] = _ptr__565[_569];
        }
      }
      else if((_568 > (int)0))
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__564[(_568 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__566[_ptr__560[_567]];
        }
      }
    }
  }
  if (_559)
  {
    {
      int _6773 = (int)0;
      int _6774 = _563;
      for (int _570 = _6773; _570 < _6774; ++_570)
      {
        {
          _ptr__561[safe_add( _562,_570 )] += ((*natconmap_efix)(_ptr__560[_570]));
        }
      }
    }
  }
  {}
}
void mosek::fusion::Model :: getVariableDuals(bool _571,std::shared_ptr< monty::ndarray< long long,1 > > _572,std::shared_ptr< monty::ndarray< double,1 > > _573,int _574) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_571,_572,_573,_574); }void mosek::fusion::p_Model::getVariableDuals(bool _571,std::shared_ptr< monty::ndarray< long long,1 > > _572,std::shared_ptr< monty::ndarray< double,1 > > _573,int _574){
  _checked_ptr_1<long long> _ptr__572(_572 ? _572->raw() : nullptr, _572 ? _572->size(0) : 0);
  _checked_ptr_1<double> _ptr__573(_573 ? _573->raw() : nullptr, _573 ? _573->size(0) : 0);
  int _575 = (int)((_572)->size(0));
  if (_571)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _576 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__576(_576 ? _576->raw() : nullptr,_576 ? _576->size(0) : 0);
      int _6775 = (int)0;
      int _6776 = _575;
      for (int _577 = _6775; _577 < _6776; ++_577)
      {
        {
          if ((_ptr__572[_577] > (int)0))
          {
            {
              _ptr__573[safe_add( _574,_577 )] = _ptr__576[(_ptr__572[_577] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__573[safe_add( _574,_577 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _578 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__578(_578 ? _578->raw() : nullptr,_578 ? _578->size(0) : 0);
      int _6777 = (int)0;
      int _6778 = _575;
      for (int _579 = _6777; _579 < _6778; ++_579)
      {
        {
          if ((_ptr__572[_579] > (int)0))
          {
            {
              _ptr__573[safe_add( _574,_579 )] = (-_ptr__578[(_ptr__572[_579] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__573[safe_add( _574,_579 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _580,std::shared_ptr< monty::ndarray< long long,1 > > _581,std::shared_ptr< monty::ndarray< double,1 > > _582,int _583) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_580,_581,_582,_583); }void mosek::fusion::p_Model::getVariableValues(bool _580,std::shared_ptr< monty::ndarray< long long,1 > > _581,std::shared_ptr< monty::ndarray< double,1 > > _582,int _583){
  _checked_ptr_1<long long> _ptr__581(_581 ? _581->raw() : nullptr, _581 ? _581->size(0) : 0);
  _checked_ptr_1<double> _ptr__582(_582 ? _582->raw() : nullptr, _582 ? _582->size(0) : 0);
  int _584 = (int)((_581)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6779;
  bool _6780 = _580;
  if (_6780)
  {
    _6779 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6779 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _585 = _6779;
  _checked_ptr_1<double> _ptr__585(_585 ? _585->raw() : nullptr,_585 ? _585->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6781;
  bool _6782 = (natbarvar_numbarvarelm > (int)0);
  if (_6782)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6783;
    bool _6784 = _580;
    if (_6784)
    {
      _6783 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6783 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6781 = _6783;
  }
  else
  {
    _6781 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _586 = _6781;
  _checked_ptr_1<double> _ptr__586(_586 ? _586->raw() : nullptr,_586 ? _586->size(0) : 0);
  int _6785 = (int)0;
  int _6786 = _584;
  for (int _587 = _6785; _587 < _6786; ++_587)
  {
    {
      if ((_ptr__581[_587] > (int)0))
      {
        {
          _ptr__582[safe_add( _583,_587 )] = _ptr__585[(_ptr__581[_587] - (int)1)];
        }
      }
      else if((_ptr__581[_587] < (int)0))
      {
        {
          long long _588 = (-safe_add( _ptr__581[_587],(int)1 ));
          _ptr__582[safe_add( _583,_587 )] = _ptr__586[_588];
        }
      }
      else
      {
        {
          _ptr__582[safe_add( _583,_587 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _589,std::shared_ptr< monty::ndarray< long long,1 > > _590,std::shared_ptr< monty::ndarray< double,1 > > _591) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_589,_590,_591); }void mosek::fusion::p_Model::setVariableValues(bool _589,std::shared_ptr< monty::ndarray< long long,1 > > _590,std::shared_ptr< monty::ndarray< double,1 > > _591){
  _checked_ptr_1<long long> _ptr__590(_590 ? _590->raw() : nullptr, _590 ? _590->size(0) : 0);
  _checked_ptr_1<double> _ptr__591(_591 ? _591->raw() : nullptr, _591 ? _591->size(0) : 0);
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6787 = (int)0;
  int _6788 = (int)((vars)->size(0));
  for (int _592 = _6787; _592 < _6788; ++_592)
  {
    {
      if ((NULL != ((*vars)(_592)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_592)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6789 = (int)0;
  int _6790 = (int)((barvars)->size(0));
  for (int _593 = _6789; _593 < _6790; ++_593)
  {
    {
      if ((NULL != ((*barvars)(_593)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_593)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6791 = (int)0;
  int _6792 = (int)((cons)->size(0));
  for (int _594 = _6791; _594 < _6792; ++_594)
  {
    {
      if ((NULL != ((*cons)(_594)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_594)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _595) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_595); }void mosek::fusion::p_Model::writeTask(const std::string & _595){
  _pubthis->flushNames();
  task_write(_595);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _596) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_596); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _596){
  return task_get_liinf(_596);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _597) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_597); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _597){
  return task_get_iinf(_597);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _598) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_598); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _598){
  return task_get_dinf(_598);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _599) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_599); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _599){
  task_setCallbackHandler(_599);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _600) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_600); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _600){
  task_setDataCallbackHandler(_600);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _601) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_601); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _601){
  task_setLogHandler(_601);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _602,double _603) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_602,_603); }void mosek::fusion::p_Model::setSolverParam(const std::string & _602,double _603){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_602,_603);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _604,int _605) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_604,_605); }void mosek::fusion::p_Model::setSolverParam(const std::string & _604,int _605){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_604,_605);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _606,const std::string & _607) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_606,_607); }void mosek::fusion::p_Model::setSolverParam(const std::string & _606,const std::string & _607){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_606,_607);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
  task_solve();
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _608){
  if ((NULL != initsol_xx.get()))
  {
    {
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _610 = __mosek_2fusion_2Model__get_sol_cache(_608,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_610)->xx.get()))
          {
            {
              int _6793 = (int)0;
              int _6794 = (int)((initsol_xx)->size(0));
              for (int _611 = _6793; _611 < _6794; ++_611)
              {
                {
                  if ((!((*initsol_xx_flag)(_611))))
                  {
                    {
                      ((*initsol_xx)(_611)) = ((*mosek::fusion::p_SolutionStruct::_get_impl(_610)->xx)(_611));
                    }
                  }
                  {}
                }
              }
            }
          }
          else
          {
            {
              int _6795 = (int)0;
              int _6796 = (int)((initsol_xx)->size(0));
              for (int _612 = _6795; _612 < _6796; ++_612)
              {
                {
                  if ((!((*initsol_xx_flag)(_612))))
                  {
                    {
                      ((*initsol_xx)(_612)) = 0.0;
                    }
                  }
                  {}
                }
              }
            }
          }
        }
      }
      catch (mosek::fusion::SolutionError _609)
      {
        {
          int _6797 = (int)0;
          int _6798 = (int)((initsol_xx)->size(0));
          for (int _613 = _6797; _613 < _6798; ++_613)
          {
            {
              if ((!((*initsol_xx_flag)(_613))))
              {
                {
                  ((*initsol_xx)(_613)) = 0.0;
                }
              }
              {}
            }
          }
        }
      }
      task_putxx_slice(_608,(int)0,(int)((initsol_xx)->size(0)),initsol_xx);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _614,bool _615,bool _616){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _617 = nullptr;
  mosek::fusion::SolutionType _618 = _614;
  if ((_618 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _618 = solutionptr;
    }
  }
  {}
  if ((_618 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _617 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _617 = sol_bas;
        }
      }
      else
      {
        {
          _617 = sol_itr;
        }
      }
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _617 = sol_itr;
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _617 = sol_bas;
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _617 = sol_itg;
    }
  }
  {}
  if ((NULL == _617.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_616 || ((_615 && _617->isPrimalAcceptable(acceptable_sol)) || ((!_615) && _617->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _617;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _619 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _620 = mosek::fusion::p_SolutionStruct::_get_impl(_617)->pstatus;
          if ((!_615))
          {
            {
              _620 = mosek::fusion::p_SolutionStruct::_get_impl(_617)->dstatus;
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_620 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected"));
          throw ::mosek::fusion::SolutionError(_619->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _621,bool _622){
  return __mosek_2fusion_2Model__get_sol_cache(_621,_622,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _623,std::shared_ptr< monty::ndarray< double,1 > > _624){
  _checked_ptr_1<int> _ptr__623(_623 ? _623->raw() : nullptr, _623 ? _623->size(0) : 0);
  _checked_ptr_1<double> _ptr__624(_624 ? _624->raw() : nullptr, _624 ? _624->size(0) : 0);
  ensure_initsol_xx();
  int _6799 = (int)0;
  int _6800 = (int)((_623)->size(0));
  for (int _625 = _6799; _625 < _6800; ++_625)
  {
    {
      ((*initsol_xx)(_ptr__623[_625])) = _ptr__624[_625];
      ((*initsol_xx_flag)(_ptr__623[_625])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _626 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_626)));
      std::vector<bool> _6801;
      for (int _627 = (int)0, _6802 = _626; _627 < _6802 ; ++_627)
      {
        _6801.push_back(false);
      }
      auto _6803 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6801.size()),_6801.begin(),_6801.end()));
      initsol_xx_flag = _6803;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _626))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _628 = initsol_xx;
      _checked_ptr_1<double> _ptr__628(_628 ? _628->raw() : nullptr,_628 ? _628->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _629 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_626)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_626)));
      ::mosek::fusion::Utils::Tools::arraycopy(_628,(int)0,initsol_xx,(int)0,_626);
      int _6804 = (int)0;
      int _6805 = _626;
      for (int _630 = _6804; _630 < _6805; ++_630)
      {
        {
          ((*initsol_xx_flag)(_630)) = ((*_629)(_630));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _631){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_631,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _632){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_632,false))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _633){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_633,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _634){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_634,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _635){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_635,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _636){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_636,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _637){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_637,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _638){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_638,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _639){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_639,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _640){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_640,true))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _641){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_641,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _642) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_642); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _642){
  solutionptr = _642;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _643) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_643); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _643){
  acceptable_sol = _643;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _644) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_644); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _644){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _645 = nullptr;
  if ((_644 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _645 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _645 = sol_bas;
        }
      }
      else
      {
        {
          _645 = sol_itr;
        }
      }
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _645 = sol_itr;
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _645 = sol_bas;
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _645 = sol_itg;
    }
  }
  {}
  if ((NULL == _645.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_645)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _646) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_646); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _646){
  return getSolutionStatus(_646,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _647) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_647); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _647){
  return getSolutionStatus(_647,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _648,bool _649){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _651 = __mosek_2fusion_2Model__get_sol_cache(_648,_649,true);
      if (_649)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_651)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_651)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _650)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _652,monty::rc_ptr< ::mosek::fusion::Expression > _653){
  _checked_ptr_1<int> _ptr__652(_652 ? _652->raw() : nullptr, _652 ? _652->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_653)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _654 = ws->popi32();
  int _655 = ws->popi32(_654);
  int _656 = ws->popi32();
  int _657 = ws->popi32();
  bool _658 = ((int)0 != ws->popi32());
  int _659 = ws->popi32(safe_add( _656,(int)1 ));
  int _6806;
  bool _6807 = _658;
  if (_6807)
  {
    _6806 = ws->popi64(_656);
  }
  else
  {
    _6806 = (int)0;
  }
  int _660 = _6806;
  int _661 = ws->popi64(_657);
  int _662 = ws->popf64(_656);
  int _663 = ws->popf64(_657);
  std::shared_ptr< monty::ndarray< int,1 > > _664 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__664(_664 ? _664->raw() : nullptr,_664 ? _664->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _665 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__665(_665 ? _665->raw() : nullptr,_665 ? _665->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _666 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__666(_666 ? _666->raw() : nullptr,_666 ? _666->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _667 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _656,(int)1 ))));
  _checked_ptr_1<long long> _ptr__667(_667 ? _667->raw() : nullptr,_667 ? _667->size(0) : 0);
  int _6808 = (int)0;
  int _6809 = _656;
  for (int _668 = _6808; _668 < _6809; ++_668)
  {
    {
      int _6810 = _ptr__664[safe_add( _659,_668 )];
      int _6811 = _ptr__664[safe_add( safe_add( _659,_668 ),(int)1 )];
      for (int _669 = _6810; _669 < _6811; ++_669)
      {
        {
          if ((_ptr__665[safe_add( _661,_669 )] > (int)0))
          {
            {
              ++ _ptr__667[safe_add( _668,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  long long _670 = _ptr__667[_656];
  std::shared_ptr< monty::ndarray< int,1 > > _671 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_670)));
  _checked_ptr_1<int> _ptr__671(_671 ? _671->raw() : nullptr,_671 ? _671->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _672 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_670)));
  _checked_ptr_1<double> _ptr__672(_672 ? _672->raw() : nullptr,_672 ? _672->size(0) : 0);
  int _6812 = (int)0;
  int _6813 = _656;
  for (int _673 = _6812; _673 < _6813; ++_673)
  {
    {
      _ptr__667[safe_add( _673,(int)1 )] += _ptr__667[_673];
    }
  }
  int _674 = (int)0;
  int _6814 = (int)0;
  int _6815 = _656;
  for (int _675 = _6814; _675 < _6815; ++_675)
  {
    {
      int _6816 = _ptr__664[safe_add( _659,_675 )];
      int _6817 = _ptr__664[safe_add( safe_add( _659,_675 ),(int)1 )];
      for (int _676 = _6816; _676 < _6817; ++_676)
      {
        {
          if ((_ptr__665[safe_add( _661,_676 )] > (int)0))
          {
            {
              _ptr__671[_674] = (int)_ptr__665[safe_add( _661,_676 )];
              _ptr__672[_674] = _ptr__666[safe_add( _663,_676 )];
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_652,_667,_671,_672);
  int _677 = (int)0;
  int _6818 = (int)0;
  int _6819 = _656;
  for (int _678 = _6818; _678 < _6819; ++_678)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__652[_678])) > (int)0))
      {
        {
          ++ _677;
        }
      }
      {}
    }
  }
  if ((_677 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _679 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
      _checked_ptr_1<int> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _680 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
      _checked_ptr_1<int> _ptr__680(_680 ? _680->raw() : nullptr,_680 ? _680->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _681 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_677)));
      _checked_ptr_1<double> _ptr__681(_681 ? _681->raw() : nullptr,_681 ? _681->size(0) : 0);
      int _682 = (int)0;
      int _6820 = (int)0;
      int _6821 = _656;
      for (int _683 = _6820; _683 < _6821; ++_683)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__652[_683])) > (int)0))
          {
            {
              _ptr__679[_682] = _ptr__652[_683];
              _ptr__680[_682] = (int)(((*natconmap_slackidx)(_ptr__652[_683])) - (int)1);
              _ptr__681[_682] = (-1.0);
              ++ _682;
            }
          }
          {}
        }
      }
      task_putaijlist(_679,_680,_681,(long long)(_677));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _684,monty::rc_ptr< ::mosek::fusion::Expression > _685,std::shared_ptr< monty::ndarray< int,1 > > _686){
  _checked_ptr_1<int> _ptr__684(_684 ? _684->raw() : nullptr, _684 ? _684->size(0) : 0);
  _checked_ptr_1<int> _ptr__686(_686 ? _686->raw() : nullptr, _686 ? _686->size(0) : 0);
  int _687 = safe_mul( (int)((_684)->size(0)),(int)((_686)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _688 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_687)));
  _checked_ptr_1<double> _ptr__688(_688 ? _688->raw() : nullptr,_688 ? _688->size(0) : 0);
  std::vector<int> _6822;
  for (int _690 = (int)0, _6823 = (int)((_684)->size(0)); _690 < _6823 ; ++_690)
  {
    for (int _691 = (int)0, _6824 = (int)((_686)->size(0)); _691 < _6824 ; ++_691)
    {
      _6822.push_back(_ptr__684[_690]);
    }
  }
  auto _6825 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6822.size()),_6822.begin(),_6822.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _689 = _6825;
  _checked_ptr_1<int> _ptr__689(_689 ? _689->raw() : nullptr,_689 ? _689->size(0) : 0);
  std::vector<int> _6826;
  for (int _693 = (int)0, _6827 = (int)((_684)->size(0)); _693 < _6827 ; ++_693)
  {
    for (int _694 = (int)0, _6828 = (int)((_686)->size(0)); _694 < _6828 ; ++_694)
    {
      _6826.push_back(_ptr__686[_694]);
    }
  }
  auto _6829 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6826.size()),_6826.begin(),_6826.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _692 = _6829;
  _checked_ptr_1<int> _ptr__692(_692 ? _692->raw() : nullptr,_692 ? _692->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_685)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _695 = ws->popi32();
  int _696 = ws->popi32(_695);
  int _697 = ws->popi32();
  int _698 = ws->popi32();
  bool _699 = ((int)0 != ws->popi32());
  int _700 = ws->popi32(safe_add( _697,(int)1 ));
  int _6830;
  bool _6831 = _699;
  if (_6831)
  {
    _6830 = ws->popi64(_697);
  }
  else
  {
    _6830 = (int)0;
  }
  int _701 = _6830;
  int _702 = ws->popi64(_698);
  int _703 = ws->popf64(_697);
  int _704 = ws->popf64(_698);
  std::shared_ptr< monty::ndarray< int,1 > > _705 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__705(_705 ? _705->raw() : nullptr,_705 ? _705->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _706 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__706(_706 ? _706->raw() : nullptr,_706 ? _706->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _707 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__707(_707 ? _707->raw() : nullptr,_707 ? _707->size(0) : 0);
  int _708 = (int)0;
  int _6832 = (int)0;
  int _6833 = _697;
  for (int _709 = _6832; _709 < _6833; ++_709)
  {
    {
      int _710 = _ptr__705[safe_add( _700,_709 )];
      int _711 = _ptr__705[safe_add( safe_add( _700,_709 ),(int)1 )];
      int _712 = _710;
      int _713 = (int)0;
      while ( ((_713 < (int)((_686)->size(0))) && (_712 < _711)) )
      {
        {
          if ((_ptr__686[_713] < (_ptr__706[safe_add( _702,_712 )] - (int)1)))
          {
            {
              ++ _713;
            }
          }
          else if((_ptr__686[_713] > (_ptr__706[safe_add( _702,_712 )] - (int)1)))
          {
            {
              ++ _712;
            }
          }
          else
          {
            {
              _ptr__688[safe_add( _708,_713 )] = _ptr__707[safe_add( _704,_712 )];
              ++ _713;
              ++ _712;
            }
          }
        }
      }
      _708 += (int)((_686)->size(0));
    }
  }
  task_putaijlist(_689,_692,_688,(long long)(_687));
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _714,monty::rc_ptr< ::mosek::fusion::Variable > _715) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_714,_715); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _714,monty::rc_ptr< ::mosek::fusion::Variable > _715){
  if ((_714->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _716 = _715->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _717 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_716)));
  _checked_ptr_1<long long> _ptr__717(_717 ? _717->raw() : nullptr,_717 ? _717->size(0) : 0);
  if ((_716 < _715->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _718 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_716)));
      _checked_ptr_1<long long> _ptr__718(_718 ? _718->raw() : nullptr,_718 ? _718->size(0) : 0);
      _715->inst((int)0,_718,(int)0,_717);
    }
  }
  else
  {
    {
      _715->inst((int)0,_717);
    }
  }
  int _6834 = (int)0;
  int _6835 = _716;
  for (int _719 = _6834; _719 < _6835; ++_719)
  {
    {
      if ((_ptr__717[_719] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _720 = true;
  int _6836 = (int)0;
  int _6837 = (_716 - (int)1);
  for (int _721 = _6836; _721 < _6837; ++_721)
  {
    {
      _720 = (_720 && (_ptr__717[_721] < _ptr__717[(_721 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _722 = nullptr;
  _checked_ptr_1<int> _ptr__722(_722 ? _722->raw() : nullptr,_722 ? _722->size(0) : 0);
  if (_720)
  {
    {
      std::vector<int> _6838;
      for (int _723 = (int)0, _6839 = _716; _723 < _6839 ; ++_723)
      {
        _6838.push_back((int)(_ptr__717[_723] - (int)1));
      }
      auto _6840 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6838.size()),_6838.begin(),_6838.end()));
      _722 = _6840;
      _ptr__722.update(_722 ? _722->raw() : nullptr, _722 ? _722->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6841;
      for (int _725 = (-(int)1), _6842 = _716; _725 < _6842 ; ++_725)
      {
        _6841.push_back(_725);
      }
      auto _6843 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6841.size()),_6841.begin(),_6841.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _724 = _6843;
      _checked_ptr_1<long long> _ptr__724(_724 ? _724->raw() : nullptr,_724 ? _724->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_724,_717,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_716));
      std::vector<int> _6844;
      for (int _726 = (int)0, _6845 = _716; _726 < _6845 ; ++_726)
      {
        _6844.push_back((int)(_ptr__717[_ptr__724[_726]] - (int)1));
      }
      auto _6846 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6844.size()),_6844.begin(),_6844.end()));
      _722 = _6846;
      _ptr__722.update(_722 ? _722->raw() : nullptr, _722 ? _722->size(0) : 0);
    }
  }
  int _727 = (int)((_722)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _728 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_727)));
  _checked_ptr_1<double> _ptr__728(_728 ? _728->raw() : nullptr,_728 ? _728->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _729 = _722;
  _checked_ptr_1<int> _ptr__729(_729 ? _729->raw() : nullptr,_729 ? _729->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_714)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _730 = ws->popi32();
  int _731 = ws->popi32(_730);
  int _732 = ws->popi32();
  int _733 = ws->popi32();
  bool _734 = ((int)0 != ws->popi32());
  int _735 = ws->popi32(safe_add( _732,(int)1 ));
  int _6847;
  bool _6848 = _734;
  if (_6848)
  {
    _6847 = ws->popi64(_732);
  }
  else
  {
    _6847 = (int)0;
  }
  int _736 = _6847;
  int _737 = ws->popi64(_733);
  int _738 = ws->popf64(_732);
  int _739 = ws->popf64(_733);
  std::shared_ptr< monty::ndarray< int,1 > > _740 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _741 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__741(_741 ? _741->raw() : nullptr,_741 ? _741->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _742 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__742(_742 ? _742->raw() : nullptr,_742 ? _742->size(0) : 0);
  int _743 = (int)0;
  int _6849 = (int)0;
  int _6850 = _732;
  for (int _744 = _6849; _744 < _6850; ++_744)
  {
    {
      int _745 = _ptr__740[safe_add( _735,_744 )];
      int _746 = _ptr__740[safe_add( safe_add( _735,_744 ),(int)1 )];
      int _747 = _745;
      int _748 = (int)0;
      while ( ((_748 < (int)((_722)->size(0))) && (_747 < _746)) )
      {
        {
          if ((_ptr__722[_748] < (_ptr__741[safe_add( _737,_747 )] - (int)1)))
          {
            {
              ++ _748;
            }
          }
          else if((_ptr__722[_748] > (_ptr__741[safe_add( _737,_747 )] - (int)1)))
          {
            {
              ++ _747;
            }
          }
          else
          {
            {
              _ptr__728[safe_add( _743,_748 )] = _ptr__742[safe_add( _739,_747 )];
              ++ _748;
              ++ _747;
            }
          }
        }
      }
      _743 += (int)((_722)->size(0));
    }
  }
  task_putclist(_729,_728);
}
void mosek::fusion::p_Model::objective_(const std::string & _749,mosek::fusion::ObjectiveSense _750,monty::rc_ptr< ::mosek::fusion::Expression > _751){
  task_putobjectivename(_749);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _752 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _753 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_751)).as<::mosek::fusion::Expression>())->eval(_752,_753,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _754 = mosek::fusion::p_WorkStack::_get_impl(_752)->i32;
  _checked_ptr_1<int> _ptr__754(_754 ? _754->raw() : nullptr,_754 ? _754->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _755 = mosek::fusion::p_WorkStack::_get_impl(_752)->i64;
  _checked_ptr_1<long long> _ptr__755(_755 ? _755->raw() : nullptr,_755 ? _755->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _756 = mosek::fusion::p_WorkStack::_get_impl(_752)->f64;
  _checked_ptr_1<double> _ptr__756(_756 ? _756->raw() : nullptr,_756 ? _756->size(0) : 0);
  int _757 = _752->popi32();
  int _758 = (int)1;
  int _6851 = (int)0;
  int _6852 = _757;
  for (int _759 = _6851; _759 < _6852; ++_759)
  {
    {
      _757 *= _752->popi32();
    }
  }
  if ((_758 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _760 = _752->popi32();
  if ((_760 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _761 = _752->popi32();
  bool _762 = (_752->popi32() != (int)0);
  int _763 = _752->popi32(safe_add( _760,(int)1 ));
  int _764 = _752->popi64(_761);
  int _765 = _752->popf64(_760);
  int _766 = _752->popf64(_761);
  int _767 = (int)0;
  int _768 = (int)0;
  int _6853 = (int)0;
  int _6854 = _761;
  for (int _769 = _6853; _769 < _6854; ++_769)
  {
    {
      if ((_ptr__755[safe_add( _764,_769 )] < (int)0))
      {
        {
          ++ _768;
        }
      }
      else if((_ptr__755[safe_add( _764,_769 )] > (int)0))
      {
        {
          ++ _767;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _770 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_767)));
  _checked_ptr_1<int> _ptr__770(_770 ? _770->raw() : nullptr,_770 ? _770->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _771 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_767)));
  _checked_ptr_1<double> _ptr__771(_771 ? _771->raw() : nullptr,_771 ? _771->size(0) : 0);
  {
    int _772 = (int)0;
    int _6855 = (int)0;
    int _6856 = _761;
    for (int _773 = _6855; _773 < _6856; ++_773)
    {
      {
        if ((_ptr__755[safe_add( _764,_773 )] > (int)0))
        {
          {
            _ptr__770[_772] = (int)(_ptr__755[safe_add( _764,_773 )] - (int)1);
            _ptr__771[_772] = _ptr__756[safe_add( _766,_773 )];
            ++ _772;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_750 == ::mosek::fusion::ObjectiveSense::Maximize),_770,_771,_ptr__756[_765]);
  if ((_768 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _774 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__774(_774 ? _774->raw() : nullptr,_774 ? _774->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _775 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__775(_775 ? _775->raw() : nullptr,_775 ? _775->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _776 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__776(_776 ? _776->raw() : nullptr,_776 ? _776->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _777 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_768)));
      _checked_ptr_1<double> _ptr__777(_777 ? _777->raw() : nullptr,_777 ? _777->size(0) : 0);
      int _6857 = (int)0;
      int _6858 = _768;
      for (int _778 = _6857; _778 < _6858; ++_778)
      {
        {
          long long _779 = (-safe_add( _ptr__755[safe_add( _764,_778 )],(int)1 ));
          _ptr__774[_778] = ((*natbarvar_idx)(_779));
          _ptr__775[_778] = ((*natbarvar_i)(_779));
          _ptr__776[_778] = ((*natbarvar_j)(_779));
          double _6859;
          bool _6860 = (_ptr__775[_778] == _ptr__776[_778]);
          if (_6860)
          {
            _6859 = _ptr__756[safe_add( _766,_778 )];
          }
          else
          {
            _6859 = (0.5 * _ptr__756[safe_add( _766,_778 )]);
          }
          _ptr__777[_778] = _6859;
        }
      }
      task_putbarc(_774,_775,_776,_777);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _780) { mosek::fusion::p_Model::_get_impl(this)->objective(_780); }void mosek::fusion::p_Model::objective(double _780){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_780));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _781,double _782) { mosek::fusion::p_Model::_get_impl(this)->objective(_781,_782); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _781,double _782){
  objective_(std::string (""),_781,::mosek::fusion::p_Expr::constTerm(_782));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _783,monty::rc_ptr< ::mosek::fusion::Expression > _784) { mosek::fusion::p_Model::_get_impl(this)->objective(_783,_784); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _783,monty::rc_ptr< ::mosek::fusion::Expression > _784){
  objective_(std::string (""),_783,_784);
}
void mosek::fusion::Model :: objective(const std::string & _785,double _786) { mosek::fusion::p_Model::_get_impl(this)->objective(_785,_786); }void mosek::fusion::p_Model::objective(const std::string & _785,double _786){
  objective_(_785,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_786));
}
void mosek::fusion::Model :: objective(const std::string & _787,mosek::fusion::ObjectiveSense _788,double _789) { mosek::fusion::p_Model::_get_impl(this)->objective(_787,_788,_789); }void mosek::fusion::p_Model::objective(const std::string & _787,mosek::fusion::ObjectiveSense _788,double _789){
  objective_(_787,_788,::mosek::fusion::p_Expr::constTerm(_789));
}
void mosek::fusion::Model :: objective(const std::string & _790,mosek::fusion::ObjectiveSense _791,monty::rc_ptr< ::mosek::fusion::Expression > _792) { mosek::fusion::p_Model::_get_impl(this)->objective(_790,_791,_792); }void mosek::fusion::p_Model::objective(const std::string & _790,mosek::fusion::ObjectiveSense _791,monty::rc_ptr< ::mosek::fusion::Expression > _792){
  objective_(_790,_791,_792);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_793,_794); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794) { return __mosek_2fusion_2Model__constraint(_793,_794); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_793,_794);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_795,_796,_797); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797) { return __mosek_2fusion_2Model__constraint(_795,_796,_797); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797){
  return __mosek_2fusion_2Model__constraint_(_795,_796,_797);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_798,_799); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799) { return __mosek_2fusion_2Model__constraint(_798,_799); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_798,_799);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_800,_801,_802); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802) { return __mosek_2fusion_2Model__constraint(_800,_801,_802); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802){
  return __mosek_2fusion_2Model__constraint_(_800,_801,_802);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_803,_804); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804) { return __mosek_2fusion_2Model__constraint(_803,_804); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_803,_804);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_805,_806,_807); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807) { return __mosek_2fusion_2Model__constraint(_805,_806,_807); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807){
  return __mosek_2fusion_2Model__constraint_(_805,_806,_807);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_808,_809); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809) { return __mosek_2fusion_2Model__constraint(_808,_809); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_808,_809);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_810,_811,_812); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812) { return __mosek_2fusion_2Model__constraint(_810,_811,_812); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812){
  return __mosek_2fusion_2Model__constraint_(_810,_811,_812);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_813,_814); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814) { return __mosek_2fusion_2Model__constraint(_813,_814); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_813,_814);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_815,_816,_817); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817) { return __mosek_2fusion_2Model__constraint(_815,_816,_817); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817){
  return __mosek_2fusion_2Model__constraint_(_815,_816,_817);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_818); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818) { return __mosek_2fusion_2Model__variable(_818); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_818)->shape,_818);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_819,_820,_821); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return __mosek_2fusion_2Model__variable(_819,_820,_821); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_819),(int)(_819),(int)(_820)}),_821);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_822,_823); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return __mosek_2fusion_2Model__variable(_822,_823); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_822),(int)(_822)}),_823);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_824,_825); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825) { return __mosek_2fusion_2Model__variable(_824,_825); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825){
  return __mosek_2fusion_2Model__variable_(_824,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_825);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_826,_827,_828,_829); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return __mosek_2fusion_2Model__variable(_826,_827,_828,_829); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829){
  return __mosek_2fusion_2Model__variable_(_826,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_827),(int)(_827),(int)(_828)}),_829);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_830,_831,_832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return __mosek_2fusion_2Model__variable(_830,_831,_832); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832){
  return __mosek_2fusion_2Model__variable_(_830,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_831),(int)(_831)}),_832);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_833,_834,_835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return __mosek_2fusion_2Model__variable(_833,_834,_835); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835){
  _checked_ptr_1<int> _ptr__834(_834 ? _834->raw() : nullptr, _834 ? _834->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_833,_834,_835);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_836); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836) { return __mosek_2fusion_2Model__variable(_836); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_836)->shape,_836)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_837,_838,_839); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839) { return __mosek_2fusion_2Model__variable(_837,_838,_839); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_837),(int)(_837),(int)(_838)}),_839)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_840,_841); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841) { return __mosek_2fusion_2Model__variable(_840,_841); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_840),(int)(_840)}),_841)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_842,_843); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843) { return __mosek_2fusion_2Model__variable(_842,_843); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843){
  return (__mosek_2fusion_2Model__variable_(_842,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_843)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_844,_845,_846,_847); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return __mosek_2fusion_2Model__variable(_844,_845,_846,_847); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847){
  return (__mosek_2fusion_2Model__variable_(_844,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_845),(int)(_845),(int)(_846)}),_847)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_848,_849,_850); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return __mosek_2fusion_2Model__variable(_848,_849,_850); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850){
  return (__mosek_2fusion_2Model__variable_(_848,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_849),(int)(_849)}),_850)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_851,_852,_853); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return __mosek_2fusion_2Model__variable(_851,_852,_853); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853){
  _checked_ptr_1<int> _ptr__852(_852 ? _852->raw() : nullptr, _852 ? _852->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_851,_852,_853)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_854); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854) { return __mosek_2fusion_2Model__variable(_854); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_854);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_855); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855) { return __mosek_2fusion_2Model__variable(_855); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_855);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_856); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856) { return __mosek_2fusion_2Model__variable(_856); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_856);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_857,_858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858) { return __mosek_2fusion_2Model__variable(_857,_858); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858){
  _checked_ptr_1<int> _ptr__857(_857 ? _857->raw() : nullptr, _857 ? _857->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_857,_858);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_859,_860); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860) { return __mosek_2fusion_2Model__variable(_859,_860); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860){
  _checked_ptr_1<int> _ptr__859(_859 ? _859->raw() : nullptr, _859 ? _859->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_859,_860);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_861,_862); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862) { return __mosek_2fusion_2Model__variable(_861,_862); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862){
  _checked_ptr_1<int> _ptr__861(_861 ? _861->raw() : nullptr, _861 ? _861->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_861,_862);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _863) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_863); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _863) { return __mosek_2fusion_2Model__variable(_863); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _863){
  _checked_ptr_1<int> _ptr__863(_863 ? _863->raw() : nullptr, _863 ? _863->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_863,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_864,_865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return __mosek_2fusion_2Model__variable(_864,_865); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_864)}),_865);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_866,_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return __mosek_2fusion_2Model__variable(_866,_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_866)}),_867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868,_869); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869) { return __mosek_2fusion_2Model__variable(_868,_869); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_868)}),_869);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _870) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_870); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _870) { return __mosek_2fusion_2Model__variable(_870); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _870){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_870)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_871,_872); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872) { return __mosek_2fusion_2Model__variable(_871,_872); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872){
  return __mosek_2fusion_2Model__variable_(_871,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_873,_874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874) { return __mosek_2fusion_2Model__variable(_873,_874); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874){
  return __mosek_2fusion_2Model__ranged_variable(_873,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_874);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_875,_876); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876) { return __mosek_2fusion_2Model__variable(_875,_876); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876){
  return __mosek_2fusion_2Model__variable_(_875,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_876);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_877,_878,_879); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879) { return __mosek_2fusion_2Model__variable(_877,_878,_879); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879){
  _checked_ptr_1<int> _ptr__878(_878 ? _878->raw() : nullptr, _878 ? _878->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_877,_878,_879);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_880,_881,_882); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882) { return __mosek_2fusion_2Model__variable(_880,_881,_882); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882){
  _checked_ptr_1<int> _ptr__881(_881 ? _881->raw() : nullptr, _881 ? _881->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_880,_881,_882);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_883,_884,_885); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885) { return __mosek_2fusion_2Model__variable(_883,_884,_885); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885){
  _checked_ptr_1<int> _ptr__884(_884 ? _884->raw() : nullptr, _884 ? _884->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_883,_884,_885);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _886,std::shared_ptr< monty::ndarray< int,1 > > _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_886,_887); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _886,std::shared_ptr< monty::ndarray< int,1 > > _887) { return __mosek_2fusion_2Model__variable(_886,_887); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _886,std::shared_ptr< monty::ndarray< int,1 > > _887){
  _checked_ptr_1<int> _ptr__887(_887 ? _887->raw() : nullptr, _887 ? _887->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_886,_887,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_888,_889,_890); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return __mosek_2fusion_2Model__variable(_888,_889,_890); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890){
  return __mosek_2fusion_2Model__variable_(_888,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_889)}),_890);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_891,_892,_893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return __mosek_2fusion_2Model__variable(_891,_892,_893); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893){
  return __mosek_2fusion_2Model__ranged_variable(_891,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_892)}),_893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_894,_895,_896); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return __mosek_2fusion_2Model__variable(_894,_895,_896); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896){
  return __mosek_2fusion_2Model__variable_(_894,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_895)}),_896);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _897,int _898) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_897,_898); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _897,int _898) { return __mosek_2fusion_2Model__variable(_897,_898); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _897,int _898){
  return __mosek_2fusion_2Model__variable_(_897,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_898)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _899) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_899); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _899) { return __mosek_2fusion_2Model__variable(_899); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _899){
  return __mosek_2fusion_2Model__variable_(_899,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::RangeDomain > _902){
  _checked_ptr_1<int> _ptr__901(_901 ? _901->raw() : nullptr, _901 ? _901->size(0) : 0);
  if ((((int)((_900).size()) > (int)0) && hasVariable(_900)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_900)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6861;
  bool _6862 = (NULL != _901.get());
  if (_6862)
  {
    _6861 = _901;
  }
  else
  {
    _6861 = mosek::fusion::p_RangeDomain::_get_impl(_902)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _903 = _6861;
  _checked_ptr_1<int> _ptr__903(_903 ? _903->raw() : nullptr,_903 ? _903->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_902)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_902)->shape,_903))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _903.get()))
  {
    {
      _903 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__903.update(_903 ? _903->raw() : nullptr, _903 ? _903->size(0) : 0);
    }
  }
  {}
  int _904 = (int)((_903)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _905 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_904)));
  _checked_ptr_1<int> _ptr__905(_905 ? _905->raw() : nullptr,_905 ? _905->size(0) : 0);
  if ((_904 > (int)0))
  {
    {
      _ptr__905[(_904 - (int)1)] = (int)1;
      int _6863 = (int)1;
      int _6864 = _904;
      for (int _906 = _6863; _906 < _6864; ++_906)
      {
        {
          _ptr__905[((_904 - _906) - (int)1)] = safe_mul( _ptr__905[(_904 - _906)],_ptr__903[(_904 - _906)] );
        }
      }
    }
  }
  {}
  int _907 = (int)1;
  int _6865 = (int)0;
  int _6866 = (int)((_903)->size(0));
  for (int _908 = _6865; _908 < _6866; ++_908)
  {
    {
      _907 *= _ptr__903[_908];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _909 = nullptr;
  _checked_ptr_1<long long> _ptr__909(_909 ? _909->raw() : nullptr,_909 ? _909->size(0) : 0);
  if ((NULL != _909.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1)) != _904))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _909 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(0)))));
      _ptr__909.update(_909 ? _909->raw() : nullptr, _909 ? _909->size(0) : 0);
      int _6867 = (int)0;
      int _6868 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(0));
      for (int _910 = _6867; _910 < _6868; ++_910)
      {
        {
          int _6869 = (int)0;
          int _6870 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1));
          for (int _911 = _6869; _911 < _6870; ++_911)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_911)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_911)) >= _ptr__903[_911])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _912 = (int)0;
          int _6871 = (int)0;
          int _6872 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1));
          for (int _913 = _6871; _913 < _6872; ++_913)
          {
            {
              _912 += safe_mul( _ptr__905[_913],((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_913)) );
            }
          }
          _ptr__909[_910] = _912;
        }
      }
    }
  }
  {}
  int _6873;
  bool _6874 = (NULL != _909.get());
  if (_6874)
  {
    _6873 = (int)((_909)->size(0));
  }
  else
  {
    _6873 = _907;
  }
  int _914 = _6873;
  std::shared_ptr< monty::ndarray< double,1 > > _915;
  _checked_ptr_1<double> _ptr__915(_915 ? _915->raw() : nullptr,_915 ? _915->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _916;
  _checked_ptr_1<double> _ptr__916(_916 ? _916->raw() : nullptr,_916 ? _916->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_902)->scalable)
  {
    {
      std::vector<double> _6875;
      for (int _917 = (int)0, _6876 = _914; _917 < _6876 ; ++_917)
      {
        _6875.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_902)->lb)((int)0)));
      }
      auto _6877 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6875.size()),_6875.begin(),_6875.end()));
      _915 = _6877;
      _ptr__915.update(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
      std::vector<double> _6878;
      for (int _918 = (int)0, _6879 = _914; _918 < _6879 ; ++_918)
      {
        _6878.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_902)->ub)((int)0)));
      }
      auto _6880 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6878.size()),_6878.begin(),_6878.end()));
      _916 = _6880;
      _ptr__916.update(_916 ? _916->raw() : nullptr, _916 ? _916->size(0) : 0);
    }
  }
  else
  {
    {
      _915 = mosek::fusion::p_RangeDomain::_get_impl(_902)->lb;
      _ptr__915.update(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
      _916 = mosek::fusion::p_RangeDomain::_get_impl(_902)->ub;
      _ptr__916.update(_916 ? _916->raw() : nullptr, _916 ? _916->size(0) : 0);
    }
  }
  int _919 = natvarmap_alloc(_914);
  std::shared_ptr< monty::ndarray< int,1 > > _920 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_919))));
  _checked_ptr_1<int> _ptr__920(_920 ? _920->raw() : nullptr,_920 ? _920->size(0) : 0);
  natvarmap->get(_919,_920,(int)0);
  int _6881 = (int)0;
  int _6882 = _914;
  for (int _921 = _6881; _921 < _6882; ++_921)
  {
    {
      ((*natvarmap_idx)(_ptr__920[_921])) = _919;
    }
  }
  task_var_putboundlist_ra(_920,_915,_916);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _922 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_900,(long long)(_919),_903,_909,_920);
  if (mosek::fusion::p_RangeDomain::_get_impl(_902)->cardinal_flag)
  {
    {
      task_var_putintlist(_920);
    }
  }
  {}
  ((*vars)(_919)) = (_922).as<::mosek::fusion::ModelVariable>();
  if (((int)((_900).size()) > (int)0))
  {
    {
      var_map->setItem(_900,_919);
    }
  }
  {}
  return (_922).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _923,std::shared_ptr< monty::ndarray< int,1 > > _924,monty::rc_ptr< ::mosek::fusion::ConeDomain > _925){
  _checked_ptr_1<int> _ptr__924(_924 ? _924->raw() : nullptr, _924 ? _924->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6883;
  bool _6884 = (NULL != _924.get());
  if (_6884)
  {
    _6883 = _924;
  }
  else
  {
    _6883 = mosek::fusion::p_ConeDomain::_get_impl(_925)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _926 = _6883;
  _checked_ptr_1<int> _ptr__926(_926 ? _926->raw() : nullptr,_926 ? _926->size(0) : 0);
  if ((((int)((_923).size()) > (int)0) && hasVariable(_923)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_923)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _926.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_925)->shape.get()) && (!::mosek::fusion::p_Set::match(_926,mosek::fusion::p_ConeDomain::_get_impl(_925)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_925->getAxis() >= (int)((_926)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _6885;
  bool _6886 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_925)->shape.get());
  if (_6886)
  {
    _6885 = _925->getAxis();
  }
  else
  {
    _6885 = ((int)((_926)->size(0)) - (int)1);
  }
  int _927 = _6885;
  int _928 = _ptr__926[_927];
  int _929 = (int)((_926)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _930 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_929)));
  _checked_ptr_1<int> _ptr__930(_930 ? _930->raw() : nullptr,_930 ? _930->size(0) : 0);
  _ptr__930[(_929 - (int)1)] = (int)1;
  int _6887 = (int)1;
  int _6888 = _929;
  for (int _931 = _6887; _931 < _6888; ++_931)
  {
    {
      _ptr__930[((_929 - _931) - (int)1)] = safe_mul( _ptr__930[(_929 - _931)],_ptr__926[(_929 - _931)] );
    }
  }
  int _932 = _ptr__926[(int)0];
  int _6889 = (int)1;
  int _6890 = (int)((_926)->size(0));
  for (int _933 = _6889; _933 < _6890; ++_933)
  {
    {
      _932 *= _ptr__926[_933];
    }
  }
  int _934 = (int)1;
  int _6891 = (int)0;
  int _6892 = _927;
  for (int _935 = _6891; _935 < _6892; ++_935)
  {
    {
      _934 *= _ptr__926[_935];
    }
  }
  int _936 = (int)1;
  int _6893 = safe_add( _927,(int)1 );
  int _6894 = _929;
  for (int _937 = _6893; _937 < _6894; ++_937)
  {
    {
      _936 *= _ptr__926[_937];
    }
  }
  int _938 = safe_mul( _934,_936 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InQCone) && (_928 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_928 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_928 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_928 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_928 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_928 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _939 = natvarmap_alloc(_932);
  int _940 = natconemap_alloc(_938);
  ((*natvarmap_type)(_939)) = safe_add( _940,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_939))));
  _checked_ptr_1<int> _ptr__941(_941 ? _941->raw() : nullptr,_941 ? _941->size(0) : 0);
  natvarmap->get(_939,_941,(int)0);
  int _6895 = (int)0;
  int _6896 = _932;
  for (int _942 = _6895; _942 < _6896; ++_942)
  {
    {
      ((*natvarmap_idx)(_ptr__941[_942])) = _939;
    }
  }
  task_var_putboundlist_fr(_941);
  if (mosek::fusion::p_ConeDomain::_get_impl(_925)->int_flag)
  {
    {
      task_var_putintlist(_941);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _943 = _941;
  _checked_ptr_1<int> _ptr__943(_943 ? _943->raw() : nullptr,_943 ? _943->size(0) : 0);
  if ((_927 < ((int)((_926)->size(0)) - (int)1)))
  {
    {
      _943 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_941)->size(0)))));
      _ptr__943.update(_943 ? _943->raw() : nullptr, _943 ? _943->size(0) : 0);
      int _944 = (int)0;
      int _6897 = (int)0;
      int _6898 = _934;
      for (int _945 = _6897; _945 < _6898; ++_945)
      {
        {
          int _6899 = (int)0;
          int _6900 = _936;
          for (int _946 = _6899; _946 < _6900; ++_946)
          {
            {
              int _6901 = (int)0;
              int _6902 = _928;
              for (int _947 = _6901; _947 < _6902; ++_947)
              {
                {
                  _ptr__943[_944] = _ptr__941[safe_add( safe_mul( safe_add( safe_mul( _945,_928 ),_947 ),_936 ),_946 )];
                  ++ _944;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _948 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_938)));
  _checked_ptr_1<int> _ptr__948(_948 ? _948->raw() : nullptr,_948 ? _948->size(0) : 0);
  natconemap->get(_940,_948,(int)0);
  ((*natconemap_dim)(_940)) = _928;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_948,_928,_938,_943);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_948,_928,_938,_943);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_948,_928,_938,_943);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _6903;
                  for (int _949 = (int)0, _6904 = _938; _949 < _6904 ; ++_949)
                  {
                    _6903.push_back(mosek::fusion::p_ConeDomain::_get_impl(_925)->alpha);
                  }
                  auto _6905 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6903.size()),_6903.begin(),_6903.end()));
                  task_put_ppowcones(_948,_928,_938,_943,_6905);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_948,_928,_938,_943);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _6906;
                          for (int _950 = (int)0, _6907 = _938; _950 < _6907 ; ++_950)
                          {
                            _6906.push_back(mosek::fusion::p_ConeDomain::_get_impl(_925)->alpha);
                          }
                          auto _6908 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6906.size()),_6906.begin(),_6906.end()));
                          task_put_dpowcones(_948,_928,_938,_943,_6908);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _6909 = (int)0;
  int _6910 = (int)((_948)->size(0));
  for (int _951 = _6909; _951 < _6910; ++_951)
  {
    {
      task_cone_name(_ptr__948[_951],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__948[_951])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _952 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_923,_939,_926,_941);
  ((*vars)(_939)) = (_952).as<::mosek::fusion::ModelVariable>();
  if (((int)((_923).size()) > (int)0))
  {
    {
      var_map->setItem(_923,_939);
    }
  }
  {}
  return (_952).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _953,std::shared_ptr< monty::ndarray< int,1 > > _954,monty::rc_ptr< ::mosek::fusion::LinearDomain > _955){
  _checked_ptr_1<int> _ptr__954(_954 ? _954->raw() : nullptr, _954 ? _954->size(0) : 0);
  if ((((int)((_953).size()) > (int)0) && hasVariable(_953)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_953)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6911;
  bool _6912 = (NULL != _954.get());
  if (_6912)
  {
    _6911 = _954;
  }
  else
  {
    _6911 = mosek::fusion::p_LinearDomain::_get_impl(_955)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _956 = _6911;
  _checked_ptr_1<int> _ptr__956(_956 ? _956->raw() : nullptr,_956 ? _956->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_955)->shape,_956))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _956.get()))
  {
    {
      _956 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__956.update(_956 ? _956->raw() : nullptr, _956 ? _956->size(0) : 0);
    }
  }
  {}
  int _957 = (int)((_956)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _958 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_957)));
  _checked_ptr_1<int> _ptr__958(_958 ? _958->raw() : nullptr,_958 ? _958->size(0) : 0);
  if ((_957 > (int)0))
  {
    {
      _ptr__958[(_957 - (int)1)] = (int)1;
      int _6913 = (int)1;
      int _6914 = _957;
      for (int _959 = _6913; _959 < _6914; ++_959)
      {
        {
          _ptr__958[((_957 - _959) - (int)1)] = safe_mul( _ptr__958[(_957 - _959)],_ptr__956[(_957 - _959)] );
        }
      }
    }
  }
  {}
  int _960 = (int)1;
  int _6915 = (int)0;
  int _6916 = (int)((_956)->size(0));
  for (int _961 = _6915; _961 < _6916; ++_961)
  {
    {
      _960 *= _ptr__956[_961];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _962 = nullptr;
  _checked_ptr_1<long long> _ptr__962(_962 ? _962->raw() : nullptr,_962 ? _962->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _963 = nullptr;
  _checked_ptr_1<int> _ptr__963(_963 ? _963->raw() : nullptr,_963 ? _963->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1)) != _957))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _964 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(0));
      _962 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_964)));
      _ptr__962.update(_962 ? _962->raw() : nullptr, _962 ? _962->size(0) : 0);
      int _6917 = (int)0;
      int _6918 = _964;
      for (int _965 = _6917; _965 < _6918; ++_965)
      {
        {
          int _6919 = (int)0;
          int _6920 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1));
          for (int _966 = _6919; _966 < _6920; ++_966)
          {
            {
              if (((((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_966)) < (int)0) || (((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_966)) >= _ptr__956[_966])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _967 = (int)0;
          int _6921 = (int)0;
          int _6922 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1));
          for (int _968 = _6921; _968 < _6922; ++_968)
          {
            {
              _967 += safe_mul( _ptr__958[_968],((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_968)) );
            }
          }
          _ptr__962[_965] = _967;
        }
      }
      std::shared_ptr< monty::ndarray< int,2 > > _969 = mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity;
      int _970 = (int)0;
      int _6923 = (int)0;
      int _6924 = _957;
      for (int _971 = _6923; _971 < _6924; ++_971)
      {
        {
          if ((_970 < _ptr__956[_971]))
          {
            {
              _970 = _ptr__956[_971];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _972 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_964)));
      _checked_ptr_1<int> _ptr__972(_972 ? _972->raw() : nullptr,_972 ? _972->size(0) : 0);
      int _6925 = (int)0;
      int _6926 = _964;
      for (int _973 = _6925; _973 < _6926; ++_973)
      {
        {
          _ptr__972[_973] = _973;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _974 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_964)));
      _checked_ptr_1<int> _ptr__974(_974 ? _974->raw() : nullptr,_974 ? _974->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _975 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _970,(int)1 ))));
      _checked_ptr_1<int> _ptr__975(_975 ? _975->raw() : nullptr,_975 ? _975->size(0) : 0);
      int _6927 = (int)0;
      int _6928 = _957;
      for (int _976 = _6927; _976 < _6928; ++_976)
      {
        {
          int _977 = ((_957 - _976) - (int)1);
          int _6929 = (int)0;
          int _6930 = safe_add( _ptr__956[_977],(int)1 );
          for (int _978 = _6929; _978 < _6930; ++_978)
          {
            {
              _ptr__975[_978] = (int)0;
            }
          }
          int _6931 = (int)0;
          int _6932 = _964;
          for (int _979 = _6931; _979 < _6932; ++_979)
          {
            {
              ++ _ptr__975[safe_add( ((*_969)(_979,_977)),(int)1 )];
            }
          }
          int _6933 = (int)0;
          int _6934 = _ptr__956[_977];
          for (int _980 = _6933; _980 < _6934; ++_980)
          {
            {
              _ptr__975[safe_add( _980,(int)1 )] += _ptr__975[_980];
            }
          }
          int _6935 = (int)0;
          int _6936 = _964;
          for (int _981 = _6935; _981 < _6936; ++_981)
          {
            {
              int _982 = _ptr__972[_981];
              _ptr__974[_ptr__975[((*_969)(_982,_977))]] = _982;
              ++ _ptr__975[((*_969)(_982,_977))];
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _983 = _972;
          _checked_ptr_1<int> _ptr__983(_983 ? _983->raw() : nullptr,_983 ? _983->size(0) : 0);
          _972 = _974;
          _ptr__972.update(_972 ? _972->raw() : nullptr, _972 ? _972->size(0) : 0);
          _974 = _983;
          _ptr__974.update(_974 ? _974->raw() : nullptr, _974 ? _974->size(0) : 0);
        }
      }
      int _6937 = (int)0;
      int _6938 = _964;
      for (int _984 = _6937; _984 < _6938; ++_984)
      {
        {
          int _985 = _ptr__972[_984];
          long long _986 = (int)0;
          int _6939 = (int)0;
          int _6940 = _957;
          for (int _987 = _6939; _987 < _6940; ++_987)
          {
            {
              _986 += safe_mul( _ptr__958[_987],((*_969)(_985,_987)) );
            }
          }
          _ptr__962[_984] = _986;
        }
      }
    }
  }
  {}
  int _6941;
  bool _6942 = (NULL != _962.get());
  if (_6942)
  {
    _6941 = (int)((_962)->size(0));
  }
  else
  {
    _6941 = _960;
  }
  int _988 = _6941;
  std::shared_ptr< monty::ndarray< double,1 > > _989 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_988)));
  _checked_ptr_1<double> _ptr__989(_989 ? _989->raw() : nullptr,_989 ? _989->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)->size(0)) == (int)1))
      {
        {
          int _6943 = (int)0;
          int _6944 = _988;
          for (int _990 = _6943; _990 < _6944; ++_990)
          {
            {
              _ptr__989[_990] = ((*mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)->size(0)) == _988))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd,(int)0,_989,(int)0,_988);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _991 = natvarmap_alloc(_988);
  std::shared_ptr< monty::ndarray< int,1 > > _992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_991))));
  _checked_ptr_1<int> _ptr__992(_992 ? _992->raw() : nullptr,_992 ? _992->size(0) : 0);
  natvarmap->get(_991,_992,(int)0);
  int _6945 = (int)0;
  int _6946 = _988;
  for (int _993 = _6945; _993 < _6946; ++_993)
  {
    {
      ((*natvarmap_idx)(_ptr__992[_993])) = _991;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_992);
      ((*natvarmap_type)(_991)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_992,_989);
      ((*natvarmap_type)(_991)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_992,_989);
      ((*natvarmap_type)(_991)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_992,_989);
      ((*natvarmap_type)(_991)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _994 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_953,(long long)(_991),_956,_962,_992);
  if (mosek::fusion::p_LinearDomain::_get_impl(_955)->cardinal_flag)
  {
    {
      task_var_putintlist(_992);
    }
  }
  {}
  ((*vars)(_991)) = (_994).as<::mosek::fusion::ModelVariable>();
  if (((int)((_953).size()) > (int)0))
  {
    {
      var_map->setItem(_953,_991);
    }
  }
  {}
  return (_994).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _995,std::shared_ptr< monty::ndarray< int,1 > > _996,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _997){
  _checked_ptr_1<int> _ptr__996(_996 ? _996->raw() : nullptr, _996 ? _996->size(0) : 0);
  if ((((int)((_995).size()) > (int)0) && hasVariable(_995)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_995)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6947;
  bool _6948 = (NULL != _996.get());
  if (_6948)
  {
    _6947 = _996;
  }
  else
  {
    _6947 = mosek::fusion::p_LinPSDDomain::_get_impl(_997)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _998 = _6947;
  _checked_ptr_1<int> _ptr__998(_998 ? _998->raw() : nullptr,_998 ? _998->size(0) : 0);
  if ((NULL == _998.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_997)->shape,_998)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _999 = (int)((_998)->size(0));
  int _1000 = mosek::fusion::p_LinPSDDomain::_get_impl(_997)->conedim;
  if (((_1000 < (int)0) || (_1000 >= _999)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1001 = _ptr__998[_1000];
  int _1002 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1001 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1002,safe_add( _1002,(int)1 ) ) / (int)2) != _1001))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1003 = (int)1;
  int _1004 = _ptr__998[_1000];
  int _1005 = (int)1;
  int _6949 = (int)0;
  int _6950 = _1000;
  for (int _1006 = _6949; _1006 < _6950; ++_1006)
  {
    {
      _1005 *= _ptr__998[_1006];
    }
  }
  int _6951 = safe_add( _1000,(int)1 );
  int _6952 = _999;
  for (int _1007 = _6951; _1007 < _6952; ++_1007)
  {
    {
      _1003 *= _ptr__998[_1007];
    }
  }
  int _1008 = safe_mul( _1005,_1003 );
  int _1009 = safe_mul( _1008,_1001 );
  int _1010 = natbarvarmap_alloc(_1008,_1002);
  std::shared_ptr< monty::ndarray< int,1 > > _1011 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1009)));
  _checked_ptr_1<int> _ptr__1011(_1011 ? _1011->raw() : nullptr,_1011 ? _1011->size(0) : 0);
  natbarvarmap_get(_1010,_1011);
  std::shared_ptr< monty::ndarray< long long,1 > > _1012 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1008,_1004 ))));
  _checked_ptr_1<long long> _ptr__1012(_1012 ? _1012->raw() : nullptr,_1012 ? _1012->size(0) : 0);
  {
    int _1013 = (int)0;
    int _6953 = (int)0;
    int _6954 = _1005;
    for (int _1014 = _6953; _1014 < _6954; ++_1014)
    {
      {
        int _6955 = (int)0;
        int _6956 = _1004;
        for (int _1015 = _6955; _1015 < _6956; ++_1015)
        {
          {
            int _6957 = (int)0;
            int _6958 = safe_add( _1015,(int)1 );
            for (int _1016 = _6957; _1016 < _6958; ++_1016)
            {
              {
                int _6959 = (int)0;
                int _6960 = _1003;
                for (int _1017 = _6959; _1017 < _6960; ++_1017)
                {
                  {
                    _ptr__1012[_1013] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1014,_1003 ),_1017 ))),safe_add( (safe_mul( _1015,((safe_mul( (int)2,_1002 ) - _1015) - (int)1) ) / (int)2),_1016 ) );
                    ++ _1013;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1018 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_995,_1010,_998,_1000,_1012);
  ((*barvars)(_1010)) = (_1018).as<::mosek::fusion::ModelVariable>();
  if (((int)((_995).size()) > (int)0))
  {
    {
      var_map->setItem(_995,(-safe_add( _1010,(int)1 )));
    }
  }
  {}
  return (_1018).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1019,std::shared_ptr< monty::ndarray< int,1 > > _1020,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1021){
  _checked_ptr_1<int> _ptr__1020(_1020 ? _1020->raw() : nullptr, _1020 ? _1020->size(0) : 0);
  if ((((int)((_1019).size()) > (int)0) && hasVariable(_1019)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1019)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1022 = _1020;
  _checked_ptr_1<int> _ptr__1022(_1022 ? _1022->raw() : nullptr,_1022 ? _1022->size(0) : 0);
  if ((NULL == _1022.get()))
  {
    {
      _1022 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->shape;
      _ptr__1022.update(_1022 ? _1022->raw() : nullptr, _1022 ? _1022->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1022.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1023 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim1;
  int _1024 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim2;
  int _1025 = (int)((_1022)->size(0));
  int _1026 = _ptr__1022[_1023];
  if ((_1023 > _1024))
  {
    {
      int _1027 = _1023;
      _1023 = _1024;
      _1024 = _1027;
    }
  }
  {}
  if (((_1023 == _1024) || ((_1023 < (int)0) || (_1024 >= _1025))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1022[_1023] != _ptr__1022[_1024]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1028 = (int)1;
  int _6961 = (int)0;
  int _6962 = _1023;
  for (int _1029 = _6961; _1029 < _6962; ++_1029)
  {
    {
      _1028 *= _ptr__1022[_1029];
    }
  }
  int _6963 = safe_add( _1023,(int)1 );
  int _6964 = _1024;
  for (int _1030 = _6963; _1030 < _6964; ++_1030)
  {
    {
      _1028 *= _ptr__1022[_1030];
    }
  }
  int _6965 = safe_add( _1024,(int)1 );
  int _6966 = _1025;
  for (int _1031 = _6965; _1031 < _6966; ++_1031)
  {
    {
      _1028 *= _ptr__1022[_1031];
    }
  }
  int _1032 = (safe_mul( safe_mul( _1028,_1026 ),safe_add( _1026,(int)1 ) ) / (int)2);
  int _1033 = natbarvarmap_alloc(_1028,_1026);
  std::shared_ptr< monty::ndarray< long long,1 > > _1034 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1032)));
  _checked_ptr_1<long long> _ptr__1034(_1034 ? _1034->raw() : nullptr,_1034 ? _1034->size(0) : 0);
  natbarvar_get(_1033,_1034);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1035 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1019,_1033,_1022,mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim2,_1034);
  ((*barvars)(_1033)) = (_1035).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1019).size()) > (int)0))
  {
    {
      var_map->setItem(_1019,(-safe_add( _1033,(int)1 )));
    }
  }
  {}
  return (_1035).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1036,monty::rc_ptr< ::mosek::fusion::Expression > _1037,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1038){
  if ((((int)((_1036).size()) > (int)0) && hasConstraint(_1036)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1036)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1039 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1037)).as<::mosek::fusion::Expression>());
  _1039->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1040 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1040(_1040 ? _1040->raw() : nullptr,_1040 ? _1040->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1041 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1041(_1041 ? _1041->raw() : nullptr,_1041 ? _1041->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1042 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1042(_1042 ? _1042->raw() : nullptr,_1042 ? _1042->size(0) : 0);
  int _1043 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1044 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1045 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1046 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1047 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1048 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1049 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1050 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1051 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape)->size(0)) != _1043))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _6967 = (int)0;
          int _6968 = _1043;
          for (int _1052 = _6967; _1052 < _6968; ++_1052)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape)(_1052)) != _ptr__1040[safe_add( _1044,_1052 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1053 = (int)1;
  int _6969 = (int)0;
  int _6970 = _1043;
  for (int _1054 = _6969; _1054 < _6970; ++_1054)
  {
    {
      _1053 *= _ptr__1040[safe_add( _1044,_1054 )];
    }
  }
  int _1055 = natconmap_alloc(_1053);
  std::shared_ptr< monty::ndarray< int,1 > > _1056 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1053)));
  _checked_ptr_1<int> _ptr__1056(_1056 ? _1056->raw() : nullptr,_1056 ? _1056->size(0) : 0);
  natconmap->get(_1055,_1056,(int)0);
  int _6971 = (int)0;
  int _6972 = _1053;
  for (int _1057 = _6971; _1057 < _6972; ++_1057)
  {
    {
      ((*natconmap_idx)(_ptr__1056[_1057])) = _1055;
      ((*natconmap_slackidx)(_ptr__1056[_1057])) = (int)0;
    }
  }
  ((*natconmap_type)(_1055)) = (int)4;
  putarows(_1056,rs,_1045,_1046,_1048,_1049,_1051);
  std::shared_ptr< monty::ndarray< double,1 > > _1058 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1053)));
  _checked_ptr_1<double> _ptr__1058(_1058 ? _1058->raw() : nullptr,_1058 ? _1058->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1059 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1053)));
  _checked_ptr_1<double> _ptr__1059(_1059 ? _1059->raw() : nullptr,_1059 ? _1059->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1060 = natconmap_efix;
  _checked_ptr_1<double> _ptr__1060(_1060 ? _1060->raw() : nullptr,_1060 ? _1060->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1061 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->lb;
  _checked_ptr_1<double> _ptr__1061(_1061 ? _1061->raw() : nullptr,_1061 ? _1061->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1062 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->ub;
  _checked_ptr_1<double> _ptr__1062(_1062 ? _1062->raw() : nullptr,_1062 ? _1062->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1063 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->sparsity;
  bool _1064 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1065 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->sparsity;
  {
    int _6973 = (int)0;
    int _6974 = _1045;
    for (int _1066 = _6973; _1066 < _6974; ++_1066)
    {
      {
        _ptr__1060[_ptr__1056[_1066]] = _ptr__1042[safe_add( _1050,_1066 )];
      }
    }
    if (_1064)
    {
      {
        int _6975 = (int)0;
        int _6976 = _1053;
        for (int _1067 = _6975; _1067 < _6976; ++_1067)
        {
          {
            _ptr__1058[_1067] = (((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->lb)((int)0)) - _ptr__1042[safe_add( _1050,_1067 )]);
            _ptr__1059[_1067] = (((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->ub)((int)0)) - _ptr__1042[safe_add( _1050,_1067 )]);
          }
        }
      }
    }
    else if((NULL != _1065.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1068 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1043)));
        _checked_ptr_1<int> _ptr__1068(_1068 ? _1068->raw() : nullptr,_1068 ? _1068->size(0) : 0);
        _ptr__1068[(_1043 - (int)1)] = (int)1;
        int _6977 = (int)1;
        int _6978 = _1043;
        for (int _1069 = _6977; _1069 < _6978; ++_1069)
        {
          {
            _ptr__1068[((_1043 - _1069) - (int)1)] = safe_mul( _ptr__1068[(_1043 - _1069)],_ptr__1040[(safe_add( _1044,_1043 ) - _1069)] );
          }
        }
        int _6979 = (int)0;
        int _6980 = _1053;
        for (int _1070 = _6979; _1070 < _6980; ++_1070)
        {
          {
            _ptr__1058[_1070] = (-_ptr__1042[safe_add( _1050,_1070 )]);
            _ptr__1059[_1070] = (-_ptr__1042[safe_add( _1050,_1070 )]);
          }
        }
        int _6981 = (int)0;
        int _6982 = (int)((_1061)->size(0));
        for (int _1071 = _6981; _1071 < _6982; ++_1071)
        {
          {
            int _1072 = (int)0;
            int _6983 = (int)0;
            int _6984 = _1043;
            for (int _1073 = _6983; _1073 < _6984; ++_1073)
            {
              {
                _1072 += safe_mul( _ptr__1068[_1073],((*_1065)(_1071,_1073)) );
              }
            }
            _ptr__1058[_1072] += _ptr__1061[_1071];
            _ptr__1059[_1072] += _ptr__1062[_1071];
          }
        }
      }
    }
    else
    {
      {
        int _6985 = (int)0;
        int _6986 = _1053;
        for (int _1074 = _6985; _1074 < _6986; ++_1074)
        {
          {
            _ptr__1058[_1074] = (_ptr__1061[_1074] - _ptr__1042[safe_add( _1050,_1074 )]);
            _ptr__1059[_1074] = (_ptr__1062[_1074] - _ptr__1042[safe_add( _1050,_1074 )]);
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1056,_1058,_1059);
  std::vector<int> _6987;
  for (int _1076 = (int)0, _6988 = _1043; _1076 < _6988 ; ++_1076)
  {
    _6987.push_back(_ptr__1040[safe_add( _1044,_1076 )]);
  }
  auto _6989 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6987.size()),_6987.begin(),_6987.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1075 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1036,_6989,_1056);
  ((*cons)(_1055)) = (_1075).as<::mosek::fusion::ModelConstraint>();
  return (_1075).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_constr_expr(std::shared_ptr< monty::ndarray< int,1 > > _1077,std::shared_ptr< monty::ndarray< double,1 > > _1078){
  _checked_ptr_1<int> _ptr__1077(_1077 ? _1077->raw() : nullptr, _1077 ? _1077->size(0) : 0);
  _checked_ptr_1<double> _ptr__1078(_1078 ? _1078->raw() : nullptr, _1078 ? _1078->size(0) : 0);
  int _1079 = (int)((_1077)->size(0));
  int _6990 = (int)0;
  int _6991 = _1079;
  for (int _1080 = _6990; _1080 < _6991; ++_1080)
  {
    {
      ((*natconmap_efix)(_ptr__1077[_1080])) += _ptr__1078[_1080];
    }
  }
  std::vector<double> _6992;
  for (int _1082 = (int)0, _6993 = _1079; _1082 < _6993 ; ++_1082)
  {
    _6992.push_back((((*natconmap_lb)(_ptr__1077[_1082])) - ((*natconmap_efix)(_ptr__1077[_1082]))));
  }
  auto _6994 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6992.size()),_6992.begin(),_6992.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1081 = _6994;
  _checked_ptr_1<double> _ptr__1081(_1081 ? _1081->raw() : nullptr,_1081 ? _1081->size(0) : 0);
  std::vector<double> _6995;
  for (int _1084 = (int)0, _6996 = _1079; _1084 < _6996 ; ++_1084)
  {
    _6995.push_back((((*natconmap_ub)(_ptr__1077[_1084])) - ((*natconmap_efix)(_ptr__1077[_1084]))));
  }
  auto _6997 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6995.size()),_6995.begin(),_6995.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1083 = _6997;
  _checked_ptr_1<double> _ptr__1083(_1083 ? _1083->raw() : nullptr,_1083 ? _1083->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Model.add_constr_expr"));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1085,monty::rc_ptr< ::mosek::fusion::WorkStack > _1086,int _1087,int _1088,int _1089,int _1090,int _1091){
  _checked_ptr_1<int> _ptr__1085(_1085 ? _1085->raw() : nullptr, _1085 ? _1085->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1092 = mosek::fusion::p_WorkStack::_get_impl(_1086)->i32;
  _checked_ptr_1<int> _ptr__1092(_1092 ? _1092->raw() : nullptr,_1092 ? _1092->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1093 = mosek::fusion::p_WorkStack::_get_impl(_1086)->i64;
  _checked_ptr_1<long long> _ptr__1093(_1093 ? _1093->raw() : nullptr,_1093 ? _1093->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1094 = mosek::fusion::p_WorkStack::_get_impl(_1086)->f64;
  _checked_ptr_1<double> _ptr__1094(_1094 ? _1094->raw() : nullptr,_1094 ? _1094->size(0) : 0);
  int _1095 = (int)0;
  int _1096 = (int)0;
  int _1097 = (int)0;
  int _6998 = (int)0;
  int _6999 = _1087;
  for (int _1098 = _6998; _1098 < _6999; ++_1098)
  {
    {
      int _1099 = _ptr__1092[safe_add( _1089,_1098 )];
      int _1100 = _ptr__1092[safe_add( safe_add( _1089,_1098 ),(int)1 )];
      int _1101 = _1099;
      while ( ((_1101 < _1100) && (_ptr__1093[safe_add( _1090,_1101 )] < (int)0)) )
      {
        {
          int _1102 = ((*natbarvar_idx)((-safe_add( _ptr__1093[safe_add( _1090,_1101 )],(int)1 ))));
          int _1103 = _1101;
          ++ _1101;
          while ( ((_1101 < _1100) && ((_ptr__1093[safe_add( _1090,_1101 )] < (int)0) && (_1102 == ((*natbarvar_idx)((-safe_add( _ptr__1093[safe_add( _1090,_1101 )],(int)1 ))))))) )
          {
            {
              ++ _1101;
            }
          }
          ++ _1096;
        }
      }
      _1097 += (_1101 - _1099);
      _1095 += (_1100 - _1101);
    }
  }
  int _1104 = (int)((_1085)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1105 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1104,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1105(_1105 ? _1105->raw() : nullptr,_1105 ? _1105->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1106 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1095)));
  _checked_ptr_1<int> _ptr__1106(_1106 ? _1106->raw() : nullptr,_1106 ? _1106->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1107 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1095)));
  _checked_ptr_1<double> _ptr__1107(_1107 ? _1107->raw() : nullptr,_1107 ? _1107->size(0) : 0);
  {
    int _1108 = (int)0;
    int _7000 = (int)0;
    int _7001 = _1087;
    for (int _1109 = _7000; _1109 < _7001; ++_1109)
    {
      {
        int _1110 = (int)0;
        int _7002 = _ptr__1092[safe_add( _1089,_1109 )];
        int _7003 = _ptr__1092[safe_add( safe_add( _1089,_1109 ),(int)1 )];
        for (int _1111 = _7002; _1111 < _7003; ++_1111)
        {
          {
            if ((_ptr__1093[safe_add( _1090,_1111 )] > (int)0))
            {
              {
                _ptr__1106[safe_add( _1108,_1110 )] = (int)(_ptr__1093[safe_add( _1090,_1111 )] - (int)1);
                _ptr__1107[safe_add( _1108,_1110 )] = _ptr__1094[safe_add( _1091,_1111 )];
                ++ _1110;
              }
            }
            {}
          }
        }
        _ptr__1105[safe_add( _1109,(int)1 )] = safe_add( _ptr__1105[_1109],_1110 );
        _1108 += _1110;
      }
    }
  }
  task_putarowlist(_1085,_1105,_1106,_1107);
  if ((_1096 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1112 = _1085;
      _checked_ptr_1<int> _ptr__1112(_1112 ? _1112->raw() : nullptr,_1112 ? _1112->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1113 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1104,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1113(_1113 ? _1113->raw() : nullptr,_1113 ? _1113->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1114 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1096)));
      _checked_ptr_1<int> _ptr__1114(_1114 ? _1114->raw() : nullptr,_1114 ? _1114->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1115 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1096)));
      _checked_ptr_1<int> _ptr__1115(_1115 ? _1115->raw() : nullptr,_1115 ? _1115->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1116 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1096)));
      _checked_ptr_1<long long> _ptr__1116(_1116 ? _1116->raw() : nullptr,_1116 ? _1116->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1117 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1097)));
      _checked_ptr_1<int> _ptr__1117(_1117 ? _1117->raw() : nullptr,_1117 ? _1117->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1118 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1097)));
      _checked_ptr_1<int> _ptr__1118(_1118 ? _1118->raw() : nullptr,_1118 ? _1118->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1119 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1097)));
      _checked_ptr_1<double> _ptr__1119(_1119 ? _1119->raw() : nullptr,_1119 ? _1119->size(0) : 0);
      int _1120 = (int)0;
      int _1121 = (int)0;
      int _7004 = (int)0;
      int _7005 = _1104;
      for (int _1122 = _7004; _1122 < _7005; ++_1122)
      {
        {
          int _1123 = _ptr__1092[safe_add( _1089,_1122 )];
          int _1124 = _ptr__1092[safe_add( safe_add( _1089,_1122 ),(int)1 )];
          while ( ((_1123 < _1124) && (_ptr__1093[safe_add( _1090,_1123 )] < (int)0)) )
          {
            {
              int _1125 = _1123;
              int _1126 = ((*natbarvar_idx)((-safe_add( _ptr__1093[safe_add( _1090,_1123 )],(int)1 ))));
              while ( ((_1123 < _1124) && ((_ptr__1093[safe_add( _1090,_1123 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1093[safe_add( _1090,_1123 )],(int)1 )))) == _1126))) )
              {
                {
                  _ptr__1117[_1121] = ((*natbarvar_i)((-safe_add( _ptr__1093[safe_add( _1090,_1123 )],(int)1 ))));
                  _ptr__1118[_1121] = ((*natbarvar_j)((-safe_add( _ptr__1093[safe_add( _1090,_1123 )],(int)1 ))));
                  if ((_ptr__1117[_1121] == _ptr__1118[_1121]))
                  {
                    {
                      _ptr__1119[_1121] = _ptr__1094[safe_add( _1091,_1123 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1119[_1121] = (0.5 * _ptr__1094[safe_add( _1091,_1123 )]);
                    }
                  }
                  ++ _1121;
                  ++ _1123;
                }
              }
              _ptr__1114[_1120] = _1126;
              _ptr__1115[_1120] = ((*natbarvar_dim)(_1126));
              _ptr__1116[_1120] = (_1123 - _1125);
              ++ _1120;
            }
          }
          _1123 = _1124;
          _ptr__1113[safe_add( _1122,(int)1 )] = _1120;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1127 = task_appendsymmatlist(_1115,_1116,_1117,_1118,_1119);
      _checked_ptr_1<long long> _ptr__1127(_1127 ? _1127->raw() : nullptr,_1127 ? _1127->size(0) : 0);
      task_putbararowlist(_1112,_1113,_1114,_1127);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1128,monty::rc_ptr< ::mosek::fusion::Expression > _1129,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1130){
  std::shared_ptr< monty::ndarray< int,1 > > _1131 = _1129->getShape();
  _checked_ptr_1<int> _ptr__1131(_1131 ? _1131->raw() : nullptr,_1131 ? _1131->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1130)->shape.get()) && (!::mosek::fusion::p_Set::match(_1131,mosek::fusion::p_PSDDomain::_get_impl(_1130)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1132;
  int _1133;
  int _1134;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1130)->axisIsSet)
  {
    {
      _1132 = (mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim2);
      int _7006;
      bool _7007 = _1132;
      if (_7007)
      {
        _7006 = mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim1;
      }
      else
      {
        _7006 = mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim2;
      }
      _1134 = _7006;
      int _7008;
      bool _7009 = _1132;
      if (_7009)
      {
        _7008 = mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim2;
      }
      else
      {
        _7008 = mosek::fusion::p_PSDDomain::_get_impl(_1130)->conedim1;
      }
      _1133 = _7008;
    }
  }
  else
  {
    {
      _1132 = true;
      _1134 = ((int)((_1131)->size(0)) - (int)2);
      _1133 = ((int)((_1131)->size(0)) - (int)1);
    }
  }
  if (((_1133 >= (int)((_1131)->size(0))) || (_ptr__1131[_1134] != _ptr__1131[_1133])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7010;
  bool _7011 = (mosek::fusion::p_PSDDomain::_get_impl(_1130)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7011)
  {
    _7010 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1134,_1133,_1129).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7010 = _1129;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1135 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1134,_1133,_7010)).as<::mosek::fusion::Expression>());
  _1135->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1136 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1136(_1136 ? _1136->raw() : nullptr,_1136 ? _1136->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1137 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1137(_1137 ? _1137->raw() : nullptr,_1137 ? _1137->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1138 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1138(_1138 ? _1138->raw() : nullptr,_1138 ? _1138->size(0) : 0);
  int _1139 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1140 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1139)));
  _checked_ptr_1<int> _ptr__1140(_1140 ? _1140->raw() : nullptr,_1140 ? _1140->size(0) : 0);
  rs->popi32(_1139,_1140,(int)0);
  int _1141 = rs->popi32();
  int _1142 = rs->popi32();
  bool _1143 = (rs->popi32() != (int)0);
  int _1144 = rs->popi32(safe_add( _1141,(int)1 ));
  int _7012;
  bool _7013 = _1143;
  if (_7013)
  {
    _7012 = rs->popi64(_1141);
  }
  else
  {
    _7012 = (-(int)99999);
  }
  int _1145 = _7012;
  int _1146 = rs->popi64(_1142);
  int _1147 = rs->popf64(_1141);
  int _1148 = rs->popf64(_1142);
  int _1149 = _ptr__1140[_1133];
  int _1150 = (safe_mul( _1149,safe_add( _1149,(int)1 ) ) / (int)2);
  int _7014 = (int)0;
  int _7015 = _1139;
  for (int _1151 = _7014; _1151 < _7015; ++_1151)
  {
    {
      if (((_1151 != _1134) && (_1151 != _1133)))
      {
        {
          _1150 *= _ptr__1140[_1151];
        }
      }
      {}
    }
  }
  int _1152 = natconmap_alloc(_1150);
  std::shared_ptr< monty::ndarray< int,1 > > _1153 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1150)));
  _checked_ptr_1<int> _ptr__1153(_1153 ? _1153->raw() : nullptr,_1153 ? _1153->size(0) : 0);
  natconmap->get(_1152,_1153,(int)0);
  putarows(_1153,rs,_1141,_1142,_1144,_1146,_1148);
  std::shared_ptr< monty::ndarray< int,1 > > _1154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1154(_1154 ? _1154->raw() : nullptr,_1154 ? _1154->size(0) : 0);
  int _7016 = (int)0;
  int _7017 = _1134;
  for (int _1155 = _7016; _1155 < _7017; ++_1155)
  {
    {
      _ptr__1154[(int)0] *= _ptr__1140[_1155];
    }
  }
  _ptr__1154[(int)1] = _ptr__1140[_1134];
  int _7018 = safe_add( _1134,(int)1 );
  int _7019 = _1133;
  for (int _1156 = _7018; _1156 < _7019; ++_1156)
  {
    {
      _ptr__1154[(int)2] *= _ptr__1140[_1156];
    }
  }
  _ptr__1154[(int)3] = _ptr__1140[_1133];
  int _7020 = safe_add( _1133,(int)1 );
  int _7021 = _1139;
  for (int _1157 = _7020; _1157 < _7021; ++_1157)
  {
    {
      _ptr__1154[(int)4] *= _ptr__1140[_1157];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1158 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1158(_1158 ? _1158->raw() : nullptr,_1158 ? _1158->size(0) : 0);
  _ptr__1158[(int)4] = (int)1;
  int _7022 = (int)1;
  int _7023 = (int)5;
  for (int _1159 = _7022; _1159 < _7023; ++_1159)
  {
    {
      _ptr__1158[(((int)5 - _1159) - (int)1)] = safe_mul( _ptr__1158[((int)5 - _1159)],_ptr__1154[((int)5 - _1159)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1160 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1150)));
  _checked_ptr_1<double> _ptr__1160(_1160 ? _1160->raw() : nullptr,_1160 ? _1160->size(0) : 0);
  if ((_1145 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7024 = (int)0;
      int _7025 = _1141;
      for (int _1161 = _7024; _1161 < _7025; ++_1161)
      {
        {
          ((*natconmap_efix)(_ptr__1153[_1161])) = _ptr__1138[safe_add( _1147,_1161 )];
          ((*natconmap_lb)(_ptr__1153[_1161])) = (int)0;
          ((*natconmap_ub)(_ptr__1153[_1161])) = (int)0;
          _ptr__1160[_1161] = (-_ptr__1138[safe_add( _1147,_1161 )]);
        }
      }
    }
  }
  task_con_putboundlist_fx(_1153,_1160);
  int _1162 = safe_mul( safe_mul( _ptr__1154[(int)0],_ptr__1154[(int)2] ),_ptr__1154[(int)4] );
  int _1163 = _ptr__1154[(int)1];
  int _1164 = natbarvarmap_alloc(_1162,_1163);
  std::shared_ptr< monty::ndarray< int,1 > > _1165 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1162)));
  _checked_ptr_1<int> _ptr__1165(_1165 ? _1165->raw() : nullptr,_1165 ? _1165->size(0) : 0);
  natbarvarmap_get(_1164,_1165);
  std::vector<int> _7026;
  for (int _1167 = (int)0, _7027 = (safe_mul( _1163,safe_add( _1163,(int)1 ) ) / (int)2); _1167 < _7027 ; ++_1167)
  {
    _7026.push_back(_1163);
  }
  auto _7028 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7026.size()),_7026.begin(),_7026.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1166 = _7028;
  _checked_ptr_1<int> _ptr__1166(_1166 ? _1166->raw() : nullptr,_1166 ? _1166->size(0) : 0);
  std::vector<long long> _7029;
  for (int _1169 = (int)0, _7030 = (safe_mul( _1163,safe_add( _1163,(int)1 ) ) / (int)2); _1169 < _7030 ; ++_1169)
  {
    _7029.push_back((int)1);
  }
  auto _7031 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7029.size()),_7029.begin(),_7029.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1168 = _7031;
  _checked_ptr_1<long long> _ptr__1168(_1168 ? _1168->raw() : nullptr,_1168 ? _1168->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1170 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1163,safe_add( _1163,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1170(_1170 ? _1170->raw() : nullptr,_1170 ? _1170->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1171 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1163,safe_add( _1163,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1171(_1171 ? _1171->raw() : nullptr,_1171 ? _1171->size(0) : 0);
  std::vector<double> _7032;
  for (int _1173 = (int)0, _7033 = (safe_mul( _1163,safe_add( _1163,(int)1 ) ) / (int)2); _1173 < _7033 ; ++_1173)
  {
    _7032.push_back((-1.0));
  }
  auto _7034 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7032.size()),_7032.begin(),_7032.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1172 = _7034;
  _checked_ptr_1<double> _ptr__1172(_1172 ? _1172->raw() : nullptr,_1172 ? _1172->size(0) : 0);
  {
    int _1174 = (int)0;
    int _7035 = (int)0;
    int _7036 = _1163;
    for (int _1175 = _7035; _1175 < _7036; ++_1175)
    {
      {
        int _7037 = (int)0;
        int _7038 = safe_add( _1175,(int)1 );
        for (int _1176 = _7037; _1176 < _7038; ++_1176)
        {
          {
            _ptr__1170[_1174] = _1175;
            _ptr__1171[_1174] = _1176;
            ++ _1174;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1177 = task_appendsymmatlist(_1166,_1168,_1170,_1171,_1172);
  _checked_ptr_1<long long> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1178 = _1153;
  _checked_ptr_1<int> _ptr__1178(_1178 ? _1178->raw() : nullptr,_1178 ? _1178->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1150)));
  _checked_ptr_1<int> _ptr__1179(_1179 ? _1179->raw() : nullptr,_1179 ? _1179->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1180 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1150)));
  _checked_ptr_1<long long> _ptr__1180(_1180 ? _1180->raw() : nullptr,_1180 ? _1180->size(0) : 0);
  {
    int _1181 = (int)0;
    if (_1132)
    {
      {
        int _7039 = (int)0;
        int _7040 = _ptr__1154[(int)0];
        for (int _1182 = _7039; _1182 < _7040; ++_1182)
        {
          {
            int _7041 = (int)0;
            int _7042 = _ptr__1154[(int)1];
            for (int _1183 = _7041; _1183 < _7042; ++_1183)
            {
              {
                int _7043 = (int)0;
                int _7044 = _ptr__1154[(int)2];
                for (int _1184 = _7043; _1184 < _7044; ++_1184)
                {
                  {
                    int _7045 = (int)0;
                    int _7046 = safe_add( _1183,(int)1 );
                    for (int _1185 = _7045; _1185 < _7046; ++_1185)
                    {
                      {
                        int _7047 = (int)0;
                        int _7048 = _ptr__1154[(int)4];
                        for (int _1186 = _7047; _1186 < _7048; ++_1186)
                        {
                          {
                            _ptr__1180[_1181] = _ptr__1177[safe_add( (safe_mul( _1183,safe_add( _1183,(int)1 ) ) / (int)2),_1185 )];
                            _ptr__1179[_1181] = _ptr__1165[safe_add( safe_mul( safe_add( safe_mul( _1182,_ptr__1154[(int)2] ),_1184 ),_ptr__1154[(int)4] ),_1186 )];
                            ((*natconmap_slackidx)(_ptr__1153[_1181])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1179[_1181])),(safe_mul( _1185,((safe_mul( (int)2,_ptr__1154[(int)1] ) - _1185) - (int)1) ) / (int)2) ),_1183 );
                            ++ _1181;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7049 = (int)0;
        int _7050 = _ptr__1154[(int)0];
        for (int _1187 = _7049; _1187 < _7050; ++_1187)
        {
          {
            int _7051 = (int)0;
            int _7052 = _ptr__1154[(int)1];
            for (int _1188 = _7051; _1188 < _7052; ++_1188)
            {
              {
                int _7053 = (int)0;
                int _7054 = _ptr__1154[(int)2];
                for (int _1189 = _7053; _1189 < _7054; ++_1189)
                {
                  {
                    int _7055 = _1188;
                    int _7056 = _ptr__1154[(int)1];
                    for (int _1190 = _7055; _1190 < _7056; ++_1190)
                    {
                      {
                        int _7057 = (int)0;
                        int _7058 = _ptr__1154[(int)4];
                        for (int _1191 = _7057; _1191 < _7058; ++_1191)
                        {
                          {
                            _ptr__1180[_1181] = _ptr__1177[safe_add( (safe_mul( _1190,safe_add( _1190,(int)1 ) ) / (int)2),_1188 )];
                            _ptr__1179[_1181] = _ptr__1165[safe_add( safe_mul( safe_add( safe_mul( _1187,_ptr__1154[(int)2] ),_1189 ),_ptr__1154[(int)4] ),_1191 )];
                            ((*natconmap_slackidx)(_ptr__1153[_1181])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1179[_1181])),(safe_mul( _1188,((safe_mul( (int)2,_ptr__1154[(int)1] ) - _1188) - (int)1) ) / (int)2) ),_1190 );
                            ++ _1181;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1178,_1179,_1180);
  ((*natconmap_type)(_1152)) = (-safe_add( _1164,(int)1 ));
  std::vector<long long> _7059;
  for (int _1193 = (int)0, _7060 = _1150; _1193 < _7060 ; ++_1193)
  {
    _7059.push_back(((*natconmap_slackidx)(_ptr__1153[_1193])));
  }
  auto _7061 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7059.size()),_7059.begin(),_7059.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1192 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1128,_1152,_1140,_1134,_1133,_7061,_1153);
  ((*cons)(_1152)) = (_1192).as<::mosek::fusion::ModelConstraint>();
  return (_1192).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1194,monty::rc_ptr< ::mosek::fusion::Expression > _1195,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1196){
  if ((((int)((_1194).size()) > (int)0) && hasConstraint(_1194)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1194)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1194).size()) > (int)0) && hasConstraint(_1194)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1194)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1197 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1195)).as<::mosek::fusion::Expression>());
  _1197->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1198 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1198(_1198 ? _1198->raw() : nullptr,_1198 ? _1198->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1199 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1199(_1199 ? _1199->raw() : nullptr,_1199 ? _1199->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1200 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1200(_1200 ? _1200->raw() : nullptr,_1200 ? _1200->size(0) : 0);
  int _1201 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1202 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1201)));
  _checked_ptr_1<int> _ptr__1202(_1202 ? _1202->raw() : nullptr,_1202 ? _1202->size(0) : 0);
  rs->popi32(_1201,_1202,(int)0);
  int _1203 = rs->popi32();
  int _1204 = rs->popi32();
  bool _1205 = (rs->popi32() != (int)0);
  int _1206 = rs->popi32(safe_add( _1203,(int)1 ));
  int _1207 = rs->popi64(_1204);
  int _1208 = rs->popf64(_1203);
  int _1209 = rs->popf64(_1204);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1196)->shape.get()) && (!::mosek::fusion::p_Set::match(_1202,mosek::fusion::p_LinPSDDomain::_get_impl(_1196)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1210 = (int)1;
  int _7062 = (int)0;
  int _7063 = _1201;
  for (int _1211 = _7062; _1211 < _7063; ++_1211)
  {
    {
      _1210 *= _ptr__1202[_1211];
    }
  }
  int _1212 = mosek::fusion::p_LinPSDDomain::_get_impl(_1196)->conedim;
  int _1213 = _ptr__1202[_1212];
  int _1214 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1213 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1214,safe_add( _1214,(int)1 ) ) / (int)2) != _1213))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1215 = (int)1;
  int _7064 = (int)0;
  int _7065 = _1212;
  for (int _1216 = _7064; _1216 < _7065; ++_1216)
  {
    {
      _1215 *= _ptr__1202[_1216];
    }
  }
  int _1217 = (int)1;
  int _7066 = safe_add( _1212,(int)1 );
  int _7067 = _1201;
  for (int _1218 = _7066; _1218 < _7067; ++_1218)
  {
    {
      _1217 *= _ptr__1202[_1218];
    }
  }
  int _1219 = safe_mul( _1215,_1217 );
  int _1220 = natconmap_alloc(_1210);
  std::shared_ptr< monty::ndarray< int,1 > > _1221 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1210)));
  _checked_ptr_1<int> _ptr__1221(_1221 ? _1221->raw() : nullptr,_1221 ? _1221->size(0) : 0);
  natconmap->get(_1220,_1221,(int)0);
  putarows(_1221,rs,_1203,_1204,_1206,_1207,_1209);
  int _1222 = natbarvarmap_alloc(_1219,_1214);
  std::shared_ptr< monty::ndarray< int,1 > > _1223 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1219)));
  _checked_ptr_1<int> _ptr__1223(_1223 ? _1223->raw() : nullptr,_1223 ? _1223->size(0) : 0);
  natbarvarmap_get(_1222,_1223);
  ((*barvars)(_1222)) = nullptr;
  int _1224 = safe_mul( safe_mul( _1213,_1215 ),_1217 );
  std::vector<int> _7068;
  for (int _1226 = (int)0, _7069 = _1213; _1226 < _7069 ; ++_1226)
  {
    _7068.push_back(_1226);
  }
  auto _7070 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7068.size()),_7068.begin(),_7068.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1225 = _7070;
  _checked_ptr_1<int> _ptr__1225(_1225 ? _1225->raw() : nullptr,_1225 ? _1225->size(0) : 0);
  std::vector<long long> _7071;
  for (int _1228 = (int)0, _7072 = _1213; _1228 < _7072 ; ++_1228)
  {
    _7071.push_back((int)1);
  }
  auto _7073 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7071.size()),_7071.begin(),_7071.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1227 = _7073;
  _checked_ptr_1<long long> _ptr__1227(_1227 ? _1227->raw() : nullptr,_1227 ? _1227->size(0) : 0);
  std::vector<double> _7074;
  for (int _1230 = (int)0, _7075 = _1213; _1230 < _7075 ; ++_1230)
  {
    _7074.push_back((-1.0));
  }
  auto _7076 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7074.size()),_7074.begin(),_7074.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1229 = _7076;
  _checked_ptr_1<double> _ptr__1229(_1229 ? _1229->raw() : nullptr,_1229 ? _1229->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1231 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1213)));
  _checked_ptr_1<int> _ptr__1231(_1231 ? _1231->raw() : nullptr,_1231 ? _1231->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1213)));
  _checked_ptr_1<int> _ptr__1232(_1232 ? _1232->raw() : nullptr,_1232 ? _1232->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1233 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1224)));
  _checked_ptr_1<int> _ptr__1233(_1233 ? _1233->raw() : nullptr,_1233 ? _1233->size(0) : 0);
  {
    int _1234 = (int)0;
    int _7077 = (int)0;
    int _7078 = _1215;
    for (int _1235 = _7077; _1235 < _7078; ++_1235)
    {
      {
        int _7079 = (int)0;
        int _7080 = _1214;
        for (int _1236 = _7079; _1236 < _7080; ++_1236)
        {
          {
            int _7081 = (int)0;
            int _7082 = safe_add( _1236,(int)1 );
            for (int _1237 = _7081; _1237 < _7082; ++_1237)
            {
              {
                int _7083 = (int)0;
                int _7084 = _1217;
                for (int _1238 = _7083; _1238 < _7084; ++_1238)
                {
                  {
                    _ptr__1233[_1234] = safe_add( safe_mul( _1235,_1217 ),_1238 );
                    _ptr__1231[_1234] = _1236;
                    _ptr__1232[_1234] = _1237;
                    ++ _1234;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1220)) = (-safe_add( _1222,(int)1 ));
    int _7085 = (int)0;
    int _7086 = _1210;
    for (int _1239 = _7085; _1239 < _7086; ++_1239)
    {
      {
        ((*natconmap_blockid)(_ptr__1221[_1239])) = _1220;
        ((*natconmap_idx)(_ptr__1221[_1239])) = _1239;
        ((*natconmap_efix)(_ptr__1221[_1239])) = _ptr__1200[safe_add( _1208,_1239 )];
        ((*natconmap_lb)(_ptr__1221[_1239])) = (int)0;
        ((*natconmap_ub)(_ptr__1221[_1239])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1240 = task_appendsymmatlist(_1225,_1227,_1231,_1232,_1229);
  _checked_ptr_1<long long> _ptr__1240(_1240 ? _1240->raw() : nullptr,_1240 ? _1240->size(0) : 0);
  task_putbaraijlist(_1221,_1233,_1240);
  std::vector<double> _7087;
  for (int _1242 = (int)0, _7088 = _1210; _1242 < _7088 ; ++_1242)
  {
    _7087.push_back((-_ptr__1200[safe_add( _1208,_1242 )]));
  }
  auto _7089 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7087.size()),_7087.begin(),_7087.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1241 = _7089;
  _checked_ptr_1<double> _ptr__1241(_1241 ? _1241->raw() : nullptr,_1241 ? _1241->size(0) : 0);
  task_con_putboundlist_fx(_1221,_1241);
  std::vector<long long> _7090;
  for (int _1244 = (int)0, _7091 = _1210; _1244 < _7091 ; ++_1244)
  {
    _7090.push_back(((*natconmap_slackidx)(_ptr__1221[_1244])));
  }
  auto _7092 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7090.size()),_7090.begin(),_7090.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1243 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1194,_1220,_1202,_1212,_1221,_7092);
  ((*cons)(_1220)) = (_1243).as<::mosek::fusion::ModelConstraint>();
  return (_1243).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1245,monty::rc_ptr< ::mosek::fusion::Expression > _1246,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1247){
  if ((((int)((_1245).size()) > (int)0) && hasConstraint(_1245)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1245)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1245).size()) > (int)0) && hasConstraint(_1245)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1245)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1248 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1246)).as<::mosek::fusion::Expression>());
  _1248->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1249 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1249(_1249 ? _1249->raw() : nullptr,_1249 ? _1249->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1250 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1250(_1250 ? _1250->raw() : nullptr,_1250 ? _1250->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1251 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1251(_1251 ? _1251->raw() : nullptr,_1251 ? _1251->size(0) : 0);
  int _1252 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1253 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1254 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1255 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1256 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1257 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1258 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1259 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1260 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7093;
  for (int _1262 = (int)0, _7094 = _1252; _1262 < _7094 ; ++_1262)
  {
    _7093.push_back(_ptr__1249[safe_add( _1253,_1262 )]);
  }
  auto _7095 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7093.size()),_7093.begin(),_7093.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1261 = _7095;
  _checked_ptr_1<int> _ptr__1261(_1261 ? _1261->raw() : nullptr,_1261 ? _1261->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1247)->shape.get()) && (!::mosek::fusion::p_Set::match(_1261,mosek::fusion::p_ConeDomain::_get_impl(_1247)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7096;
  bool _7097 = _1247->axisIsSet();
  if (_7097)
  {
    _7096 = _1247->getAxis();
  }
  else
  {
    _7096 = (_1252 - (int)1);
  }
  int _1263 = _7096;
  int _1264 = _ptr__1261[_1263];
  int _1265 = (int)1;
  int _1266 = (int)1;
  int _1267 = (int)1;
  {
    int _7098 = (int)0;
    int _7099 = _1252;
    for (int _1268 = _7098; _1268 < _7099; ++_1268)
    {
      {
        _1267 *= _ptr__1261[_1268];
      }
    }
    int _7100 = (int)0;
    int _7101 = _1263;
    for (int _1269 = _7100; _1269 < _7101; ++_1269)
    {
      {
        _1266 *= _ptr__1261[_1269];
      }
    }
    int _7102 = safe_add( _1263,(int)1 );
    int _7103 = _1252;
    for (int _1270 = _7102; _1270 < _7103; ++_1270)
    {
      {
        _1265 *= _ptr__1261[_1270];
      }
    }
  }
  int _1271 = safe_mul( _1266,_1265 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InQCone) && (_1264 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1264 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1264 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1264 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1264 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1264 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1264)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1272 = natvarmap_alloc(_1267);
  std::shared_ptr< monty::ndarray< int,1 > > _1273 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1267)));
  _checked_ptr_1<int> _ptr__1273(_1273 ? _1273->raw() : nullptr,_1273 ? _1273->size(0) : 0);
  natvarmap->get(_1272,_1273,(int)0);
  int _1274 = natconemap_alloc(_1271);
  int _7104 = (int)0;
  int _7105 = _1267;
  for (int _1275 = _7104; _1275 < _7105; ++_1275)
  {
    {
      ((*natvarmap_idx)(_ptr__1273[_1275])) = _1272;
    }
  }
  task_var_putboundlist_fr(_1273);
  std::shared_ptr< monty::ndarray< int,1 > > _7106;
  bool _7107 = (_1263 < ((int)((_1261)->size(0)) - (int)1));
  if (_7107)
  {
    _7106 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1273)->size(0)))));
  }
  else
  {
    _7106 = _1273;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1276 = _7106;
  _checked_ptr_1<int> _ptr__1276(_1276 ? _1276->raw() : nullptr,_1276 ? _1276->size(0) : 0);
  if ((_1263 < ((int)((_1261)->size(0)) - (int)1)))
  {
    {
      int _1277 = (int)0;
      int _7108 = (int)0;
      int _7109 = _1266;
      for (int _1278 = _7108; _1278 < _7109; ++_1278)
      {
        {
          int _7110 = (int)0;
          int _7111 = _1265;
          for (int _1279 = _7110; _1279 < _7111; ++_1279)
          {
            {
              int _7112 = (int)0;
              int _7113 = _1264;
              for (int _1280 = _7112; _1280 < _7113; ++_1280)
              {
                {
                  _ptr__1276[_1277] = _ptr__1273[safe_add( safe_mul( safe_add( safe_mul( _1278,_1264 ),_1280 ),_1265 ),_1279 )];
                  ++ _1277;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1281 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1271)));
  _checked_ptr_1<int> _ptr__1281(_1281 ? _1281->raw() : nullptr,_1281 ? _1281->size(0) : 0);
  natconemap->get(_1274,_1281,(int)0);
  ((*natconemap_dim)(_1274)) = _1264;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1281,_1264,_1271,_1276);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1281,_1264,_1271,_1276);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1281,_1264,_1271,_1276);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7114;
      for (int _1282 = (int)0, _7115 = _1271; _1282 < _7115 ; ++_1282)
      {
        _7114.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1247)->alpha);
      }
      auto _7116 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7114.size()),_7114.begin(),_7114.end()));
      task_put_ppowcones(_1281,_1264,_1271,_1276,_7116);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1281,_1264,_1271,_1276);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1247)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7117;
      for (int _1283 = (int)0, _7118 = _1271; _1283 < _7118 ; ++_1283)
      {
        _7117.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1247)->alpha);
      }
      auto _7119 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7117.size()),_7117.begin(),_7117.end()));
      task_put_dpowcones(_1281,_1264,_1271,_1276,_7119);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1272)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1284 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1267)));
  _checked_ptr_1<double> _ptr__1284(_1284 ? _1284->raw() : nullptr,_1284 ? _1284->size(0) : 0);
  int _1285 = natconmap_alloc(_1267);
  std::shared_ptr< monty::ndarray< int,1 > > _1286 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1267)));
  _checked_ptr_1<int> _ptr__1286(_1286 ? _1286->raw() : nullptr,_1286 ? _1286->size(0) : 0);
  natconmap->get(_1285,_1286,(int)0);
  ((*natconmap_type)(_1285)) = safe_add( _1272,(int)6 );
  {
    int _7120 = (int)0;
    int _7121 = _1267;
    for (int _1287 = _7120; _1287 < _7121; ++_1287)
    {
      {
        ((*natconmap_efix)(_ptr__1286[_1287])) = _ptr__1251[safe_add( _1259,_1287 )];
      }
    }
    int _7122 = (int)0;
    int _7123 = _1267;
    for (int _1288 = _7122; _1288 < _7123; ++_1288)
    {
      {
        ((*natconmap_lb)(_ptr__1286[_1288])) = (int)0;
      }
    }
    int _7124 = (int)0;
    int _7125 = _1267;
    for (int _1289 = _7124; _1289 < _7125; ++_1289)
    {
      {
        ((*natconmap_ub)(_ptr__1286[_1289])) = (int)0;
      }
    }
    int _7126 = (int)0;
    int _7127 = _1267;
    for (int _1290 = _7126; _1290 < _7127; ++_1290)
    {
      {
        _ptr__1284[_1290] = (-_ptr__1251[safe_add( _1259,_1290 )]);
      }
    }
    int _7128 = (int)0;
    int _7129 = _1267;
    for (int _1291 = _7128; _1291 < _7129; ++_1291)
    {
      {
        ((*natconmap_slackidx)(_ptr__1286[_1291])) = safe_add( _ptr__1273[_1291],(int)1 );
      }
    }
    int _7130 = (int)0;
    int _7131 = _1267;
    for (int _1292 = _7130; _1292 < _7131; ++_1292)
    {
      {
        ((*natconmap_blockid)(_ptr__1286[_1292])) = _1285;
      }
    }
    int _7132 = (int)0;
    int _7133 = _1267;
    for (int _1293 = _7132; _1293 < _7133; ++_1293)
    {
      {
        ((*natconmap_idx)(_ptr__1286[_1293])) = _1293;
      }
    }
  }
  putarows(_1286,rs,_1254,_1255,_1257,_1258,_1260);
  task_con_putboundlist_fx(_1286,_1284);
  std::vector<double> _7134;
  for (int _1294 = (int)0, _7135 = (int)((_1286)->size(0)); _1294 < _7135 ; ++_1294)
  {
    _7134.push_back((-1.0));
  }
  auto _7136 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7134.size()),_7134.begin(),_7134.end()));
  task_putaijlist(_1286,_1273,_7136,(long long)((int)((_1286)->size(0))));
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1295 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1245,_1247,_1261,_1285,_1286,_1273);
  ((*cons)(_1285)) = (_1295).as<::mosek::fusion::ModelConstraint>();
  return (_1295).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1296,monty::rc_ptr< ::mosek::fusion::Expression > _1297,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1298){
  if ((((int)((_1296).size()) > (int)0) && hasConstraint(_1296)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1296)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1299 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1297)).as<::mosek::fusion::Expression>());
  _1299->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1300 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1300(_1300 ? _1300->raw() : nullptr,_1300 ? _1300->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1301 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1301(_1301 ? _1301->raw() : nullptr,_1301 ? _1301->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1302 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1302(_1302 ? _1302->raw() : nullptr,_1302 ? _1302->size(0) : 0);
  int _1303 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1304 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1305 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1306 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1307 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1308 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1309 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1310 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1311 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7137;
  for (int _1313 = (int)0, _7138 = _1303; _1313 < _7138 ; ++_1313)
  {
    _7137.push_back(_ptr__1300[safe_add( _1304,_1313 )]);
  }
  auto _7139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7137.size()),_7137.begin(),_7137.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1312 = _7139;
  _checked_ptr_1<int> _ptr__1312(_1312 ? _1312->raw() : nullptr,_1312 ? _1312->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1298)->shape.get()) && (!::mosek::fusion::p_Set::match(_1312,mosek::fusion::p_LinearDomain::_get_impl(_1298)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1314 = (int)1;
  int _7140 = (int)0;
  int _7141 = _1303;
  for (int _1315 = _7140; _1315 < _7141; ++_1315)
  {
    {
      _1314 *= _ptr__1312[_1315];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1316;
  _checked_ptr_1<double> _ptr__1316(_1316 ? _1316->raw() : nullptr,_1316 ? _1316->size(0) : 0);
  int _1317 = natconmap_alloc(_1314);
  std::shared_ptr< monty::ndarray< int,1 > > _1318 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1314)));
  _checked_ptr_1<int> _ptr__1318(_1318 ? _1318->raw() : nullptr,_1318 ? _1318->size(0) : 0);
  natconmap->get(_1317,_1318,(int)0);
  putarows(_1318,rs,_1305,_1306,_1308,_1309,_1311);
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1319 = mosek::fusion::p_LinearDomain::_get_impl(_1298)->sparsity;
    std::shared_ptr< monty::ndarray< double,1 > > _1320 = mosek::fusion::p_LinearDomain::_get_impl(_1298)->bnd;
    _checked_ptr_1<double> _ptr__1320(_1320 ? _1320->raw() : nullptr,_1320 ? _1320->size(0) : 0);
    bool _1321 = mosek::fusion::p_LinearDomain::_get_impl(_1298)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1322 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1322(_1322 ? _1322->raw() : nullptr,_1322 ? _1322->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1323 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1323(_1323 ? _1323->raw() : nullptr,_1323 ? _1323->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1324 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1324(_1324 ? _1324->raw() : nullptr,_1324 ? _1324->size(0) : 0);
    {
      int _7142 = (int)0;
      int _7143 = _1305;
      for (int _1325 = _7142; _1325 < _7143; ++_1325)
      {
        {
          _ptr__1322[_ptr__1318[_1325]] = _ptr__1302[safe_add( _1310,_1325 )];
        }
      }
      if ((NULL == _1320.get()))
      {
        {
          int _7144 = (int)0;
          int _7145 = _1305;
          for (int _1326 = _7144; _1326 < _7145; ++_1326)
          {
            {
              _ptr__1323[_ptr__1318[_1326]] = (int)0;
              _ptr__1324[_ptr__1318[_1326]] = (int)0;
            }
          }
        }
      }
      else if(_1321)
      {
        {
          int _7146 = (int)0;
          int _7147 = _1305;
          for (int _1327 = _7146; _1327 < _7147; ++_1327)
          {
            {
              _ptr__1323[_ptr__1318[_1327]] = _ptr__1320[(int)0];
              _ptr__1324[_ptr__1318[_1327]] = _ptr__1320[(int)0];
            }
          }
        }
      }
      else if((NULL != _1319.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1328 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1303)));
          _checked_ptr_1<int> _ptr__1328(_1328 ? _1328->raw() : nullptr,_1328 ? _1328->size(0) : 0);
          _ptr__1328[(_1303 - (int)1)] = (int)1;
          int _7148 = (int)1;
          int _7149 = _1303;
          for (int _1329 = _7148; _1329 < _7149; ++_1329)
          {
            {
              _ptr__1328[((_1303 - _1329) - (int)1)] = safe_mul( _ptr__1328[(_1303 - _1329)],_ptr__1312[(_1303 - _1329)] );
            }
          }
          int _7150 = (int)0;
          int _7151 = (int)((_1319)->size(0));
          for (int _1330 = _7150; _1330 < _7151; ++_1330)
          {
            {
              int _1331 = (int)0;
              int _7152 = (int)0;
              int _7153 = _1303;
              for (int _1332 = _7152; _1332 < _7153; ++_1332)
              {
                {
                  _1331 += safe_mul( _ptr__1328[_1332],((*_1319)(_1330,_1332)) );
                }
              }
              _ptr__1323[_ptr__1318[_1331]] = _ptr__1320[_1330];
              _ptr__1324[_ptr__1318[_1331]] = _ptr__1320[_1330];
            }
          }
        }
      }
      else
      {
        {
          int _7154 = (int)0;
          int _7155 = _1305;
          for (int _1333 = _7154; _1333 < _7155; ++_1333)
          {
            {
              _ptr__1323[_ptr__1318[_1333]] = _ptr__1320[_1333];
              _ptr__1324[_ptr__1318[_1333]] = _ptr__1320[_1333];
            }
          }
        }
      }
    }
    std::vector<double> _7156;
    for (int _1334 = (int)0, _7157 = (int)((_1318)->size(0)); _1334 < _7157 ; ++_1334)
    {
      _7156.push_back((_ptr__1323[_ptr__1318[_1334]] - _ptr__1322[_ptr__1318[_1334]]));
    }
    auto _7158 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7156.size()),_7156.begin(),_7156.end()));
    _1316 = _7158;
    _ptr__1316.update(_1316 ? _1316->raw() : nullptr, _1316 ? _1316->size(0) : 0);
  }
  int _7159 = (int)0;
  int _7160 = _1314;
  for (int _1335 = _7159; _1335 < _7160; ++_1335)
  {
    {
      ((*natconmap_idx)(_ptr__1318[_1335])) = _1317;
      ((*natconmap_slackidx)(_ptr__1318[_1335])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1298)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1317)) = (int)1;
      task_con_putboundlist_fr(_1318);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1298)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1317)) = (int)3;
      task_con_putboundlist_up(_1318,_1316);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1298)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1317)) = (int)2;
      task_con_putboundlist_lo(_1318,_1316);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1298)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1317)) = (int)5;
      task_con_putboundlist_fx(_1318,_1316);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1336 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1296,_1317,_1312,_1318);
  ((*cons)(_1317)) = (_1336).as<::mosek::fusion::ModelConstraint>();
  return (_1336).as<::mosek::fusion::Constraint>();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1337) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1337); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1337){
  return con_map->hasItem(_1337);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1338) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1338); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1338){
  return var_map->hasItem(_1338);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1339) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1339); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1339) { return __mosek_2fusion_2Model__getConstraint(_1339); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1339){
  return (((*cons)(_1339))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1340) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1340); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1340) { return __mosek_2fusion_2Model__getConstraint(_1340); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1340){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7161;
  bool _7162 = con_map->hasItem(_1340);
  if (_7162)
  {
    _7161 = ((*cons)(con_map->getItem(_1340)));
  }
  else
  {
    _7161 = nullptr;
  }
  return (_7161).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1341) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1341); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1341) { return __mosek_2fusion_2Model__getVariable(_1341); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1341){
  return (((*vars)(_1341))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1342) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1342); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1342) { return __mosek_2fusion_2Model__getVariable(_1342); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1342){
  if (var_map->hasItem(_1342))
  {
    {
      int _1343 = var_map->getItem(_1342);
      if ((_1343 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1343,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1343))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1344,    std::shared_ptr< monty::ndarray< int,1 > > _1345,    std::shared_ptr< monty::ndarray< long long,1 > > _1346,    std::shared_ptr< monty::ndarray< long long,1 > > _1347){ return new mosek::fusion::SliceVariable(_1344,_1345,_1346,_1347); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1344,    std::shared_ptr< monty::ndarray< int,1 > > _1345,    std::shared_ptr< monty::ndarray< long long,1 > > _1346,    std::shared_ptr< monty::ndarray< long long,1 > > _1347) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1344,_1345,_1346,_1347); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1344,    std::shared_ptr< monty::ndarray< int,1 > > _1345,    std::shared_ptr< monty::ndarray< long long,1 > > _1346,    std::shared_ptr< monty::ndarray< long long,1 > > _1347){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1345(_1345 ? _1345->raw() : nullptr, _1345 ? _1345->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1346(_1346 ? _1346->raw() : nullptr, _1346 ? _1346->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1347(_1347 ? _1347->raw() : nullptr, _1347 ? _1347->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1344,_1345,_1346,_1347);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1347;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1346;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1345;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1348,    monty::rc_ptr< ::mosek::fusion::Model > _1349){ return new mosek::fusion::SymRangedVariable(_1348,_1349); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1348,    monty::rc_ptr< ::mosek::fusion::Model > _1349) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1348,_1349); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1348,    monty::rc_ptr< ::mosek::fusion::Model > _1349){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1348,_1349);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1348)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1348)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1348)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1348)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1348)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1350,    const std::string &  _1351,    long long _1352,    int _1353,    std::shared_ptr< monty::ndarray< long long,1 > > _1354,    std::shared_ptr< monty::ndarray< int,1 > > _1355){ return new mosek::fusion::SymRangedVariable(_1350,_1351,_1352,_1353,_1354,_1355); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1350,    const std::string &  _1351,    long long _1352,    int _1353,    std::shared_ptr< monty::ndarray< long long,1 > > _1354,    std::shared_ptr< monty::ndarray< int,1 > > _1355) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1350,_1351,_1352,_1353,_1354,_1355); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1350,    const std::string &  _1351,    long long _1352,    int _1353,    std::shared_ptr< monty::ndarray< long long,1 > > _1354,    std::shared_ptr< monty::ndarray< int,1 > > _1355){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1354(_1354 ? _1354->raw() : nullptr, _1354 ? _1354->size(0) : 0);
    _checked_ptr_1<int> _ptr__1355(_1355 ? _1355->raw() : nullptr, _1355 ? _1355->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1350,_1351,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1353),(int)(_1353)}),_1352,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1353,_1354),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1353,_1354,_1355));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1351;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1355;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1354;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1353;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1356,std::shared_ptr< monty::ndarray< double,1 > > _1357){
  _checked_ptr_1<double> _ptr__1357(_1357 ? _1357->raw() : nullptr, _1357 ? _1357->size(0) : 0);
  dual_lu(_1356,_1357,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1358,std::shared_ptr< monty::ndarray< double,1 > > _1359){
  _checked_ptr_1<double> _ptr__1359(_1359 ? _1359->raw() : nullptr, _1359 ? _1359->size(0) : 0);
  dual_lu(_1358,_1359,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1360 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7163 = (int)0;
          int _7164 = (int)((nativeidxs)->size(0));
          for (int _1361 = _7163; _1361 < _7164; ++_1361)
          {
            {
              std::string _7165;
              bool _7166 = ((int)((name).size()) == (int)0);
              if (_7166)
              {
                _7165 = std::string ("");
              }
              else
              {
                _7165 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1361 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1361 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1360.get())->varname(((*nativeidxs)(_1361)),_7165);
            }
          }
        }
      }
      else
      {
        {
          int _7167 = (int)0;
          int _7168 = (int)((sparsity)->size(0));
          for (int _1362 = _7167; _1362 < _7168; ++_1362)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1360.get())->varname(((*nativeidxs)(_1362)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1362)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1362)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1363){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1363)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1364,std::shared_ptr< monty::ndarray< long long,1 > > _1365,std::shared_ptr< monty::ndarray< int,1 > > _1366){
  _checked_ptr_1<long long> _ptr__1365(_1365 ? _1365->raw() : nullptr, _1365 ? _1365->size(0) : 0);
  _checked_ptr_1<int> _ptr__1366(_1366 ? _1366->raw() : nullptr, _1366 ? _1366->size(0) : 0);
  if ((NULL == _1365.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1367 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1364,_1364 ))));
      _checked_ptr_1<long long> _ptr__1367(_1367 ? _1367->raw() : nullptr,_1367 ? _1367->size(0) : 0);
      int _1368 = (int)0;
      {
        int _7169 = (int)0;
        int _7170 = _1364;
        for (int _1369 = _7169; _1369 < _7170; ++_1369)
        {
          {
            _ptr__1367[safe_add( safe_mul( _1369,_1364 ),_1369 )] = safe_add( _ptr__1366[_1368],(int)1 );
            ++ _1368;
            int _7171 = safe_add( _1369,(int)1 );
            int _7172 = _1364;
            for (int _1370 = _7171; _1370 < _7172; ++_1370)
            {
              {
                _ptr__1367[safe_add( safe_mul( _1369,_1364 ),_1370 )] = safe_add( _ptr__1366[_1368],(int)1 );
                _ptr__1367[safe_add( safe_mul( _1370,_1364 ),_1369 )] = safe_add( _ptr__1366[_1368],(int)1 );
                ++ _1368;
              }
            }
          }
        }
      }
      return _1367;
    }
  }
  else
  {
    {
      int _1371 = (int)0;
      {
        int _7173 = (int)0;
        int _7174 = (int)((_1365)->size(0));
        for (int _1372 = _7173; _1372 < _7174; ++_1372)
        {
          {
            int _7175;
            bool _7176 = ((_ptr__1365[_1372] % safe_add( _1364,(int)1 )) == (int)0);
            if (_7176)
            {
              _7175 = (int)1;
            }
            else
            {
              _7175 = (int)2;
            }
            _1371 += _7175;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1373 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1371)));
      _checked_ptr_1<long long> _ptr__1373(_1373 ? _1373->raw() : nullptr,_1373 ? _1373->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1371)));
      _checked_ptr_1<long long> _ptr__1374(_1374 ? _1374->raw() : nullptr,_1374 ? _1374->size(0) : 0);
      {
        int _1375 = (int)0;
        int _7177 = (int)0;
        int _7178 = (int)((_1365)->size(0));
        for (int _1376 = _7177; _1376 < _7178; ++_1376)
        {
          {
            long long _1377 = (_ptr__1365[_1376] / _1364);
            long long _1378 = (_ptr__1365[_1376] % _1364);
            _ptr__1373[_1375] = _ptr__1365[_1376];
            _ptr__1374[_1375] = safe_add( _ptr__1366[_1376],(int)1 );
            ++ _1375;
            if ((_1377 != _1378))
            {
              {
                _ptr__1373[_1375] = safe_add( safe_mul( _1378,_1364 ),_1377 );
                _ptr__1374[_1375] = safe_add( _ptr__1366[_1376],(int)1 );
                ++ _1375;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7179;
      for (int _1380 = (int)0, _7180 = _1371; _1380 < _7180 ; ++_1380)
      {
        _7179.push_back(_1380);
      }
      auto _7181 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7179.size()),_7179.begin(),_7179.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1379 = _7181;
      _checked_ptr_1<long long> _ptr__1379(_1379 ? _1379->raw() : nullptr,_1379 ? _1379->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1379,_1373,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1371));
      std::vector<long long> _7182;
      for (int _1381 = (int)0, _7183 = _1371; _1381 < _7183 ; ++_1381)
      {
        _7182.push_back(_ptr__1374[_ptr__1379[_1381]]);
      }
      auto _7184 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7182.size()),_7182.begin(),_7182.end()));
      return _7184;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1382,std::shared_ptr< monty::ndarray< long long,1 > > _1383){
  _checked_ptr_1<long long> _ptr__1383(_1383 ? _1383->raw() : nullptr, _1383 ? _1383->size(0) : 0);
  if ((NULL == _1383.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1384 = (int)0;
      {
        int _7185 = (int)0;
        int _7186 = (int)((_1383)->size(0));
        for (int _1385 = _7185; _1385 < _7186; ++_1385)
        {
          {
            int _7187;
            bool _7188 = ((_ptr__1383[_1385] % safe_add( _1382,(int)1 )) == (int)0);
            if (_7188)
            {
              _7187 = (int)1;
            }
            else
            {
              _7187 = (int)2;
            }
            _1384 += _7187;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1386 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1384)));
      _checked_ptr_1<long long> _ptr__1386(_1386 ? _1386->raw() : nullptr,_1386 ? _1386->size(0) : 0);
      {
        int _1387 = (int)0;
        int _7189 = (int)0;
        int _7190 = (int)((_1383)->size(0));
        for (int _1388 = _7189; _1388 < _7190; ++_1388)
        {
          {
            long long _1389 = (_ptr__1383[_1388] / _1382);
            long long _1390 = (_ptr__1383[_1388] % _1382);
            _ptr__1386[_1387] = _ptr__1383[_1388];
            ++ _1387;
            if ((_1389 != _1390))
            {
              {
                _ptr__1386[_1387] = safe_add( safe_mul( _1390,_1382 ),_1389 );
                ++ _1387;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7191;
      for (int _1392 = (int)0, _7192 = _1384; _1392 < _7192 ; ++_1392)
      {
        _7191.push_back(_1392);
      }
      auto _7193 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7191.size()),_7191.begin(),_7191.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1391 = _7193;
      _checked_ptr_1<long long> _ptr__1391(_1391 ? _1391->raw() : nullptr,_1391 ? _1391->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1391,_1386,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1384));
      std::vector<long long> _7194;
      for (int _1393 = (int)0, _7195 = _1384; _1393 < _7195 ; ++_1393)
      {
        _7194.push_back(_ptr__1386[_ptr__1391[_1393]]);
      }
      auto _7196 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7194.size()),_7194.begin(),_7194.end()));
      return _7196;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1394,    monty::rc_ptr< ::mosek::fusion::Model > _1395){ return new mosek::fusion::RangedVariable(_1394,_1395); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1394,    monty::rc_ptr< ::mosek::fusion::Model > _1395) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1394,_1395); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1394,    monty::rc_ptr< ::mosek::fusion::Model > _1395){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1394,_1395);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1394)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1394)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1394)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1394)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1394)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1396,    const std::string &  _1397,    long long _1398,    std::shared_ptr< monty::ndarray< int,1 > > _1399,    std::shared_ptr< monty::ndarray< long long,1 > > _1400,    std::shared_ptr< monty::ndarray< int,1 > > _1401){ return new mosek::fusion::RangedVariable(_1396,_1397,_1398,_1399,_1400,_1401); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1396,    const std::string &  _1397,    long long _1398,    std::shared_ptr< monty::ndarray< int,1 > > _1399,    std::shared_ptr< monty::ndarray< long long,1 > > _1400,    std::shared_ptr< monty::ndarray< int,1 > > _1401) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1396,_1397,_1398,_1399,_1400,_1401); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1396,    const std::string &  _1397,    long long _1398,    std::shared_ptr< monty::ndarray< int,1 > > _1399,    std::shared_ptr< monty::ndarray< long long,1 > > _1400,    std::shared_ptr< monty::ndarray< int,1 > > _1401){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1399(_1399 ? _1399->raw() : nullptr, _1399 ? _1399->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1400(_1400 ? _1400->raw() : nullptr, _1400 ? _1400->size(0) : 0);
    _checked_ptr_1<int> _ptr__1401(_1401 ? _1401->raw() : nullptr, _1401 ? _1401->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1396,_1397,_1399,_1398,_1400,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1401));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1401;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1400;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1397;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1399;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1402,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1403) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1402,_1403); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1402,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1403) { return __mosek_2fusion_2RangedVariable__elementDesc(_1402,_1403); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1402,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1403){
  _pubthis->elementName(_1402,_1403);
  _1403->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1403;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1404 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1405 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1405->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1405->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7197 = (int)1;
          int _7198 = _pubthis->getND();
          for (int _1406 = _7197; _1406 < _7198; ++_1406)
          {
            {
              _1405->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1406);
            }
          }
        }
      }
      {}
      _1405->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1404.get())->varnames(nativeidxs,_1405->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1407,std::shared_ptr< monty::ndarray< double,1 > > _1408){
  _checked_ptr_1<double> _ptr__1408(_1408 ? _1408->raw() : nullptr, _1408 ? _1408->size(0) : 0);
  dual_lu(_1407,_1408,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1409,std::shared_ptr< monty::ndarray< double,1 > > _1410){
  _checked_ptr_1<double> _ptr__1410(_1410 ? _1410->raw() : nullptr, _1410 ? _1410->size(0) : 0);
  dual_lu(_1409,_1410,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1411){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1411)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1412){
  _checked_ptr_1<int> _ptr__1412(_1412 ? _1412->raw() : nullptr, _1412 ? _1412->size(0) : 0);
  std::vector<long long> _7199;
  for (int _1413 = (int)0, _7200 = (int)((_1412)->size(0)); _1413 < _7200 ; ++_1413)
  {
    _7199.push_back(safe_add( _ptr__1412[_1413],(int)1 ));
  }
  auto _7201 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7199.size()),_7199.begin(),_7199.end()));
  return _7201;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415){ return new mosek::fusion::LinearPSDVariable(_1414,_1415); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1414,_1415); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1414,_1415);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1414)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1414)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1414)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1414)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1414)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    int _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    int _1420,    std::shared_ptr< monty::ndarray< long long,1 > > _1421){ return new mosek::fusion::LinearPSDVariable(_1416,_1417,_1418,_1419,_1420,_1421); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    int _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    int _1420,    std::shared_ptr< monty::ndarray< long long,1 > > _1421) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1416,_1417,_1418,_1419,_1420,_1421); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    int _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    int _1420,    std::shared_ptr< monty::ndarray< long long,1 > > _1421){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1419(_1419 ? _1419->raw() : nullptr, _1419 ? _1419->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1421(_1421 ? _1421->raw() : nullptr, _1421 ? _1421->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1416,_1417,_1419,_1418,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1421));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1417;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1420;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1418;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1419;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1421;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1422 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1422->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1422->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1422->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7202 = (int)1;
  int _7203 = (int)((shape)->size(0));
  for (int _1423 = _7202; _1423 < _7203; ++_1423)
  {
    {
      _1422->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1423)));
    }
  }
  _1422->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1422->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1424) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1424); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1424){
  _checked_ptr_1<long long> _ptr__1424(_1424 ? _1424->raw() : nullptr, _1424 ? _1424->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1425) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1425); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1425){
  _checked_ptr_1<long long> _ptr__1425(_1425 ? _1425->raw() : nullptr, _1425 ? _1425->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1426){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1426)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1427){
  _checked_ptr_1<long long> _ptr__1427(_1427 ? _1427->raw() : nullptr, _1427 ? _1427->size(0) : 0);
  std::vector<long long> _7204;
  for (int _1428 = (int)0, _7205 = (int)((_1427)->size(0)); _1428 < _7205 ; ++_1428)
  {
    _7204.push_back((-safe_add( _ptr__1427[_1428],(int)1 )));
  }
  auto _7206 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7204.size()),_7204.begin(),_7204.end()));
  return _7206;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1429,    monty::rc_ptr< ::mosek::fusion::Model > _1430){ return new mosek::fusion::PSDVariable(_1429,_1430); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1429,    monty::rc_ptr< ::mosek::fusion::Model > _1430) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1429,_1430); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1429,    monty::rc_ptr< ::mosek::fusion::Model > _1430){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1429,_1430);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1429)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1429)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1429)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1429)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1429)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1429)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1431,    const std::string &  _1432,    int _1433,    std::shared_ptr< monty::ndarray< int,1 > > _1434,    int _1435,    int _1436,    std::shared_ptr< monty::ndarray< long long,1 > > _1437){ return new mosek::fusion::PSDVariable(_1431,_1432,_1433,_1434,_1435,_1436,_1437); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1431,    const std::string &  _1432,    int _1433,    std::shared_ptr< monty::ndarray< int,1 > > _1434,    int _1435,    int _1436,    std::shared_ptr< monty::ndarray< long long,1 > > _1437) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1431,_1432,_1433,_1434,_1435,_1436,_1437); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1431,    const std::string &  _1432,    int _1433,    std::shared_ptr< monty::ndarray< int,1 > > _1434,    int _1435,    int _1436,    std::shared_ptr< monty::ndarray< long long,1 > > _1437){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1434(_1434 ? _1434->raw() : nullptr, _1434 ? _1434->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1437(_1437 ? _1437->raw() : nullptr, _1437 ? _1437->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1431,_1432,_1434,_1433,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1434,_1435,_1436,_1437));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1433;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1437;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1432;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1434;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1435;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1436;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1438 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1438->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1438->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1438->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7207 = (int)1;
  int _7208 = (int)((shape)->size(0));
  for (int _1439 = _7207; _1439 < _7208; ++_1439)
  {
    {
      _1438->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1439)));
    }
  }
  _1438->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1438->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1440,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1441) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1440,_1441); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1440,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1441) { return __mosek_2fusion_2PSDVariable__elementDesc(_1440,_1441); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1440,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1441){
  _pubthis->elementName(_1440,_1441);
  _1441->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1441;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1442){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1442)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1443,int _1444,int _1445,std::shared_ptr< monty::ndarray< long long,1 > > _1446){
  _checked_ptr_1<int> _ptr__1443(_1443 ? _1443->raw() : nullptr, _1443 ? _1443->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1446(_1446 ? _1446->raw() : nullptr, _1446 ? _1446->size(0) : 0);
  int _1447 = (int)((_1443)->size(0));
  bool _1448 = (_1444 < _1445);
  int _7209;
  bool _7210 = _1448;
  if (_7210)
  {
    _7209 = _1444;
  }
  else
  {
    _7209 = _1445;
  }
  int _1449 = _7209;
  int _7211;
  bool _7212 = (!_1448);
  if (_7212)
  {
    _7211 = _1444;
  }
  else
  {
    _7211 = _1445;
  }
  int _1450 = _7211;
  int _1451 = (int)1;
  int _7213 = (int)0;
  int _7214 = _1449;
  for (int _1452 = _7213; _1452 < _7214; ++_1452)
  {
    {
      _1451 *= _ptr__1443[_1452];
    }
  }
  int _1453 = _ptr__1443[_1449];
  int _1454 = (int)1;
  int _7215 = safe_add( _1449,(int)1 );
  int _7216 = _1450;
  for (int _1455 = _7215; _1455 < _7216; ++_1455)
  {
    {
      _1454 *= _ptr__1443[_1455];
    }
  }
  int _1456 = _ptr__1443[_1450];
  int _1457 = (int)1;
  int _7217 = safe_add( _1450,(int)1 );
  int _7218 = _1447;
  for (int _1458 = _7217; _1458 < _7218; ++_1458)
  {
    {
      _1457 *= _ptr__1443[_1458];
    }
  }
  int _1459 = safe_mul( safe_mul( safe_mul( safe_mul( _1451,_1453 ),_1454 ),_1456 ),_1457 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1460 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1459)));
  _checked_ptr_1<long long> _ptr__1460(_1460 ? _1460->raw() : nullptr,_1460 ? _1460->size(0) : 0);
  int _1461 = _1457;
  int _1462 = safe_mul( _1461,_1456 );
  int _1463 = safe_mul( _1462,_1454 );
  int _1464 = safe_mul( _1463,_1463 );
  {
    int _1465 = (int)0;
    int _7219 = (int)0;
    int _7220 = _1451;
    for (int _1466 = _7219; _1466 < _7220; ++_1466)
    {
      {
        int _7221 = (int)0;
        int _7222 = _1456;
        for (int _1467 = _7221; _1467 < _7222; ++_1467)
        {
          {
            int _7223 = (int)0;
            int _7224 = _1454;
            for (int _1468 = _7223; _1468 < _7224; ++_1468)
            {
              {
                int _7225 = _1467;
                int _7226 = _1453;
                for (int _1469 = _7225; _1469 < _7226; ++_1469)
                {
                  {
                    int _7227 = (int)0;
                    int _7228 = _1457;
                    for (int _1470 = _7227; _1470 < _7228; ++_1470)
                    {
                      {
                        _ptr__1460[safe_add( safe_add( safe_add( safe_add( safe_mul( _1466,_1464 ),safe_mul( _1469,_1463 ) ),safe_mul( _1468,_1462 ) ),safe_mul( _1467,_1461 ) ),_1470 )] = (-safe_add( _ptr__1446[_1465],(int)1 ));
                        _ptr__1460[safe_add( safe_add( safe_add( safe_add( safe_mul( _1466,_1464 ),safe_mul( _1467,_1463 ) ),safe_mul( _1468,_1462 ) ),safe_mul( _1469,_1461 ) ),_1470 )] = (-safe_add( _ptr__1446[_1465],(int)1 ));
                        ++ _1465;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1460;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1471,    monty::rc_ptr< ::mosek::fusion::Model > _1472){ return new mosek::fusion::SymLinearVariable(_1471,_1472); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1471,    monty::rc_ptr< ::mosek::fusion::Model > _1472) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1471,_1472); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1471,    monty::rc_ptr< ::mosek::fusion::Model > _1472){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1471,_1472);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1471)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1471)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1471)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1471)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1471)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1473,    const std::string &  _1474,    long long _1475,    int _1476,    std::shared_ptr< monty::ndarray< long long,1 > > _1477,    std::shared_ptr< monty::ndarray< int,1 > > _1478){ return new mosek::fusion::SymLinearVariable(_1473,_1474,_1475,_1476,_1477,_1478); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1473,    const std::string &  _1474,    long long _1475,    int _1476,    std::shared_ptr< monty::ndarray< long long,1 > > _1477,    std::shared_ptr< monty::ndarray< int,1 > > _1478) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1473,_1474,_1475,_1476,_1477,_1478); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1473,    const std::string &  _1474,    long long _1475,    int _1476,    std::shared_ptr< monty::ndarray< long long,1 > > _1477,    std::shared_ptr< monty::ndarray< int,1 > > _1478){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1477(_1477 ? _1477->raw() : nullptr, _1477 ? _1477->size(0) : 0);
    _checked_ptr_1<int> _ptr__1478(_1478 ? _1478->raw() : nullptr, _1478 ? _1478->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1473,_1474,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1476),(int)(_1476)}),_1475,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1476,_1477),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1476,_1477,_1478));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1474;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1478;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1477;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1476;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1479 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7229 = (int)0;
          int _7230 = (int)((nativeidxs)->size(0));
          for (int _1480 = _7229; _1480 < _7230; ++_1480)
          {
            {
              std::string _7231;
              bool _7232 = ((int)((name).size()) == (int)0);
              if (_7232)
              {
                _7231 = std::string ("");
              }
              else
              {
                _7231 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1480 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1480 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1479.get())->varname(((*nativeidxs)(_1480)),_7231);
            }
          }
        }
      }
      else
      {
        {
          int _7233 = (int)0;
          int _7234 = (int)((sparsity)->size(0));
          for (int _1481 = _7233; _1481 < _7234; ++_1481)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1479.get())->varname(((*nativeidxs)(_1481)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1481)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1481)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1482){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1482)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1483,std::shared_ptr< monty::ndarray< long long,1 > > _1484,std::shared_ptr< monty::ndarray< int,1 > > _1485){
  _checked_ptr_1<long long> _ptr__1484(_1484 ? _1484->raw() : nullptr, _1484 ? _1484->size(0) : 0);
  _checked_ptr_1<int> _ptr__1485(_1485 ? _1485->raw() : nullptr, _1485 ? _1485->size(0) : 0);
  if ((NULL == _1484.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1486 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1483,_1483 ))));
      _checked_ptr_1<long long> _ptr__1486(_1486 ? _1486->raw() : nullptr,_1486 ? _1486->size(0) : 0);
      int _1487 = (int)0;
      {
        int _7235 = (int)0;
        int _7236 = _1483;
        for (int _1488 = _7235; _1488 < _7236; ++_1488)
        {
          {
            _ptr__1486[safe_add( safe_mul( _1488,_1483 ),_1488 )] = safe_add( _ptr__1485[_1487],(int)1 );
            ++ _1487;
            int _7237 = safe_add( _1488,(int)1 );
            int _7238 = _1483;
            for (int _1489 = _7237; _1489 < _7238; ++_1489)
            {
              {
                _ptr__1486[safe_add( safe_mul( _1488,_1483 ),_1489 )] = safe_add( _ptr__1485[_1487],(int)1 );
                _ptr__1486[safe_add( safe_mul( _1489,_1483 ),_1488 )] = safe_add( _ptr__1485[_1487],(int)1 );
                ++ _1487;
              }
            }
          }
        }
      }
      return _1486;
    }
  }
  else
  {
    {
      int _1490 = (int)0;
      {
        int _7239 = (int)0;
        int _7240 = (int)((_1484)->size(0));
        for (int _1491 = _7239; _1491 < _7240; ++_1491)
        {
          {
            int _7241;
            bool _7242 = ((_ptr__1484[_1491] % safe_add( _1483,(int)1 )) == (int)0);
            if (_7242)
            {
              _7241 = (int)1;
            }
            else
            {
              _7241 = (int)2;
            }
            _1490 += _7241;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1492 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1490)));
      _checked_ptr_1<long long> _ptr__1492(_1492 ? _1492->raw() : nullptr,_1492 ? _1492->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1493 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1490)));
      _checked_ptr_1<long long> _ptr__1493(_1493 ? _1493->raw() : nullptr,_1493 ? _1493->size(0) : 0);
      {
        int _1494 = (int)0;
        int _7243 = (int)0;
        int _7244 = (int)((_1484)->size(0));
        for (int _1495 = _7243; _1495 < _7244; ++_1495)
        {
          {
            long long _1496 = (_ptr__1484[_1495] / _1483);
            long long _1497 = (_ptr__1484[_1495] % _1483);
            _ptr__1492[_1494] = _ptr__1484[_1495];
            _ptr__1493[_1494] = safe_add( _ptr__1485[_1495],(int)1 );
            ++ _1494;
            if ((_1496 != _1497))
            {
              {
                _ptr__1492[_1494] = safe_add( safe_mul( _1497,_1483 ),_1496 );
                _ptr__1493[_1494] = safe_add( _ptr__1485[_1495],(int)1 );
                ++ _1494;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7245;
      for (int _1499 = (int)0, _7246 = _1490; _1499 < _7246 ; ++_1499)
      {
        _7245.push_back(_1499);
      }
      auto _7247 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7245.size()),_7245.begin(),_7245.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1498 = _7247;
      _checked_ptr_1<long long> _ptr__1498(_1498 ? _1498->raw() : nullptr,_1498 ? _1498->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1498,_1492,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1490));
      std::vector<long long> _7248;
      for (int _1500 = (int)0, _7249 = _1490; _1500 < _7249 ; ++_1500)
      {
        _7248.push_back(_ptr__1493[_ptr__1498[_1500]]);
      }
      auto _7250 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7248.size()),_7248.begin(),_7248.end()));
      return _7250;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1501,std::shared_ptr< monty::ndarray< long long,1 > > _1502){
  _checked_ptr_1<long long> _ptr__1502(_1502 ? _1502->raw() : nullptr, _1502 ? _1502->size(0) : 0);
  if ((NULL == _1502.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1503 = (int)0;
      {
        int _7251 = (int)0;
        int _7252 = (int)((_1502)->size(0));
        for (int _1504 = _7251; _1504 < _7252; ++_1504)
        {
          {
            int _7253;
            bool _7254 = ((_ptr__1502[_1504] % safe_add( _1501,(int)1 )) == (int)0);
            if (_7254)
            {
              _7253 = (int)1;
            }
            else
            {
              _7253 = (int)2;
            }
            _1503 += _7253;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1505 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1503)));
      _checked_ptr_1<long long> _ptr__1505(_1505 ? _1505->raw() : nullptr,_1505 ? _1505->size(0) : 0);
      {
        int _1506 = (int)0;
        int _7255 = (int)0;
        int _7256 = (int)((_1502)->size(0));
        for (int _1507 = _7255; _1507 < _7256; ++_1507)
        {
          {
            long long _1508 = (_ptr__1502[_1507] / _1501);
            long long _1509 = (_ptr__1502[_1507] % _1501);
            _ptr__1505[_1506] = _ptr__1502[_1507];
            ++ _1506;
            if ((_1508 != _1509))
            {
              {
                _ptr__1505[_1506] = safe_add( safe_mul( _1509,_1501 ),_1508 );
                ++ _1506;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7257;
      for (int _1511 = (int)0, _7258 = _1503; _1511 < _7258 ; ++_1511)
      {
        _7257.push_back(_1511);
      }
      auto _7259 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7257.size()),_7257.begin(),_7257.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1510 = _7259;
      _checked_ptr_1<long long> _ptr__1510(_1510 ? _1510->raw() : nullptr,_1510 ? _1510->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1510,_1505,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1503));
      std::vector<long long> _7260;
      for (int _1512 = (int)0, _7261 = _1503; _1512 < _7261 ; ++_1512)
      {
        _7260.push_back(_ptr__1505[_ptr__1510[_1512]]);
      }
      auto _7262 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7260.size()),_7260.begin(),_7260.end()));
      return _7262;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1513,    monty::rc_ptr< ::mosek::fusion::Model > _1514){ return new mosek::fusion::LinearVariable(_1513,_1514); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1513,    monty::rc_ptr< ::mosek::fusion::Model > _1514) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1513,_1514); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1513,    monty::rc_ptr< ::mosek::fusion::Model > _1514){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1513,_1514);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1513)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1513)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1513)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1513)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1513)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1515,    const std::string &  _1516,    long long _1517,    std::shared_ptr< monty::ndarray< int,1 > > _1518,    std::shared_ptr< monty::ndarray< long long,1 > > _1519,    std::shared_ptr< monty::ndarray< int,1 > > _1520){ return new mosek::fusion::LinearVariable(_1515,_1516,_1517,_1518,_1519,_1520); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1515,    const std::string &  _1516,    long long _1517,    std::shared_ptr< monty::ndarray< int,1 > > _1518,    std::shared_ptr< monty::ndarray< long long,1 > > _1519,    std::shared_ptr< monty::ndarray< int,1 > > _1520) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1515,_1516,_1517,_1518,_1519,_1520); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1515,    const std::string &  _1516,    long long _1517,    std::shared_ptr< monty::ndarray< int,1 > > _1518,    std::shared_ptr< monty::ndarray< long long,1 > > _1519,    std::shared_ptr< monty::ndarray< int,1 > > _1520){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1518(_1518 ? _1518->raw() : nullptr, _1518 ? _1518->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1519(_1519 ? _1519->raw() : nullptr, _1519 ? _1519->size(0) : 0);
    _checked_ptr_1<int> _ptr__1520(_1520 ? _1520->raw() : nullptr, _1520 ? _1520->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1515,_1516,_1518,_1517,_1519,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1520));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1516;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1520;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1519;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1518;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1521 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1521->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7263 = (int)1;
      int _7264 = (int)((shape)->size(0));
      for (int _1522 = _7263; _1522 < _7264; ++_1522)
      {
        {
          _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1522)));
        }
      }
    }
  }
  {}
  _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1521->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1523 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1524 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1524->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1524->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7265 = (int)1;
          int _7266 = _pubthis->getND();
          for (int _1525 = _7265; _1525 < _7266; ++_1525)
          {
            {
              _1524->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1525);
            }
          }
        }
      }
      {}
      _1524->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7267;
      bool _7268 = (_pubthis->getND() > (int)0);
      if (_7268)
      {
        _7267 = _pubthis->getShape();
      }
      else
      {
        _7267 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1523.get())->varnames(nativeidxs,_1524->toString(),_7267,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1526){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1526)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1527){
  _checked_ptr_1<int> _ptr__1527(_1527 ? _1527->raw() : nullptr, _1527 ? _1527->size(0) : 0);
  std::vector<long long> _7269;
  for (int _1528 = (int)0, _7270 = (int)((_1527)->size(0)); _1528 < _7270 ; ++_1528)
  {
    _7269.push_back(safe_add( _ptr__1527[_1528],(int)1 ));
  }
  auto _7271 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7269.size()),_7269.begin(),_7269.end()));
  return _7271;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1529,    monty::rc_ptr< ::mosek::fusion::Model > _1530){ return new mosek::fusion::ConicVariable(_1529,_1530); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1529,    monty::rc_ptr< ::mosek::fusion::Model > _1530) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1529,_1530); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1529,    monty::rc_ptr< ::mosek::fusion::Model > _1530){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1529,_1530);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1529)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1529)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1529)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1529)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1529)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1529)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1531,    const std::string &  _1532,    int _1533,    std::shared_ptr< monty::ndarray< int,1 > > _1534,    std::shared_ptr< monty::ndarray< int,1 > > _1535){ return new mosek::fusion::ConicVariable(_1531,_1532,_1533,_1534,_1535); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1531,    const std::string &  _1532,    int _1533,    std::shared_ptr< monty::ndarray< int,1 > > _1534,    std::shared_ptr< monty::ndarray< int,1 > > _1535) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1531,_1532,_1533,_1534,_1535); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1531,    const std::string &  _1532,    int _1533,    std::shared_ptr< monty::ndarray< int,1 > > _1534,    std::shared_ptr< monty::ndarray< int,1 > > _1535){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1534(_1534 ? _1534->raw() : nullptr, _1534 ? _1534->size(0) : 0);
    _checked_ptr_1<int> _ptr__1535(_1535 ? _1535->raw() : nullptr, _1535 ? _1535->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1531,_1532,_1534,_1533,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1535));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1532;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1533;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1534;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1535;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1536 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1536->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7272 = (int)1;
  int _7273 = (int)((shape)->size(0));
  for (int _1537 = _7272; _1537 < _7273; ++_1537)
  {
    {
      _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1537)));
    }
  }
  _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1536->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1538 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1539 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1539->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1539->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7274 = (int)1;
      int _7275 = _pubthis->getND();
      for (int _1540 = _7274; _1540 < _7275; ++_1540)
      {
        {
          _1539->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1540);
        }
      }
      _1539->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7276;
      bool _7277 = (_pubthis->getND() > (int)0);
      if (_7277)
      {
        _7276 = _pubthis->getShape();
      }
      else
      {
        _7276 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1538.get())->varnames(nativeidxs,_1539->toString(),_7276,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1541){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1541)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1542){
  _checked_ptr_1<int> _ptr__1542(_1542 ? _1542->raw() : nullptr, _1542 ? _1542->size(0) : 0);
  std::vector<long long> _7278;
  for (int _1543 = (int)0, _7279 = (int)((_1542)->size(0)); _1543 < _7279 ; ++_1543)
  {
    _7278.push_back(safe_add( _ptr__1542[_1543],(int)1 ));
  }
  auto _7280 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7278.size()),_7278.begin(),_7278.end()));
  return _7280;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1544,    monty::rc_ptr< ::mosek::fusion::Model > _1545){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1544,_1545);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1544)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1544)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1544)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1544)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1544)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1546,    const std::string &  _1547,    std::shared_ptr< monty::ndarray< int,1 > > _1548,    long long _1549,    std::shared_ptr< monty::ndarray< long long,1 > > _1550,    std::shared_ptr< monty::ndarray< long long,1 > > _1551){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1548(_1548 ? _1548->raw() : nullptr, _1548 ? _1548->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1550(_1550 ? _1550->raw() : nullptr, _1550 ? _1550->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1551(_1551 ? _1551->raw() : nullptr, _1551 ? _1551->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1546,_1548,_1550,_1551);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1547;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1549;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1548;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1550;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1551;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1552,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1553) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1552,_1553); }void mosek::fusion::p_ModelVariable::elementName(long long _1552,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1553){
  std::string _7281;
  bool _7282 = ((int)((name).size()) == (int)0);
  if (_7282)
  {
    _7281 = std::string ("_");
  }
  else
  {
    _7281 = name;
  }
  _1553->__mosek_2fusion_2Utils_2StringBuffer__a(_7281)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1552))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1555){ return new mosek::fusion::NilVariable(_1555); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1555) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1555); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1555){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1555(_1555 ? _1555->raw() : nullptr, _1555 ? _1555->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1555),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7283;
    for (int _1556 = (int)0, _7284 = (int)((_1555)->size(0)); _1556 < _7284 ; ++_1556)
    {
      _7283.push_back(_ptr__1555[_1556]);
    }
    auto _7285 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7283.size()),_7283.begin(),_7283.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7285;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1558) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1557,_1558); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1558) { return __mosek_2fusion_2NilVariable__elementDesc(_1557,_1558); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1558){
  return _1558;
}
void mosek::fusion::NilVariable :: elementName(long long _1559,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1560) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1559,_1560); }void mosek::fusion::p_NilVariable::elementName(long long _1559,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1560){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1561,std::shared_ptr< monty::ndarray< long long,1 > > _1562,std::shared_ptr< monty::ndarray< long long,1 > > _1563) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1561,_1562,_1563); }int mosek::fusion::p_NilVariable::inst(int _1561,std::shared_ptr< monty::ndarray< long long,1 > > _1562,std::shared_ptr< monty::ndarray< long long,1 > > _1563){
  _checked_ptr_1<long long> _ptr__1562(_1562 ? _1562->raw() : nullptr, _1562 ? _1562->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1563(_1563 ? _1563->raw() : nullptr, _1563 ? _1563->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1564,std::shared_ptr< monty::ndarray< long long,1 > > _1565) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1564,_1565); }void mosek::fusion::p_NilVariable::inst(int _1564,std::shared_ptr< monty::ndarray< long long,1 > > _1565){
  _checked_ptr_1<long long> _ptr__1565(_1565 ? _1565->raw() : nullptr, _1565 ? _1565->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1566,bool _1567) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1566,_1567); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1566,bool _1567){
  _checked_ptr_1<double> _ptr__1566(_1566 ? _1566->raw() : nullptr, _1566 ? _1566->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1568,std::shared_ptr< monty::ndarray< double,1 > > _1569,bool _1570) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1568,_1569,_1570); }void mosek::fusion::p_NilVariable::values(int _1568,std::shared_ptr< monty::ndarray< double,1 > > _1569,bool _1570){
  _checked_ptr_1<double> _ptr__1569(_1569 ? _1569->raw() : nullptr, _1569 ? _1569->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1571); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return __mosek_2fusion_2NilVariable__index(_1571); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return __mosek_2fusion_2NilVariable__index(_1571); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return __mosek_2fusion_2NilVariable__index(_1571); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571){
  _checked_ptr_1<int> _ptr__1571(_1571 ? _1571->raw() : nullptr, _1571 ? _1571->size(0) : 0);
  std::vector<int> _7286;
  for (int _1572 = (int)0, _7287 = (int)((shape)->size(0)); _1572 < _7287 ; ++_1572)
  {
    _7286.push_back((int)1);
  }
  auto _7288 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7286.size()),_7286.begin(),_7286.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7288)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1573) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1573) { return __mosek_2fusion_2NilVariable__index(_1573); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1573) { return __mosek_2fusion_2NilVariable__index(_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1573) { return __mosek_2fusion_2NilVariable__index(_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1573){
  std::vector<int> _7289;
  for (int _1574 = (int)0, _7290 = (int)((shape)->size(0)); _1574 < _7290 ; ++_1574)
  {
    _7289.push_back((int)1);
  }
  auto _7291 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7289.size()),_7289.begin(),_7289.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7291)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1575,_1576); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return __mosek_2fusion_2NilVariable__slice(_1575,_1576); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return __mosek_2fusion_2NilVariable__slice(_1575,_1576); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return __mosek_2fusion_2NilVariable__slice(_1575,_1576); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576){
  _checked_ptr_1<int> _ptr__1575(_1575 ? _1575->raw() : nullptr, _1575 ? _1575->size(0) : 0);
  _checked_ptr_1<int> _ptr__1576(_1576 ? _1576->raw() : nullptr, _1576 ? _1576->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1575)->size(0))) || ((int)((shape)->size(0)) != (int)((_1576)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7292 = (int)0;
  int _7293 = (int)((_1575)->size(0));
  for (int _1577 = _7292; _1577 < _7293; ++_1577)
  {
    {
      if (((_ptr__1576[_1577] > _ptr__1575[_1577]) || ((_ptr__1575[_1577] < (int)0) || (_ptr__1576[_1577] >= ((*shape)(_1577))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7294;
  for (int _1578 = (int)0, _7295 = (int)((shape)->size(0)); _1578 < _7295 ; ++_1578)
  {
    _7294.push_back((_ptr__1576[_1578] - _ptr__1575[_1578]));
  }
  auto _7296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7294.size()),_7294.begin(),_7294.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7296)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1579,int _1580) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1579,_1580); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1579,int _1580) { return __mosek_2fusion_2NilVariable__slice(_1579,_1580); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1579,int _1580) { return __mosek_2fusion_2NilVariable__slice(_1579,_1580); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1579,int _1580) { return __mosek_2fusion_2NilVariable__slice(_1579,_1580); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1579,int _1580){
  if (((_1580 > _1579) || ((_1579 < (int)0) || (_1580 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1580 - _1579))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1581,    monty::rc_ptr< ::mosek::fusion::Model > _1582){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1582;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1581)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1581)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1581)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1583,    std::shared_ptr< monty::ndarray< int,1 > > _1584,    std::shared_ptr< monty::ndarray< long long,1 > > _1585,    std::shared_ptr< monty::ndarray< long long,1 > > _1586){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1584(_1584 ? _1584->raw() : nullptr, _1584 ? _1584->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1585(_1585 ? _1585->raw() : nullptr, _1585 ? _1585->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1586(_1586 ? _1586->raw() : nullptr, _1586 ? _1586->size(0) : 0);
    model = _1583;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1584;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1585;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1586;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1587 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1587->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1587->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7297 = (int)1;
      int _7298 = (int)((shape)->size(0));
      for (int _1588 = _7297; _1588 < _7298; ++_1588)
      {
        {
          _1587->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1588)));
        }
      }
    }
  }
  {}
  _1587->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1587->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1589,monty::rc_ptr< ::mosek::fusion::WorkStack > _1590,monty::rc_ptr< ::mosek::fusion::WorkStack > _1591) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1589,_1590,_1591); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1589,monty::rc_ptr< ::mosek::fusion::WorkStack > _1590,monty::rc_ptr< ::mosek::fusion::WorkStack > _1591){
  int _1592 = (int)((nativeidxs)->size(0));
  int _1593 = _1592;
  int _1594 = (int)((shape)->size(0));
  bool _1595 = (NULL != sparsity.get());
  _1589->alloc_expr(_1594,_1593,_1592,_1595);
  int _1596 = mosek::fusion::p_WorkStack::_get_impl(_1589)->ptr_base;
  int _1597 = mosek::fusion::p_WorkStack::_get_impl(_1589)->nidxs_base;
  int _1598 = mosek::fusion::p_WorkStack::_get_impl(_1589)->sp_base;
  int _1599 = mosek::fusion::p_WorkStack::_get_impl(_1589)->cof_base;
  int _1600 = mosek::fusion::p_WorkStack::_get_impl(_1589)->bfix_base;
  int _1601 = mosek::fusion::p_WorkStack::_get_impl(_1589)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1602 = mosek::fusion::p_WorkStack::_get_impl(_1589)->i32;
  _checked_ptr_1<int> _ptr__1602(_1602 ? _1602->raw() : nullptr,_1602 ? _1602->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1603 = mosek::fusion::p_WorkStack::_get_impl(_1589)->i64;
  _checked_ptr_1<long long> _ptr__1603(_1603 ? _1603->raw() : nullptr,_1603 ? _1603->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1604 = mosek::fusion::p_WorkStack::_get_impl(_1589)->f64;
  _checked_ptr_1<double> _ptr__1604(_1604 ? _1604->raw() : nullptr,_1604 ? _1604->size(0) : 0);
  int _7299 = (int)0;
  int _7300 = _1594;
  for (int _1605 = _7299; _1605 < _7300; ++_1605)
  {
    {
      _ptr__1602[safe_add( _1601,_1605 )] = ((*shape)(_1605));
    }
  }
  {
    int _7301 = (int)0;
    int _7302 = safe_add( _1592,(int)1 );
    for (int _1606 = _7301; _1606 < _7302; ++_1606)
    {
      {
        _ptr__1602[safe_add( _1596,_1606 )] = _1606;
      }
    }
    int _7303 = (int)0;
    int _7304 = _1592;
    for (int _1607 = _7303; _1607 < _7304; ++_1607)
    {
      {
        _ptr__1603[safe_add( _1597,_1607 )] = ((*nativeidxs)(_1607));
      }
    }
    if (_1595)
    {
      {
        int _7305 = (int)0;
        int _7306 = _1592;
        for (int _1608 = _7305; _1608 < _7306; ++_1608)
        {
          {
            _ptr__1603[safe_add( _1598,_1608 )] = ((*sparsity)(_1608));
          }
        }
      }
    }
    {}
    int _7307 = (int)0;
    int _7308 = _1592;
    for (int _1609 = _7307; _1609 < _7308; ++_1609)
    {
      {
        _ptr__1604[safe_add( _1599,_1609 )] = 1.0;
      }
    }
    int _7309 = (int)0;
    int _7310 = _1592;
    for (int _1610 = _7309; _1610 < _7310; ++_1610)
    {
      {
        _ptr__1604[safe_add( _1600,_1610 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1611); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611) { return __mosek_2fusion_2BaseVariable__reshape(_1611); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611) { return __mosek_2fusion_2BaseVariable__reshape(_1611); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611){
  _checked_ptr_1<int> _ptr__1611(_1611 ? _1611->raw() : nullptr, _1611 ? _1611->size(0) : 0);
  long long _1612 = (int)1;
  int _7311 = (int)0;
  int _7312 = (int)((_1611)->size(0));
  for (int _1613 = _7311; _1613 < _7312; ++_1613)
  {
    {
      if ((_ptr__1611[_1613] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1612 *= _ptr__1611[_1613];
    }
  }
  if ((_1612 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7313;
  for (int _1614 = (int)0, _7314 = (int)((_1611)->size(0)); _1614 < _7314 ; ++_1614)
  {
    _7313.push_back(_ptr__1611[_1614]);
  }
  auto _7315 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7313.size()),_7313.begin(),_7313.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7315,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1615) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1615); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1615){
  _checked_ptr_1<double> _ptr__1615(_1615 ? _1615->raw() : nullptr, _1615 ? _1615->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1615)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1615);
    }
  }
  else
  {
    {
      if (((int)((_1615)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7316;
      for (int _1617 = (int)0, _7317 = (int)((nativeidxs)->size(0)); _1617 < _7317 ; ++_1617)
      {
        _7316.push_back(_ptr__1615[((*sparsity)(_1617))]);
      }
      auto _7318 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7316.size()),_7316.begin(),_7316.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1616 = _7318;
      _checked_ptr_1<double> _ptr__1616(_1616 ? _1616->raw() : nullptr,_1616 ? _1616->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1616);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1618) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1618); }int mosek::fusion::p_BaseVariable::getDim(int _1618){
  return ((*shape)(_1618));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1619 = (long long)1;
  int _7319 = (int)0;
  int _7320 = (int)((shape)->size(0));
  for (int _1620 = _7319; _1620 < _7320; ++_1620)
  {
    {
      _1619 *= ((*shape)(_1620));
    }
  }
  return _1619;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1621 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1621(_1621 ? _1621->raw() : nullptr,_1621 ? _1621->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1621,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1622 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1622(_1622 ? _1622->raw() : nullptr,_1622 ? _1622->size(0) : 0);
      int _7321 = (int)0;
      int _7322 = (int)((nativeidxs)->size(0));
      for (int _1623 = _7321; _1623 < _7322; ++_1623)
      {
        {
          _ptr__1622[((*sparsity)(_1623))] = _ptr__1621[_1623];
        }
      }
      _1621 = _1622;
      _ptr__1621.update(_1621 ? _1621->raw() : nullptr, _1621 ? _1621->size(0) : 0);
    }
  }
  {}
  return _1621;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1624 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1624(_1624 ? _1624->raw() : nullptr,_1624 ? _1624->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1624,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1625 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1625(_1625 ? _1625->raw() : nullptr,_1625 ? _1625->size(0) : 0);
      int _7323 = (int)0;
      int _7324 = (int)((nativeidxs)->size(0));
      for (int _1626 = _7323; _1626 < _7324; ++_1626)
      {
        {
          _ptr__1625[((*sparsity)(_1626))] = _ptr__1624[_1626];
        }
      }
      _1624 = _1625;
      _ptr__1624.update(_1624 ? _1624->raw() : nullptr, _1624 ? _1624->size(0) : 0);
    }
  }
  {}
  return _1624;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1627 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1627(_1627 ? _1627->raw() : nullptr,_1627 ? _1627->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7325;
      bool _7326 = (NULL == sparsity.get());
      if (_7326)
      {
        _7325 = nullptr;
      }
      else
      {
        _7325 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1628 = _7325;
      _checked_ptr_1<long long> _ptr__1628(_1628 ? _1628->raw() : nullptr,_1628 ? _1628->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1629 = (int)0;
          int _7327 = (int)0;
          int _7328 = ((*shape)((int)1));
          for (int _1630 = _7327; _1630 < _7328; ++_1630)
          {
            {
              int _7329 = (int)0;
              int _7330 = ((*shape)((int)0));
              for (int _1631 = _7329; _1631 < _7330; ++_1631)
              {
                {
                  _ptr__1627[_1629] = ((*nativeidxs)(safe_add( safe_mul( _1631,((*shape)((int)1)) ),_1630 )));
                  ++ _1629;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1632 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1632(_1632 ? _1632->raw() : nullptr,_1632 ? _1632->size(0) : 0);
          int _1633 = ((*shape)((int)0));
          int _1634 = ((*shape)((int)1));
          int _7331 = (int)0;
          int _7332 = (int)((sparsity)->size(0));
          for (int _1635 = _7331; _1635 < _7332; ++_1635)
          {
            {
              ++ _ptr__1632[safe_add( (((*sparsity)(_1635)) % _1634),(int)1 )];
            }
          }
          int _7333 = (int)0;
          int _7334 = _1634;
          for (int _1636 = _7333; _1636 < _7334; ++_1636)
          {
            {
              _ptr__1632[safe_add( _1636,(int)1 )] += _ptr__1632[_1636];
            }
          }
          int _7335 = (int)0;
          int _7336 = (int)((sparsity)->size(0));
          for (int _1637 = _7335; _1637 < _7336; ++_1637)
          {
            {
              long long _1638 = (((*sparsity)(_1637)) % _1634);
              _ptr__1627[_ptr__1632[_1638]] = ((*nativeidxs)(_1637));
              _ptr__1628[_ptr__1632[_1638]] = safe_add( (((*sparsity)(_1637)) / _1634),safe_mul( (((*sparsity)(_1637)) % _1634),_1633 ) );
              ++ _ptr__1632[_1638];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1628,_1627)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1639,int _1640,int _1641) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1639,_1640,_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1639,int _1640,int _1641) { return __mosek_2fusion_2BaseVariable__index(_1639,_1640,_1641); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1639,int _1640,int _1641) { return __mosek_2fusion_2BaseVariable__index(_1639,_1640,_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1639,int _1640,int _1641){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1639),(int)(_1640),(int)(_1641)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1642,int _1643) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1642,_1643); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1642,int _1643) { return __mosek_2fusion_2BaseVariable__index(_1642,_1643); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1642,int _1643) { return __mosek_2fusion_2BaseVariable__index(_1642,_1643); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1642,int _1643){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1642),(int)(_1643)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1644) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1644) { return __mosek_2fusion_2BaseVariable__index(_1644); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1644) { return __mosek_2fusion_2BaseVariable__index(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1644){
  _checked_ptr_1<int> _ptr__1644(_1644 ? _1644->raw() : nullptr, _1644 ? _1644->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1645 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1644)->size(0)))));
  int _7337 = (int)0;
  int _7338 = (int)((_1644)->size(0));
  for (int _1646 = _7337; _1646 < _7338; ++_1646)
  {
    {
      ((*_1645)((int)0,_1646)) = _ptr__1644[_1646];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1645)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1647) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1647); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1647) { return __mosek_2fusion_2BaseVariable__index(_1647); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1647) { return __mosek_2fusion_2BaseVariable__index(_1647); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1647){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1647)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1648,_1649,_1650); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650) { return __mosek_2fusion_2BaseVariable__pick(_1648,_1649,_1650); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650) { return __mosek_2fusion_2BaseVariable__pick(_1648,_1649,_1650); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650){
  _checked_ptr_1<int> _ptr__1648(_1648 ? _1648->raw() : nullptr, _1648 ? _1648->size(0) : 0);
  _checked_ptr_1<int> _ptr__1649(_1649 ? _1649->raw() : nullptr, _1649 ? _1649->size(0) : 0);
  _checked_ptr_1<int> _ptr__1650(_1650 ? _1650->raw() : nullptr, _1650 ? _1650->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1648)->size(0)) != (int)((_1649)->size(0))) || ((int)((_1648)->size(0)) != (int)((_1650)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1651 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1648)->size(0)),(int)3)));
  int _7339 = (int)0;
  int _7340 = (int)((_1648)->size(0));
  for (int _1652 = _7339; _1652 < _7340; ++_1652)
  {
    {
      ((*_1651)(_1652,(int)0)) = _ptr__1648[_1652];
      ((*_1651)(_1652,(int)1)) = _ptr__1649[_1652];
      ((*_1651)(_1652,(int)2)) = _ptr__1650[_1652];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1651);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1653,_1654); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654) { return __mosek_2fusion_2BaseVariable__pick(_1653,_1654); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654) { return __mosek_2fusion_2BaseVariable__pick(_1653,_1654); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654){
  _checked_ptr_1<int> _ptr__1653(_1653 ? _1653->raw() : nullptr, _1653 ? _1653->size(0) : 0);
  _checked_ptr_1<int> _ptr__1654(_1654 ? _1654->raw() : nullptr, _1654 ? _1654->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1653)->size(0)) != (int)((_1654)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1655 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1653)->size(0)),(int)2)));
  int _7341 = (int)0;
  int _7342 = (int)((_1653)->size(0));
  for (int _1656 = _7341; _1656 < _7342; ++_1656)
  {
    {
      ((*_1655)(_1656,(int)0)) = _ptr__1653[_1656];
      ((*_1655)(_1656,(int)1)) = _ptr__1654[_1656];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1655);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1657) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1657); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1657) { return __mosek_2fusion_2BaseVariable__pick(_1657); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1657) { return __mosek_2fusion_2BaseVariable__pick(_1657); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1657){
  if (((int)((shape)->size(0)) != (int)((_1657)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7343 = (int)0;
  int _7344 = (int)((_1657)->size(0));
  for (int _1658 = _7343; _1658 < _7344; ++_1658)
  {
    {
      int _7345 = (int)0;
      int _7346 = (int)((_1657)->size(1));
      for (int _1659 = _7345; _1659 < _7346; ++_1659)
      {
        {
          if (((((*_1657)(_1658,_1659)) < (int)0) || (((*_1657)(_1658,_1659)) >= ((*shape)(_1659)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
            }
          }
          {}
        }
      }
    }
  }
  int _1660 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1661 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1660)));
  _checked_ptr_1<long long> _ptr__1661(_1661 ? _1661->raw() : nullptr,_1661 ? _1661->size(0) : 0);
  _ptr__1661[(_1660 - (int)1)] = (int)1;
  int _7347 = (int)1;
  int _7348 = _1660;
  for (int _1662 = _7347; _1662 < _7348; ++_1662)
  {
    {
      _ptr__1661[((_1660 - _1662) - (int)1)] = safe_mul( _ptr__1661[(_1660 - _1662)],((*shape)((_1660 - _1662))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1663 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1657)->size(0)))});
  _checked_ptr_1<int> _ptr__1663(_1663 ? _1663->raw() : nullptr,_1663 ? _1663->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1664;
  _checked_ptr_1<long long> _ptr__1664(_1664 ? _1664->raw() : nullptr,_1664 ? _1664->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1665 = nullptr;
  _checked_ptr_1<long long> _ptr__1665(_1665 ? _1665->raw() : nullptr,_1665 ? _1665->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1664 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1657)->size(0)))));
      _ptr__1664.update(_1664 ? _1664->raw() : nullptr, _1664 ? _1664->size(0) : 0);
      {
        int _7349 = (int)0;
        int _7350 = (int)((_1657)->size(0));
        for (int _1666 = _7349; _1666 < _7350; ++_1666)
        {
          {
            long long _1667 = (long long)0;
            int _7351 = (int)0;
            int _7352 = _1660;
            for (int _1668 = _7351; _1668 < _7352; ++_1668)
            {
              {
                _1667 += safe_mul( _ptr__1661[_1668],((*_1657)(_1666,_1668)) );
              }
            }
            _ptr__1664[_1666] = ((*nativeidxs)(_1667));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1669 = (int)0;
      int _7353 = (int)0;
      int _7354 = (int)((_1657)->size(0));
      for (int _1670 = _7353; _1670 < _7354; ++_1670)
      {
        {
          long long _1671 = (long long)0;
          int _7355 = (int)0;
          int _7356 = _1660;
          for (int _1672 = _7355; _1672 < _7356; ++_1672)
          {
            {
              _1671 += safe_mul( _ptr__1661[_1672],((*_1657)(_1670,_1672)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1671) >= (int)0))
          {
            {
              ++ _1669;
            }
          }
          {}
        }
      }
      _1664 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1669)));
      _ptr__1664.update(_1664 ? _1664->raw() : nullptr, _1664 ? _1664->size(0) : 0);
      _1665 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1669)));
      _ptr__1665.update(_1665 ? _1665->raw() : nullptr, _1665 ? _1665->size(0) : 0);
      {
        int _1673 = (int)0;
        int _7357 = (int)0;
        int _7358 = (int)((_1657)->size(0));
        for (int _1674 = _7357; _1674 < _7358; ++_1674)
        {
          {
            long long _1675 = (long long)0;
            int _7359 = (int)0;
            int _7360 = _1660;
            for (int _1676 = _7359; _1676 < _7360; ++_1676)
            {
              {
                _1675 += safe_mul( _ptr__1661[_1676],((*_1657)(_1674,_1676)) );
              }
            }
            int _1677 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1675);
            if ((_1677 >= (int)0))
            {
              {
                _ptr__1664[_1673] = ((*nativeidxs)(_1677));
                _ptr__1665[_1673] = _1674;
                ++ _1673;
              }
            }
            {}
          }
        }
      }
      if ((_1669 == (int)((_1657)->size(0))))
      {
        {
          _1665 = nullptr;
          _ptr__1665.update(_1665 ? _1665->raw() : nullptr, _1665 ? _1665->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1663,_1665,_1664)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return __mosek_2fusion_2BaseVariable__pick(_1678); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return __mosek_2fusion_2BaseVariable__pick(_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1678){
  _checked_ptr_1<int> _ptr__1678(_1678 ? _1678->raw() : nullptr, _1678 ? _1678->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7361 = (int)0;
  int _7362 = (int)((_1678)->size(0));
  for (int _1679 = _7361; _1679 < _7362; ++_1679)
  {
    {
      if (((_ptr__1678[_1679] < (int)0) || (_ptr__1678[_1679] >= ((*shape)((int)0)))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1680;
  _checked_ptr_1<long long> _ptr__1680(_1680 ? _1680->raw() : nullptr,_1680 ? _1680->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1681 = nullptr;
  _checked_ptr_1<long long> _ptr__1681(_1681 ? _1681->raw() : nullptr,_1681 ? _1681->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7363;
      for (int _1682 = (int)0, _7364 = (int)((_1678)->size(0)); _1682 < _7364 ; ++_1682)
      {
        _7363.push_back(((*nativeidxs)(_ptr__1678[_1682])));
      }
      auto _7365 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7363.size()),_7363.begin(),_7363.end()));
      _1680 = _7365;
      _ptr__1680.update(_1680 ? _1680->raw() : nullptr, _1680 ? _1680->size(0) : 0);
    }
  }
  else
  {
    {
      int _1683 = (int)0;
      int _7366 = (int)0;
      int _7367 = (int)((_1678)->size(0));
      for (int _1684 = _7366; _1684 < _7367; ++_1684)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1678[_1684])) >= (int)0))
          {
            {
              ++ _1683;
            }
          }
          {}
        }
      }
      _1680 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1683)));
      _ptr__1680.update(_1680 ? _1680->raw() : nullptr, _1680 ? _1680->size(0) : 0);
      _1681 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1683)));
      _ptr__1681.update(_1681 ? _1681->raw() : nullptr, _1681 ? _1681->size(0) : 0);
      int _1685 = (int)0;
      int _7368 = (int)0;
      int _7369 = (int)((_1678)->size(0));
      for (int _1686 = _7368; _1686 < _7369; ++_1686)
      {
        {
          int _1687 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1678[_1686]));
          if ((_1687 >= (int)0))
          {
            {
              _ptr__1681[_1685] = _1686;
              _ptr__1680[_1685] = ((*nativeidxs)(_1687));
              ++ _1685;
            }
          }
          {}
        }
      }
      if ((_1683 == (int)((_1678)->size(0))))
      {
        {
          _1681 = nullptr;
          _ptr__1681.update(_1681 ? _1681->raw() : nullptr, _1681 ? _1681->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1678)->size(0)))}),_1681,_1680)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1688) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1688); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1688) { return __mosek_2fusion_2BaseVariable__antidiag(_1688); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1688) { return __mosek_2fusion_2BaseVariable__antidiag(_1688); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1688){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1688 >= ((*shape)((int)1))) || ((-_1688) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1688 >= (int)0))
  {
    {
      int _7370;
      bool _7371 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1688));
      if (_7371)
      {
        _7370 = ((*shape)((int)0));
      }
      else
      {
        _7370 = (((*shape)((int)1)) - _1688);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1688))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7370);
    }
  }
  else
  {
    {
      int _7372;
      bool _7373 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1688 ));
      if (_7373)
      {
        _7372 = ((*shape)((int)1));
      }
      else
      {
        _7372 = safe_add( ((*shape)((int)0)),_1688 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1688)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7372);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7374;
  bool _7375 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7375)
  {
    _7374 = ((*shape)((int)0));
  }
  else
  {
    _7374 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7374);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1689) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1689); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1689) { return __mosek_2fusion_2BaseVariable__diag(_1689); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1689) { return __mosek_2fusion_2BaseVariable__diag(_1689); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1689){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1689 >= ((*shape)((int)1))) || ((-_1689) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1689 >= (int)0))
  {
    {
      int _7376;
      bool _7377 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1689));
      if (_7377)
      {
        _7376 = ((*shape)((int)0));
      }
      else
      {
        _7376 = (((*shape)((int)1)) - _1689);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1689)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7376);
    }
  }
  else
  {
    {
      int _7378;
      bool _7379 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1689 ));
      if (_7379)
      {
        _7378 = ((*shape)((int)1));
      }
      else
      {
        _7378 = safe_add( ((*shape)((int)0)),_1689 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1689)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7378);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7380;
  bool _7381 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7381)
  {
    _7380 = ((*shape)((int)0));
  }
  else
  {
    _7380 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7380);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1690,std::shared_ptr< monty::ndarray< int,1 > > _1691,int _1692){
  _checked_ptr_1<int> _ptr__1690(_1690 ? _1690->raw() : nullptr, _1690 ? _1690->size(0) : 0);
  _checked_ptr_1<int> _ptr__1691(_1691 ? _1691->raw() : nullptr, _1691 ? _1691->size(0) : 0);
  int _1693 = (int)((shape)->size(0));
  if (((_1693 != (int)((_1690)->size(0))) || (_1693 != (int)((_1691)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7382 = (int)0;
  int _7383 = _1693;
  for (int _1694 = _7382; _1694 < _7383; ++_1694)
  {
    {
      if (((_ptr__1690[_1694] < (int)0) || (_ptr__1690[_1694] >= ((*shape)(_1694)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1695 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1693)));
  _checked_ptr_1<long long> _ptr__1695(_1695 ? _1695->raw() : nullptr,_1695 ? _1695->size(0) : 0);
  _ptr__1695[(_1693 - (int)1)] = (int)1;
  int _7384 = (int)1;
  int _7385 = _1693;
  for (int _1696 = _7384; _1696 < _7385; ++_1696)
  {
    {
      _ptr__1695[((_1693 - _1696) - (int)1)] = safe_mul( _ptr__1695[(_1693 - _1696)],((*shape)((_1693 - _1696))) );
    }
  }
  long long _1697 = (long long)0;
  int _7386 = (int)0;
  int _7387 = (int)((_1691)->size(0));
  for (int _1698 = _7386; _1698 < _7387; ++_1698)
  {
    {
      _1697 += safe_mul( _ptr__1690[_1698],_ptr__1695[_1698] );
    }
  }
  long long _1699 = (long long)0;
  int _7388 = (int)0;
  int _7389 = (int)((_1691)->size(0));
  for (int _1700 = _7388; _1700 < _7389; ++_1700)
  {
    {
      _1699 += safe_mul( _ptr__1691[_1700],_ptr__1695[_1700] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1701 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1692)));
      _checked_ptr_1<long long> _ptr__1701(_1701 ? _1701->raw() : nullptr,_1701 ? _1701->size(0) : 0);
      int _7390 = (int)0;
      int _7391 = _1692;
      for (int _1702 = _7390; _1702 < _7391; ++_1702)
      {
        {
          _ptr__1701[_1702] = ((*nativeidxs)(safe_add( _1697,safe_mul( _1699,_1702 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1692)}),nullptr,_1701)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1703 = (int)0;
      int _7392 = (int)0;
      int _7393 = _1692;
      for (int _1704 = _7392; _1704 < _7393; ++_1704)
      {
        {
          long long _1705 = safe_add( _1697,safe_mul( _1699,_1704 ) );
          int _1706 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1705);
          if ((_1706 >= (int)0))
          {
            {
              ++ _1703;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1707 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1703)));
      _checked_ptr_1<long long> _ptr__1707(_1707 ? _1707->raw() : nullptr,_1707 ? _1707->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1708 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1703)));
      _checked_ptr_1<long long> _ptr__1708(_1708 ? _1708->raw() : nullptr,_1708 ? _1708->size(0) : 0);
      int _1709 = (int)0;
      int _7394 = (int)0;
      int _7395 = _1692;
      for (int _1710 = _7394; _1710 < _7395; ++_1710)
      {
        {
          _ptr__1707[_1710] = ((*nativeidxs)(safe_add( _1697,safe_mul( _1699,_1710 ) )));
          long long _1711 = safe_add( _1697,safe_mul( _1699,_1710 ) );
          int _1712 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1711);
          if ((_1712 >= (int)0))
          {
            {
              _ptr__1708[_1709] = _1710;
              _ptr__1707[_1709] = ((*nativeidxs)(_1712));
              ++ _1709;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1692)}),_1708,_1707)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1713,_1714); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__slice(_1713,_1714); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__slice(_1713,_1714); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714){
  _checked_ptr_1<int> _ptr__1713(_1713 ? _1713->raw() : nullptr, _1713 ? _1713->size(0) : 0);
  _checked_ptr_1<int> _ptr__1714(_1714 ? _1714->raw() : nullptr, _1714 ? _1714->size(0) : 0);
  if (((int)((_1713)->size(0)) != (int)((_1714)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1713)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7396 = (int)0;
      int _7397 = (int)((shape)->size(0));
      for (int _1715 = _7396; _1715 < _7397; ++_1715)
      {
        {
          if (((_ptr__1713[_1715] < (int)0) || (_ptr__1714[_1715] > ((*shape)(_1715)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1713[_1715] > _ptr__1714[_1715]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1716 = (int)((shape)->size(0));
      std::vector<int> _7398;
      for (int _1718 = (int)0, _7399 = _1716; _1718 < _7399 ; ++_1718)
      {
        _7398.push_back((_ptr__1714[_1718] - _ptr__1713[_1718]));
      }
      auto _7400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7398.size()),_7398.begin(),_7398.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1717 = _7400;
      _checked_ptr_1<int> _ptr__1717(_1717 ? _1717->raw() : nullptr,_1717 ? _1717->size(0) : 0);
      int _1719 = (int)1;
      int _7401 = (int)0;
      int _7402 = _1716;
      for (int _1720 = _7401; _1720 < _7402; ++_1720)
      {
        {
          _1719 *= (_ptr__1714[_1720] - _ptr__1713[_1720]);
        }
      }
      if ((_1719 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1721 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1722 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1716)));
          _checked_ptr_1<int> _ptr__1722(_1722 ? _1722->raw() : nullptr,_1722 ? _1722->size(0) : 0);
          int _7403 = (int)0;
          int _7404 = (int)((sparsity)->size(0));
          for (int _1723 = _7403; _1723 < _7404; ++_1723)
          {
            {
              long long _1724 = ((*sparsity)(_1723));
              int _7405 = (int)1;
              int _7406 = _1716;
              for (int _1725 = _7405; _1725 < _7406; ++_1725)
              {
                {
                  _ptr__1722[(_1716 - _1725)] = (int)(_1724 % ((*shape)((_1716 - _1725))));
                  _1724 /= ((*shape)((_1716 - _1725)));
                }
              }
              _ptr__1722[(int)0] = (int)_1724;
              int _1726 = (int)0;
              while ( ((_ptr__1722[_1726] >= _ptr__1713[_1726]) && (_ptr__1722[_1726] < _ptr__1714[_1726])) )
              {
                {
                  ++ _1726;
                }
              }
              if ((_1726 == _1716))
              {
                {
                  ++ _1721;
                }
              }
              {}
            }
          }
          int _1727 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1728 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1721)));
          _checked_ptr_1<long long> _ptr__1728(_1728 ? _1728->raw() : nullptr,_1728 ? _1728->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1729 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1721)));
          _checked_ptr_1<long long> _ptr__1729(_1729 ? _1729->raw() : nullptr,_1729 ? _1729->size(0) : 0);
          int _7407 = (int)0;
          int _7408 = (int)((sparsity)->size(0));
          for (int _1730 = _7407; _1730 < _7408; ++_1730)
          {
            {
              long long _1731 = ((*sparsity)(_1730));
              int _7409 = (int)1;
              int _7410 = _1716;
              for (int _1732 = _7409; _1732 < _7410; ++_1732)
              {
                {
                  _ptr__1722[(_1716 - _1732)] = (int)(_1731 % ((*shape)((_1716 - _1732))));
                  _1731 /= ((*shape)((_1716 - _1732)));
                }
              }
              _ptr__1722[(int)0] = (int)_1731;
              int _1733 = (int)0;
              while ( ((_ptr__1722[_1733] >= _ptr__1713[_1733]) && (_ptr__1722[_1733] < _ptr__1714[_1733])) )
              {
                {
                  ++ _1733;
                }
              }
              if ((_1733 == _1716))
              {
                {
                  _ptr__1728[_1727] = ((*nativeidxs)(_1730));
                  int _1734 = (int)0;
                  int _7411 = (int)0;
                  int _7412 = _1716;
                  for (int _1735 = _7411; _1735 < _7412; ++_1735)
                  {
                    {
                      _1734 = safe_add( safe_mul( _1734,_ptr__1717[_1735] ),(_ptr__1722[_1735] - _ptr__1713[_1735]) );
                    }
                  }
                  _ptr__1729[_1727] = _1734;
                  ++ _1727;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1717,_1729,_1728)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1736 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1719)));
          _checked_ptr_1<long long> _ptr__1736(_1736 ? _1736->raw() : nullptr,_1736 ? _1736->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1737 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1716)));
            _checked_ptr_1<int> _ptr__1737(_1737 ? _1737->raw() : nullptr,_1737 ? _1737->size(0) : 0);
            _ptr__1737[(_1716 - (int)1)] = (int)1;
            int _7413 = (int)1;
            int _7414 = _1716;
            for (int _1738 = _7413; _1738 < _7414; ++_1738)
            {
              {
                _ptr__1737[((_1716 - _1738) - (int)1)] = safe_mul( _ptr__1737[(_1716 - _1738)],((*shape)((_1716 - _1738))) );
              }
            }
            int _1739 = (int)0;
            int _7415 = (int)0;
            int _7416 = _1716;
            for (int _1740 = _7415; _1740 < _7416; ++_1740)
            {
              {
                _1739 += safe_mul( _ptr__1713[_1740],_ptr__1737[_1740] );
              }
            }
            std::vector<int> _7417;
            for (int _1742 = (int)0, _7418 = _1716; _1742 < _7418 ; ++_1742)
            {
              _7417.push_back(_1739);
            }
            auto _7419 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7417.size()),_7417.begin(),_7417.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1741 = _7419;
            _checked_ptr_1<int> _ptr__1741(_1741 ? _1741->raw() : nullptr,_1741 ? _1741->size(0) : 0);
            std::vector<int> _7420;
            for (int _1744 = (int)0, _7421 = _1716; _1744 < _7421 ; ++_1744)
            {
              _7420.push_back(_ptr__1713[_1744]);
            }
            auto _7422 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7420.size()),_7420.begin(),_7420.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1743 = _7422;
            _checked_ptr_1<int> _ptr__1743(_1743 ? _1743->raw() : nullptr,_1743 ? _1743->size(0) : 0);
            int _7423 = (int)0;
            int _7424 = _1719;
            for (int _1745 = _7423; _1745 < _7424; ++_1745)
            {
              {
                _ptr__1736[_1745] = ((*nativeidxs)(_ptr__1741[(_1716 - (int)1)]));
                _ptr__1743[(_1716 - (int)1)] += (int)1;
                _ptr__1741[(_1716 - (int)1)] += _ptr__1737[(_1716 - (int)1)];
                if ((_ptr__1743[(_1716 - (int)1)] >= _ptr__1714[(_1716 - (int)1)]))
                {
                  {
                    int _1746 = (_1716 - (int)1);
                    while ( ((_1746 > (int)0) && (_ptr__1743[_1746] >= _ptr__1714[_1746])) )
                    {
                      {
                        _ptr__1743[_1746] = _ptr__1713[_1746];
                        _ptr__1743[(_1746 - (int)1)] += (int)1;
                        _ptr__1741[(_1746 - (int)1)] += _ptr__1737[(_1746 - (int)1)];
                        -- _1746;
                      }
                    }
                    int _7425 = safe_add( _1746,(int)1 );
                    int _7426 = _1716;
                    for (int _1747 = _7425; _1747 < _7426; ++_1747)
                    {
                      {
                        _ptr__1741[_1747] = _ptr__1741[_1746];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1717,nullptr,_1736)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1748,int _1749) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1748,_1749); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1748,int _1749) { return __mosek_2fusion_2BaseVariable__slice(_1748,_1749); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1748,int _1749) { return __mosek_2fusion_2BaseVariable__slice(_1748,_1749); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1748,int _1749){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1748 == (int)0) && (_1749 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1748 < (int)0) || (_1749 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1748 > _1749))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1748 == _1749))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1750 = (_1749 - _1748);
      int _1751 = (int)0;
      int _1752 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1748));
      int _1753 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1749));
      std::vector<long long> _7427;
      for (int _1754 = _1752, _7428 = _1753; _1754 < _7428 ; ++_1754)
      {
        _7427.push_back((((*sparsity)(_1754)) - _1748));
      }
      auto _7429 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7427.size()),_7427.begin(),_7427.end()));
      std::vector<long long> _7430;
      for (int _1755 = _1752, _7431 = _1753; _1755 < _7431 ; ++_1755)
      {
        _7430.push_back(((*nativeidxs)(_1755)));
      }
      auto _7432 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7430.size()),_7430.begin(),_7430.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1750)}),_7429,_7432)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1756 = (_1749 - _1748);
      std::shared_ptr< monty::ndarray< long long,1 > > _1757 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1756)));
      _checked_ptr_1<long long> _ptr__1757(_1757 ? _1757->raw() : nullptr,_1757 ? _1757->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1748,_1757,(int)0,_1756);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1756)}),nullptr,_1757)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1758,std::shared_ptr< monty::ndarray< long long,1 > > _1759,int _1760,std::shared_ptr< monty::ndarray< long long,1 > > _1761) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1758,_1759,_1760,_1761); }int mosek::fusion::p_BaseVariable::inst(int _1758,std::shared_ptr< monty::ndarray< long long,1 > > _1759,int _1760,std::shared_ptr< monty::ndarray< long long,1 > > _1761){
  _checked_ptr_1<long long> _ptr__1759(_1759 ? _1759->raw() : nullptr, _1759 ? _1759->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1761(_1761 ? _1761->raw() : nullptr, _1761 ? _1761->size(0) : 0);
  if ((NULL == mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity.get()))
  {
    {
      int _7433 = (int)0;
      int _7434 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
      for (int _1762 = _7433; _1762 < _7434; ++_1762)
      {
        {
          _ptr__1759[safe_add( _1762,_1758 )] = _1762;
          _ptr__1761[safe_add( _1762,_1760 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1762));
        }
      }
    }
  }
  else
  {
    {
      int _7435 = (int)0;
      int _7436 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1763 = _7435; _1763 < _7436; ++_1763)
      {
        {
          _ptr__1759[safe_add( _1758,_1763 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)(_1763));
          _ptr__1761[safe_add( _1763,_1760 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1763));
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1764,std::shared_ptr< monty::ndarray< long long,1 > > _1765) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1764,_1765); }void mosek::fusion::p_BaseVariable::inst(int _1764,std::shared_ptr< monty::ndarray< long long,1 > > _1765){
  _checked_ptr_1<long long> _ptr__1765(_1765 ? _1765->raw() : nullptr, _1765 ? _1765->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7437 = (int)0;
      int _7438 = (int)((nativeidxs)->size(0));
      for (int _1766 = _7437; _1766 < _7438; ++_1766)
      {
        {
          _ptr__1765[safe_add( _1764,_1766 )] = ((*nativeidxs)(_1766));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1767 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1767(_1767 ? _1767->raw() : nullptr,_1767 ? _1767->size(0) : 0);
      int _1768 = (int)1;
      int _7439 = (int)0;
      int _7440 = (int)((_1767)->size(0));
      for (int _1769 = _7439; _1769 < _7440; ++_1769)
      {
        {
          _1768 *= _ptr__1767[_1769];
        }
      }
      int _7441 = (int)0;
      int _7442 = _1768;
      for (int _1770 = _7441; _1770 < _7442; ++_1770)
      {
        {
          _ptr__1765[safe_add( _1764,_1770 )] = (int)0;
        }
      }
      int _7443 = (int)0;
      int _7444 = (int)((sparsity)->size(0));
      for (int _1771 = _7443; _1771 < _7444; ++_1771)
      {
        {
          _ptr__1765[safe_add( _1764,((*sparsity)(_1771)) )] = ((*nativeidxs)(_1771));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1772,bool _1773) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1772,_1773); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1772,bool _1773){
  _checked_ptr_1<double> _ptr__1772(_1772 ? _1772->raw() : nullptr, _1772 ? _1772->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1773,nativeidxs,_1772);
    }
  }
  else
  {
    {
      int _1774 = (int)1;
      int _7445 = (int)0;
      int _7446 = (int)((shape)->size(0));
      for (int _1775 = _7445; _1775 < _7446; ++_1775)
      {
        {
          _1774 *= ((*shape)(_1775));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1776 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1774)));
      _checked_ptr_1<long long> _ptr__1776(_1776 ? _1776->raw() : nullptr,_1776 ? _1776->size(0) : 0);
      int _7447 = (int)0;
      int _7448 = (int)((nativeidxs)->size(0));
      for (int _1777 = _7447; _1777 < _7448; ++_1777)
      {
        {
          _ptr__1776[((*sparsity)(_1777))] = ((*nativeidxs)(_1777));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1773,_1776,_1772);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1778,std::shared_ptr< monty::ndarray< double,1 > > _1779,bool _1780){
  _checked_ptr_1<double> _ptr__1779(_1779 ? _1779->raw() : nullptr, _1779 ? _1779->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1780,nativeidxs,_1779,_1778);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1781 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1781(_1781 ? _1781->raw() : nullptr,_1781 ? _1781->size(0) : 0);
      int _7449 = (int)0;
      int _7450 = (int)((sparsity)->size(0));
      for (int _1782 = _7449; _1782 < _7450; ++_1782)
      {
        {
          _ptr__1781[((*sparsity)(_1782))] = ((*nativeidxs)(_1782));
        }
      }
      model->getVariableDuals(_1780,_1781,_1779,_1778);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1783,std::shared_ptr< monty::ndarray< double,1 > > _1784,bool _1785) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1783,_1784,_1785); }void mosek::fusion::p_BaseVariable::values(int _1783,std::shared_ptr< monty::ndarray< double,1 > > _1784,bool _1785){
  _checked_ptr_1<double> _ptr__1784(_1784 ? _1784->raw() : nullptr, _1784 ? _1784->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1785,nativeidxs,_1784,_1783);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1786 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1786(_1786 ? _1786->raw() : nullptr,_1786 ? _1786->size(0) : 0);
      int _7451 = (int)0;
      int _7452 = (int)((sparsity)->size(0));
      for (int _1787 = _7451; _1787 < _7452; ++_1787)
      {
        {
          _ptr__1786[((*sparsity)(_1787))] = ((*nativeidxs)(_1787));
        }
      }
      model->getVariableValues(_1785,_1786,_1784,_1783);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1795) { return __mosek_2fusion_2Variable__reshape(_1795); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1801,std::shared_ptr< monty::ndarray< int,1 > > _1802,std::shared_ptr< monty::ndarray< int,1 > > _1803) { return __mosek_2fusion_2Variable__pick(_1801,_1802,_1803); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1804,std::shared_ptr< monty::ndarray< int,1 > > _1805) { return __mosek_2fusion_2Variable__pick(_1804,_1805); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1806) { return __mosek_2fusion_2Variable__pick(_1806); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1806) { return __mosek_2fusion_2Variable__pick(_1806); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1807) { return __mosek_2fusion_2Variable__pick(_1807); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1807) { return __mosek_2fusion_2Variable__pick(_1807); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1808) { return __mosek_2fusion_2Variable__antidiag(_1808); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1809) { return __mosek_2fusion_2Variable__diag(_1809); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1810) { return __mosek_2fusion_2Variable__index(_1810); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1810) { return __mosek_2fusion_2Variable__index(_1810); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1811,int _1812,int _1813) { return __mosek_2fusion_2Variable__index(_1811,_1812,_1813); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1814,int _1815) { return __mosek_2fusion_2Variable__index(_1814,_1815); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1816) { return __mosek_2fusion_2Variable__index(_1816); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1816) { return __mosek_2fusion_2Variable__index(_1816); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1817,std::shared_ptr< monty::ndarray< int,1 > > _1818) { return __mosek_2fusion_2Variable__slice(_1817,_1818); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1817,std::shared_ptr< monty::ndarray< int,1 > > _1818) { return __mosek_2fusion_2Variable__slice(_1817,_1818); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1819,int _1820) { return __mosek_2fusion_2Variable__slice(_1819,_1820); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1819,int _1820) { return __mosek_2fusion_2Variable__slice(_1819,_1820); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1821) { return mosek::fusion::p_Var::empty(_1821); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1821){
  _checked_ptr_1<int> _ptr__1821(_1821 ? _1821->raw() : nullptr, _1821 ? _1821->size(0) : 0);
  int _7453 = (int)0;
  int _7454 = (int)((_1821)->size(0));
  for (int _1822 = _7453; _1822 < _7454; ++_1822)
  {
    {
      if ((_ptr__1821[_1822] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1821)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1823) { return mosek::fusion::p_Var::compress(_1823); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1823){
  std::shared_ptr< monty::ndarray< int,1 > > _1824 = _1823->getShape();
  _checked_ptr_1<int> _ptr__1824(_1824 ? _1824->raw() : nullptr,_1824 ? _1824->size(0) : 0);
  int _1825 = (int)((_1824)->size(0));
  int _1826 = (int)0;
  int _7455 = (int)0;
  int _7456 = _1825;
  for (int _1827 = _7455; _1827 < _7456; ++_1827)
  {
    {
      if ((_ptr__1824[_1827] != (int)1))
      {
        {
          ++ _1826;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1828 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1826)));
  _checked_ptr_1<int> _ptr__1828(_1828 ? _1828->raw() : nullptr,_1828 ? _1828->size(0) : 0);
  {
    int _1829 = (int)0;
    int _7457 = (int)0;
    int _7458 = _1825;
    for (int _1830 = _7457; _1830 < _7458; ++_1830)
    {
      {
        if ((_ptr__1824[_1830] != (int)1))
        {
          {
            _ptr__1828[_1829] = _ptr__1824[_1830];
            ++ _1829;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1823,_1828);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1831,    int _1832) { return mosek::fusion::p_Var::reshape(_1831,_1832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1831,int _1832){
  return ::mosek::fusion::p_Var::reshape(_1831,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1832)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1833,    int _1834,    int _1835) { return mosek::fusion::p_Var::reshape(_1833,_1834,_1835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1833,int _1834,int _1835){
  return ::mosek::fusion::p_Var::reshape(_1833,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1834),(int)(_1835)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1836) { return mosek::fusion::p_Var::flatten(_1836); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1836){
  return ::mosek::fusion::p_Var::reshape(_1836,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1836->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1837,    std::shared_ptr< monty::ndarray< int,1 > > _1838) { return mosek::fusion::p_Var::reshape(_1837,_1838); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1837,std::shared_ptr< monty::ndarray< int,1 > > _1838){
  _checked_ptr_1<int> _ptr__1838(_1838 ? _1838->raw() : nullptr, _1838 ? _1838->size(0) : 0);
  return _1837->__mosek_2fusion_2Variable__reshape(_1838);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1839,std::shared_ptr< monty::ndarray< int,1 > > _1840){
  _checked_ptr_1<int> _ptr__1840(_1840 ? _1840->raw() : nullptr, _1840 ? _1840->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1841;
  _checked_ptr_1<long long> _ptr__1841(_1841 ? _1841->raw() : nullptr,_1841 ? _1841->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1842;
  _checked_ptr_1<long long> _ptr__1842(_1842 ? _1842->raw() : nullptr,_1842 ? _1842->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1843 = _1839->getShape();
  _checked_ptr_1<int> _ptr__1843(_1843 ? _1843->raw() : nullptr,_1843 ? _1843->size(0) : 0);
  int _1844 = (int)((_1843)->size(0));
  int _1845 = (int)1;
  int _7459 = (int)0;
  int _7460 = _1844;
  for (int _1846 = _7459; _1846 < _7460; ++_1846)
  {
    {
      _1845 *= _ptr__1843[_1846];
    }
  }
  int _1847 = _1839->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1848 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
  _checked_ptr_1<long long> _ptr__1848(_1848 ? _1848->raw() : nullptr,_1848 ? _1848->size(0) : 0);
  _ptr__1848[(_1844 - (int)1)] = (int)1;
  int _7461 = (int)1;
  int _7462 = _1844;
  for (int _1849 = _7461; _1849 < _7462; ++_1849)
  {
    {
      _ptr__1848[((_1844 - _1849) - (int)1)] = safe_mul( _ptr__1848[(_1844 - _1849)],_ptr__1843[_ptr__1840[(_1844 - _1849)]] );
    }
  }
  if ((_1847 < _1845))
  {
    {
      _1841 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1847)));
      _ptr__1841.update(_1841 ? _1841->raw() : nullptr, _1841 ? _1841->size(0) : 0);
      _1842 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1847)));
      _ptr__1842.update(_1842 ? _1842->raw() : nullptr, _1842 ? _1842->size(0) : 0);
      _1839->inst((int)0,_1841,(int)0,_1842);
    }
  }
  else
  {
    {
      _1841 = nullptr;
      _ptr__1841.update(_1841 ? _1841->raw() : nullptr, _1841 ? _1841->size(0) : 0);
      _1842 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1847)));
      _ptr__1842.update(_1842 ? _1842->raw() : nullptr, _1842 ? _1842->size(0) : 0);
      _1839->inst((int)0,_1842);
    }
  }
  if ((NULL == _1841.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1850 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1847)));
      _checked_ptr_1<long long> _ptr__1850(_1850 ? _1850->raw() : nullptr,_1850 ? _1850->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1844)));
        _checked_ptr_1<int> _ptr__1851(_1851 ? _1851->raw() : nullptr,_1851 ? _1851->size(0) : 0);
        int _7463 = (int)0;
        int _7464 = _1847;
        for (int _1852 = _7463; _1852 < _7464; ++_1852)
        {
          {
            int _1853 = _1852;
            int _7465 = (int)0;
            int _7466 = _1844;
            for (int _1854 = _7465; _1854 < _7466; ++_1854)
            {
              {
                _ptr__1851[((_1844 - _1852) - (int)1)] = (_1853 % _ptr__1843[((_1844 - _1852) - (int)1)]);
                _1853 /= _ptr__1843[((_1844 - _1852) - (int)1)];
              }
            }
            int _1855 = (int)0;
            int _7467 = (int)0;
            int _7468 = _1844;
            for (int _1856 = _7467; _1856 < _7468; ++_1856)
            {
              {
                _1855 += (int)safe_mul( _ptr__1851[_ptr__1840[_1856]],_ptr__1848[_1856] );
              }
            }
            _ptr__1850[_1855] = _ptr__1842[_1852];
          }
        }
      }
      _1842 = _1850;
      _ptr__1842.update(_1842 ? _1842->raw() : nullptr, _1842 ? _1842->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1857 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1847)));
      _checked_ptr_1<long long> _ptr__1857(_1857 ? _1857->raw() : nullptr,_1857 ? _1857->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1858 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1844)));
        _checked_ptr_1<int> _ptr__1858(_1858 ? _1858->raw() : nullptr,_1858 ? _1858->size(0) : 0);
        int _7469 = (int)0;
        int _7470 = _1847;
        for (int _1859 = _7469; _1859 < _7470; ++_1859)
        {
          {
            int _1860 = _1859;
            int _7471 = (int)0;
            int _7472 = _1844;
            for (int _1861 = _7471; _1861 < _7472; ++_1861)
            {
              {
                _ptr__1858[((_1844 - _1859) - (int)1)] = (_1860 % _ptr__1843[((_1844 - _1859) - (int)1)]);
                _1860 /= _ptr__1843[((_1844 - _1859) - (int)1)];
              }
            }
            int _1862 = (int)0;
            int _7473 = (int)0;
            int _7474 = _1844;
            for (int _1863 = _7473; _1863 < _7474; ++_1863)
            {
              {
                _1862 += (int)safe_mul( _ptr__1858[_ptr__1840[_1863]],_ptr__1848[_1863] );
              }
            }
            _ptr__1857[_1859] = _1862;
          }
        }
      }
      std::vector<long long> _7475;
      for (int _1865 = (int)0, _7476 = _1847; _1865 < _7476 ; ++_1865)
      {
        _7475.push_back(_1865);
      }
      auto _7477 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7475.size()),_7475.begin(),_7475.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1864 = _7477;
      _checked_ptr_1<long long> _ptr__1864(_1864 ? _1864->raw() : nullptr,_1864 ? _1864->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1864,_1857,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1847));
      std::vector<long long> _7478;
      for (int _1866 = (int)0, _7479 = _1847; _1866 < _7479 ; ++_1866)
      {
        _7478.push_back(_ptr__1841[_ptr__1864[_1866]]);
      }
      auto _7480 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7478.size()),_7478.begin(),_7478.end()));
      _1841 = _7480;
      _ptr__1841.update(_1841 ? _1841->raw() : nullptr, _1841 ? _1841->size(0) : 0);
      std::vector<long long> _7481;
      for (int _1867 = (int)0, _7482 = _1847; _1867 < _7482 ; ++_1867)
      {
        _7481.push_back(_ptr__1842[_ptr__1864[_1867]]);
      }
      auto _7483 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7481.size()),_7481.begin(),_7481.end()));
      _1842 = _7483;
      _ptr__1842.update(_1842 ? _1842->raw() : nullptr, _1842 ? _1842->size(0) : 0);
    }
  }
  std::vector<int> _7484;
  for (int _1868 = (int)0, _7485 = _1844; _1868 < _7485 ; ++_1868)
  {
    _7484.push_back(_ptr__1843[_ptr__1840[_1868]]);
  }
  auto _7486 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7484.size()),_7484.begin(),_7484.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1839->__mosek_2fusion_2Variable__getModel(),_7486,_1841,_1842)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1869,    int _1870) { return mosek::fusion::p_Var::hrepeat(_1869,_1870); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1869,int _1870){
  return ::mosek::fusion::p_Var::drepeat(_1869,(int)1,_1870);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1871,    int _1872) { return mosek::fusion::p_Var::vrepeat(_1871,_1872); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1871,int _1872){
  return ::mosek::fusion::p_Var::drepeat(_1871,(int)0,_1872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1873,    int _1874) { return mosek::fusion::p_Var::repeat(_1873,_1874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1873,int _1874){
  return ::mosek::fusion::p_Var::drepeat(_1873,(int)0,_1874);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1875,    int _1876,    int _1877) { return mosek::fusion::p_Var::repeat(_1875,_1876,_1877); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1875,int _1876,int _1877){
  return ::mosek::fusion::p_Var::drepeat(_1875,_1876,_1877);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1878,int _1879,int _1880){
  if ((_1880 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1880 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1880 == (int)1))
  {
    {
      return _1878;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1881 = _1878->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1882 = _1878->getShape();
      _checked_ptr_1<int> _ptr__1882(_1882 ? _1882->raw() : nullptr,_1882 ? _1882->size(0) : 0);
      int _1883 = (int)((_1882)->size(0));
      if (((_1879 < (int)0) || (_1879 > _1883)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1884 = ::mosek::fusion::p_Set::size(_1882);
      int _1885 = _1878->numInst();
      int _1886 = safe_mul( _1885,_1880 );
      int _1887 = (int)1;
      int _7487 = (int)0;
      int _7488 = _1879;
      for (int _1888 = _7487; _1888 < _7488; ++_1888)
      {
        {
          _1887 *= _ptr__1882[_1888];
        }
      }
      int _7489;
      bool _7490 = (_1879 < _1883);
      if (_7490)
      {
        _7489 = _ptr__1882[_1879];
      }
      else
      {
        _7489 = (int)1;
      }
      int _1889 = _7489;
      int _1890 = safe_mul( _1889,_1880 );
      int _1891 = (int)1;
      int _7491 = safe_add( _1879,(int)1 );
      int _7492 = _1883;
      for (int _1892 = _7491; _1892 < _7492; ++_1892)
      {
        {
          _1891 *= _ptr__1882[_1892];
        }
      }
      int _7493;
      bool _7494 = (_1879 < _1883);
      if (_7494)
      {
        _7493 = _1883;
      }
      else
      {
        _7493 = safe_add( _1879,(int)1 );
      }
      int _1893 = _7493;
      std::shared_ptr< monty::ndarray< int,1 > > _1894 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1893)));
      _checked_ptr_1<int> _ptr__1894(_1894 ? _1894->raw() : nullptr,_1894 ? _1894->size(0) : 0);
      int _7495 = (int)0;
      int _7496 = _1883;
      for (int _1895 = _7495; _1895 < _7496; ++_1895)
      {
        {
          _ptr__1894[_1895] = _ptr__1882[_1895];
        }
      }
      int _7497 = _1883;
      int _7498 = _1893;
      for (int _1896 = _7497; _1896 < _7498; ++_1896)
      {
        {
          _ptr__1894[_1896] = (int)1;
        }
      }
      _ptr__1894[_1879] = _1890;
      if ((_1885 < _1884))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1897 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1885)));
          _checked_ptr_1<long long> _ptr__1897(_1897 ? _1897->raw() : nullptr,_1897 ? _1897->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1898 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1885)));
          _checked_ptr_1<long long> _ptr__1898(_1898 ? _1898->raw() : nullptr,_1898 ? _1898->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1899 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1886)));
          _checked_ptr_1<long long> _ptr__1899(_1899 ? _1899->raw() : nullptr,_1899 ? _1899->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1900 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1886)));
          _checked_ptr_1<long long> _ptr__1900(_1900 ? _1900->raw() : nullptr,_1900 ? _1900->size(0) : 0);
          _1878->inst((int)0,_1898,(int)0,_1897);
          {
            int _1901 = safe_mul( _1890,_1891 );
            int _1902 = safe_mul( _1889,_1891 );
            int _1903 = _1891;
            if ((_1879 == (int)0))
            {
              {
                int _1904 = (int)0;
                int _7499 = (int)0;
                int _7500 = _1880;
                for (int _1905 = _7499; _1905 < _7500; ++_1905)
                {
                  {
                    int _7501 = (int)0;
                    int _7502 = _1885;
                    for (int _1906 = _7501; _1906 < _7502; ++_1906)
                    {
                      {
                        _ptr__1900[_1904] = safe_add( _ptr__1898[_1906],safe_mul( _1905,_1884 ) );
                        _ptr__1899[_1904] = _ptr__1897[_1906];
                        ++ _1904;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1881,_1894,_1900,_1899)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1879 >= _1883))
            {
              {
                int _1907 = (int)0;
                int _7503 = (int)0;
                int _7504 = _1885;
                for (int _1908 = _7503; _1908 < _7504; ++_1908)
                {
                  {
                    int _7505 = (int)0;
                    int _7506 = _1880;
                    for (int _1909 = _7505; _1909 < _7506; ++_1909)
                    {
                      {
                        _ptr__1900[_1907] = safe_add( safe_mul( _ptr__1898[_1908],_1880 ),_1909 );
                        _ptr__1899[_1907] = _ptr__1897[_1908];
                        ++ _1907;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1881,_1894,_1900,_1899)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1910 = (int)0;
                int _7507 = (int)0;
                int _7508 = _1885;
                for (int _1911 = _7507; _1911 < _7508; ++_1911)
                {
                  {
                    long long _1912 = (_ptr__1898[_1911] / _1902);
                    long long _1913 = ((_ptr__1898[_1911] / _1903) % _1889);
                    long long _1914 = (_ptr__1898[_1911] % _1891);
                    int _7509 = (int)0;
                    int _7510 = _1880;
                    for (int _1915 = _7509; _1915 < _7510; ++_1915)
                    {
                      {
                        _ptr__1900[_1910] = safe_add( safe_add( safe_mul( _1912,_1901 ),safe_mul( safe_add( _1913,safe_mul( _1889,_1915 ) ),_1891 ) ),_1914 );
                        _ptr__1899[_1910] = _ptr__1897[_1911];
                        ++ _1910;
                      }
                    }
                  }
                }
                int _1916 = (int)1;
                int _7511 = (int)0;
                int _7512 = _1893;
                for (int _1917 = _7511; _1917 < _7512; ++_1917)
                {
                  {
                    if ((_1916 < _ptr__1894[_1917]))
                    {
                      {
                        _1916 = _ptr__1894[_1917];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1918 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1886)));
                _checked_ptr_1<int> _ptr__1918(_1918 ? _1918->raw() : nullptr,_1918 ? _1918->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1919 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1886)));
                _checked_ptr_1<int> _ptr__1919(_1919 ? _1919->raw() : nullptr,_1919 ? _1919->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1920 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1916,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1920(_1920 ? _1920->raw() : nullptr,_1920 ? _1920->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1921 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1893)));
                  _checked_ptr_1<long long> _ptr__1921(_1921 ? _1921->raw() : nullptr,_1921 ? _1921->size(0) : 0);
                  _ptr__1921[(_1893 - (int)1)] = (int)1;
                  int _7513 = (int)1;
                  int _7514 = _1893;
                  for (int _1922 = _7513; _1922 < _7514; ++_1922)
                  {
                    {
                      _ptr__1921[((_1893 - _1922) - (int)1)] = safe_mul( _ptr__1921[(_1893 - _1922)],_ptr__1894[(_1893 - _1922)] );
                    }
                  }
                  int _7515 = (int)0;
                  int _7516 = _1886;
                  for (int _1923 = _7515; _1923 < _7516; ++_1923)
                  {
                    {
                      _ptr__1918[_1923] = _1923;
                    }
                  }
                  int _7517 = (int)0;
                  int _7518 = _1893;
                  for (int _1924 = _7517; _1924 < _7518; ++_1924)
                  {
                    {
                      int _1925 = ((_1893 - _1924) - (int)1);
                      int _7519 = (int)0;
                      int _7520 = safe_add( _ptr__1894[_1925],(int)1 );
                      for (int _1926 = _7519; _1926 < _7520; ++_1926)
                      {
                        {
                          _ptr__1920[_1926] = (int)0;
                        }
                      }
                      int _7521 = (int)0;
                      int _7522 = _1886;
                      for (int _1927 = _7521; _1927 < _7522; ++_1927)
                      {
                        {
                          ++ _ptr__1920[safe_add( ((_ptr__1900[_1927] / _ptr__1921[_1925]) % _ptr__1894[_1925]),(int)1 )];
                        }
                      }
                      int _7523 = (int)0;
                      int _7524 = _ptr__1894[_1925];
                      for (int _1928 = _7523; _1928 < _7524; ++_1928)
                      {
                        {
                          _ptr__1920[safe_add( _1928,(int)1 )] += _ptr__1920[_1928];
                        }
                      }
                      int _7525 = (int)0;
                      int _7526 = _1886;
                      for (int _1929 = _7525; _1929 < _7526; ++_1929)
                      {
                        {
                          int _1930 = _ptr__1918[_1929];
                          long long _1931 = ((_ptr__1900[_1930] / _ptr__1921[_1925]) % _ptr__1894[_1925]);
                          _ptr__1919[_ptr__1920[_1931]] = _1930;
                          ++ _ptr__1920[_1931];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1932 = _1918;
                      _checked_ptr_1<int> _ptr__1932(_1932 ? _1932->raw() : nullptr,_1932 ? _1932->size(0) : 0);
                      _1918 = _1919;
                      _ptr__1918.update(_1918 ? _1918->raw() : nullptr, _1918 ? _1918->size(0) : 0);
                      _1919 = _1932;
                      _ptr__1919.update(_1919 ? _1919->raw() : nullptr, _1919 ? _1919->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7527;
                for (int _1933 = (int)0, _7528 = _1886; _1933 < _7528 ; ++_1933)
                {
                  _7527.push_back(_ptr__1900[_ptr__1918[_1933]]);
                }
                auto _7529 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7527.size()),_7527.begin(),_7527.end()));
                std::vector<long long> _7530;
                for (int _1934 = (int)0, _7531 = _1886; _1934 < _7531 ; ++_1934)
                {
                  _7530.push_back(_ptr__1899[_ptr__1918[_1934]]);
                }
                auto _7532 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7530.size()),_7530.begin(),_7530.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1881,_1894,_7529,_7532)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1935 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1885)));
          _checked_ptr_1<long long> _ptr__1935(_1935 ? _1935->raw() : nullptr,_1935 ? _1935->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1936 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1885,_1880 ))));
          _checked_ptr_1<long long> _ptr__1936(_1936 ? _1936->raw() : nullptr,_1936 ? _1936->size(0) : 0);
          _1878->inst((int)0,_1935);
          int _1937 = safe_mul( _1890,_1891 );
          int _1938 = _1891;
          int _1939 = (int)0;
          int _7533 = (int)0;
          int _7534 = _1887;
          for (int _1940 = _7533; _1940 < _7534; ++_1940)
          {
            {
              int _7535 = (int)0;
              int _7536 = _1889;
              for (int _1941 = _7535; _1941 < _7536; ++_1941)
              {
                {
                  int _7537 = (int)0;
                  int _7538 = _1891;
                  for (int _1942 = _7537; _1942 < _7538; ++_1942)
                  {
                    {
                      int _7539 = (int)0;
                      int _7540 = _1880;
                      for (int _1943 = _7539; _1943 < _7540; ++_1943)
                      {
                        {
                          _ptr__1936[safe_add( safe_add( safe_mul( _1940,_1937 ),safe_mul( safe_add( _1941,safe_mul( _1943,_1889 ) ),_1938 ) ),_1942 )] = _ptr__1935[_1939];
                        }
                      }
                      ++ _1939;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1881,_1894,nullptr,_1936)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1944) { return mosek::fusion::p_Var::stack(_1944); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1944){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7541;
  for (int _1945 = (int)0, _7542 = (int)((_1944)->size(0)); _1945 < _7542 ; ++_1945)
  {
    _7541.push_back(::mosek::fusion::p_Var::dstack(((*_1944)(_1945)),(int)1));
  }
  auto _7543 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7541.size()),_7541.begin(),_7541.end()));
  return ::mosek::fusion::p_Var::dstack(_7543,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1946,    monty::rc_ptr< ::mosek::fusion::Variable > _1947,    monty::rc_ptr< ::mosek::fusion::Variable > _1948) { return mosek::fusion::p_Var::vstack(_1946,_1947,_1948); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1946,monty::rc_ptr< ::mosek::fusion::Variable > _1947,monty::rc_ptr< ::mosek::fusion::Variable > _1948){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1946.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1947.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1948.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1949,    monty::rc_ptr< ::mosek::fusion::Variable > _1950) { return mosek::fusion::p_Var::vstack(_1949,_1950); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1949,monty::rc_ptr< ::mosek::fusion::Variable > _1950){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1949.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1950.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1951) { return mosek::fusion::p_Var::vstack(_1951); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1951){
  return ::mosek::fusion::p_Var::dstack(_1951,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1952,    monty::rc_ptr< ::mosek::fusion::Variable > _1953,    monty::rc_ptr< ::mosek::fusion::Variable > _1954) { return mosek::fusion::p_Var::hstack(_1952,_1953,_1954); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1952,monty::rc_ptr< ::mosek::fusion::Variable > _1953,monty::rc_ptr< ::mosek::fusion::Variable > _1954){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1952.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1953.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1954.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1955,    monty::rc_ptr< ::mosek::fusion::Variable > _1956) { return mosek::fusion::p_Var::hstack(_1955,_1956); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1955,monty::rc_ptr< ::mosek::fusion::Variable > _1956){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1955.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1956.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1957) { return mosek::fusion::p_Var::hstack(_1957); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1957){
  return ::mosek::fusion::p_Var::dstack(_1957,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1958,    monty::rc_ptr< ::mosek::fusion::Variable > _1959,    monty::rc_ptr< ::mosek::fusion::Variable > _1960,    int _1961) { return mosek::fusion::p_Var::stack(_1958,_1959,_1960,_1961); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1958,monty::rc_ptr< ::mosek::fusion::Variable > _1959,monty::rc_ptr< ::mosek::fusion::Variable > _1960,int _1961){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1958.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1959.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1960.get())}),_1961);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1962,    monty::rc_ptr< ::mosek::fusion::Variable > _1963,    int _1964) { return mosek::fusion::p_Var::stack(_1962,_1963,_1964); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1962,monty::rc_ptr< ::mosek::fusion::Variable > _1963,int _1964){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1962.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1963.get())}),_1964);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1965,    int _1966) { return mosek::fusion::p_Var::stack(_1965,_1966); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1965,int _1966){
  int _1967 = _1966;
  int _7544 = (int)0;
  int _7545 = (int)((_1965)->size(0));
  for (int _1968 = _7544; _1968 < _7545; ++_1968)
  {
    {
      if ((_1967 < ((*_1965)(_1968))->getND()))
      {
        {
          _1967 = ((*_1965)(_1968))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_1965,_1966);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _1969,    int _1970) { return mosek::fusion::p_Var::promote(_1969,_1970); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _1969,int _1970){
  if ((_1970 > _1969->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1971 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1970)));
      _checked_ptr_1<int> _ptr__1971(_1971 ? _1971->raw() : nullptr,_1971 ? _1971->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1972 = _1969->getShape();
      _checked_ptr_1<int> _ptr__1972(_1972 ? _1972->raw() : nullptr,_1972 ? _1972->size(0) : 0);
      int _7546 = (int)0;
      int _7547 = (int)((_1972)->size(0));
      for (int _1973 = _7546; _1973 < _7547; ++_1973)
      {
        {
          _ptr__1971[_1973] = _ptr__1972[_1973];
        }
      }
      int _7548 = (int)((_1972)->size(0));
      int _7549 = _1970;
      for (int _1974 = _7548; _1974 < _7549; ++_1974)
      {
        {
          _ptr__1971[_1974] = (int)1;
        }
      }
      return _1969->__mosek_2fusion_2Variable__reshape(_1971);
    }
  }
  else
  {
    {
      return _1969;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1975,int _1976){
  if ((_1976 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _1977 = nullptr;
  {
    int _7550 = (int)0;
    int _7551 = (int)((_1975)->size(0));
    for (int _1978 = _7550; _1978 < _7551; ++_1978)
    {
      {
        if ((NULL == _1977.get()))
        {
          {
            _1977 = ((*_1975)(_1978))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_1975)(_1978))->__mosek_2fusion_2Variable__getModel().get()) && (((*_1975)(_1978))->__mosek_2fusion_2Variable__getModel() != _1977)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1979 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7552;
            bool _7553 = ((int)((mosek::fusion::p_Model::_get_impl(_1977.get())->getName()).size()) > (int)0);
            if (_7553)
            {
              _7552 = mosek::fusion::p_Model::_get_impl(_1977.get())->getName();
            }
            else
            {
              _7552 = std::string ("?");
            }
            std::string _1980 = _7552;
            std::string _7554;
            bool _7555 = ((int)((mosek::fusion::p_Model::_get_impl(((*_1975)(_1978))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7555)
            {
              _7554 = mosek::fusion::p_Model::_get_impl(((*_1975)(_1978))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7554 = std::string ("?");
            }
            std::string _1981 = _7554;
            _1979->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1980)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1981)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_1979->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_1975)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_1975)->size(0)) == (int)1))
  {
    {
      return ((*_1975)((int)1));
    }
  }
  else
  {
    {
      int _1982 = (int)((_1975)->size(0));
      std::vector<int> _7556;
      for (int _1984 = (int)0, _7557 = _1982; _1984 < _7557 ; ++_1984)
      {
        _7556.push_back(((*_1975)(_1984))->numInst());
      }
      auto _7558 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7556.size()),_7556.begin(),_7556.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1983 = _7558;
      _checked_ptr_1<int> _ptr__1983(_1983 ? _1983->raw() : nullptr,_1983 ? _1983->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7559;
      for (int _1986 = (int)0, _7560 = _1982; _1986 < _7560 ; ++_1986)
      {
        _7559.push_back(((*_1975)(_1986))->getShape());
      }
      auto _7561 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7559.size()),_7559.begin(),_7559.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _1985 = _7561;
      std::vector<int> _7562;
      for (int _1988 = (int)0, _7563 = _1982; _1988 < _7563 ; ++_1988)
      {
        _7562.push_back((int)((((*_1985)(_1988)))->size(0)));
      }
      auto _7564 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7562.size()),_7562.begin(),_7562.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1987 = _7564;
      _checked_ptr_1<int> _ptr__1987(_1987 ? _1987->raw() : nullptr,_1987 ? _1987->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1989 = ((*_1985)((int)0));
      _checked_ptr_1<int> _ptr__1989(_1989 ? _1989->raw() : nullptr,_1989 ? _1989->size(0) : 0);
      int _1990 = _ptr__1987[(int)0];
      int _1991 = (int)0;
      int _7565 = (int)0;
      int _7566 = _1982;
      for (int _1992 = _7565; _1992 < _7566; ++_1992)
      {
        {
          _1991 += _ptr__1983[_1992];
        }
      }
      int _1993 = safe_add( _1976,(int)1 );
      int _7567 = (int)0;
      int _7568 = _1982;
      for (int _1994 = _7567; _1994 < _7568; ++_1994)
      {
        {
          if ((_1993 < _ptr__1987[_1994]))
          {
            {
              _1993 = _ptr__1987[_1994];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _1995 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1993)));
      _checked_ptr_1<int> _ptr__1995(_1995 ? _1995->raw() : nullptr,_1995 ? _1995->size(0) : 0);
      int _7569 = (int)0;
      int _7570 = _1990;
      for (int _1996 = _7569; _1996 < _7570; ++_1996)
      {
        {
          _ptr__1995[_1996] = _ptr__1989[_1996];
        }
      }
      int _7571 = _1990;
      int _7572 = _1993;
      for (int _1997 = _7571; _1997 < _7572; ++_1997)
      {
        {
          _ptr__1995[_1997] = (int)1;
        }
      }
      _ptr__1995[_1976] = (int)0;
      int _7573 = (int)0;
      int _7574 = _1982;
      for (int _1998 = _7573; _1998 < _7574; ++_1998)
      {
        {
          int _7575;
          bool _7576 = ((int)((((*_1985)(_1998)))->size(0)) > _1976);
          if (_7576)
          {
            _7575 = ((*((*_1985)(_1998)))(_1976));
          }
          else
          {
            _7575 = (int)1;
          }
          _ptr__1995[_1976] += _7575;
        }
      }
      int _7577 = (int)0;
      int _7578 = _1982;
      for (int _1999 = _7577; _1999 < _7578; ++_1999)
      {
        {
          int _7579 = (int)0;
          int _7580 = (int)((((*_1985)(_1999)))->size(0));
          for (int _2000 = _7579; _2000 < _7580; ++_2000)
          {
            {
              if (((_2000 != _1976) && (((*((*_1985)(_1999)))(_2000)) != _ptr__1995[_2000])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7581 = (int)((((*_1985)(_1999)))->size(0));
          int _7582 = _1993;
          for (int _2001 = _7581; _2001 < _7582; ++_2001)
          {
            {
              if (((_2001 != _1976) && ((int)1 != _ptr__1995[_2001])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2002 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1991)));
      _checked_ptr_1<long long> _ptr__2002(_2002 ? _2002->raw() : nullptr,_2002 ? _2002->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2003 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1991)));
      _checked_ptr_1<long long> _ptr__2003(_2003 ? _2003->raw() : nullptr,_2003 ? _2003->size(0) : 0);
      std::vector<int> _7583;
      for (int _2005 = (int)0, _7584 = (int)((_1975)->size(0)); _2005 < _7584 ; ++_2005)
      {
        int _7585;
        bool _7586 = (_1976 < (int)((((*_1985)(_2005)))->size(0)));
        if (_7586)
        {
          _7585 = ((*((*_1985)(_2005)))(_1976));
        }
        else
        {
          _7585 = (int)1;
        }
        _7583.push_back(_7585);
      }
      auto _7587 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7583.size()),_7583.begin(),_7583.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2004 = _7587;
      _checked_ptr_1<int> _ptr__2004(_2004 ? _2004->raw() : nullptr,_2004 ? _2004->size(0) : 0);
      int _2006 = (int)1;
      int _7588 = (int)0;
      int _7589 = _1976;
      for (int _2007 = _7588; _2007 < _7589; ++_2007)
      {
        {
          int _7590;
          bool _7591 = (_2007 < (int)((_1989)->size(0)));
          if (_7591)
          {
            _7590 = _ptr__1989[_2007];
          }
          else
          {
            _7590 = (int)1;
          }
          _2006 *= _7590;
        }
      }
      int _2008 = (int)0;
      int _7592 = (int)0;
      int _7593 = _1982;
      for (int _2009 = _7592; _2009 < _7593; ++_2009)
      {
        {
          _2008 += _ptr__2004[_2009];
        }
      }
      int _2010 = (int)1;
      int _7594 = safe_add( _1976,(int)1 );
      int _7595 = (int)((_1989)->size(0));
      for (int _2011 = _7594; _2011 < _7595; ++_2011)
      {
        {
          _2010 *= _ptr__1989[_2011];
        }
      }
      if ((_2006 == (int)1))
      {
        {
          int _2012 = (int)0;
          long long _2013 = (int)0;
          int _7596 = (int)0;
          int _7597 = _1982;
          for (int _2014 = _7596; _2014 < _7597; ++_2014)
          {
            {
              ((*_1975)(_2014))->inst(_2012,_2003,_2012,_2002);
              int _7598 = (int)0;
              int _7599 = _ptr__1983[_2014];
              for (int _2015 = _7598; _2015 < _7599; ++_2015)
              {
                {
                  _ptr__2003[_2012] += _2013;
                  ++ _2012;
                }
              }
              _2013 += ::mosek::fusion::p_Set::size(((*_1985)(_2014)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7600;
          bool _7601 = (_1991 < safe_mul( safe_mul( _2006,_2008 ),_2010 ));
          if (_7601)
          {
            _7600 = _2003;
          }
          else
          {
            _7600 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1977,_1995,_7600,_2002)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2016 = (int)0;
          int _7602 = (int)0;
          int _7603 = _1982;
          for (int _2017 = _7602; _2017 < _7603; ++_2017)
          {
            {
              _2016 += ((*_1975)(_2017))->inst(_2016,_2003,_2016,_2002);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2018 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1991)));
          _checked_ptr_1<int> _ptr__2018(_2018 ? _2018->raw() : nullptr,_2018 ? _2018->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2019 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1991)));
          _checked_ptr_1<int> _ptr__2019(_2019 ? _2019->raw() : nullptr,_2019 ? _2019->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2020 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1982)));
          _checked_ptr_1<int> _ptr__2020(_2020 ? _2020->raw() : nullptr,_2020 ? _2020->size(0) : 0);
          int _7604 = (int)0;
          int _7605 = (_1982 - (int)1);
          for (int _2021 = _7604; _2021 < _7605; ++_2021)
          {
            {
              _ptr__2020[safe_add( _2021,(int)1 )] = safe_add( _ptr__2020[_2021],_ptr__2004[_2021] );
            }
          }
          int _7606 = (int)0;
          int _7607 = _1991;
          for (int _2022 = _7606; _2022 < _7607; ++_2022)
          {
            {
              _ptr__2018[_2022] = _2022;
            }
          }
          int _2023 = (int)0;
          int _7608 = (int)0;
          int _7609 = _1982;
          for (int _2024 = _7608; _2024 < _7609; ++_2024)
          {
            {
              int _7610 = (int)0;
              int _7611 = _ptr__1983[_2024];
              for (int _2025 = _7610; _2025 < _7611; ++_2025)
              {
                {
                  long long _2026 = (_ptr__2003[_2023] / safe_mul( _ptr__2004[_2024],_2010 ));
                  long long _2027 = ((_ptr__2003[_2023] / _2010) % _ptr__2004[_2024]);
                  long long _2028 = (_ptr__2003[_2023] % _2010);
                  _ptr__2003[_2023] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2026,_2008 ),_2027 ),_ptr__2020[_2024] ),_2010 ),_2028 );
                  ++ _2023;
                }
              }
            }
          }
          int _2029 = (int)1;
          int _7612 = (int)0;
          int _7613 = _1993;
          for (int _2030 = _7612; _2030 < _7613; ++_2030)
          {
            {
              int _7614;
              bool _7615 = (_2029 < _ptr__1995[_2030]);
              if (_7615)
              {
                _7614 = _ptr__1995[_2030];
              }
              else
              {
                _7614 = _2029;
              }
              _2029 = _7614;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2031 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1993)));
          _checked_ptr_1<long long> _ptr__2031(_2031 ? _2031->raw() : nullptr,_2031 ? _2031->size(0) : 0);
          _ptr__2031[(_1993 - (int)1)] = (int)1;
          int _7616 = (int)1;
          int _7617 = _1993;
          for (int _2032 = _7616; _2032 < _7617; ++_2032)
          {
            {
              _ptr__2031[((_1993 - _2032) - (int)1)] = safe_mul( _ptr__2031[(_1993 - _2032)],_ptr__1995[(_1993 - _2032)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2029,(int)1 ))));
          _checked_ptr_1<int> _ptr__2033(_2033 ? _2033->raw() : nullptr,_2033 ? _2033->size(0) : 0);
          int _7618 = (int)0;
          int _7619 = _1993;
          for (int _2034 = _7618; _2034 < _7619; ++_2034)
          {
            {
              int _2035 = ((_1993 - _2034) - (int)1);
              int _7620 = (int)0;
              int _7621 = safe_add( _ptr__1995[_2035],(int)1 );
              for (int _2036 = _7620; _2036 < _7621; ++_2036)
              {
                {
                  _ptr__2033[_2036] = (int)0;
                }
              }
              int _7622 = (int)0;
              int _7623 = _1991;
              for (int _2037 = _7622; _2037 < _7623; ++_2037)
              {
                {
                  ++ _ptr__2033[safe_add( ((_ptr__2003[_2037] / _ptr__2031[_2035]) % _ptr__1995[_2035]),(int)1 )];
                }
              }
              int _7624 = (int)0;
              int _7625 = _ptr__1995[_2035];
              for (int _2038 = _7624; _2038 < _7625; ++_2038)
              {
                {
                  _ptr__2033[safe_add( _2038,(int)1 )] += _ptr__2033[_2038];
                }
              }
              int _7626 = (int)0;
              int _7627 = _1991;
              for (int _2039 = _7626; _2039 < _7627; ++_2039)
              {
                {
                  int _2040 = _ptr__2018[_2039];
                  long long _2041 = ((_ptr__2003[_2040] / _ptr__2031[_2035]) % _ptr__1995[_2035]);
                  _ptr__2019[_ptr__2033[_2041]] = _2040;
                  ++ _ptr__2033[_2041];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2042 = _2018;
              _checked_ptr_1<int> _ptr__2042(_2042 ? _2042->raw() : nullptr,_2042 ? _2042->size(0) : 0);
              _2018 = _2019;
              _ptr__2018.update(_2018 ? _2018->raw() : nullptr, _2018 ? _2018->size(0) : 0);
              _2019 = _2042;
              _ptr__2019.update(_2019 ? _2019->raw() : nullptr, _2019 ? _2019->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7628;
          bool _7629 = (_1991 < safe_mul( safe_mul( _2006,_2008 ),_2010 ));
          if (_7629)
          {
            std::vector<long long> _7630;
            for (int _2043 = (int)0, _7631 = _1991; _2043 < _7631 ; ++_2043)
            {
              _7630.push_back(_ptr__2003[_ptr__2018[_2043]]);
            }
            auto _7632 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7630.size()),_7630.begin(),_7630.end()));
            _7628 = _7632;
          }
          else
          {
            _7628 = nullptr;
          }
          std::vector<long long> _7633;
          for (int _2044 = (int)0, _7634 = _1991; _2044 < _7634 ; ++_2044)
          {
            _7633.push_back(_ptr__2002[_ptr__2018[_2044]]);
          }
          auto _7635 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7633.size()),_7633.begin(),_7633.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1977,_1995,_7628,_7635)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2045,    monty::rc_ptr< ::mosek::fusion::Model > _2046){ return new mosek::fusion::LinearPSDConstraint(_2045,_2046); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2045,    monty::rc_ptr< ::mosek::fusion::Model > _2046) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2045,_2046); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2045,    monty::rc_ptr< ::mosek::fusion::Model > _2046){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2045,_2046);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2045)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2045)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2045)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2045)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2045)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2047,    const std::string &  _2048,    int _2049,    std::shared_ptr< monty::ndarray< int,1 > > _2050,    int _2051,    std::shared_ptr< monty::ndarray< int,1 > > _2052,    std::shared_ptr< monty::ndarray< long long,1 > > _2053){ return new mosek::fusion::LinearPSDConstraint(_2047,_2048,_2049,_2050,_2051,_2052,_2053); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2047,    const std::string &  _2048,    int _2049,    std::shared_ptr< monty::ndarray< int,1 > > _2050,    int _2051,    std::shared_ptr< monty::ndarray< int,1 > > _2052,    std::shared_ptr< monty::ndarray< long long,1 > > _2053) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2047,_2048,_2049,_2050,_2051,_2052,_2053); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2047,    const std::string &  _2048,    int _2049,    std::shared_ptr< monty::ndarray< int,1 > > _2050,    int _2051,    std::shared_ptr< monty::ndarray< int,1 > > _2052,    std::shared_ptr< monty::ndarray< long long,1 > > _2053){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2050(_2050 ? _2050->raw() : nullptr, _2050 ? _2050->size(0) : 0);
    _checked_ptr_1<int> _ptr__2052(_2052 ? _2052->raw() : nullptr, _2052 ? _2052->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2053(_2053 ? _2053->raw() : nullptr, _2053 ? _2053->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2047,_2048,_2050,_2052);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2049;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2053;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2052;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2051;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2050;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2054,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2055){
  std::shared_ptr< monty::ndarray< int,1 > > _2056 = ::mosek::fusion::p_Set::idxtokey(shape,_2054);
  _checked_ptr_1<int> _ptr__2056(_2056 ? _2056->raw() : nullptr,_2056 ? _2056->size(0) : 0);
  _2055->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2056[(int)0]);
  int _7636 = (int)1;
  int _7637 = (int)((_2056)->size(0));
  for (int _2057 = _7636; _2057 < _7637; ++_2057)
  {
    {
      _2055->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2056[_2057]);
    }
  }
  _2055->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7638 = (int)1;
  int _7639 = (int)((_2056)->size(0));
  for (int _2058 = _7638; _2058 < _7639; ++_2058)
  {
    {
      _2055->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2058)));
    }
  }
  _2055->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2059){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2059)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2060,    monty::rc_ptr< ::mosek::fusion::Model > _2061){ return new mosek::fusion::PSDConstraint(_2060,_2061); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2060,    monty::rc_ptr< ::mosek::fusion::Model > _2061) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2060,_2061); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2060,    monty::rc_ptr< ::mosek::fusion::Model > _2061){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2060,_2061);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2060)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2062,    const std::string &  _2063,    int _2064,    std::shared_ptr< monty::ndarray< int,1 > > _2065,    int _2066,    int _2067,    std::shared_ptr< monty::ndarray< long long,1 > > _2068,    std::shared_ptr< monty::ndarray< int,1 > > _2069){ return new mosek::fusion::PSDConstraint(_2062,_2063,_2064,_2065,_2066,_2067,_2068,_2069); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2062,    const std::string &  _2063,    int _2064,    std::shared_ptr< monty::ndarray< int,1 > > _2065,    int _2066,    int _2067,    std::shared_ptr< monty::ndarray< long long,1 > > _2068,    std::shared_ptr< monty::ndarray< int,1 > > _2069) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2062,_2063,_2064,_2065,_2066,_2067,_2068,_2069); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2062,    const std::string &  _2063,    int _2064,    std::shared_ptr< monty::ndarray< int,1 > > _2065,    int _2066,    int _2067,    std::shared_ptr< monty::ndarray< long long,1 > > _2068,    std::shared_ptr< monty::ndarray< int,1 > > _2069){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2065(_2065 ? _2065->raw() : nullptr, _2065 ? _2065->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2068(_2068 ? _2068->raw() : nullptr, _2068 ? _2068->size(0) : 0);
    _checked_ptr_1<int> _ptr__2069(_2069 ? _2069->raw() : nullptr, _2069 ? _2069->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2062,_2063,_2065,::mosek::fusion::p_PSDConstraint::computenidxs(_2065,_2066,_2067,_2069));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2064;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2069;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2068;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2063;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2065;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2066;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2067;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2070){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2070)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2071,int _2072,int _2073,std::shared_ptr< monty::ndarray< int,1 > > _2074){
  _checked_ptr_1<int> _ptr__2071(_2071 ? _2071->raw() : nullptr, _2071 ? _2071->size(0) : 0);
  _checked_ptr_1<int> _ptr__2074(_2074 ? _2074->raw() : nullptr, _2074 ? _2074->size(0) : 0);
  int _2075 = (int)((_2071)->size(0));
  bool _2076 = (_2072 < _2073);
  int _7640;
  bool _7641 = _2076;
  if (_7641)
  {
    _7640 = _2072;
  }
  else
  {
    _7640 = _2073;
  }
  int _2077 = _7640;
  int _7642;
  bool _7643 = _2076;
  if (_7643)
  {
    _7642 = _2073;
  }
  else
  {
    _7642 = _2072;
  }
  int _2078 = _7642;
  std::shared_ptr< monty::ndarray< int,1 > > _2079 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2079(_2079 ? _2079->raw() : nullptr,_2079 ? _2079->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2080 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2080(_2080 ? _2080->raw() : nullptr,_2080 ? _2080->size(0) : 0);
  int _2081 = (int)1;
  int _7644 = (int)0;
  int _7645 = (int)((_2071)->size(0));
  for (int _2082 = _7644; _2082 < _7645; ++_2082)
  {
    {
      _2081 *= _ptr__2071[_2082];
    }
  }
  int _7646 = (int)0;
  int _7647 = _2077;
  for (int _2083 = _7646; _2083 < _7647; ++_2083)
  {
    {
      _ptr__2079[(int)0] *= _ptr__2071[_2083];
    }
  }
  _ptr__2079[(int)1] = _ptr__2071[_2077];
  int _7648 = safe_add( _2077,(int)1 );
  int _7649 = _2078;
  for (int _2084 = _7648; _2084 < _7649; ++_2084)
  {
    {
      _ptr__2079[(int)2] *= _ptr__2071[_2084];
    }
  }
  _ptr__2079[(int)3] = _ptr__2071[_2078];
  int _7650 = safe_add( _2078,(int)1 );
  int _7651 = _2075;
  for (int _2085 = _7650; _2085 < _7651; ++_2085)
  {
    {
      _ptr__2079[(int)4] *= _ptr__2071[_2085];
    }
  }
  _ptr__2080[(int)4] = (int)1;
  int _7652 = (int)1;
  int _7653 = (int)5;
  for (int _2086 = _7652; _2086 < _7653; ++_2086)
  {
    {
      _ptr__2080[(((int)5 - _2086) - (int)1)] = safe_mul( _ptr__2080[((int)5 - _2086)],_ptr__2079[((int)5 - _2086)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2087 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2081)));
  _checked_ptr_1<int> _ptr__2087(_2087 ? _2087->raw() : nullptr,_2087 ? _2087->size(0) : 0);
  int _2088 = (int)0;
  if (_2076)
  {
    {
      int _7654 = (int)0;
      int _7655 = _ptr__2079[(int)0];
      for (int _2089 = _7654; _2089 < _7655; ++_2089)
      {
        {
          int _7656 = (int)0;
          int _7657 = _ptr__2079[(int)1];
          for (int _2090 = _7656; _2090 < _7657; ++_2090)
          {
            {
              int _7658 = (int)0;
              int _7659 = _ptr__2079[(int)2];
              for (int _2091 = _7658; _2091 < _7659; ++_2091)
              {
                {
                  int _7660 = _2090;
                  int _7661 = _ptr__2079[(int)1];
                  for (int _2092 = _7660; _2092 < _7661; ++_2092)
                  {
                    {
                      int _7662 = (int)0;
                      int _7663 = _ptr__2079[(int)4];
                      for (int _2093 = _7662; _2093 < _7663; ++_2093)
                      {
                        {
                          _ptr__2087[safe_add( safe_add( safe_add( safe_add( safe_mul( _2089,_ptr__2080[(int)0] ),safe_mul( _2090,_ptr__2080[(int)1] ) ),safe_mul( _2091,_ptr__2080[(int)2] ) ),safe_mul( _2092,_ptr__2080[(int)3] ) ),safe_mul( _2093,_ptr__2080[(int)4] ) )] = _ptr__2074[_2088];
                          _ptr__2087[safe_add( safe_add( safe_add( safe_add( safe_mul( _2089,_ptr__2080[(int)0] ),safe_mul( _2092,_ptr__2080[(int)1] ) ),safe_mul( _2091,_ptr__2080[(int)2] ) ),safe_mul( _2090,_ptr__2080[(int)3] ) ),safe_mul( _2093,_ptr__2080[(int)4] ) )] = _ptr__2074[_2088];
                          ++ _2088;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7664 = (int)0;
      int _7665 = _ptr__2079[(int)0];
      for (int _2094 = _7664; _2094 < _7665; ++_2094)
      {
        {
          int _7666 = (int)0;
          int _7667 = _ptr__2079[(int)1];
          for (int _2095 = _7666; _2095 < _7667; ++_2095)
          {
            {
              int _7668 = (int)0;
              int _7669 = _ptr__2079[(int)2];
              for (int _2096 = _7668; _2096 < _7669; ++_2096)
              {
                {
                  int _7670 = (int)0;
                  int _7671 = safe_add( _2095,(int)1 );
                  for (int _2097 = _7670; _2097 < _7671; ++_2097)
                  {
                    {
                      int _7672 = (int)0;
                      int _7673 = _ptr__2079[(int)4];
                      for (int _2098 = _7672; _2098 < _7673; ++_2098)
                      {
                        {
                          _ptr__2087[safe_add( safe_add( safe_add( safe_add( safe_mul( _2094,_ptr__2080[(int)0] ),safe_mul( _2095,_ptr__2080[(int)1] ) ),safe_mul( _2096,_ptr__2080[(int)2] ) ),safe_mul( _2097,_ptr__2080[(int)3] ) ),safe_mul( _2098,_ptr__2080[(int)4] ) )] = _ptr__2074[_2088];
                          _ptr__2087[safe_add( safe_add( safe_add( safe_add( safe_mul( _2094,_ptr__2080[(int)0] ),safe_mul( _2097,_ptr__2080[(int)1] ) ),safe_mul( _2096,_ptr__2080[(int)2] ) ),safe_mul( _2095,_ptr__2080[(int)3] ) ),safe_mul( _2098,_ptr__2080[(int)4] ) )] = _ptr__2074[_2088];
                          ++ _2088;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2087;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2099){ return new mosek::fusion::ConstraintCache(_2099); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2099) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2099); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2099){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2099)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2099)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7674;
    bool _7675 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->subj.get());
    if (_7675)
    {
      _7674 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->subj);
    }
    else
    {
      _7674 = nullptr;
    }
    subj = _7674;
    std::shared_ptr< monty::ndarray< int,1 > > _7676;
    bool _7677 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->subi.get());
    if (_7677)
    {
      _7676 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->subi);
    }
    else
    {
      _7676 = nullptr;
    }
    subi = _7676;
    std::shared_ptr< monty::ndarray< double,1 > > _7678;
    bool _7679 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->cof.get());
    if (_7679)
    {
      _7678 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->cof);
    }
    else
    {
      _7678 = nullptr;
    }
    cof = _7678;
    std::shared_ptr< monty::ndarray< double,1 > > _7680;
    bool _7681 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->bfix.get());
    if (_7681)
    {
      _7680 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->bfix);
    }
    else
    {
      _7680 = nullptr;
    }
    bfix = _7680;
    std::shared_ptr< monty::ndarray< double,1 > > _7682;
    bool _7683 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_cof.get());
    if (_7683)
    {
      _7682 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_cof);
    }
    else
    {
      _7682 = nullptr;
    }
    buffer_cof = _7682;
    std::shared_ptr< monty::ndarray< int,1 > > _7684;
    bool _7685 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_subj.get());
    if (_7685)
    {
      _7684 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_subj);
    }
    else
    {
      _7684 = nullptr;
    }
    buffer_subj = _7684;
    std::shared_ptr< monty::ndarray< int,1 > > _7686;
    bool _7687 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_subi.get());
    if (_7687)
    {
      _7686 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->buffer_subi);
    }
    else
    {
      _7686 = nullptr;
    }
    buffer_subi = _7686;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2099)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2099)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7688;
    bool _7689 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barsubi.get());
    if (_7689)
    {
      _7688 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barsubi);
    }
    else
    {
      _7688 = nullptr;
    }
    barsubi = _7688;
    std::shared_ptr< monty::ndarray< int,1 > > _7690;
    bool _7691 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barsubj.get());
    if (_7691)
    {
      _7690 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barsubj);
    }
    else
    {
      _7690 = nullptr;
    }
    barsubj = _7690;
    std::shared_ptr< monty::ndarray< int,1 > > _7692;
    bool _7693 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barmatidx.get());
    if (_7693)
    {
      _7692 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2099)->barmatidx);
    }
    else
    {
      _7692 = nullptr;
    }
    barmatidx = _7692;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2100,    std::shared_ptr< monty::ndarray< double,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< double,1 > > _2103,    std::shared_ptr< monty::ndarray< int,1 > > _2104,    std::shared_ptr< monty::ndarray< int,1 > > _2105,    std::shared_ptr< monty::ndarray< int,1 > > _2106){ return new mosek::fusion::ConstraintCache(_2100,_2101,_2102,_2103,_2104,_2105,_2106); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2100,    std::shared_ptr< monty::ndarray< double,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< double,1 > > _2103,    std::shared_ptr< monty::ndarray< int,1 > > _2104,    std::shared_ptr< monty::ndarray< int,1 > > _2105,    std::shared_ptr< monty::ndarray< int,1 > > _2106) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2100,_2101,_2102,_2103,_2104,_2105,_2106); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2100,    std::shared_ptr< monty::ndarray< double,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< double,1 > > _2103,    std::shared_ptr< monty::ndarray< int,1 > > _2104,    std::shared_ptr< monty::ndarray< int,1 > > _2105,    std::shared_ptr< monty::ndarray< int,1 > > _2106){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2100(_2100 ? _2100->raw() : nullptr, _2100 ? _2100->size(0) : 0);
    _checked_ptr_1<double> _ptr__2101(_2101 ? _2101->raw() : nullptr, _2101 ? _2101->size(0) : 0);
    _checked_ptr_1<int> _ptr__2102(_2102 ? _2102->raw() : nullptr, _2102 ? _2102->size(0) : 0);
    _checked_ptr_1<double> _ptr__2103(_2103 ? _2103->raw() : nullptr, _2103 ? _2103->size(0) : 0);
    _checked_ptr_1<int> _ptr__2104(_2104 ? _2104->raw() : nullptr, _2104 ? _2104->size(0) : 0);
    _checked_ptr_1<int> _ptr__2105(_2105 ? _2105->raw() : nullptr, _2105 ? _2105->size(0) : 0);
    _checked_ptr_1<int> _ptr__2106(_2106 ? _2106->raw() : nullptr, _2106 ? _2106->size(0) : 0);
    nrows = ((int)((_2100)->size(0)) - (int)1);
    nnz = _ptr__2100[((int)((_2100)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2103.get()))
    {
      {
        bfix = _2103;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2104.get()) && ((NULL != _2105.get()) && (NULL != _2106.get()))))
    {
      {
        nbarnz = (int)((_2104)->size(0));
        if ((nbarnz > (int)((_2105)->size(0))))
        {
          {
            nbarnz = (int)((_2105)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2106)->size(0))))
        {
          {
            nbarnz = (int)((_2106)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2104,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2105,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2106,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2102,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2101,(long long)0,cof,(long long)0,nnz);
    int _7694 = (int)0;
    int _7695 = nrows;
    for (int _2107 = _7694; _2107 < _7695; ++_2107)
    {
      {
        long long _7696 = _ptr__2100[_2107];
        long long _7697 = _ptr__2100[safe_add( _2107,(int)1 )];
        for (long long _2108 = _7696; _2108 < _7697; ++_2108)
        {
          {
            ((*subi)(_2108)) = _2107;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2109){
  _checked_ptr_1<double> _ptr__2109(_2109 ? _2109->raw() : nullptr, _2109 ? _2109->size(0) : 0);
  int _7698 = (int)0;
  int _7699 = nrows;
  for (int _2110 = _7698; _2110 < _7699; ++_2110)
  {
    {
      ((*bfix)(_2110)) = (((*bfix)(_2110)) + _ptr__2109[_2110]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7700;
  for (long long _2112 = (long long)0, _7701 = nbarnz; _2112 < _7701 ; ++_2112)
  {
    _7700.push_back(_2112);
  }
  auto _7702 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7700.size()),_7700.begin(),_7700.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2111 = _7702;
  _checked_ptr_1<long long> _ptr__2111(_2111 ? _2111->raw() : nullptr,_2111 ? _2111->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2111,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2111,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2113 = barsubi;
      _checked_ptr_1<int> _ptr__2113(_2113 ? _2113->raw() : nullptr,_2113 ? _2113->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2114 = barsubj;
      _checked_ptr_1<int> _ptr__2114(_2114 ? _2114->raw() : nullptr,_2114 ? _2114->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2115 = barmatidx;
      _checked_ptr_1<int> _ptr__2115(_2115 ? _2115->raw() : nullptr,_2115 ? _2115->size(0) : 0);
      std::vector<int> _7703;
      for (long long _2116 = (int)0, _7704 = nbarnz; _2116 < _7704 ; ++_2116)
      {
        _7703.push_back(_ptr__2113[_ptr__2111[_2116]]);
      }
      auto _7705 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7703.size()),_7703.begin(),_7703.end()));
      barsubi = _7705;
      std::vector<int> _7706;
      for (long long _2117 = (int)0, _7707 = nbarnz; _2117 < _7707 ; ++_2117)
      {
        _7706.push_back(_ptr__2114[_ptr__2111[_2117]]);
      }
      auto _7708 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7706.size()),_7706.begin(),_7706.end()));
      barsubj = _7708;
      std::vector<int> _7709;
      for (long long _2118 = (int)0, _7710 = nbarnz; _2118 < _7710 ; ++_2118)
      {
        _7709.push_back(_ptr__2115[_ptr__2111[_2118]]);
      }
      auto _7711 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7709.size()),_7709.begin(),_7709.end()));
      barmatidx = _7711;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2119,std::shared_ptr< monty::ndarray< int,1 > > _2120,std::shared_ptr< monty::ndarray< int,1 > > _2121){
  _checked_ptr_1<int> _ptr__2119(_2119 ? _2119->raw() : nullptr, _2119 ? _2119->size(0) : 0);
  _checked_ptr_1<int> _ptr__2120(_2120 ? _2120->raw() : nullptr, _2120 ? _2120->size(0) : 0);
  _checked_ptr_1<int> _ptr__2121(_2121 ? _2121->raw() : nullptr, _2121 ? _2121->size(0) : 0);
  if ((NULL != _2119.get()))
  {
    {
      int _2122 = (int)((_2119)->size(0));
      if (((int)((_2119)->size(0)) <= safe_add( nbarnz,_2122 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2123 = barsubi;
          _checked_ptr_1<int> _ptr__2123(_2123 ? _2123->raw() : nullptr,_2123 ? _2123->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2124 = barsubj;
          _checked_ptr_1<int> _ptr__2124(_2124 ? _2124->raw() : nullptr,_2124 ? _2124->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2125 = barmatidx;
          _checked_ptr_1<int> _ptr__2125(_2125 ? _2125->raw() : nullptr,_2125 ? _2125->size(0) : 0);
          long long _7712;
          bool _7713 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2122 ));
          if (_7713)
          {
            _7712 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7712 = safe_add( nbarnz,safe_mul( _2122,(int)2 ) );
          }
          long long _2126 = _7712;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2126)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2126)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2126)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2123,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2124,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2125,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2119,(long long)((int)0),barsubi,nbarnz,(long long)(_2122));
      ::mosek::fusion::Utils::Tools::arraycopy(_2120,(long long)((int)0),barsubj,nbarnz,(long long)(_2122));
      ::mosek::fusion::Utils::Tools::arraycopy(_2121,(long long)((int)0),barmatidx,nbarnz,(long long)(_2122));
      nbarnz += _2122;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2127,std::shared_ptr< monty::ndarray< int,1 > > _2128,std::shared_ptr< monty::ndarray< double,1 > > _2129,std::shared_ptr< monty::ndarray< double,1 > > _2130){
  _checked_ptr_1<long long> _ptr__2127(_2127 ? _2127->raw() : nullptr, _2127 ? _2127->size(0) : 0);
  _checked_ptr_1<int> _ptr__2128(_2128 ? _2128->raw() : nullptr, _2128 ? _2128->size(0) : 0);
  _checked_ptr_1<double> _ptr__2129(_2129 ? _2129->raw() : nullptr, _2129 ? _2129->size(0) : 0);
  _checked_ptr_1<double> _ptr__2130(_2130 ? _2130->raw() : nullptr, _2130 ? _2130->size(0) : 0);
  long long _2131 = safe_add( nunordered,_ptr__2127[nrows] );
  long long _2132 = _ptr__2127[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2133;
  _checked_ptr_1<int> _ptr__2133(_2133 ? _2133->raw() : nullptr,_2133 ? _2133->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2134;
  _checked_ptr_1<int> _ptr__2134(_2134 ? _2134->raw() : nullptr,_2134 ? _2134->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2135;
  _checked_ptr_1<double> _ptr__2135(_2135 ? _2135->raw() : nullptr,_2135 ? _2135->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2131)))
  {
    {
      _2133 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2131)));
      _ptr__2133.update(_2133 ? _2133->raw() : nullptr, _2133 ? _2133->size(0) : 0);
      _2134 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2131)));
      _ptr__2134.update(_2134 ? _2134->raw() : nullptr, _2134 ? _2134->size(0) : 0);
      _2135 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2131)));
      _ptr__2135.update(_2135 ? _2135->raw() : nullptr, _2135 ? _2135->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2133,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2134,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2135,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2133 = buffer_subi;
      _ptr__2133.update(_2133 ? _2133->raw() : nullptr, _2133 ? _2133->size(0) : 0);
      _2134 = buffer_subj;
      _ptr__2134.update(_2134 ? _2134->raw() : nullptr, _2134 ? _2134->size(0) : 0);
      _2135 = buffer_cof;
      _ptr__2135.update(_2135 ? _2135->raw() : nullptr, _2135 ? _2135->size(0) : 0);
    }
  }
  int _7714 = (int)0;
  int _7715 = nrows;
  for (int _2136 = _7714; _2136 < _7715; ++_2136)
  {
    {
      long long _7716 = _ptr__2127[_2136];
      long long _7717 = _ptr__2127[safe_add( _2136,(int)1 )];
      for (long long _2137 = _7716; _2137 < _7717; ++_2137)
      {
        {
          _ptr__2133[safe_add( nunordered,_2137 )] = _2136;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2128,(long long)0,_2134,nunordered,_2132);
  ::mosek::fusion::Utils::Tools::arraycopy(_2129,(long long)0,_2135,nunordered,_2132);
  buffer_subi = _2133;
  buffer_subj = _2134;
  buffer_cof = _2135;
  if ((NULL != _2130.get()))
  {
    {
      int _7718 = (int)0;
      int _7719 = nrows;
      for (int _2138 = _7718; _2138 < _7719; ++_2138)
      {
        {
          ((*bfix)(_2138)) = (((*bfix)(_2138)) + _ptr__2130[_2138]);
        }
      }
    }
  }
  {}
  nunordered = _2131;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2139,std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< double,1 > > _2141,std::shared_ptr< monty::ndarray< double,1 > > _2142) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2139,_2140,_2141,_2142); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2139,std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< double,1 > > _2141,std::shared_ptr< monty::ndarray< double,1 > > _2142){
  _checked_ptr_1<long long> _ptr__2139(_2139 ? _2139->raw() : nullptr, _2139 ? _2139->size(0) : 0);
  _checked_ptr_1<int> _ptr__2140(_2140 ? _2140->raw() : nullptr, _2140 ? _2140->size(0) : 0);
  _checked_ptr_1<double> _ptr__2141(_2141 ? _2141->raw() : nullptr, _2141 ? _2141->size(0) : 0);
  _checked_ptr_1<double> _ptr__2142(_2142 ? _2142->raw() : nullptr, _2142 ? _2142->size(0) : 0);
  if ((((int)((_2139)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2142.get()) && ((int)((_2142)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2139,_2140,_2141,_2142);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2143,std::shared_ptr< monty::ndarray< int,1 > > _2144,std::shared_ptr< monty::ndarray< double,1 > > _2145,std::shared_ptr< monty::ndarray< double,1 > > _2146) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2143,_2144,_2145,_2146); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2143,std::shared_ptr< monty::ndarray< int,1 > > _2144,std::shared_ptr< monty::ndarray< double,1 > > _2145,std::shared_ptr< monty::ndarray< double,1 > > _2146){
  _checked_ptr_1<int> _ptr__2143(_2143 ? _2143->raw() : nullptr, _2143 ? _2143->size(0) : 0);
  _checked_ptr_1<int> _ptr__2144(_2144 ? _2144->raw() : nullptr, _2144 ? _2144->size(0) : 0);
  _checked_ptr_1<double> _ptr__2145(_2145 ? _2145->raw() : nullptr, _2145 ? _2145->size(0) : 0);
  _checked_ptr_1<double> _ptr__2146(_2146 ? _2146->raw() : nullptr, _2146 ? _2146->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2147 = nullptr;
  _checked_ptr_1<long long> _ptr__2147(_2147 ? _2147->raw() : nullptr,_2147 ? _2147->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2146.get())))
  {
    {
      int _7720 = (int)0;
      int _7721 = nrows;
      for (int _2148 = _7720; _2148 < _7721; ++_2148)
      {
        {
          _ptr__2146[_2148] = ((*bfix)(_2148));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2149 = false;
  {
    int _2150 = (int)1;
    while ( ((_2150 < nunordered) && ((((*buffer_subi)((_2150 - (int)1))) < ((*buffer_subi)(_2150))) || ((((*buffer_subi)((_2150 - (int)1))) == ((*buffer_subi)(_2150))) && (((*buffer_subj)((_2150 - (int)1))) <= ((*buffer_subj)(_2150)))))) )
    {
      {
        ++ _2150;
      }
    }
    _2149 = (_2150 == nunordered);
  }
  if ((!_2149))
  {
    {
      std::vector<long long> _7722;
      for (long long _2151 = (int)0, _7723 = nunordered; _2151 < _7723 ; ++_2151)
      {
        _7722.push_back(_2151);
      }
      auto _7724 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7722.size()),_7722.begin(),_7722.end()));
      _2147 = _7724;
      _ptr__2147.update(_2147 ? _2147->raw() : nullptr, _2147 ? _2147->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2147,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2152 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2153 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2152 ))));
  _checked_ptr_1<int> _ptr__2153(_2153 ? _2153->raw() : nullptr,_2153 ? _2153->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2152 ))));
  _checked_ptr_1<int> _ptr__2154(_2154 ? _2154->raw() : nullptr,_2154 ? _2154->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2155 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2152 ))));
  _checked_ptr_1<double> _ptr__2155(_2155 ? _2155->raw() : nullptr,_2155 ? _2155->size(0) : 0);
  long long _2156 = (long long)0;
  if (_2149)
  {
    {
      long long _2157 = (long long)0;
      int _2158 = (int)0;
      long long _2159 = nunordered;
      long long _2160 = _2152;
      int _2161 = (int)0;
      int _2162 = (int)0;
      while ( ((_2162 < _2160) && (_2161 < _2159)) )
      {
        {
          if (((((*subi)(_2162)) < ((*buffer_subi)(_2161))) || ((((*subi)(_2162)) == ((*buffer_subi)(_2161))) && (((*subj)(_2162)) < ((*buffer_subj)(_2161))))))
          {
            {
              _ptr__2153[_2158] = ((*subi)(_2162));
              _ptr__2154[_2158] = ((*subj)(_2162));
              _ptr__2155[_2158] = ((*cof)(_2162));
              ++ _2162;
              ++ _2158;
            }
          }
          else if(((((*subi)(_2162)) > ((*buffer_subi)(_2161))) || ((((*subi)(_2162)) == ((*buffer_subi)(_2161))) && (((*subj)(_2162)) > ((*buffer_subj)(_2161))))))
          {
            {
              _ptr__2153[_2158] = ((*buffer_subi)(_2161));
              _ptr__2154[_2158] = ((*buffer_subj)(_2161));
              _ptr__2155[_2158] = ((*buffer_cof)(_2161));
              _ptr__2143[_2156] = _ptr__2153[_2158];
              _ptr__2144[_2156] = _ptr__2154[_2158];
              _ptr__2145[_2156] = _ptr__2155[_2158];
              ++ _2156;
              ++ _2161;
              ++ _2158;
            }
          }
          else
          {
            {
              _ptr__2153[_2158] = ((*subi)(_2162));
              _ptr__2154[_2158] = ((*subj)(_2162));
              _ptr__2155[_2158] = ((*cof)(_2162));
              while ( ((_2162 < (int)((subi)->size(0))) && ((_2161 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2162)) == ((*buffer_subi)(_2161))) && (((*subj)(_2162)) == ((*buffer_subj)(_2161)))))) )
              {
                {
                  _ptr__2155[_2158] = (_ptr__2155[_2158] + ((*buffer_cof)(_2161)));
                  ++ _2161;
                }
              }
              _ptr__2143[_2156] = _ptr__2153[_2158];
              _ptr__2144[_2156] = _ptr__2154[_2158];
              _ptr__2145[_2156] = _ptr__2155[_2158];
              ++ _2156;
              ++ _2162;
              ++ _2158;
            }
          }
        }
      }
      while ( (_2162 < _2160) )
      {
        {
          _ptr__2153[_2158] = ((*subi)(_2162));
          _ptr__2154[_2158] = ((*subj)(_2162));
          _ptr__2155[_2158] = ((*cof)(_2162));
          ++ _2162;
          ++ _2158;
        }
      }
      while ( (_2161 < _2159) )
      {
        {
          _ptr__2153[_2158] = ((*buffer_subi)(_2161));
          _ptr__2154[_2158] = ((*buffer_subj)(_2161));
          _ptr__2155[_2158] = ((*buffer_cof)(_2161));
          _ptr__2143[_2156] = _ptr__2153[_2158];
          _ptr__2144[_2156] = _ptr__2154[_2158];
          _ptr__2145[_2156] = _ptr__2155[_2158];
          ++ _2156;
          ++ _2161;
          ++ _2158;
        }
      }
      nnz = _2158;
    }
  }
  else
  {
    {
      long long _2163 = (long long)0;
      int _2164 = (int)0;
      long long _2165 = nunordered;
      long long _2166 = _2152;
      int _2167 = (int)0;
      int _2168 = (int)0;
      while ( ((_2168 < _2166) && (_2167 < _2165)) )
      {
        {
          if (((((*subi)(_2168)) < ((*buffer_subi)(_ptr__2147[_2167]))) || ((((*subi)(_2168)) == ((*buffer_subi)(_ptr__2147[_2167]))) && (((*subj)(_2168)) < ((*buffer_subj)(_ptr__2147[_2167]))))))
          {
            {
              _ptr__2153[_2164] = ((*subi)(_2168));
              _ptr__2154[_2164] = ((*subj)(_2168));
              _ptr__2155[_2164] = ((*cof)(_2168));
              ++ _2168;
              ++ _2164;
            }
          }
          else if(((((*subi)(_2168)) > ((*buffer_subi)(_ptr__2147[_2167]))) || ((((*subi)(_2168)) == ((*buffer_subi)(_ptr__2147[_2167]))) && (((*subj)(_2168)) > ((*buffer_subj)(_ptr__2147[_2167]))))))
          {
            {
              _ptr__2153[_2164] = ((*buffer_subi)(_ptr__2147[_2167]));
              _ptr__2154[_2164] = ((*buffer_subj)(_ptr__2147[_2167]));
              _ptr__2155[_2164] = ((*buffer_cof)(_ptr__2147[_2167]));
              _ptr__2143[_2156] = _ptr__2153[_2164];
              _ptr__2144[_2156] = _ptr__2154[_2164];
              _ptr__2145[_2156] = _ptr__2155[_2164];
              ++ _2156;
              ++ _2167;
              ++ _2164;
            }
          }
          else
          {
            {
              _ptr__2153[_2164] = ((*subi)(_2168));
              _ptr__2154[_2164] = ((*subj)(_2168));
              _ptr__2155[_2164] = ((*cof)(_2168));
              while ( ((((*subi)(_2168)) == ((*buffer_subi)(_ptr__2147[_2167]))) && (((*subj)(_2168)) == ((*buffer_subj)(_ptr__2147[_2167])))) )
              {
                {
                  _ptr__2155[_2164] = (_ptr__2155[_2164] + ((*buffer_cof)(_ptr__2147[_2167])));
                  ++ _2167;
                }
              }
              _ptr__2143[_2156] = _ptr__2153[_2164];
              _ptr__2144[_2156] = _ptr__2154[_2164];
              _ptr__2145[_2156] = _ptr__2155[_2164];
              ++ _2156;
              ++ _2168;
              ++ _2164;
            }
          }
        }
      }
      nnz = _2164;
    }
  }
  subi = _2153;
  subj = _2154;
  cof = _2155;
  nunordered = (long long)0;
  return _2156;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2169,    std::shared_ptr< monty::ndarray< int,1 > > _2170,    std::shared_ptr< monty::ndarray< int,1 > > _2171){ return new mosek::fusion::SliceConstraint(_2169,_2170,_2171); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2169,    std::shared_ptr< monty::ndarray< int,1 > > _2170,    std::shared_ptr< monty::ndarray< int,1 > > _2171) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2169,_2170,_2171); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2169,    std::shared_ptr< monty::ndarray< int,1 > > _2170,    std::shared_ptr< monty::ndarray< int,1 > > _2171){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2170(_2170 ? _2170->raw() : nullptr, _2170 ? _2170->size(0) : 0);
    _checked_ptr_1<int> _ptr__2171(_2171 ? _2171->raw() : nullptr, _2171 ? _2171->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2169,_2170,_2171);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2172 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2172->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2172->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2173,    monty::rc_ptr< ::mosek::fusion::Model > _2174){ return new mosek::fusion::RangedConstraint(_2173,_2174); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2173,    monty::rc_ptr< ::mosek::fusion::Model > _2174) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2173,_2174); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2173,    monty::rc_ptr< ::mosek::fusion::Model > _2174){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2173,_2174);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2173)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2173)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2175,    const std::string &  _2176,    std::shared_ptr< monty::ndarray< int,1 > > _2177,    std::shared_ptr< monty::ndarray< int,1 > > _2178){ return new mosek::fusion::RangedConstraint(_2175,_2176,_2177,_2178); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2175,    const std::string &  _2176,    std::shared_ptr< monty::ndarray< int,1 > > _2177,    std::shared_ptr< monty::ndarray< int,1 > > _2178) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2175,_2176,_2177,_2178); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2175,    const std::string &  _2176,    std::shared_ptr< monty::ndarray< int,1 > > _2177,    std::shared_ptr< monty::ndarray< int,1 > > _2178){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2177(_2177 ? _2177->raw() : nullptr, _2177 ? _2177->size(0) : 0);
    _checked_ptr_1<int> _ptr__2178(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2175,_2176,_2177,_2178);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2177;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2178;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2179){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2179)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2180,    monty::rc_ptr< ::mosek::fusion::Model > _2181){ return new mosek::fusion::ConicConstraint(_2180,_2181); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2180,    monty::rc_ptr< ::mosek::fusion::Model > _2181) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2180,_2181); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2180,    monty::rc_ptr< ::mosek::fusion::Model > _2181){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2180,_2181);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2180)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2182,    const std::string &  _2183,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185,    int _2186,    std::shared_ptr< monty::ndarray< int,1 > > _2187,    std::shared_ptr< monty::ndarray< int,1 > > _2188){ return new mosek::fusion::ConicConstraint(_2182,_2183,_2184,_2185,_2186,_2187,_2188); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2182,    const std::string &  _2183,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185,    int _2186,    std::shared_ptr< monty::ndarray< int,1 > > _2187,    std::shared_ptr< monty::ndarray< int,1 > > _2188) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2182,_2183,_2184,_2185,_2186,_2187,_2188); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2182,    const std::string &  _2183,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185,    int _2186,    std::shared_ptr< monty::ndarray< int,1 > > _2187,    std::shared_ptr< monty::ndarray< int,1 > > _2188){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2185(_2185 ? _2185->raw() : nullptr, _2185 ? _2185->size(0) : 0);
    _checked_ptr_1<int> _ptr__2187(_2187 ? _2187->raw() : nullptr, _2187 ? _2187->size(0) : 0);
    _checked_ptr_1<int> _ptr__2188(_2188 ? _2188->raw() : nullptr, _2188 ? _2188->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2182,_2183,_2185,_2187);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2184;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2185;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2183;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2187;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2188;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2186;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2189 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2190 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7725 = (int)0;
          int _7726 = _2189;
          for (int _2191 = _7725; _2191 < _7726; ++_2191)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2190.get())->task_var_name(((*nativeslack)(_2191)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2192 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7727 = (int)0;
          int _7728 = _2189;
          for (int _2193 = _7727; _2193 < _7728; ++_2193)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2190.get())->task_var_name(((*nativeslack)(_2193)),_2192->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2193)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2194 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2194->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2194->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2195,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2196){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2197){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2197)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2198,    monty::rc_ptr< ::mosek::fusion::Model > _2199){ return new mosek::fusion::LinearConstraint(_2198,_2199); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2198,    monty::rc_ptr< ::mosek::fusion::Model > _2199) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2198,_2199); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2198,    monty::rc_ptr< ::mosek::fusion::Model > _2199){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2198,_2199);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2198)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2198)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2200,    const std::string &  _2201,    int _2202,    std::shared_ptr< monty::ndarray< int,1 > > _2203,    std::shared_ptr< monty::ndarray< int,1 > > _2204){ return new mosek::fusion::LinearConstraint(_2200,_2201,_2202,_2203,_2204); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2200,    const std::string &  _2201,    int _2202,    std::shared_ptr< monty::ndarray< int,1 > > _2203,    std::shared_ptr< monty::ndarray< int,1 > > _2204) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2200,_2201,_2202,_2203,_2204); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2200,    const std::string &  _2201,    int _2202,    std::shared_ptr< monty::ndarray< int,1 > > _2203,    std::shared_ptr< monty::ndarray< int,1 > > _2204){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2203(_2203 ? _2203->raw() : nullptr, _2203 ? _2203->size(0) : 0);
    _checked_ptr_1<int> _ptr__2204(_2204 ? _2204->raw() : nullptr, _2204 ? _2204->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2200,_2201,_2203,_2204);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2202;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2201;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2205 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2205->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2205->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2206,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2207){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2208){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2208)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2209,    monty::rc_ptr< ::mosek::fusion::Model > _2210){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2209,_2210);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2209)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2209)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2209)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2209)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2211,    const std::string &  _2212,    std::shared_ptr< monty::ndarray< int,1 > > _2213,    std::shared_ptr< monty::ndarray< int,1 > > _2214){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2213(_2213 ? _2213->raw() : nullptr, _2213 ? _2213->size(0) : 0);
    _checked_ptr_1<int> _ptr__2214(_2214 ? _2214->raw() : nullptr, _2214 ? _2214->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2211,_2213,_2214);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2212;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2214;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2213;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2215 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2215->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2215->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2216 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          mosek::fusion::p_Model::_get_impl(_2216.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2217 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          _2217->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
          if ((_pubthis->getND() > (int)0))
          {
            {
              _2217->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
              int _7729 = (int)1;
              int _7730 = _pubthis->getND();
              for (int _2218 = _7729; _2218 < _7730; ++_2218)
              {
                {
                  _2217->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2218);
                }
              }
            }
          }
          {}
          _2217->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
          std::shared_ptr< monty::ndarray< int,1 > > _7731;
          bool _7732 = (_pubthis->getND() > (int)0);
          if (_7732)
          {
            _7731 = _pubthis->getShape();
          }
          else
          {
            _7731 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
          }
          mosek::fusion::p_Model::_get_impl(_2216.get())->connames(nativeidxs,_2217->toString(),_7731,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
          names_flushed = true;
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2220,    monty::rc_ptr< ::mosek::fusion::Model > _2221){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2221;
    shape = mosek::fusion::p_Constraint::_get_impl(_2220)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2220)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223,    std::shared_ptr< monty::ndarray< int,1 > > _2224){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2223(_2223 ? _2223->raw() : nullptr, _2223 ? _2223->size(0) : 0);
    _checked_ptr_1<int> _ptr__2224(_2224 ? _2224->raw() : nullptr, _2224 ? _2224->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2222;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2223;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2224;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2225,long long _2226,std::shared_ptr< monty::ndarray< std::string,1 > > _2227){
  _checked_ptr_1<long long> _ptr__2225(_2225 ? _2225->raw() : nullptr, _2225 ? _2225->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2228 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2228(_2228 ? _2228->raw() : nullptr,_2228 ? _2228->size(0) : 0);
  values(false,(int)0,_2228);
  return _2228;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2229 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2229(_2229 ? _2229->raw() : nullptr,_2229 ? _2229->size(0) : 0);
  values(true,(int)0,_2229);
  return _2229;
}
void mosek::fusion::p_Constraint::values(bool _2230,int _2231,std::shared_ptr< monty::ndarray< double,1 > > _2232){
  _checked_ptr_1<double> _ptr__2232(_2232 ? _2232->raw() : nullptr, _2232 ? _2232->size(0) : 0);
  model->getConstraintValues(_2230,nativeidxs,_2232,_2231);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2233) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2233); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2233){
  std::shared_ptr< monty::ndarray< int,1 > > _2234 = _2233->getShape();
  _checked_ptr_1<int> _ptr__2234(_2234 ? _2234->raw() : nullptr,_2234 ? _2234->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2234)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7733 = (int)0;
  int _7734 = (int)((_2234)->size(0));
  for (int _2235 = _7733; _2235 < _7734; ++_2235)
  {
    {
      if ((_ptr__2234[_2235] != ((*shape)(_2235))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7735 = (int)((_2234)->size(0));
  int _7736 = (int)((shape)->size(0));
  for (int _2236 = _7735; _2236 < _7736; ++_2236)
  {
    {
      if ((((*shape)(_2236)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2233);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2237,monty::rc_ptr< ::mosek::fusion::Variable > _2238) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2237,_2238); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2237,monty::rc_ptr< ::mosek::fusion::Variable > _2238){
  int _2239 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2240 = _2237->getShape();
  _checked_ptr_1<int> _ptr__2240(_2240 ? _2240->raw() : nullptr,_2240 ? _2240->size(0) : 0);
  if ((_2239 < (int)((_2240)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7737 = (int)0;
  int _7738 = (int)((_2240)->size(0));
  for (int _2241 = _7737; _2241 < _7738; ++_2241)
  {
    {
      if ((_ptr__2240[_2241] != ((*shape)(_2241))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7739 = (int)((_2240)->size(0));
  int _7740 = (int)((shape)->size(0));
  for (int _2242 = _7739; _2242 < _7740; ++_2242)
  {
    {
      if ((((*shape)(_2242)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2243 = _2238->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2244 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2243)));
  _checked_ptr_1<long long> _ptr__2244(_2244 ? _2244->raw() : nullptr,_2244 ? _2244->size(0) : 0);
  if ((_2243 < _2238->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2245 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2243)));
      _checked_ptr_1<long long> _ptr__2245(_2245 ? _2245->raw() : nullptr,_2245 ? _2245->size(0) : 0);
      _2238->inst((int)0,_2245,(int)0,_2244);
    }
  }
  else
  {
    {
      _2238->inst((int)0,_2244);
    }
  }
  int _7741 = (int)0;
  int _7742 = _2243;
  for (int _2246 = _7741; _2246 < _7742; ++_2246)
  {
    {
      if ((_ptr__2244[_2246] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2247;
  _checked_ptr_1<int> _ptr__2247(_2247 ? _2247->raw() : nullptr,_2247 ? _2247->size(0) : 0);
  {
    bool _2248 = true;
    int _7743 = (int)0;
    int _7744 = (_2243 - (int)1);
    for (int _2249 = _7743; _2249 < _7744; ++_2249)
    {
      {
        _2248 = (_2248 && (_ptr__2244[_2249] < _ptr__2244[safe_add( _2249,(int)1 )]));
      }
    }
    if (_2248)
    {
      {
        std::vector<int> _7745;
        for (int _2250 = (int)0, _7746 = _2243; _2250 < _7746 ; ++_2250)
        {
          _7745.push_back((int)(_ptr__2244[_2250] - (int)1));
        }
        auto _7747 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7745.size()),_7745.begin(),_7745.end()));
        _2247 = _7747;
        _ptr__2247.update(_2247 ? _2247->raw() : nullptr, _2247 ? _2247->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7748;
        for (int _2252 = (int)0, _7749 = _2243; _2252 < _7749 ; ++_2252)
        {
          _7748.push_back(_2252);
        }
        auto _7750 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7748.size()),_7748.begin(),_7748.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2251 = _7750;
        _checked_ptr_1<long long> _ptr__2251(_2251 ? _2251->raw() : nullptr,_2251 ? _2251->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2251,_2244,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2243));
        int _2253 = (int)1;
        int _7751 = (int)1;
        int _7752 = _2243;
        for (int _2254 = _7751; _2254 < _7752; ++_2254)
        {
          {
            if ((_ptr__2244[_ptr__2251[(_2254 - (int)1)]] < _ptr__2244[_ptr__2251[_2254]]))
            {
              {
                ++ _2253;
              }
            }
            {}
          }
        }
        _2247 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2253)));
        _ptr__2247.update(_2247 ? _2247->raw() : nullptr, _2247 ? _2247->size(0) : 0);
        int _2255 = (int)0;
        _ptr__2247[(int)0] = (int)(_ptr__2244[_ptr__2251[(int)0]] - (int)1);
        int _7753 = (int)1;
        int _7754 = _2243;
        for (int _2256 = _7753; _2256 < _7754; ++_2256)
        {
          {
            if ((_ptr__2244[(_2256 - (int)1)] < _ptr__2244[_2256]))
            {
              {
                _ptr__2247[_2255] = (int)(_ptr__2244[_ptr__2251[_2256]] - (int)1);
                ++ _2255;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2237,_2247);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2257 = (int)1;
  int _7755 = (int)0;
  int _7756 = (int)((shape)->size(0));
  for (int _2258 = _7755; _2258 < _7756; ++_2258)
  {
    {
      _2257 *= ((*shape)(_2258));
    }
  }
  return _2257;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2259,    int _2260) { return mosek::fusion::p_Constraint::stack(_2259,_2260); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2259,int _2260){
  return ::mosek::fusion::p_Constraint::dstack(_2259,_2260);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2261,    monty::rc_ptr< ::mosek::fusion::Constraint > _2262,    monty::rc_ptr< ::mosek::fusion::Constraint > _2263,    int _2264) { return mosek::fusion::p_Constraint::stack(_2261,_2262,_2263,_2264); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2261,monty::rc_ptr< ::mosek::fusion::Constraint > _2262,monty::rc_ptr< ::mosek::fusion::Constraint > _2263,int _2264){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2261.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2262.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2263.get())}),_2264);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2265,    monty::rc_ptr< ::mosek::fusion::Constraint > _2266,    int _2267) { return mosek::fusion::p_Constraint::stack(_2265,_2266,_2267); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2265,monty::rc_ptr< ::mosek::fusion::Constraint > _2266,int _2267){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2265.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2266.get())}),_2267);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2268) { return mosek::fusion::p_Constraint::hstack(_2268); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2268){
  return ::mosek::fusion::p_Constraint::dstack(_2268,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2269) { return mosek::fusion::p_Constraint::vstack(_2269); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2269){
  return ::mosek::fusion::p_Constraint::dstack(_2269,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2270,    monty::rc_ptr< ::mosek::fusion::Constraint > _2271,    monty::rc_ptr< ::mosek::fusion::Constraint > _2272) { return mosek::fusion::p_Constraint::hstack(_2270,_2271,_2272); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2270,monty::rc_ptr< ::mosek::fusion::Constraint > _2271,monty::rc_ptr< ::mosek::fusion::Constraint > _2272){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2270.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2271.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2272.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2273,    monty::rc_ptr< ::mosek::fusion::Constraint > _2274,    monty::rc_ptr< ::mosek::fusion::Constraint > _2275) { return mosek::fusion::p_Constraint::vstack(_2273,_2274,_2275); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2273,monty::rc_ptr< ::mosek::fusion::Constraint > _2274,monty::rc_ptr< ::mosek::fusion::Constraint > _2275){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2273.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2274.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2275.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2276,    monty::rc_ptr< ::mosek::fusion::Constraint > _2277) { return mosek::fusion::p_Constraint::hstack(_2276,_2277); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2276,monty::rc_ptr< ::mosek::fusion::Constraint > _2277){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2276.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2277.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2278,    monty::rc_ptr< ::mosek::fusion::Constraint > _2279) { return mosek::fusion::p_Constraint::vstack(_2278,_2279); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2278,monty::rc_ptr< ::mosek::fusion::Constraint > _2279){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2278.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2279.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2280,int _2281){
  monty::rc_ptr< ::mosek::fusion::Model > _2282 = nullptr;
  {
    int _7757 = (int)0;
    int _7758 = (int)((_2280)->size(0));
    for (int _2283 = _7757; _2283 < _7758; ++_2283)
    {
      {
        if ((NULL == _2282.get()))
        {
          {
            _2282 = ((*_2280)(_2283))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2283)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2283)))->model != _2282)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2284 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7759;
            bool _7760 = ((int)((mosek::fusion::p_Model::_get_impl(_2282.get())->getName()).size()) > (int)0);
            if (_7760)
            {
              _7759 = mosek::fusion::p_Model::_get_impl(_2282.get())->getName();
            }
            else
            {
              _7759 = std::string ("?");
            }
            std::string _2285 = _7759;
            std::string _7761;
            bool _7762 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2280)(_2283))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7762)
            {
              _7761 = mosek::fusion::p_Model::_get_impl(((*_2280)(_2283))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7761 = std::string ("?");
            }
            std::string _2286 = _7761;
            _2284->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2286)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2284->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2280)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2280)->size(0)) == (int)1))
  {
    {
      return ((*_2280)((int)1));
    }
  }
  else
  {
    {
      int _2287 = (int)((_2280)->size(0));
      int _2288 = (int)1;
      int _7763 = (int)0;
      int _7764 = _2287;
      for (int _2289 = _7763; _2289 < _7764; ++_2289)
      {
        {
          int _7765;
          bool _7766 = (((*_2280)(_2289))->getND() > _2288);
          if (_7766)
          {
            _7765 = ((*_2280)(_2289))->getND();
          }
          else
          {
            _7765 = _2288;
          }
          _2288 = _7765;
        }
      }
      if ((_2281 == _2288))
      {
        {
          ++ _2288;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2290 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2287,_2288)));
      int _7767 = (int)0;
      int _7768 = _2287;
      for (int _2291 = _7767; _2291 < _7768; ++_2291)
      {
        {
          int _7769 = (int)0;
          int _7770 = _2288;
          for (int _2292 = _7769; _2292 < _7770; ++_2292)
          {
            {
              ((*_2290)(_2291,_2292)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7771;
      for (int _2294 = (int)0, _7772 = _2287; _2294 < _7772 ; ++_2294)
      {
        _7771.push_back(((*_2280)(_2294))->getSize());
      }
      auto _7773 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7771.size()),_7771.begin(),_7771.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2293 = _7773;
      _checked_ptr_1<int> _ptr__2293(_2293 ? _2293->raw() : nullptr,_2293 ? _2293->size(0) : 0);
      int _2295 = (int)0;
      int _7774 = (int)0;
      int _7775 = _2287;
      for (int _2296 = _7774; _2296 < _7775; ++_2296)
      {
        {
          _2295 += _ptr__2293[_2296];
        }
      }
      int _7776 = (int)0;
      int _7777 = _2287;
      for (int _2297 = _7776; _2297 < _7777; ++_2297)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2298 = ((*_2280)(_2297))->getShape();
          _checked_ptr_1<int> _ptr__2298(_2298 ? _2298->raw() : nullptr,_2298 ? _2298->size(0) : 0);
          int _7778 = (int)0;
          int _7779 = (int)((_2298)->size(0));
          for (int _2299 = _7778; _2299 < _7779; ++_2299)
          {
            {
              ((*_2290)(_2297,_2299)) = _ptr__2298[_2299];
            }
          }
        }
      }
      if (((_2281 < (int)0) || (_2281 > _2288)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7780 = (int)0;
      int _7781 = _2281;
      for (int _2300 = _7780; _2300 < _7781; ++_2300)
      {
        {
          int _7782 = (int)1;
          int _7783 = _2287;
          for (int _2301 = _7782; _2301 < _7783; ++_2301)
          {
            {
              if ((((*_2290)((int)0,_2300)) != ((*_2290)(_2301,_2300))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7784 = safe_add( _2281,(int)1 );
      int _7785 = _2288;
      for (int _2302 = _7784; _2302 < _7785; ++_2302)
      {
        {
          int _7786 = (int)1;
          int _7787 = _2287;
          for (int _2303 = _7786; _2303 < _7787; ++_2303)
          {
            {
              if ((((*_2290)((int)0,_2302)) != ((*_2290)(_2303,_2302))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2304 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2295)));
      _checked_ptr_1<int> _ptr__2304(_2304 ? _2304->raw() : nullptr,_2304 ? _2304->size(0) : 0);
      std::vector<int> _7788;
      for (int _2306 = (int)0, _7789 = _2288; _2306 < _7789 ; ++_2306)
      {
        _7788.push_back(((*_2290)((int)0,_2306)));
      }
      auto _7790 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7788.size()),_7788.begin(),_7788.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2305 = _7790;
      _checked_ptr_1<int> _ptr__2305(_2305 ? _2305->raw() : nullptr,_2305 ? _2305->size(0) : 0);
      int _7791 = (int)0;
      int _7792 = _2288;
      for (int _2307 = _7791; _2307 < _7792; ++_2307)
      {
        {
          _ptr__2305[_2281] += ((*_2290)(_2307,_2281));
        }
      }
      {
        int _2308 = (int)((_2305)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2309 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2280)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2309(_2309 ? _2309->raw() : nullptr,_2309 ? _2309->size(0) : 0);
        int _7793 = (int)0;
        int _7794 = (int)((_2280)->size(0));
        for (int _2310 = _7793; _2310 < _7794; ++_2310)
        {
          {
            _ptr__2309[safe_add( _2310,(int)1 )] = safe_add( _ptr__2309[_2310],((*_2290)(_2310,_2281)) );
          }
        }
        if ((_2281 == (int)0))
        {
          {
            int _2311 = (int)0;
            int _7795 = (int)0;
            int _7796 = _2287;
            for (int _2312 = _7795; _2312 < _7796; ++_2312)
            {
              {
                int _2313 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2312)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2312)))->nativeidxs,(int)0,_2304,_2311,_2313);
                _2311 += _2313;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7797;
            for (int _2315 = (int)0, _7798 = _2287; _2315 < _7798 ; ++_2315)
            {
              _7797.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2315)))->nativeidxs);
            }
            auto _7799 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7797.size()),_7797.begin(),_7797.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2314 = _7799;
            if ((_2281 < _2288))
            {
              {
                int _2316 = (int)1;
                int _7800 = (int)0;
                int _7801 = _2281;
                for (int _2317 = _7800; _2317 < _7801; ++_2317)
                {
                  {
                    _2316 *= _ptr__2305[_2317];
                  }
                }
                int _2318 = (int)1;
                int _7802 = safe_add( _2281,(int)1 );
                int _7803 = _2288;
                for (int _2319 = _7802; _2319 < _7803; ++_2319)
                {
                  {
                    _2318 *= _ptr__2305[_2319];
                  }
                }
                int _2320 = (int)0;
                int _7804 = (int)0;
                int _7805 = _2316;
                for (int _2321 = _7804; _2321 < _7805; ++_2321)
                {
                  {
                    int _7806 = (int)0;
                    int _7807 = _2287;
                    for (int _2322 = _7806; _2322 < _7807; ++_2322)
                    {
                      {
                        int _2323 = (int)0;
                        int _2324 = ((*_2290)(_2322,_2281));
                        int _7808 = (int)0;
                        int _7809 = _2324;
                        for (int _2325 = _7808; _2325 < _7809; ++_2325)
                        {
                          {
                            int _7810 = (int)0;
                            int _7811 = _2318;
                            for (int _2326 = _7810; _2326 < _7811; ++_2326)
                            {
                              {
                                _ptr__2304[_2320] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2280)(_2287)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2321,_2318 ),_2324 ),_2323 )));
                                ++ _2320;
                                ++ _2323;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2327 = (int)1;
                int _7812 = (int)0;
                int _7813 = _2288;
                for (int _2328 = _7812; _2328 < _7813; ++_2328)
                {
                  {
                    _2327 *= _ptr__2305[_2328];
                  }
                }
                int _2329 = (int)0;
                int _7814 = (int)0;
                int _7815 = _2327;
                for (int _2330 = _7814; _2330 < _7815; ++_2330)
                {
                  {
                    int _7816 = (int)0;
                    int _7817 = _2287;
                    for (int _2331 = _7816; _2331 < _7817; ++_2331)
                    {
                      {
                        _ptr__2304[_2329] = ((*((*_2314)(_2331)))(_2330));
                        ++ _2329;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2282,_2305,_2304)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2332) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2332); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2332) { return __mosek_2fusion_2Constraint__index(_2332); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2332){
  _checked_ptr_1<int> _ptr__2332(_2332 ? _2332->raw() : nullptr, _2332 ? _2332->size(0) : 0);
  if (((int)((_2332)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7818 = (int)0;
      int _7819 = (int)((shape)->size(0));
      for (int _2333 = _7818; _2333 < _7819; ++_2333)
      {
        {
          if (((_ptr__2332[_2333] < (int)0) || (_ptr__2332[_2333] > ((*shape)(_2333)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2334 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2334)));
      _checked_ptr_1<long long> _ptr__2335(_2335 ? _2335->raw() : nullptr,_2335 ? _2335->size(0) : 0);
      _ptr__2335[(_2334 - (int)1)] = (int)1;
      int _7820 = (int)1;
      int _7821 = _2334;
      for (int _2336 = _7820; _2336 < _7821; ++_2336)
      {
        {
          _ptr__2335[((_2334 - _2336) - (int)1)] = safe_mul( _ptr__2335[(_2334 - _2336)],((*shape)(_2336)) );
        }
      }
      int _2337 = (int)0;
      int _7822 = (int)0;
      int _7823 = _2334;
      for (int _2338 = _7822; _2338 < _7823; ++_2338)
      {
        {
          _2337 += (int)safe_mul( _ptr__2335[_2338],_ptr__2332[_2338] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2337)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2339) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2339); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2339) { return __mosek_2fusion_2Constraint__index(_2339); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2339){
  if ((((int)((shape)->size(0)) == (int)0) && (_2339 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2339 < (int)0) || (_2339 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2339)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2340,std::shared_ptr< monty::ndarray< int,1 > > _2341) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2340,_2341); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2340,std::shared_ptr< monty::ndarray< int,1 > > _2341) { return __mosek_2fusion_2Constraint__slice(_2340,_2341); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2340,std::shared_ptr< monty::ndarray< int,1 > > _2341){
  _checked_ptr_1<int> _ptr__2340(_2340 ? _2340->raw() : nullptr, _2340 ? _2340->size(0) : 0);
  _checked_ptr_1<int> _ptr__2341(_2341 ? _2341->raw() : nullptr, _2341 ? _2341->size(0) : 0);
  if (((int)((_2340)->size(0)) != (int)((_2341)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2340)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7824 = (int)0;
      int _7825 = (int)((shape)->size(0));
      for (int _2342 = _7824; _2342 < _7825; ++_2342)
      {
        {
          if (((_ptr__2340[_2342] < (int)0) || (_ptr__2341[_2342] > ((*shape)(_2342)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2340[_2342] > _ptr__2341[_2342]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2343 = (int)((shape)->size(0));
      std::vector<int> _7826;
      for (int _2345 = (int)0, _7827 = _2343; _2345 < _7827 ; ++_2345)
      {
        _7826.push_back((_ptr__2341[_2345] - _ptr__2340[_2345]));
      }
      auto _7828 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7826.size()),_7826.begin(),_7826.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2344 = _7828;
      _checked_ptr_1<int> _ptr__2344(_2344 ? _2344->raw() : nullptr,_2344 ? _2344->size(0) : 0);
      int _2346 = (int)1;
      int _7829 = (int)0;
      int _7830 = _2343;
      for (int _2347 = _7829; _2347 < _7830; ++_2347)
      {
        {
          _2346 *= (_ptr__2341[_2347] - _ptr__2340[_2347]);
        }
      }
      if ((_2346 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2344,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2348 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2346)));
          _checked_ptr_1<int> _ptr__2348(_2348 ? _2348->raw() : nullptr,_2348 ? _2348->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2349 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2343)));
            _checked_ptr_1<int> _ptr__2349(_2349 ? _2349->raw() : nullptr,_2349 ? _2349->size(0) : 0);
            _ptr__2349[(_2343 - (int)1)] = (int)1;
            int _7831 = (int)1;
            int _7832 = _2343;
            for (int _2350 = _7831; _2350 < _7832; ++_2350)
            {
              {
                _ptr__2349[((_2343 - _2350) - (int)1)] = safe_mul( _ptr__2349[(_2343 - _2350)],((*shape)((_2343 - _2350))) );
              }
            }
            int _2351 = (int)0;
            int _7833 = (int)0;
            int _7834 = _2343;
            for (int _2352 = _7833; _2352 < _7834; ++_2352)
            {
              {
                _2351 += safe_mul( _ptr__2340[_2352],_ptr__2349[_2352] );
              }
            }
            std::vector<int> _7835;
            for (int _2354 = (int)0, _7836 = _2343; _2354 < _7836 ; ++_2354)
            {
              _7835.push_back(_2351);
            }
            auto _7837 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7835.size()),_7835.begin(),_7835.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2353 = _7837;
            _checked_ptr_1<int> _ptr__2353(_2353 ? _2353->raw() : nullptr,_2353 ? _2353->size(0) : 0);
            std::vector<int> _7838;
            for (int _2356 = (int)0, _7839 = _2343; _2356 < _7839 ; ++_2356)
            {
              _7838.push_back(_ptr__2340[_2356]);
            }
            auto _7840 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7838.size()),_7838.begin(),_7838.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2355 = _7840;
            _checked_ptr_1<int> _ptr__2355(_2355 ? _2355->raw() : nullptr,_2355 ? _2355->size(0) : 0);
            int _7841 = (int)0;
            int _7842 = _2346;
            for (int _2357 = _7841; _2357 < _7842; ++_2357)
            {
              {
                _ptr__2348[_2357] = ((*nativeidxs)(_ptr__2353[(_2343 - (int)1)]));
                _ptr__2355[(_2343 - (int)1)] += (int)1;
                _ptr__2353[(_2343 - (int)1)] += _ptr__2349[(_2343 - (int)1)];
                if ((_ptr__2355[(_2343 - (int)1)] >= _ptr__2341[(_2343 - (int)1)]))
                {
                  {
                    int _2358 = (_2343 - (int)1);
                    while ( ((_2358 > (int)0) && (_ptr__2355[_2358] >= _ptr__2341[_2358])) )
                    {
                      {
                        _ptr__2355[_2358] = _ptr__2340[_2358];
                        _ptr__2355[(_2358 - (int)1)] += (int)1;
                        _ptr__2353[(_2358 - (int)1)] += _ptr__2349[(_2358 - (int)1)];
                        -- _2358;
                      }
                    }
                    int _7843 = safe_add( _2358,(int)1 );
                    int _7844 = _2343;
                    for (int _2359 = _7843; _2359 < _7844; ++_2359)
                    {
                      {
                        _ptr__2353[_2359] = _ptr__2353[_2358];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2344,_2348)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2360,int _2361) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2360,_2361); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2360,int _2361) { return __mosek_2fusion_2Constraint__slice(_2360,_2361); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2360,int _2361){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2360 == (int)0) && (_2361 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2360 < (int)0) || (_2361 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2360 > _2361))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7845;
      for (int _2362 = _2360, _7846 = _2361; _2362 < _7846 ; ++_2362)
      {
        _7845.push_back(((*nativeidxs)(_2362)));
      }
      auto _7847 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7845.size()),_7845.begin(),_7845.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2361 - _2360))}),_7847)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2363 = (int)1;
  int _7848 = (int)0;
  int _7849 = (int)((shape)->size(0));
  for (int _2364 = _7848; _2364 < _7849; ++_2364)
  {
    {
      _2363 *= ((*shape)(_2364));
    }
  }
  return _2363;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7850;
  for (int _2365 = (int)0, _7851 = (int)((shape)->size(0)); _2365 < _7851 ; ++_2365)
  {
    _7850.push_back(((*shape)(_2365)));
  }
  auto _7852 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7850.size()),_7850.begin(),_7850.end()));
  return _7852;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2366) { return mosek::fusion::p_Set::size(_2366); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2366){
  _checked_ptr_1<int> _ptr__2366(_2366 ? _2366->raw() : nullptr, _2366 ? _2366->size(0) : 0);
  long long _2367 = (long long)1;
  int _7853 = (int)0;
  int _7854 = (int)((_2366)->size(0));
  for (int _2368 = _7853; _2368 < _7854; ++_2368)
  {
    {
      _2367 *= _ptr__2366[_2368];
    }
  }
  return _2367;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2369,    std::shared_ptr< monty::ndarray< int,1 > > _2370) { return mosek::fusion::p_Set::match(_2369,_2370); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2369,std::shared_ptr< monty::ndarray< int,1 > > _2370){
  _checked_ptr_1<int> _ptr__2369(_2369 ? _2369->raw() : nullptr, _2369 ? _2369->size(0) : 0);
  _checked_ptr_1<int> _ptr__2370(_2370 ? _2370->raw() : nullptr, _2370 ? _2370->size(0) : 0);
  if (((int)((_2369)->size(0)) != (int)((_2370)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _7855 = (int)0;
  int _7856 = (int)((_2369)->size(0));
  for (int _2371 = _7855; _2371 < _7856; ++_2371)
  {
    {
      if ((_ptr__2369[_2371] != _ptr__2370[_2371]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2372,    std::shared_ptr< monty::ndarray< int,1 > > _2373) { return mosek::fusion::p_Set::linearidx(_2372,_2373); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2372,std::shared_ptr< monty::ndarray< int,1 > > _2373){
  _checked_ptr_1<int> _ptr__2372(_2372 ? _2372->raw() : nullptr, _2372 ? _2372->size(0) : 0);
  _checked_ptr_1<int> _ptr__2373(_2373 ? _2373->raw() : nullptr, _2373 ? _2373->size(0) : 0);
  long long _2374 = _ptr__2373[(int)0];
  int _7857 = (int)1;
  int _7858 = (int)((_2373)->size(0));
  for (int _2375 = _7857; _2375 < _7858; ++_2375)
  {
    {
      _2374 = safe_add( safe_mul( _2374,_ptr__2372[_2375] ),_ptr__2373[_2375] );
    }
  }
  return _2374;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2376,    long long _2377) { return mosek::fusion::p_Set::idxtokey(_2376,_2377); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2376,long long _2377){
  _checked_ptr_1<int> _ptr__2376(_2376 ? _2376->raw() : nullptr, _2376 ? _2376->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2378 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2376)->size(0)))));
  _checked_ptr_1<int> _ptr__2378(_2378 ? _2378->raw() : nullptr,_2378 ? _2378->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2376,_2377,_2378);
  return _2378;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2379,    long long _2380,    std::shared_ptr< monty::ndarray< int,1 > > _2381) { mosek::fusion::p_Set::idxtokey(_2379,_2380,_2381); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2379,long long _2380,std::shared_ptr< monty::ndarray< int,1 > > _2381){
  _checked_ptr_1<int> _ptr__2379(_2379 ? _2379->raw() : nullptr, _2379 ? _2379->size(0) : 0);
  _checked_ptr_1<int> _ptr__2381(_2381 ? _2381->raw() : nullptr, _2381 ? _2381->size(0) : 0);
  int _2382 = (int)((_2379)->size(0));
  if ((_2382 > (int)0))
  {
    {
      long long _2383 = _2380;
      int _7859 = (int)0;
      int _7860 = (_2382 - (int)1);
      for (int _2384 = _7859; _2384 < _7860; ++_2384)
      {
        {
          _ptr__2381[((_2382 - _2384) - (int)1)] = (int)(_2383 % _ptr__2379[((_2382 - _2384) - (int)1)]);
          _2383 /= _ptr__2379[((_2382 - _2384) - (int)1)];
        }
      }
      _ptr__2381[(int)0] = (int)_2383;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2385,    long long _2386) { return mosek::fusion::p_Set::indexToString(_2385,_2386); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2385,long long _2386){
  _checked_ptr_1<int> _ptr__2385(_2385 ? _2385->raw() : nullptr, _2385 ? _2385->size(0) : 0);
  int _2387 = (int)((_2385)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2388 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2387 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2387 == (int)1))
  {
    {
      return _2388->__mosek_2fusion_2Utils_2StringBuffer__a(_2386)->toString();
    }
  }
  else
  {
    {
      long long _2389 = _2386;
      std::shared_ptr< monty::ndarray< int,1 > > _2390 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2387)));
      _checked_ptr_1<int> _ptr__2390(_2390 ? _2390->raw() : nullptr,_2390 ? _2390->size(0) : 0);
      int _7861 = (int)1;
      int _7862 = _2387;
      for (int _2391 = _7861; _2391 < _7862; ++_2391)
      {
        {
          _ptr__2390[(_2387 - _2391)] = (int)(_2389 % _ptr__2385[(_2387 - _2391)]);
          _2389 /= _ptr__2385[(_2387 - _2391)];
        }
      }
      _ptr__2390[(int)0] = (int)_2389;
      _2388->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2390[(int)0]);
      int _7863 = (int)1;
      int _7864 = _2387;
      for (int _2392 = _7863; _2392 < _7864; ++_2392)
      {
        {
          _2388->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2390[_2392]);
        }
      }
      return _2388->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2393) { return mosek::fusion::p_Set::keyToString(_2393); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2393){
  _checked_ptr_1<int> _ptr__2393(_2393 ? _2393->raw() : nullptr, _2393 ? _2393->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2394 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2394->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2393[(int)0]);
  int _7865 = (int)1;
  int _7866 = (int)((_2393)->size(0));
  for (int _2395 = _7865; _2395 < _7866; ++_2395)
  {
    {
      _2394->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2393[_2395]);
    }
  }
  return _2394->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2396,    long long _2397,    std::shared_ptr< monty::ndarray< int,1 > > _2398) { mosek::fusion::p_Set::indexToKey(_2396,_2397,_2398); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2396,long long _2397,std::shared_ptr< monty::ndarray< int,1 > > _2398){
  _checked_ptr_1<int> _ptr__2396(_2396 ? _2396->raw() : nullptr, _2396 ? _2396->size(0) : 0);
  _checked_ptr_1<int> _ptr__2398(_2398 ? _2398->raw() : nullptr, _2398 ? _2398->size(0) : 0);
  int _2399 = (int)((_2396)->size(0));
  if ((_2399 == (int)1))
  {
    {
      _ptr__2398[(int)0] = (int)_2397;
    }
  }
  else
  {
    {
      long long _2400 = _2397;
      int _7867 = (int)1;
      int _7868 = _2399;
      for (int _2401 = _7867; _2401 < _7868; ++_2401)
      {
        {
          _ptr__2398[(_2399 - _2401)] = (int)(_2400 % _ptr__2396[(_2399 - _2401)]);
          _2400 /= _ptr__2396[(_2399 - _2401)];
        }
      }
      _ptr__2398[(int)0] = (int)_2400;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2402) { return mosek::fusion::p_Set::strides(_2402); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2402){
  _checked_ptr_1<int> _ptr__2402(_2402 ? _2402->raw() : nullptr, _2402 ? _2402->size(0) : 0);
  int _2403 = (int)((_2402)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2404 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2403)));
  _checked_ptr_1<long long> _ptr__2404(_2404 ? _2404->raw() : nullptr,_2404 ? _2404->size(0) : 0);
  _ptr__2404[(_2403 - (int)1)] = (int)1;
  int _7869 = (int)1;
  int _7870 = _2403;
  for (int _2405 = _7869; _2405 < _7870; ++_2405)
  {
    {
      _ptr__2404[((_2403 - _2405) - (int)1)] = safe_mul( _ptr__2404[(_2403 - _2405)],_ptr__2402[(_2403 - _2405)] );
    }
  }
  return _2404;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2406,    std::shared_ptr< monty::ndarray< int,1 > > _2407) { return mosek::fusion::p_Set::make(_2406,_2407); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2406,std::shared_ptr< monty::ndarray< int,1 > > _2407){
  _checked_ptr_1<int> _ptr__2406(_2406 ? _2406->raw() : nullptr, _2406 ? _2406->size(0) : 0);
  _checked_ptr_1<int> _ptr__2407(_2407 ? _2407->raw() : nullptr, _2407 ? _2407->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2408 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2406)->size(0)),(int)((_2407)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2408(_2408 ? _2408->raw() : nullptr,_2408 ? _2408->size(0) : 0);
  int _7871 = (int)0;
  int _7872 = (int)((_2406)->size(0));
  for (int _2409 = _7871; _2409 < _7872; ++_2409)
  {
    {
      _ptr__2408[_2409] = _ptr__2406[_2409];
    }
  }
  int _7873 = (int)0;
  int _7874 = (int)((_2407)->size(0));
  for (int _2410 = _7873; _2410 < _7874; ++_2410)
  {
    {
      _ptr__2408[safe_add( (int)((_2406)->size(0)),_2410 )] = _ptr__2407[_2410];
    }
  }
  return _2408;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2411) { return mosek::fusion::p_Set::make(_2411); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2411){
  _checked_ptr_1<int> _ptr__2411(_2411 ? _2411->raw() : nullptr, _2411 ? _2411->size(0) : 0);
  std::vector<int> _7875;
  for (int _2412 = (int)0, _7876 = (int)((_2411)->size(0)); _2412 < _7876 ; ++_2412)
  {
    _7875.push_back(_ptr__2411[_2412]);
  }
  auto _7877 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7875.size()),_7875.begin(),_7875.end()));
  return _7877;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2413,    int _2414,    int _2415) { return mosek::fusion::p_Set::make(_2413,_2414,_2415); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2413,int _2414,int _2415){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2413),(int)(_2414),(int)(_2415)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2416,    int _2417) { return mosek::fusion::p_Set::make(_2416,_2417); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2416,int _2417){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2416),(int)(_2417)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2418) { return mosek::fusion::p_Set::make(_2418); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2418){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2418)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2419) { return mosek::fusion::p_Set::make(_2419); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2419){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2419)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2420,    double _2421,    std::shared_ptr< monty::ndarray< int,1 > > _2422){ return new mosek::fusion::ConeDomain(_2420,_2421,_2422); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2420,    double _2421,    std::shared_ptr< monty::ndarray< int,1 > > _2422) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2420,_2421,_2422); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2420,    double _2421,    std::shared_ptr< monty::ndarray< int,1 > > _2422){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2422(_2422 ? _2422->raw() : nullptr, _2422 ? _2422->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7878;
    bool _7879 = (NULL != _2422.get());
    if (_7879)
    {
      _7878 = ::mosek::fusion::p_Set::make(_2422);
    }
    else
    {
      _7878 = nullptr;
    }
    shape = _7878;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2421;
    key = _2420;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2421;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2423,    std::shared_ptr< monty::ndarray< int,1 > > _2424){ return new mosek::fusion::ConeDomain(_2423,_2424); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2423,    std::shared_ptr< monty::ndarray< int,1 > > _2424) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2423,_2424); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2423,    std::shared_ptr< monty::ndarray< int,1 > > _2424){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2424(_2424 ? _2424->raw() : nullptr, _2424 ? _2424->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2423,1.0,_2424);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2425){
  _checked_ptr_1<int> _ptr__2425(_2425 ? _2425->raw() : nullptr, _2425 ? _2425->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2425,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2426) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2426); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2426) { return __mosek_2fusion_2ConeDomain__axis(_2426); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2426){
  axisidx = _2426;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2427,    int _2428){ return new mosek::fusion::LinPSDDomain(_2427,_2428); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2427,    int _2428) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2427,_2428); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2427,    int _2428){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2427(_2427 ? _2427->raw() : nullptr, _2427 ? _2427->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2428;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2427);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2429){ return new mosek::fusion::LinPSDDomain(_2429); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2429) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2429); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2429){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2429(_2429 ? _2429->raw() : nullptr, _2429 ? _2429->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2429);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2430,    std::shared_ptr< monty::ndarray< int,1 > > _2431,    int _2432,    int _2433){ return new mosek::fusion::PSDDomain(_2430,_2431,_2432,_2433); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2430,    std::shared_ptr< monty::ndarray< int,1 > > _2431,    int _2432,    int _2433) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2430,_2431,_2432,_2433); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2430,    std::shared_ptr< monty::ndarray< int,1 > > _2431,    int _2432,    int _2433){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2431(_2431 ? _2431->raw() : nullptr, _2431 ? _2431->size(0) : 0);
    axisIsSet = true;
    shape = _2431;
    key = _2430;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2432;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2433;
    int _2434 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2432) && (((int)((shape)->size(0)) > _2433) && ((_2432 >= (int)0) && ((_2433 >= (int)0) && (_2432 != _2433)))))) && (((*shape)(_2432)) == ((*shape)(_2433)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2435,    std::shared_ptr< monty::ndarray< int,1 > > _2436){ return new mosek::fusion::PSDDomain(_2435,_2436); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2435,    std::shared_ptr< monty::ndarray< int,1 > > _2436) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2435,_2436); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2435,    std::shared_ptr< monty::ndarray< int,1 > > _2436){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2436(_2436 ? _2436->raw() : nullptr, _2436 ? _2436->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2435,_2436,((int)((_2436)->size(0)) - (int)2),((int)((_2436)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2437){ return new mosek::fusion::PSDDomain(_2437); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2437) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2437); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2437){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2437;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2438,int _2439) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2438,_2439); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2438,int _2439) { return __mosek_2fusion_2PSDDomain__axis(_2438,_2439); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2438,int _2439){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2438;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2439;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2438 >= (int)0) && ((_2439 >= (int)0) && (_2438 != _2439))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2438) && (((int)((shape)->size(0)) > _2439) && ((_2438 >= (int)0) && ((_2439 >= (int)0) && (_2438 != _2439)))))) && (((*shape)(_2438)) == ((*shape)(_2439))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2440){ return new mosek::fusion::SymmetricRangeDomain(_2440); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2440) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2440); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2440){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2440);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7880;
    bool _7881 = (NULL == shape.get());
    if (_7881)
    {
      _7880 = (int)0;
    }
    else
    {
      _7880 = ((*shape)((int)0));
    }
    dim = _7880;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2441,    std::shared_ptr< monty::ndarray< double,1 > > _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< int,1 > > _2444){ return new mosek::fusion::RangeDomain(_2441,_2442,_2443,_2444); }mosek::fusion::RangeDomain::RangeDomain  (bool _2441,    std::shared_ptr< monty::ndarray< double,1 > > _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< int,1 > > _2444) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2441,_2442,_2443,_2444); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2441,    std::shared_ptr< monty::ndarray< double,1 > > _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< int,1 > > _2444){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2442(_2442 ? _2442->raw() : nullptr, _2442 ? _2442->size(0) : 0);
    _checked_ptr_1<double> _ptr__2443(_2443 ? _2443->raw() : nullptr, _2443 ? _2443->size(0) : 0);
    _checked_ptr_1<int> _ptr__2444(_2444 ? _2444->raw() : nullptr, _2444 ? _2444->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2441,_2442,_2443,_2444,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2445,    std::shared_ptr< monty::ndarray< double,1 > > _2446,    std::shared_ptr< monty::ndarray< double,1 > > _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448,    std::shared_ptr< monty::ndarray< int,2 > > _2449){ return new mosek::fusion::RangeDomain(_2445,_2446,_2447,_2448,_2449); }mosek::fusion::RangeDomain::RangeDomain  (bool _2445,    std::shared_ptr< monty::ndarray< double,1 > > _2446,    std::shared_ptr< monty::ndarray< double,1 > > _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448,    std::shared_ptr< monty::ndarray< int,2 > > _2449) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2445,_2446,_2447,_2448,_2449); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2445,    std::shared_ptr< monty::ndarray< double,1 > > _2446,    std::shared_ptr< monty::ndarray< double,1 > > _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448,    std::shared_ptr< monty::ndarray< int,2 > > _2449){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2446(_2446 ? _2446->raw() : nullptr, _2446 ? _2446->size(0) : 0);
    _checked_ptr_1<double> _ptr__2447(_2447 ? _2447->raw() : nullptr, _2447 ? _2447->size(0) : 0);
    _checked_ptr_1<int> _ptr__2448(_2448 ? _2448->raw() : nullptr, _2448 ? _2448->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2445,_2446,_2447,_2448,_2449,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2450,    std::shared_ptr< monty::ndarray< double,1 > > _2451,    std::shared_ptr< monty::ndarray< double,1 > > _2452,    std::shared_ptr< monty::ndarray< int,1 > > _2453,    std::shared_ptr< monty::ndarray< int,2 > > _2454,    int _2455){ return new mosek::fusion::RangeDomain(_2450,_2451,_2452,_2453,_2454,_2455); }mosek::fusion::RangeDomain::RangeDomain  (bool _2450,    std::shared_ptr< monty::ndarray< double,1 > > _2451,    std::shared_ptr< monty::ndarray< double,1 > > _2452,    std::shared_ptr< monty::ndarray< int,1 > > _2453,    std::shared_ptr< monty::ndarray< int,2 > > _2454,    int _2455) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2450,_2451,_2452,_2453,_2454,_2455); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2450,    std::shared_ptr< monty::ndarray< double,1 > > _2451,    std::shared_ptr< monty::ndarray< double,1 > > _2452,    std::shared_ptr< monty::ndarray< int,1 > > _2453,    std::shared_ptr< monty::ndarray< int,2 > > _2454,    int _2455){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2451(_2451 ? _2451->raw() : nullptr, _2451 ? _2451->size(0) : 0);
    _checked_ptr_1<double> _ptr__2452(_2452 ? _2452->raw() : nullptr, _2452 ? _2452->size(0) : 0);
    _checked_ptr_1<int> _ptr__2453(_2453 ? _2453->raw() : nullptr, _2453 ? _2453->size(0) : 0);
    cardinal_flag = false;
    shape = _2453;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2450;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2452;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2451;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2454;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2456){ return new mosek::fusion::RangeDomain(_2456); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2456) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2456); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2456){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2456)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2456)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2456)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2456)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2456)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2456)->lb;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2457) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2457); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2457) { return __mosek_2fusion_2RangeDomain__sparse(_2457); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2457){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2457)->size(0)),(int)((_2457)->size(1)))));
  {
    int _2458 = (int)0;
    for(;(_2458 < (int)((_2457)->size(0)));++ _2458)
    {
      {
        {
          int _2459 = (int)0;
          for(;(_2459 < (int)((_2457)->size(1)));++ _2459)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2458,_2459)) = ((*_2457)(_2458,_2459));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2460) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2460); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2460) { return __mosek_2fusion_2RangeDomain__sparse(_2460); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2460){
  _checked_ptr_1<int> _ptr__2460(_2460 ? _2460->raw() : nullptr, _2460 ? _2460->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2460)->size(0)),(int)1)));
  int _7882 = (int)0;
  int _7883 = (int)((_2460)->size(0));
  for (int _2461 = _7882; _2461 < _7883; ++_2461)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2461,(int)0)) = _ptr__2460[_2461];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2462) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2462); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2462) { return __mosek_2fusion_2RangeDomain__withShape(_2462); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2462){
  _checked_ptr_1<int> _ptr__2462(_2462 ? _2462->raw() : nullptr, _2462 ? _2462->size(0) : 0);
  shape = _2462;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2463){
  _checked_ptr_1<int> _ptr__2463(_2463 ? _2463->raw() : nullptr, _2463 ? _2463->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2463)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _7884 = (int)0;
      int _7885 = (int)((shape)->size(0));
      for (int _2464 = _7884; _2464 < _7885; ++_2464)
      {
        {
          if ((((*shape)(_2464)) != _ptr__2463[_2464]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2465){ return new mosek::fusion::SymmetricLinearDomain(_2465); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2465) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2465); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2465){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2465;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2465)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2465)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2465)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2465)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7886;
    bool _7887 = (NULL == shape.get());
    if (_7887)
    {
      _7886 = (int)0;
    }
    else
    {
      _7886 = ((*shape)((int)0));
    }
    dim = _7886;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2466) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2466); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2466) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2466); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2466){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2466)->size(0)),(int)((_2466)->size(1)))));
  {
    int _2467 = (int)0;
    for(;(_2467 < (int)((_2466)->size(0)));++ _2467)
    {
      {
        {
          int _2468 = (int)0;
          for(;(_2468 < (int)((_2466)->size(1)));++ _2468)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2467,_2468)) = ((*_2466)(_2467,_2468));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2469) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2469); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2469) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2469); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2469){
  _checked_ptr_1<int> _ptr__2469(_2469 ? _2469->raw() : nullptr, _2469 ? _2469->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2469)->size(0)),(int)1)));
  int _7888 = (int)0;
  int _7889 = (int)((_2469)->size(0));
  for (int _2470 = _7888; _2470 < _7889; ++_2470)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2470,(int)0)) = _ptr__2469[_2470];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2471){
  _checked_ptr_1<int> _ptr__2471(_2471 ? _2471->raw() : nullptr, _2471 ? _2471->size(0) : 0);
  int _7890 = (int)0;
  int _7891 = (int)((_2471)->size(0));
  for (int _2472 = _7890; _2472 < _7891; ++_2472)
  {
    {
      if ((_ptr__2471[_2472] == ((*shape)(_2472))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2473,    bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476){ return new mosek::fusion::LinearDomain(_2473,_2474,_2475,_2476); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2473,    bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2473,_2474,_2475,_2476); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2473,    bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2475(_2475 ? _2475->raw() : nullptr, _2475 ? _2475->size(0) : 0);
    _checked_ptr_1<int> _ptr__2476(_2476 ? _2476->raw() : nullptr, _2476 ? _2476->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2473,_2474,_2475,_2476,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2477,    bool _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482){ return new mosek::fusion::LinearDomain(_2477,_2478,_2479,_2480,_2481,_2482); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2477,    bool _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2477,_2478,_2479,_2480,_2481,_2482); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2477,    bool _2478,    std::shared_ptr< monty::ndarray< double,1 > > _2479,    std::shared_ptr< monty::ndarray< int,1 > > _2480,    std::shared_ptr< monty::ndarray< int,2 > > _2481,    int _2482){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2479(_2479 ? _2479->raw() : nullptr, _2479 ? _2479->size(0) : 0);
    _checked_ptr_1<int> _ptr__2480(_2480 ? _2480->raw() : nullptr, _2480 ? _2480->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2478;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2480;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2477;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2479;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2481;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2483){ return new mosek::fusion::LinearDomain(_2483); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2483) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2483); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2483){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2483)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2483)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2483)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2483)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2483)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2483)->cardinal_flag;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2484); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) { return __mosek_2fusion_2LinearDomain__sparse(_2484); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2484)->size(0)),(int)((_2484)->size(1)))));
  {
    int _2485 = (int)0;
    for(;(_2485 < (int)((_2484)->size(0)));++ _2485)
    {
      {
        {
          int _2486 = (int)0;
          for(;(_2486 < (int)((_2484)->size(1)));++ _2486)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2485,_2486)) = ((*_2484)(_2485,_2486));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2487); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) { return __mosek_2fusion_2LinearDomain__sparse(_2487); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487){
  _checked_ptr_1<int> _ptr__2487(_2487 ? _2487->raw() : nullptr, _2487 ? _2487->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2487)->size(0)),(int)1)));
  int _7892 = (int)0;
  int _7893 = (int)((_2487)->size(0));
  for (int _2488 = _7892; _2488 < _7893; ++_2488)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2488,(int)0)) = _ptr__2487[_2488];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2489); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) { return __mosek_2fusion_2LinearDomain__withShape(_2489); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489){
  _checked_ptr_1<int> _ptr__2489(_2489 ? _2489->raw() : nullptr, _2489 ? _2489->size(0) : 0);
  shape = _2489;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2490){
  _checked_ptr_1<int> _ptr__2490(_2490 ? _2490->raw() : nullptr, _2490 ? _2490->size(0) : 0);
  if ((!scalable))
  {
    {
      int _7894 = (int)0;
      int _7895 = (int)((_2490)->size(0));
      for (int _2491 = _7894; _2491 < _7895; ++_2491)
      {
        {
          if ((_ptr__2490[_2491] == ((*shape)(_2491))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2492){
  _checked_ptr_1<int> _ptr__2492(_2492 ? _2492->raw() : nullptr, _2492 ? _2492->size(0) : 0);
  long long _2493 = (long long)1;
  int _7896 = (int)0;
  int _7897 = (int)((_2492)->size(0));
  for (int _2494 = _7896; _2494 < _7897; ++_2494)
  {
    {
      _2493 *= _ptr__2492[_2494];
    }
  }
  return _2493;
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2495,monty::rc_ptr< ::mosek::fusion::Matrix > _2496){
  if (_2496->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2497 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2496->numNonzeros())));
      _checked_ptr_1<int> _ptr__2497(_2497 ? _2497->raw() : nullptr,_2497 ? _2497->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2498 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2496->numNonzeros())));
      _checked_ptr_1<int> _ptr__2498(_2498 ? _2498->raw() : nullptr,_2498 ? _2498->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2499 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2496->numNonzeros())));
      _checked_ptr_1<double> _ptr__2499(_2499 ? _2499->raw() : nullptr,_2499 ? _2499->size(0) : 0);
      _2496->getDataAsTriplets(_2497,_2498,_2499);
      std::shared_ptr< monty::ndarray< int,2 > > _2500 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2497)->size(0)),(int)2)));
      int _7898 = (int)0;
      int _7899 = (int)((_2497)->size(0));
      for (int _2501 = _7898; _2501 < _7899; ++_2501)
      {
        {
          ((*_2500)(_2501,(int)0)) = _ptr__2497[_2501];
          ((*_2500)(_2501,(int)1)) = _ptr__2498[_2501];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2495,false,_2499,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2496)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2496)->dimj)}),_2500,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2495,false,_2496->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2496)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2496)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2502){
  _checked_ptr_1<int> _ptr__2502(_2502 ? _2502->raw() : nullptr, _2502 ? _2502->size(0) : 0);
  long long _2503 = (int)1;
  int _7900 = (int)0;
  int _7901 = (int)((_2502)->size(0));
  for (int _2504 = _7900; _2504 < _7901; ++_2504)
  {
    {
      _2503 *= _ptr__2502[_2504];
    }
  }
  return _2503;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2505,std::shared_ptr< monty::ndarray< double,1 > > _2506,std::shared_ptr< monty::ndarray< double,1 > > _2507,std::shared_ptr< monty::ndarray< int,2 > > _2508,std::shared_ptr< monty::ndarray< int,1 > > _2509){
  _checked_ptr_1<double> _ptr__2506(_2506 ? _2506->raw() : nullptr, _2506 ? _2506->size(0) : 0);
  _checked_ptr_1<double> _ptr__2507(_2507 ? _2507->raw() : nullptr, _2507 ? _2507->size(0) : 0);
  _checked_ptr_1<int> _ptr__2509(_2509 ? _2509->raw() : nullptr, _2509 ? _2509->size(0) : 0);
  if (((!_2505) && ((int)((_2506)->size(0)) != (int)((_2507)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2508.get()) && ((int)((_2508)->size(0)) != (int)((_2506)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _7902 = (int)0;
  int _7903 = (int)((_2507)->size(0));
  for (int _2510 = _7902; _2510 < _7903; ++_2510)
  {
    {
      if ((_ptr__2506[_2510] > _ptr__2507[_2510]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2509.get()) && (::mosek::fusion::p_Domain::dimsize(_2509) != (int)((_2506)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2505,_2506,_2507,_2509)->__mosek_2fusion_2RangeDomain__sparse(_2508);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2511) { return mosek::fusion::p_Domain::symmetric(_2511); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2511){
  return _2511->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2512) { return mosek::fusion::p_Domain::symmetric(_2512); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2512){
  return _2512->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2513,    std::shared_ptr< monty::ndarray< int,2 > > _2514) { return mosek::fusion::p_Domain::sparse(_2513,_2514); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2513,std::shared_ptr< monty::ndarray< int,2 > > _2514){
  return _2513->__mosek_2fusion_2RangeDomain__sparse(_2514);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2515,    std::shared_ptr< monty::ndarray< int,1 > > _2516) { return mosek::fusion::p_Domain::sparse(_2515,_2516); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2515,std::shared_ptr< monty::ndarray< int,1 > > _2516){
  _checked_ptr_1<int> _ptr__2516(_2516 ? _2516->raw() : nullptr, _2516 ? _2516->size(0) : 0);
  return _2515->__mosek_2fusion_2RangeDomain__sparse(_2516);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2517,    std::shared_ptr< monty::ndarray< int,2 > > _2518) { return mosek::fusion::p_Domain::sparse(_2517,_2518); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2517,std::shared_ptr< monty::ndarray< int,2 > > _2518){
  return _2517->__mosek_2fusion_2LinearDomain__sparse(_2518);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2519,    std::shared_ptr< monty::ndarray< int,1 > > _2520) { return mosek::fusion::p_Domain::sparse(_2519,_2520); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2519,std::shared_ptr< monty::ndarray< int,1 > > _2520){
  _checked_ptr_1<int> _ptr__2520(_2520 ? _2520->raw() : nullptr, _2520 ? _2520->size(0) : 0);
  return _2519->__mosek_2fusion_2LinearDomain__sparse(_2520);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2521) { return mosek::fusion::p_Domain::integral(_2521); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2521){
  return _2521->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2522) { return mosek::fusion::p_Domain::integral(_2522); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2522){
  return _2522->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2523) { return mosek::fusion::p_Domain::integral(_2523); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2523){
  return _2523->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2524,    int _2525) { return mosek::fusion::p_Domain::axis(_2524,_2525); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2524,int _2525){
  return _2524->__mosek_2fusion_2ConeDomain__axis(_2525);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2526,    std::shared_ptr< monty::ndarray< int,1 > > _2527) { return mosek::fusion::p_Domain::inDPowerCone(_2526,_2527); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2526,std::shared_ptr< monty::ndarray< int,1 > > _2527){
  _checked_ptr_1<int> _ptr__2527(_2527 ? _2527->raw() : nullptr, _2527 ? _2527->size(0) : 0);
  std::vector<int> _7904;
  for (int _2528 = (int)0, _7905 = (int)((_2527)->size(0)); _2528 < _7905 ; ++_2528)
  {
    _7904.push_back(_ptr__2527[_2528]);
  }
  auto _7906 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7904.size()),_7904.begin(),_7904.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2526,_7906);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2529,    int _2530) { return mosek::fusion::p_Domain::inDPowerCone(_2529,_2530); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2529,int _2530){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2529,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2530),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2531) { return mosek::fusion::p_Domain::inDPowerCone(_2531); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2531){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2531,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2532,    std::shared_ptr< monty::ndarray< int,1 > > _2533) { return mosek::fusion::p_Domain::inPPowerCone(_2532,_2533); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2532,std::shared_ptr< monty::ndarray< int,1 > > _2533){
  _checked_ptr_1<int> _ptr__2533(_2533 ? _2533->raw() : nullptr, _2533 ? _2533->size(0) : 0);
  std::vector<int> _7907;
  for (int _2534 = (int)0, _7908 = (int)((_2533)->size(0)); _2534 < _7908 ; ++_2534)
  {
    _7907.push_back(_ptr__2533[_2534]);
  }
  auto _7909 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7907.size()),_7907.begin(),_7907.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2532,_7909);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2535,    int _2536) { return mosek::fusion::p_Domain::inPPowerCone(_2535,_2536); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2535,int _2536){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2535,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2536),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2537) { return mosek::fusion::p_Domain::inPPowerCone(_2537); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2537){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2537,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2538) { return mosek::fusion::p_Domain::inDExpCone(_2538); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2538){
  _checked_ptr_1<int> _ptr__2538(_2538 ? _2538->raw() : nullptr, _2538 ? _2538->size(0) : 0);
  std::vector<int> _7910;
  for (int _2539 = (int)0, _7911 = (int)((_2538)->size(0)); _2539 < _7911 ; ++_2539)
  {
    _7910.push_back(_ptr__2538[_2539]);
  }
  auto _7912 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7910.size()),_7910.begin(),_7910.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_7912);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2540) { return mosek::fusion::p_Domain::inDExpCone(_2540); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2540){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2540),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2541) { return mosek::fusion::p_Domain::inPExpCone(_2541); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2541){
  _checked_ptr_1<int> _ptr__2541(_2541 ? _2541->raw() : nullptr, _2541 ? _2541->size(0) : 0);
  std::vector<int> _7913;
  for (int _2542 = (int)0, _7914 = (int)((_2541)->size(0)); _2542 < _7914 ; ++_2542)
  {
    _7913.push_back(_ptr__2541[_2542]);
  }
  auto _7915 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7913.size()),_7913.begin(),_7913.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_7915);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2543) { return mosek::fusion::p_Domain::inPExpCone(_2543); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2543){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2543),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2544) { return mosek::fusion::p_Domain::inRotatedQCone(_2544); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2544){
  _checked_ptr_1<int> _ptr__2544(_2544 ? _2544->raw() : nullptr, _2544 ? _2544->size(0) : 0);
  std::vector<int> _7916;
  for (int _2545 = (int)0, _7917 = (int)((_2544)->size(0)); _2545 < _7917 ; ++_2545)
  {
    _7916.push_back(_ptr__2544[_2545]);
  }
  auto _7918 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7916.size()),_7916.begin(),_7916.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_7918);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2546,    int _2547) { return mosek::fusion::p_Domain::inRotatedQCone(_2546,_2547); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2546,int _2547){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2546),(int)(_2547)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2548) { return mosek::fusion::p_Domain::inRotatedQCone(_2548); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2548){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2548)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2549) { return mosek::fusion::p_Domain::inQCone(_2549); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2549){
  _checked_ptr_1<int> _ptr__2549(_2549 ? _2549->raw() : nullptr, _2549 ? _2549->size(0) : 0);
  std::vector<int> _7919;
  for (int _2550 = (int)0, _7920 = (int)((_2549)->size(0)); _2550 < _7920 ; ++_2550)
  {
    _7919.push_back(_ptr__2549[_2550]);
  }
  auto _7921 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7919.size()),_7919.begin(),_7919.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_7921);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2551,    int _2552) { return mosek::fusion::p_Domain::inQCone(_2551,_2552); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2551,int _2552){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2551),(int)(_2552)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2553) { return mosek::fusion::p_Domain::inQCone(_2553); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2553){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2553)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2554,    int _2555) { return mosek::fusion::p_Domain::isLinPSD(_2554,_2555); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2554,int _2555){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2554,safe_add( _2554,(int)1 ) ) / (int)2),_2555));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2556) { return mosek::fusion::p_Domain::isLinPSD(_2556); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2556){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2556,safe_add( _2556,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2557,    int _2558) { return mosek::fusion::p_Domain::isTrilPSD(_2557,_2558); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2557,int _2558){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2558),(int)(_2557),(int)(_2557)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2559) { return mosek::fusion::p_Domain::isTrilPSD(_2559); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2559){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2559),(int)(_2559)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2560,    int _2561) { return mosek::fusion::p_Domain::inPSDCone(_2560,_2561); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2560,int _2561){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2561),(int)(_2560),(int)(_2560)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2562) { return mosek::fusion::p_Domain::inPSDCone(_2562); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2562){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2562),(int)(_2562)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2563) { return mosek::fusion::p_Domain::binary(_2563); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2563){
  _checked_ptr_1<int> _ptr__2563(_2563 ? _2563->raw() : nullptr, _2563 ? _2563->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2563)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2564,    int _2565) { return mosek::fusion::p_Domain::binary(_2564,_2565); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2564,int _2565){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2564),(int)(_2565)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2566) { return mosek::fusion::p_Domain::binary(_2566); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2566){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2566)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2567,    std::shared_ptr< monty::ndarray< double,1 > > _2568,    std::shared_ptr< monty::ndarray< int,1 > > _2569) { return mosek::fusion::p_Domain::inRange(_2567,_2568,_2569); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2567,std::shared_ptr< monty::ndarray< double,1 > > _2568,std::shared_ptr< monty::ndarray< int,1 > > _2569){
  _checked_ptr_1<double> _ptr__2567(_2567 ? _2567->raw() : nullptr, _2567 ? _2567->size(0) : 0);
  _checked_ptr_1<double> _ptr__2568(_2568 ? _2568->raw() : nullptr, _2568 ? _2568->size(0) : 0);
  _checked_ptr_1<int> _ptr__2569(_2569 ? _2569->raw() : nullptr, _2569 ? _2569->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2567,_2568,_2569);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2570,    double _2571,    std::shared_ptr< monty::ndarray< int,1 > > _2572) { return mosek::fusion::p_Domain::inRange(_2570,_2571,_2572); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2570,double _2571,std::shared_ptr< monty::ndarray< int,1 > > _2572){
  _checked_ptr_1<double> _ptr__2570(_2570 ? _2570->raw() : nullptr, _2570 ? _2570->size(0) : 0);
  _checked_ptr_1<int> _ptr__2572(_2572 ? _2572->raw() : nullptr, _2572 ? _2572->size(0) : 0);
  std::vector<double> _7922;
  for (int _2573 = (int)0, _7923 = (int)((_2570)->size(0)); _2573 < _7923 ; ++_2573)
  {
    _7922.push_back(_2571);
  }
  auto _7924 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7922.size()),_7922.begin(),_7922.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2570,_7924,_2572);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2574,    std::shared_ptr< monty::ndarray< double,1 > > _2575,    std::shared_ptr< monty::ndarray< int,1 > > _2576) { return mosek::fusion::p_Domain::inRange(_2574,_2575,_2576); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2574,std::shared_ptr< monty::ndarray< double,1 > > _2575,std::shared_ptr< monty::ndarray< int,1 > > _2576){
  _checked_ptr_1<double> _ptr__2575(_2575 ? _2575->raw() : nullptr, _2575 ? _2575->size(0) : 0);
  _checked_ptr_1<int> _ptr__2576(_2576 ? _2576->raw() : nullptr, _2576 ? _2576->size(0) : 0);
  std::vector<double> _7925;
  for (int _2577 = (int)0, _7926 = (int)((_2575)->size(0)); _2577 < _7926 ; ++_2577)
  {
    _7925.push_back(_2574);
  }
  auto _7927 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7925.size()),_7925.begin(),_7925.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_7927,_2575,_2576);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2578,    double _2579,    std::shared_ptr< monty::ndarray< int,1 > > _2580) { return mosek::fusion::p_Domain::inRange(_2578,_2579,_2580); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2578,double _2579,std::shared_ptr< monty::ndarray< int,1 > > _2580){
  _checked_ptr_1<int> _ptr__2580(_2580 ? _2580->raw() : nullptr, _2580 ? _2580->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2578)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2579)}),_2580);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2581,    std::shared_ptr< monty::ndarray< double,1 > > _2582) { return mosek::fusion::p_Domain::inRange(_2581,_2582); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2581,std::shared_ptr< monty::ndarray< double,1 > > _2582){
  _checked_ptr_1<double> _ptr__2581(_2581 ? _2581->raw() : nullptr, _2581 ? _2581->size(0) : 0);
  _checked_ptr_1<double> _ptr__2582(_2582 ? _2582->raw() : nullptr, _2582 ? _2582->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2581,_2582,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2581)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2583,    double _2584) { return mosek::fusion::p_Domain::inRange(_2583,_2584); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2583,double _2584){
  _checked_ptr_1<double> _ptr__2583(_2583 ? _2583->raw() : nullptr, _2583 ? _2583->size(0) : 0);
  std::vector<double> _7928;
  for (int _2585 = (int)0, _7929 = (int)((_2583)->size(0)); _2585 < _7929 ; ++_2585)
  {
    _7928.push_back(_2584);
  }
  auto _7930 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7928.size()),_7928.begin(),_7928.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2583,_7930,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2583)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2586,    std::shared_ptr< monty::ndarray< double,1 > > _2587) { return mosek::fusion::p_Domain::inRange(_2586,_2587); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2586,std::shared_ptr< monty::ndarray< double,1 > > _2587){
  _checked_ptr_1<double> _ptr__2587(_2587 ? _2587->raw() : nullptr, _2587 ? _2587->size(0) : 0);
  std::vector<double> _7931;
  for (int _2588 = (int)0, _7932 = (int)((_2587)->size(0)); _2588 < _7932 ; ++_2588)
  {
    _7931.push_back(_2586);
  }
  auto _7933 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7931.size()),_7931.begin(),_7931.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_7933,_2587,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2587)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2589,    double _2590) { return mosek::fusion::p_Domain::inRange(_2589,_2590); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2589,double _2590){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2589)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2590)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2591) { return mosek::fusion::p_Domain::greaterThan(_2591); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2591){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2591);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2592,    std::shared_ptr< monty::ndarray< int,1 > > _2593) { return mosek::fusion::p_Domain::greaterThan(_2592,_2593); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2592,std::shared_ptr< monty::ndarray< int,1 > > _2593){
  _checked_ptr_1<double> _ptr__2592(_2592 ? _2592->raw() : nullptr, _2592 ? _2592->size(0) : 0);
  _checked_ptr_1<int> _ptr__2593(_2593 ? _2593->raw() : nullptr, _2593 ? _2593->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2592),_2593);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2594) { return mosek::fusion::p_Domain::greaterThan(_2594); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2594){
  std::vector<double> _7934;
  for (int _2595 = (int)0, _7935 = (int)((_2594)->size(0)); _2595 < _7935 ; ++_2595)
  {
    for (int _2596 = (int)0, _7936 = (int)((_2594)->size(1)); _2596 < _7936 ; ++_2596)
    {
      _7934.push_back(((*_2594)(_2595,_2596)));
    }
  }
  auto _7937 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7934.size()),_7934.begin(),_7934.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_7937,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2594)->size(0))),(int)((int)((_2594)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2597) { return mosek::fusion::p_Domain::greaterThan(_2597); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2597){
  _checked_ptr_1<double> _ptr__2597(_2597 ? _2597->raw() : nullptr, _2597 ? _2597->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2597),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2597)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2598,    std::shared_ptr< monty::ndarray< int,1 > > _2599) { return mosek::fusion::p_Domain::greaterThan(_2598,_2599); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2598,std::shared_ptr< monty::ndarray< int,1 > > _2599){
  _checked_ptr_1<int> _ptr__2599(_2599 ? _2599->raw() : nullptr, _2599 ? _2599->size(0) : 0);
  std::vector<double> _7938;
  for (long long _2600 = (int)0, _7939 = ::mosek::fusion::p_Domain::prod(_2599); _2600 < _7939 ; ++_2600)
  {
    _7938.push_back(_2598);
  }
  auto _7940 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7938.size()),_7938.begin(),_7938.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7940,_2599);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2601,    int _2602,    int _2603) { return mosek::fusion::p_Domain::greaterThan(_2601,_2602,_2603); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2601,int _2602,int _2603){
  std::vector<double> _7941;
  for (int _2604 = (int)0, _7942 = safe_mul( _2603,_2602 ); _2604 < _7942 ; ++_2604)
  {
    _7941.push_back(_2601);
  }
  auto _7943 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7941.size()),_7941.begin(),_7941.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7943,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2602),(int)(_2603)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2605,    int _2606) { return mosek::fusion::p_Domain::greaterThan(_2605,_2606); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2605,int _2606){
  std::vector<double> _7944;
  for (int _2607 = (int)0, _7945 = _2606; _2607 < _7945 ; ++_2607)
  {
    _7944.push_back(_2605);
  }
  auto _7946 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7944.size()),_7944.begin(),_7944.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7946,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2606)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2608) { return mosek::fusion::p_Domain::greaterThan(_2608); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2608){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2608)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2609) { return mosek::fusion::p_Domain::lessThan(_2609); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2609){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2609);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2610,    std::shared_ptr< monty::ndarray< int,1 > > _2611) { return mosek::fusion::p_Domain::lessThan(_2610,_2611); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2610,std::shared_ptr< monty::ndarray< int,1 > > _2611){
  _checked_ptr_1<double> _ptr__2610(_2610 ? _2610->raw() : nullptr, _2610 ? _2610->size(0) : 0);
  _checked_ptr_1<int> _ptr__2611(_2611 ? _2611->raw() : nullptr, _2611 ? _2611->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2610),_2611);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2612) { return mosek::fusion::p_Domain::lessThan(_2612); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2612){
  std::vector<double> _7947;
  for (int _2613 = (int)0, _7948 = (int)((_2612)->size(0)); _2613 < _7948 ; ++_2613)
  {
    for (int _2614 = (int)0, _7949 = (int)((_2612)->size(1)); _2614 < _7949 ; ++_2614)
    {
      _7947.push_back(((*_2612)(_2613,_2614)));
    }
  }
  auto _7950 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7947.size()),_7947.begin(),_7947.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_7950,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2612)->size(0))),(int)((int)((_2612)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2615) { return mosek::fusion::p_Domain::lessThan(_2615); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2615){
  _checked_ptr_1<double> _ptr__2615(_2615 ? _2615->raw() : nullptr, _2615 ? _2615->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2615),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2615)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2616,    std::shared_ptr< monty::ndarray< int,1 > > _2617) { return mosek::fusion::p_Domain::lessThan(_2616,_2617); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617){
  _checked_ptr_1<int> _ptr__2617(_2617 ? _2617->raw() : nullptr, _2617 ? _2617->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2616)}),_2617);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2618,    int _2619,    int _2620) { return mosek::fusion::p_Domain::lessThan(_2618,_2619,_2620); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2618,int _2619,int _2620){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2618)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2619),(int)(_2620)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2621,    int _2622) { return mosek::fusion::p_Domain::lessThan(_2621,_2622); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2621,int _2622){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2621)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2622)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2623) { return mosek::fusion::p_Domain::lessThan(_2623); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2623){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2623)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2624) { return mosek::fusion::p_Domain::equalsTo(_2624); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2624){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2624);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2625,    std::shared_ptr< monty::ndarray< int,1 > > _2626) { return mosek::fusion::p_Domain::equalsTo(_2625,_2626); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2625,std::shared_ptr< monty::ndarray< int,1 > > _2626){
  _checked_ptr_1<double> _ptr__2625(_2625 ? _2625->raw() : nullptr, _2625 ? _2625->size(0) : 0);
  _checked_ptr_1<int> _ptr__2626(_2626 ? _2626->raw() : nullptr, _2626 ? _2626->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2625),_2626);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2627) { return mosek::fusion::p_Domain::equalsTo(_2627); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2627){
  std::vector<double> _7951;
  for (int _2628 = (int)0, _7952 = (int)((_2627)->size(0)); _2628 < _7952 ; ++_2628)
  {
    for (int _2629 = (int)0, _7953 = (int)((_2627)->size(1)); _2629 < _7953 ; ++_2629)
    {
      _7951.push_back(((*_2627)(_2628,_2629)));
    }
  }
  auto _7954 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7951.size()),_7951.begin(),_7951.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_7954,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2627)->size(0))),(int)((int)((_2627)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2630) { return mosek::fusion::p_Domain::equalsTo(_2630); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2630){
  _checked_ptr_1<double> _ptr__2630(_2630 ? _2630->raw() : nullptr, _2630 ? _2630->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2630),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2630)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2631,    std::shared_ptr< monty::ndarray< int,1 > > _2632) { return mosek::fusion::p_Domain::equalsTo(_2631,_2632); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2631,std::shared_ptr< monty::ndarray< int,1 > > _2632){
  _checked_ptr_1<int> _ptr__2632(_2632 ? _2632->raw() : nullptr, _2632 ? _2632->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2631)}),_2632);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2633,    int _2634,    int _2635) { return mosek::fusion::p_Domain::equalsTo(_2633,_2634,_2635); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2633,int _2634,int _2635){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2633)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2634),(int)(_2635)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2636,    int _2637) { return mosek::fusion::p_Domain::equalsTo(_2636,_2637); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2636,int _2637){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2636)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2637)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2638) { return mosek::fusion::p_Domain::equalsTo(_2638); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2638){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2638)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2639) { return mosek::fusion::p_Domain::unbounded(_2639); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2639){
  _checked_ptr_1<int> _ptr__2639(_2639 ? _2639->raw() : nullptr, _2639 ? _2639->size(0) : 0);
  std::vector<int> _7955;
  for (int _2640 = (int)0, _7956 = (int)((_2639)->size(0)); _2640 < _7956 ; ++_2640)
  {
    _7955.push_back(_ptr__2639[_2640]);
  }
  auto _7957 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7955.size()),_7955.begin(),_7955.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_7957);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2641,    int _2642) { return mosek::fusion::p_Domain::unbounded(_2641,_2642); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2641,int _2642){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2641),(int)(_2642)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2643) { return mosek::fusion::p_Domain::unbounded(_2643); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2643){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2643)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    std::shared_ptr< monty::ndarray< double,1 > > _2646){ return new mosek::fusion::ExprConst(_2644,_2645,_2646); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    std::shared_ptr< monty::ndarray< double,1 > > _2646) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2644,_2645,_2646); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    std::shared_ptr< monty::ndarray< double,1 > > _2646){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2644(_2644 ? _2644->raw() : nullptr, _2644 ? _2644->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2645(_2645 ? _2645->raw() : nullptr, _2645 ? _2645->size(0) : 0);
    _checked_ptr_1<double> _ptr__2646(_2646 ? _2646->raw() : nullptr, _2646 ? _2646->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2644);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2646);
    std::shared_ptr< monty::ndarray< long long,1 > > _7958;
    bool _7959 = (NULL != _2645.get());
    if (_7959)
    {
      _7958 = ::mosek::fusion::Utils::Tools::arraycopy(_2645);
    }
    else
    {
      _7958 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _7958;
    ::mosek::fusion::p_ExprConst::validate(_2644,_2646,_2645);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2647,    std::shared_ptr< monty::ndarray< long long,1 > > _2648,    double _2649){ return new mosek::fusion::ExprConst(_2647,_2648,_2649); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2647,    std::shared_ptr< monty::ndarray< long long,1 > > _2648,    double _2649) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2647,_2648,_2649); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2647,    std::shared_ptr< monty::ndarray< long long,1 > > _2648,    double _2649){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2647(_2647 ? _2647->raw() : nullptr, _2647 ? _2647->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2648(_2648 ? _2648->raw() : nullptr, _2648 ? _2648->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2647);
    long long _7960;
    bool _7961 = (NULL == _2648.get());
    if (_7961)
    {
      _7960 = ::mosek::fusion::p_Set::size(_2647);
    }
    else
    {
      _7960 = (int)((_2648)->size(0));
    }
    long long _2650 = _7960;
    std::vector<double> _7962;
    for (long long _2651 = (int)0, _7963 = _2650; _2651 < _7963 ; ++_2651)
    {
      _7962.push_back(_2649);
    }
    auto _7964 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7962.size()),_7962.begin(),_7962.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _7964;
    std::shared_ptr< monty::ndarray< long long,1 > > _7965;
    bool _7966 = (NULL != _2648.get());
    if (_7966)
    {
      _7965 = ::mosek::fusion::Utils::Tools::arraycopy(_2648);
    }
    else
    {
      _7965 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _7965;
    ::mosek::fusion::p_ExprConst::validate(_2647,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2648);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2652,monty::rc_ptr< ::mosek::fusion::WorkStack > _2653,monty::rc_ptr< ::mosek::fusion::WorkStack > _2654) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2652,_2653,_2654); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2652,monty::rc_ptr< ::mosek::fusion::WorkStack > _2653,monty::rc_ptr< ::mosek::fusion::WorkStack > _2654){
  std::shared_ptr< monty::ndarray< int,1 > > _2655 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2655(_2655 ? _2655->raw() : nullptr,_2655 ? _2655->size(0) : 0);
  int _2656 = (int)((bfix)->size(0));
  bool _2657 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2655)));
  int _2658 = _2652->alloci32(safe_add( _2656,(int)1 ));
  int _7967;
  bool _7968 = _2657;
  if (_7968)
  {
    _7967 = (int)1;
  }
  else
  {
    _7967 = (int)0;
  }
  _2652->pushi32(_7967);
  _2652->pushi32((int)0);
  _2652->pushi32(_2656);
  int _7969 = (int)0;
  int _7970 = (int)((_2655)->size(0));
  for (int _2659 = _7969; _2659 < _7970; ++_2659)
  {
    {
      _2652->pushi32(_ptr__2655[_2659]);
    }
  }
  _2652->pushi32((int)((_2655)->size(0)));
  if ((NULL != sparsity.get()))
  {
    {
      int _2660 = _2652->alloci64((int)((sparsity)->size(0)));
      std::shared_ptr< monty::ndarray< long long,1 > > _2661 = mosek::fusion::p_WorkStack::_get_impl(_2652)->i64;
      _checked_ptr_1<long long> _ptr__2661(_2661 ? _2661->raw() : nullptr,_2661 ? _2661->size(0) : 0);
      int _7971 = (int)0;
      int _7972 = (int)((sparsity)->size(0));
      for (int _2662 = _7971; _2662 < _7972; ++_2662)
      {
        {
          _ptr__2661[safe_add( _2660,_2662 )] = ((*sparsity)(_2662));
        }
      }
    }
  }
  {}
  int _2663 = _2652->allocf64((int)((bfix)->size(0)));
  std::shared_ptr< monty::ndarray< double,1 > > _2664 = mosek::fusion::p_WorkStack::_get_impl(_2652)->f64;
  _checked_ptr_1<double> _ptr__2664(_2664 ? _2664->raw() : nullptr,_2664 ? _2664->size(0) : 0);
  int _7973 = (int)0;
  int _7974 = (int)((bfix)->size(0));
  for (int _2665 = _7973; _2665 < _7974; ++_2665)
  {
    {
      _ptr__2664[safe_add( _2663,_2665 )] = ((*bfix)(_2665));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2666 = mosek::fusion::p_WorkStack::_get_impl(_2652)->i32;
  _checked_ptr_1<int> _ptr__2666(_2666 ? _2666->raw() : nullptr,_2666 ? _2666->size(0) : 0);
  int _7975 = (int)0;
  int _7976 = safe_add( _2656,(int)1 );
  for (int _2667 = _7975; _2667 < _7976; ++_2667)
  {
    {
      _ptr__2666[safe_add( _2658,_2667 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2668,std::shared_ptr< monty::ndarray< double,1 > > _2669,std::shared_ptr< monty::ndarray< long long,1 > > _2670){
  _checked_ptr_1<int> _ptr__2668(_2668 ? _2668->raw() : nullptr, _2668 ? _2668->size(0) : 0);
  _checked_ptr_1<double> _ptr__2669(_2669 ? _2669->raw() : nullptr, _2669 ? _2669->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2670(_2670 ? _2670->raw() : nullptr, _2670 ? _2670->size(0) : 0);
  long long _2671 = ::mosek::fusion::p_Set::size(_2668);
  if ((NULL != _2670.get()))
  {
    {
      if (((int)((_2670)->size(0)) != (int)((_2669)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      int _7977 = (int)0;
      int _7978 = (int)((_2670)->size(0));
      for (int _2672 = _7977; _2672 < _7978; ++_2672)
      {
        {
          if (((_ptr__2670[_2672] < (int)0) || (_ptr__2670[_2672] >= _2671)))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_2669)->size(0)) != _2671))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2673,    std::shared_ptr< monty::ndarray< int,2 > > _2674){ return new mosek::fusion::ExprPick(_2673,_2674); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2673,    std::shared_ptr< monty::ndarray< int,2 > > _2674) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2673,_2674); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2673,    std::shared_ptr< monty::ndarray< int,2 > > _2674){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2674)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2675 = _2673->getShape();
    _checked_ptr_1<int> _ptr__2675(_2675 ? _2675->raw() : nullptr,_2675 ? _2675->size(0) : 0);
    int _2676 = (int)((_2675)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2673;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2674)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2677 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2677(_2677 ? _2677->raw() : nullptr,_2677 ? _2677->size(0) : 0);
    if (((int)((_2674)->size(1)) != _2676))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    int _7979 = (int)0;
    int _7980 = (int)((_2674)->size(0));
    for (int _2678 = _7979; _2678 < _7980; ++_2678)
    {
      {
        int _7981 = (int)0;
        int _7982 = _2676;
        for (int _2679 = _7981; _2679 < _7982; ++_2679)
        {
          {
            if (((((*_2674)(_2678,_2679)) < (int)0) || (((*_2674)(_2678,_2679)) >= _ptr__2675[_2679])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2680 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2676)));
      _checked_ptr_1<long long> _ptr__2680(_2680 ? _2680->raw() : nullptr,_2680 ? _2680->size(0) : 0);
      _ptr__2680[(_2676 - (int)1)] = (int)1;
      int _7983 = (int)1;
      int _7984 = _2676;
      for (int _2681 = _7983; _2681 < _7984; ++_2681)
      {
        {
          _ptr__2680[((_2676 - _2681) - (int)1)] = safe_mul( _ptr__2680[(_2676 - _2681)],_ptr__2675[(_2676 - _2681)] );
        }
      }
      int _7985 = (int)0;
      int _7986 = (int)((_2674)->size(0));
      for (int _2682 = _7985; _2682 < _7986; ++_2682)
      {
        {
          long long _2683 = (long long)0;
          int _7987 = (int)0;
          int _7988 = _2676;
          for (int _2684 = _7987; _2684 < _7988; ++_2684)
          {
            {
              _2683 += safe_mul( _ptr__2680[_2684],((*_2674)(_2682,_2684)) );
            }
          }
          _ptr__2677[_2682] = _2683;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2685,    std::shared_ptr< monty::ndarray< long long,1 > > _2686){ return new mosek::fusion::ExprPick(_2685,_2686); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2685,    std::shared_ptr< monty::ndarray< long long,1 > > _2686) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2685,_2686); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2685,    std::shared_ptr< monty::ndarray< long long,1 > > _2686){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2686(_2686 ? _2686->raw() : nullptr, _2686 ? _2686->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2686)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2685;
    std::shared_ptr< monty::ndarray< int,1 > > _2687 = _2685->getShape();
    _checked_ptr_1<int> _ptr__2687(_2687 ? _2687->raw() : nullptr,_2687 ? _2687->size(0) : 0);
    long long _2688 = ::mosek::fusion::p_Set::size(_2687);
    int _7989 = (int)0;
    int _7990 = (int)((_2686)->size(0));
    for (int _2689 = _7989; _2689 < _7990; ++_2689)
    {
      {
        if (((_ptr__2686[_2689] < (int)0) || (_ptr__2686[_2689] >= _2688)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
          }
        }
        {}
      }
    }
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2686);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2690,monty::rc_ptr< ::mosek::fusion::WorkStack > _2691,monty::rc_ptr< ::mosek::fusion::WorkStack > _2692) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2690,_2691,_2692); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2690,monty::rc_ptr< ::mosek::fusion::WorkStack > _2691,monty::rc_ptr< ::mosek::fusion::WorkStack > _2692){
  expr->eval(_2691,_2690,_2692);
  _2691->pop_expr();
  int _2693 = mosek::fusion::p_WorkStack::_get_impl(_2691)->nd;
  int _2694 = mosek::fusion::p_WorkStack::_get_impl(_2691)->shape_base;
  int _2695 = mosek::fusion::p_WorkStack::_get_impl(_2691)->nelem;
  int _2696 = mosek::fusion::p_WorkStack::_get_impl(_2691)->nnz;
  bool _2697 = mosek::fusion::p_WorkStack::_get_impl(_2691)->hassp;
  int _2698 = mosek::fusion::p_WorkStack::_get_impl(_2691)->ptr_base;
  int _2699 = mosek::fusion::p_WorkStack::_get_impl(_2691)->sp_base;
  int _2700 = mosek::fusion::p_WorkStack::_get_impl(_2691)->nidxs_base;
  int _2701 = mosek::fusion::p_WorkStack::_get_impl(_2691)->bfix_base;
  int _2702 = mosek::fusion::p_WorkStack::_get_impl(_2691)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2703 = mosek::fusion::p_WorkStack::_get_impl(_2691)->i32;
  _checked_ptr_1<int> _ptr__2703(_2703 ? _2703->raw() : nullptr,_2703 ? _2703->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2704 = mosek::fusion::p_WorkStack::_get_impl(_2691)->i64;
  _checked_ptr_1<long long> _ptr__2704(_2704 ? _2704->raw() : nullptr,_2704 ? _2704->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2705 = mosek::fusion::p_WorkStack::_get_impl(_2691)->f64;
  _checked_ptr_1<double> _ptr__2705(_2705 ? _2705->raw() : nullptr,_2705 ? _2705->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2706 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2706(_2706 ? _2706->raw() : nullptr,_2706 ? _2706->size(0) : 0);
  if ((!_2697))
  {
    {
      int _2707 = (int)((_2706)->size(0));
      int _2708 = (int)1;
      int _2709 = (int)0;
      int _7991 = (int)0;
      int _7992 = (int)((_2706)->size(0));
      for (int _2710 = _7991; _2710 < _7992; ++_2710)
      {
        {
          _2709 += (_ptr__2703[safe_add( safe_add( _2698,_ptr__2706[_2710] ),(int)1 )] - _ptr__2703[safe_add( _2698,_ptr__2706[_2710] )]);
        }
      }
      _2690->alloc_expr(_2708,_2707,_2709,false);
      int _2711 = mosek::fusion::p_WorkStack::_get_impl(_2690)->cof_base;
      int _2712 = mosek::fusion::p_WorkStack::_get_impl(_2690)->bfix_base;
      int _2713 = mosek::fusion::p_WorkStack::_get_impl(_2690)->nidxs_base;
      int _2714 = mosek::fusion::p_WorkStack::_get_impl(_2690)->ptr_base;
      int _2715 = mosek::fusion::p_WorkStack::_get_impl(_2690)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2716 = mosek::fusion::p_WorkStack::_get_impl(_2690)->i32;
      _checked_ptr_1<int> _ptr__2716(_2716 ? _2716->raw() : nullptr,_2716 ? _2716->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2717 = mosek::fusion::p_WorkStack::_get_impl(_2690)->i64;
      _checked_ptr_1<long long> _ptr__2717(_2717 ? _2717->raw() : nullptr,_2717 ? _2717->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2718 = mosek::fusion::p_WorkStack::_get_impl(_2690)->f64;
      _checked_ptr_1<double> _ptr__2718(_2718 ? _2718->raw() : nullptr,_2718 ? _2718->size(0) : 0);
      _ptr__2716[_2715] = (int)((_2706)->size(0));
      int _2719 = (int)0;
      _ptr__2716[_2714] = (int)0;
      int _7993 = (int)0;
      int _7994 = (int)((_2706)->size(0));
      for (int _2720 = _7993; _2720 < _7994; ++_2720)
      {
        {
          int _7995 = _ptr__2703[safe_add( _2698,_ptr__2706[_2720] )];
          int _7996 = _ptr__2703[safe_add( safe_add( _2698,_ptr__2706[_2720] ),(int)1 )];
          for (int _2721 = _7995; _2721 < _7996; ++_2721)
          {
            {
              _ptr__2717[safe_add( _2713,_2719 )] = _ptr__2704[safe_add( _2700,_2721 )];
              _ptr__2718[safe_add( _2711,_2719 )] = _ptr__2705[safe_add( _2702,_2721 )];
              ++ _2719;
            }
          }
          _ptr__2718[safe_add( _2712,_2720 )] = _ptr__2705[safe_add( _2701,_ptr__2706[_2720] )];
          _ptr__2716[safe_add( safe_add( _2714,_2720 ),(int)1 )] = _2719;
        }
      }
    }
  }
  else
  {
    {
      int _2722 = (int)1;
      int _2723 = (int)((_2706)->size(0));
      int _2724 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2725 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2725(_2725 ? _2725->raw() : nullptr,_2725 ? _2725->size(0) : 0);
      int _2726 = _2692->alloci32((int)((_2725)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2727 = mosek::fusion::p_WorkStack::_get_impl(_2692)->i32;
      _checked_ptr_1<int> _ptr__2727(_2727 ? _2727->raw() : nullptr,_2727 ? _2727->size(0) : 0);
      int _7997 = (int)0;
      int _7998 = (int)((_2725)->size(0));
      for (int _2728 = _7997; _2728 < _7998; ++_2728)
      {
        {
          int _2729 = _2695;
          int _2730 = (int)0;
          while ( (_2730 < (_2729 - (int)1)) )
          {
            {
              int _2731 = (safe_add( safe_add( _2729,_2730 ),(int)1 ) / (int)2);
              if ((_ptr__2704[safe_add( _2699,_2731 )] >= _ptr__2725[_2728]))
              {
                {
                  _2729 = _2731;
                }
              }
              else
              {
                {
                  _2730 = _2731;
                }
              }
            }
          }
          ++ _2730;
          if (((_2730 < _2695) && (_ptr__2704[safe_add( _2699,_2730 )] == _ptr__2725[_2728])))
          {
            {
              _ptr__2727[safe_add( _2726,_2728 )] = _2730;
              _2724 += (_ptr__2703[safe_add( safe_add( _2698,_2730 ),(int)1 )] - _ptr__2703[safe_add( _2698,_2730 )]);
            }
          }
          else
          {
            {
              _ptr__2727[safe_add( _2726,_2728 )] = (-(int)1);
            }
          }
        }
      }
      _2690->alloc_expr(_2722,_2723,_2724,false);
      int _2732 = mosek::fusion::p_WorkStack::_get_impl(_2690)->ptr_base;
      int _2733 = mosek::fusion::p_WorkStack::_get_impl(_2690)->nidxs_base;
      int _2734 = mosek::fusion::p_WorkStack::_get_impl(_2690)->cof_base;
      int _2735 = mosek::fusion::p_WorkStack::_get_impl(_2690)->bfix_base;
      int _2736 = mosek::fusion::p_WorkStack::_get_impl(_2690)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2737 = mosek::fusion::p_WorkStack::_get_impl(_2690)->i32;
      _checked_ptr_1<int> _ptr__2737(_2737 ? _2737->raw() : nullptr,_2737 ? _2737->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2738 = mosek::fusion::p_WorkStack::_get_impl(_2690)->i64;
      _checked_ptr_1<long long> _ptr__2738(_2738 ? _2738->raw() : nullptr,_2738 ? _2738->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2739 = mosek::fusion::p_WorkStack::_get_impl(_2690)->f64;
      _checked_ptr_1<double> _ptr__2739(_2739 ? _2739->raw() : nullptr,_2739 ? _2739->size(0) : 0);
      _ptr__2737[_2736] = (int)((_2725)->size(0));
      _ptr__2737[_2732] = (int)0;
      int _2740 = (int)0;
      int _7999 = (int)0;
      int _8000 = (int)((_2725)->size(0));
      for (int _2741 = _7999; _2741 < _8000; ++_2741)
      {
        {
          if ((_ptr__2727[safe_add( _2726,_2741 )] >= (int)0))
          {
            {
              int _2742 = _ptr__2727[safe_add( _2726,_2741 )];
              int _8001 = _ptr__2703[safe_add( _2698,_2742 )];
              int _8002 = _ptr__2703[safe_add( safe_add( _2698,_2742 ),(int)1 )];
              for (int _2743 = _8001; _2743 < _8002; ++_2743)
              {
                {
                  _ptr__2738[safe_add( _2733,_2740 )] = _ptr__2704[safe_add( _2700,_2743 )];
                  _ptr__2739[safe_add( _2734,_2740 )] = _ptr__2705[safe_add( _2702,_2743 )];
                  ++ _2740;
                }
              }
              _ptr__2739[safe_add( _2735,_2741 )] = _ptr__2705[safe_add( _2701,_2742 )];
            }
          }
          else
          {
            {
              _ptr__2739[safe_add( _2735,_2741 )] = 0.0;
            }
          }
          _ptr__2737[safe_add( safe_add( _2732,_2741 ),(int)1 )] = _2740;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2744,    std::shared_ptr< monty::ndarray< int,1 > > _2745,    std::shared_ptr< monty::ndarray< int,1 > > _2746){ return new mosek::fusion::ExprSlice(_2744,_2745,_2746); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2744,    std::shared_ptr< monty::ndarray< int,1 > > _2745,    std::shared_ptr< monty::ndarray< int,1 > > _2746) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2744,_2745,_2746); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2744,    std::shared_ptr< monty::ndarray< int,1 > > _2745,    std::shared_ptr< monty::ndarray< int,1 > > _2746){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2745(_2745 ? _2745->raw() : nullptr, _2745 ? _2745->size(0) : 0);
    _checked_ptr_1<int> _ptr__2746(_2746 ? _2746->raw() : nullptr, _2746 ? _2746->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2744->getShape(),_2745,_2746));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2744;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2745;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2746;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2747,monty::rc_ptr< ::mosek::fusion::WorkStack > _2748,monty::rc_ptr< ::mosek::fusion::WorkStack > _2749) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2747,_2748,_2749); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2747,monty::rc_ptr< ::mosek::fusion::WorkStack > _2748,monty::rc_ptr< ::mosek::fusion::WorkStack > _2749){
  expr->eval(_2748,_2747,_2749);
  int _2750 = _2748->popi32();
  int _2751 = _2748->popi32(_2750);
  int _2752 = _2748->popi32();
  int _2753 = _2748->popi32();
  bool _2754 = (_2748->popi32() != (int)0);
  int _2755 = _2748->popi32(safe_add( _2752,(int)1 ));
  int _8003;
  bool _8004 = _2754;
  if (_8004)
  {
    _8003 = _2748->popi64(_2752);
  }
  else
  {
    _8003 = (-(int)1);
  }
  int _2756 = _8003;
  int _2757 = _2748->popi64(_2753);
  int _2758 = _2748->popf64(_2752);
  int _2759 = _2748->popf64(_2753);
  std::shared_ptr< monty::ndarray< int,1 > > _2760 = mosek::fusion::p_WorkStack::_get_impl(_2748)->i32;
  _checked_ptr_1<int> _ptr__2760(_2760 ? _2760->raw() : nullptr,_2760 ? _2760->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2761 = mosek::fusion::p_WorkStack::_get_impl(_2748)->i64;
  _checked_ptr_1<long long> _ptr__2761(_2761 ? _2761->raw() : nullptr,_2761 ? _2761->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2762 = mosek::fusion::p_WorkStack::_get_impl(_2748)->f64;
  _checked_ptr_1<double> _ptr__2762(_2762 ? _2762->raw() : nullptr,_2762 ? _2762->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2763 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2750)));
  _checked_ptr_1<long long> _ptr__2763(_2763 ? _2763->raw() : nullptr,_2763 ? _2763->size(0) : 0);
  _ptr__2763[(_2750 - (int)1)] = (int)1;
  int _8005 = (int)1;
  int _8006 = _2750;
  for (int _2764 = _8005; _2764 < _8006; ++_2764)
  {
    {
      _ptr__2763[((_2750 - _2764) - (int)1)] = safe_mul( _ptr__2763[(_2750 - _2764)],_ptr__2760[(safe_add( _2751,_2750 ) - _2764)] );
    }
  }
  int _2765 = (int)0;
  int _2766 = (int)0;
  if (_2754)
  {
    {
      int _8007 = (int)0;
      int _8008 = _2752;
      for (int _2767 = _8007; _2767 < _8008; ++_2767)
      {
        {
          bool _2768 = true;
          int _8009 = (int)0;
          int _8010 = _2750;
          for (int _2769 = _8009; _2769 < _8010; ++_2769)
          {
            {
              long long _2770 = ((_ptr__2761[safe_add( _2756,_2767 )] / _ptr__2763[_2769]) % _ptr__2760[safe_add( _2751,_2769 )]);
              _2768 = (_2768 && ((_2770 >= ((*first)(_2769))) && (_2770 < ((*last)(_2769)))));
            }
          }
          if (_2768)
          {
            {
              _2766 += (_ptr__2760[safe_add( safe_add( _2755,_2767 ),(int)1 )] - _ptr__2760[safe_add( _2755,_2767 )]);
              ++ _2765;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2765 = (int)1;
      int _8011 = (int)0;
      int _8012 = _2750;
      for (int _2771 = _8011; _2771 < _8012; ++_2771)
      {
        {
          _2765 *= (((*last)(_2771)) - ((*first)(_2771)));
        }
      }
      int _8013 = (int)0;
      int _8014 = _2752;
      for (int _2772 = _8013; _2772 < _8014; ++_2772)
      {
        {
          bool _2773 = true;
          int _8015 = (int)0;
          int _8016 = _2750;
          for (int _2774 = _8015; _2774 < _8016; ++_2774)
          {
            {
              long long _2775 = ((_2772 / _ptr__2763[_2774]) % _ptr__2760[safe_add( _2751,_2774 )]);
              _2773 = (_2773 && ((_2775 >= ((*first)(_2774))) && (_2775 < ((*last)(_2774)))));
            }
          }
          if (_2773)
          {
            {
              _2766 += (_ptr__2760[safe_add( safe_add( _2755,_2772 ),(int)1 )] - _ptr__2760[safe_add( _2755,_2772 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8017;
  for (int _2777 = (int)0, _8018 = _2750; _2777 < _8018 ; ++_2777)
  {
    _8017.push_back((((*last)(_2777)) - ((*first)(_2777))));
  }
  auto _8019 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8017.size()),_8017.begin(),_8017.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2776 = _8019;
  _checked_ptr_1<int> _ptr__2776(_2776 ? _2776->raw() : nullptr,_2776 ? _2776->size(0) : 0);
  int _2778 = _2747->allocf64(_2766);
  int _2779 = _2747->allocf64(_2765);
  int _2780 = _2747->alloci64(_2766);
  int _8020;
  bool _8021 = _2754;
  if (_8021)
  {
    _8020 = _2747->alloci64(_2765);
  }
  else
  {
    _8020 = (-(int)1);
  }
  int _2781 = _8020;
  int _2782 = _2747->alloci32(safe_add( _2765,(int)1 ));
  int _8022;
  bool _8023 = _2754;
  if (_8023)
  {
    _8022 = (int)1;
  }
  else
  {
    _8022 = (int)0;
  }
  _2747->pushi32(_8022);
  _2747->pushi32(_2766);
  _2747->pushi32(_2765);
  int _8024 = (int)0;
  int _8025 = _2750;
  for (int _2783 = _8024; _2783 < _8025; ++_2783)
  {
    {
      _2747->pushi32(_ptr__2776[_2783]);
    }
  }
  _2747->pushi32(_2750);
  std::shared_ptr< monty::ndarray< int,1 > > _2784 = mosek::fusion::p_WorkStack::_get_impl(_2747)->i32;
  _checked_ptr_1<int> _ptr__2784(_2784 ? _2784->raw() : nullptr,_2784 ? _2784->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2785 = mosek::fusion::p_WorkStack::_get_impl(_2747)->i64;
  _checked_ptr_1<long long> _ptr__2785(_2785 ? _2785->raw() : nullptr,_2785 ? _2785->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2786 = mosek::fusion::p_WorkStack::_get_impl(_2747)->f64;
  _checked_ptr_1<double> _ptr__2786(_2786 ? _2786->raw() : nullptr,_2786 ? _2786->size(0) : 0);
  _ptr__2784[_2782] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2787 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2750)));
  _checked_ptr_1<long long> _ptr__2787(_2787 ? _2787->raw() : nullptr,_2787 ? _2787->size(0) : 0);
  _ptr__2787[(_2750 - (int)1)] = (int)1;
  int _8026 = (int)1;
  int _8027 = _2750;
  for (int _2788 = _8026; _2788 < _8027; ++_2788)
  {
    {
      _ptr__2787[((_2750 - _2788) - (int)1)] = safe_mul( _ptr__2787[(_2750 - _2788)],_ptr__2776[(_2750 - _2788)] );
    }
  }
  int _2789 = (int)0;
  int _2790 = (int)0;
  if (_2754)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2791 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2750)));
      _checked_ptr_1<int> _ptr__2791(_2791 ? _2791->raw() : nullptr,_2791 ? _2791->size(0) : 0);
      int _8028 = (int)0;
      int _8029 = _2752;
      for (int _2792 = _8028; _2792 < _8029; ++_2792)
      {
        {
          bool _2793 = true;
          int _8030 = (int)0;
          int _8031 = _2750;
          for (int _2794 = _8030; _2794 < _8031; ++_2794)
          {
            {
              _ptr__2791[_2794] = (int)((_ptr__2761[safe_add( _2756,_2792 )] / _ptr__2763[_2794]) % _ptr__2760[safe_add( _2751,_2794 )]);
              _2793 = (_2793 && ((_ptr__2791[_2794] >= ((*first)(_2794))) && (_ptr__2791[_2794] < ((*last)(_2794)))));
            }
          }
          if (_2793)
          {
            {
              int _8032 = _ptr__2760[safe_add( _2755,_2792 )];
              int _8033 = _ptr__2760[safe_add( safe_add( _2755,_2792 ),(int)1 )];
              for (int _2795 = _8032; _2795 < _8033; ++_2795)
              {
                {
                  _ptr__2785[safe_add( _2780,_2790 )] = _ptr__2761[safe_add( _2757,_2795 )];
                  _ptr__2786[safe_add( _2778,_2790 )] = _ptr__2762[safe_add( _2759,_2795 )];
                  ++ _2790;
                }
              }
              long long _2796 = (long long)0;
              int _8034 = (int)0;
              int _8035 = _2750;
              for (int _2797 = _8034; _2797 < _8035; ++_2797)
              {
                {
                  _2796 += safe_mul( _ptr__2787[_2797],(_ptr__2791[_2797] - ((*first)(_2797))) );
                }
              }
              _ptr__2785[safe_add( _2781,_2789 )] = _2796;
              _ptr__2786[safe_add( _2779,_2789 )] = _ptr__2762[safe_add( _2758,_2792 )];
              _ptr__2784[safe_add( safe_add( _2782,_2789 ),(int)1 )] = _2790;
              ++ _2789;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8036 = (int)0;
      int _8037 = _2752;
      for (int _2798 = _8036; _2798 < _8037; ++_2798)
      {
        {
          bool _2799 = true;
          int _8038 = (int)0;
          int _8039 = _2750;
          for (int _2800 = _8038; _2800 < _8039; ++_2800)
          {
            {
              long long _2801 = ((_2798 / _ptr__2763[_2800]) % _ptr__2760[safe_add( _2751,_2800 )]);
              _2799 = (_2799 && ((_2801 >= ((*first)(_2800))) && (_2801 < ((*last)(_2800)))));
            }
          }
          if (_2799)
          {
            {
              int _8040 = _ptr__2760[safe_add( _2755,_2798 )];
              int _8041 = _ptr__2760[safe_add( safe_add( _2755,_2798 ),(int)1 )];
              for (int _2802 = _8040; _2802 < _8041; ++_2802)
              {
                {
                  _ptr__2785[safe_add( _2780,_2790 )] = _ptr__2761[safe_add( _2757,_2802 )];
                  _ptr__2786[safe_add( _2778,_2790 )] = _ptr__2762[safe_add( _2759,_2802 )];
                  ++ _2790;
                }
              }
              _ptr__2786[safe_add( _2779,_2789 )] = _ptr__2762[safe_add( _2758,_2798 )];
              _ptr__2784[safe_add( safe_add( _2782,_2789 ),(int)1 )] = _2790;
              ++ _2789;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2803,std::shared_ptr< monty::ndarray< int,1 > > _2804,std::shared_ptr< monty::ndarray< int,1 > > _2805){
  _checked_ptr_1<int> _ptr__2803(_2803 ? _2803->raw() : nullptr, _2803 ? _2803->size(0) : 0);
  _checked_ptr_1<int> _ptr__2804(_2804 ? _2804->raw() : nullptr, _2804 ? _2804->size(0) : 0);
  _checked_ptr_1<int> _ptr__2805(_2805 ? _2805->raw() : nullptr, _2805 ? _2805->size(0) : 0);
  if ((((int)((_2803)->size(0)) != (int)((_2804)->size(0))) || ((int)((_2803)->size(0)) != (int)((_2805)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8042 = (int)0;
  int _8043 = (int)((_2803)->size(0));
  for (int _2806 = _8042; _2806 < _8043; ++_2806)
  {
    {
      if (((_ptr__2804[_2806] < (int)0) || ((_ptr__2805[_2806] < _ptr__2804[_2806]) || (_ptr__2805[_2806] > _ptr__2803[_2806]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8044;
  for (int _2807 = (int)0, _8045 = (int)((_2803)->size(0)); _2807 < _8045 ; ++_2807)
  {
    _8044.push_back((_ptr__2805[_2807] - _ptr__2804[_2807]));
  }
  auto _8046 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8044.size()),_8044.begin(),_8044.end()));
  return _8046;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2808 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8047 = (int)1;
  int _8048 = (int)((first)->size(0));
  for (int _2809 = _8047; _2809 < _8048; ++_2809)
  {
    {
      _2808->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2809)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2809)));
    }
  }
  _2808->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2808->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2810,    monty::rc_ptr< ::mosek::fusion::Expression > _2811){ return new mosek::fusion::ExprPermuteDims(_2810,_2811); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2810,    monty::rc_ptr< ::mosek::fusion::Expression > _2811) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2810,_2811); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2810,    monty::rc_ptr< ::mosek::fusion::Expression > _2811){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2810(_2810 ? _2810->raw() : nullptr, _2810 ? _2810->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2810,_2811,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2812 = _2811->getShape();
    _checked_ptr_1<int> _ptr__2812(_2812 ? _2812->raw() : nullptr,_2812 ? _2812->size(0) : 0);
    if (((int)((_2810)->size(0)) != (int)((_2812)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8049;
    for (int _2814 = (int)0, _8050 = (int)((_2810)->size(0)); _2814 < _8050 ; ++_2814)
    {
      _8049.push_back((int)0);
    }
    auto _8051 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8049.size()),_8049.begin(),_8049.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2813 = _8051;
    _checked_ptr_1<int> _ptr__2813(_2813 ? _2813->raw() : nullptr,_2813 ? _2813->size(0) : 0);
    int _8052 = (int)0;
    int _8053 = (int)((_2813)->size(0));
    for (int _2815 = _8052; _2815 < _8053; ++_2815)
    {
      {
        if (((_ptr__2810[_2815] < (int)0) || (_ptr__2810[_2815] > (int)((_2812)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2813[_ptr__2810[_2815]];
      }
    }
    int _8054 = (int)0;
    int _8055 = (int)((_2813)->size(0));
    for (int _2816 = _8054; _2816 < _8055; ++_2816)
    {
      {
        if (((_ptr__2813[_2816] < (int)1) || (_ptr__2813[_2816] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2817,    monty::rc_ptr< ::mosek::fusion::Expression > _2818,    int _2819){ return new mosek::fusion::ExprPermuteDims(_2817,_2818,_2819); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2817,    monty::rc_ptr< ::mosek::fusion::Expression > _2818,    int _2819) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2817,_2818,_2819); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2817,    monty::rc_ptr< ::mosek::fusion::Expression > _2818,    int _2819){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2817(_2817 ? _2817->raw() : nullptr, _2817 ? _2817->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2817,_2818->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2818;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2817);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2820,monty::rc_ptr< ::mosek::fusion::WorkStack > _2821,monty::rc_ptr< ::mosek::fusion::WorkStack > _2822) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2820,_2821,_2822); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2820,monty::rc_ptr< ::mosek::fusion::WorkStack > _2821,monty::rc_ptr< ::mosek::fusion::WorkStack > _2822){
  expr->eval(_2821,_2820,_2822);
  int _2823 = _2821->popi32();
  int _2824 = _2821->popi32(_2823);
  std::shared_ptr< monty::ndarray< long long,1 > > _2825 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2823)));
  _checked_ptr_1<long long> _ptr__2825(_2825 ? _2825->raw() : nullptr,_2825 ? _2825->size(0) : 0);
  _ptr__2825[(_2823 - (int)1)] = (int)1;
  int _8056 = (int)1;
  int _8057 = _2823;
  for (int _2826 = _8056; _2826 < _8057; ++_2826)
  {
    {
      _ptr__2825[((_2823 - _2826) - (int)1)] = safe_mul( _ptr__2825[(_2823 - _2826)],((*mosek::fusion::p_WorkStack::_get_impl(_2821)->i32)((safe_add( _2824,_2823 ) - _2826))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2827 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2823)));
  _checked_ptr_1<int> _ptr__2827(_2827 ? _2827->raw() : nullptr,_2827 ? _2827->size(0) : 0);
  _ptr__2827[(_2823 - (int)1)] = (int)1;
  int _8058 = (int)1;
  int _8059 = _2823;
  for (int _2828 = _8058; _2828 < _8059; ++_2828)
  {
    {
      _ptr__2827[((_2823 - _2828) - (int)1)] = safe_mul( _ptr__2827[(_2823 - _2828)],((*mosek::fusion::p_WorkStack::_get_impl(_2821)->i32)(safe_add( _2824,((*dperm)((_2823 - _2828))) ))) );
    }
  }
  int _2829 = _2821->popi32();
  int _2830 = _2821->popi32();
  bool _2831 = (_2821->popi32() != (int)0);
  int _2832 = _2821->popi32(safe_add( _2829,(int)1 ));
  int _8060;
  bool _8061 = (!_2831);
  if (_8061)
  {
    _8060 = (-(int)1);
  }
  else
  {
    _8060 = _2821->popi64(_2829);
  }
  int _2833 = _8060;
  int _2834 = _2821->popi64(_2830);
  int _2835 = _2821->popf64(_2829);
  int _2836 = _2821->popf64(_2830);
  std::shared_ptr< monty::ndarray< int,1 > > _2837 = mosek::fusion::p_WorkStack::_get_impl(_2821)->i32;
  _checked_ptr_1<int> _ptr__2837(_2837 ? _2837->raw() : nullptr,_2837 ? _2837->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2838 = mosek::fusion::p_WorkStack::_get_impl(_2821)->i64;
  _checked_ptr_1<long long> _ptr__2838(_2838 ? _2838->raw() : nullptr,_2838 ? _2838->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2839 = mosek::fusion::p_WorkStack::_get_impl(_2821)->f64;
  _checked_ptr_1<double> _ptr__2839(_2839 ? _2839->raw() : nullptr,_2839 ? _2839->size(0) : 0);
  if (_2831)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2840 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2829)));
      _checked_ptr_1<long long> _ptr__2840(_2840 ? _2840->raw() : nullptr,_2840 ? _2840->size(0) : 0);
      {
        int _8062 = (int)0;
        int _8063 = _2829;
        for (int _2841 = _8062; _2841 < _8063; ++_2841)
        {
          {
            long long _2842 = (long long)0;
            int _8064 = (int)0;
            int _8065 = _2823;
            for (int _2843 = _8064; _2843 < _8065; ++_2843)
            {
              {
                _2842 += safe_mul( ((_ptr__2838[safe_add( _2833,_2841 )] / _ptr__2825[_2843]) % _ptr__2837[safe_add( _2824,_2843 )]),_ptr__2827[((*dperm)(_2843))] );
              }
            }
            _ptr__2840[_2841] = _2842;
          }
        }
      }
      std::vector<long long> _8066;
      for (int _2845 = (int)0, _8067 = _2829; _2845 < _8067 ; ++_2845)
      {
        _8066.push_back(_2845);
      }
      auto _8068 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8066.size()),_8066.begin(),_8066.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2844 = _8068;
      _checked_ptr_1<long long> _ptr__2844(_2844 ? _2844->raw() : nullptr,_2844 ? _2844->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2844,_2840,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2829));
      int _2846 = _2820->alloci32(safe_add( _2829,(int)1 ));
      int _2847 = _2820->alloci64(_2830);
      int _2848 = _2820->alloci64(_2829);
      int _2849 = _2820->allocf64(_2830);
      int _2850 = _2820->allocf64(_2829);
      _2820->pushi32((int)1);
      _2820->pushi32(_2830);
      _2820->pushi32(_2829);
      int _8069 = (int)0;
      int _8070 = _2823;
      for (int _2851 = _8069; _2851 < _8070; ++_2851)
      {
        {
          _2820->pushi32(_ptr__2837[safe_add( _2824,((*dperm)(_2851)) )]);
        }
      }
      _2820->pushi32(_2823);
      std::shared_ptr< monty::ndarray< int,1 > > _2852 = mosek::fusion::p_WorkStack::_get_impl(_2820)->i32;
      _checked_ptr_1<int> _ptr__2852(_2852 ? _2852->raw() : nullptr,_2852 ? _2852->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2853 = mosek::fusion::p_WorkStack::_get_impl(_2820)->i64;
      _checked_ptr_1<long long> _ptr__2853(_2853 ? _2853->raw() : nullptr,_2853 ? _2853->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2854 = mosek::fusion::p_WorkStack::_get_impl(_2820)->f64;
      _checked_ptr_1<double> _ptr__2854(_2854 ? _2854->raw() : nullptr,_2854 ? _2854->size(0) : 0);
      _ptr__2852[_2846] = (int)0;
      int _2855 = (int)0;
      int _2856 = (int)0;
      int _8071 = (int)0;
      int _8072 = _2829;
      for (int _2857 = _8071; _2857 < _8072; ++_2857)
      {
        {
          long long _2858 = _ptr__2844[_2857];
          int _8073 = _ptr__2837[safe_add( _2832,_2858 )];
          int _8074 = _ptr__2837[safe_add( safe_add( _2832,_2858 ),(int)1 )];
          for (int _2859 = _8073; _2859 < _8074; ++_2859)
          {
            {
              _ptr__2853[safe_add( _2847,_2856 )] = _ptr__2838[safe_add( _2834,_2859 )];
              _ptr__2854[safe_add( _2849,_2856 )] = _ptr__2839[safe_add( _2836,_2859 )];
              ++ _2856;
            }
          }
          _ptr__2853[safe_add( _2848,_2857 )] = _ptr__2840[_2858];
          _ptr__2854[safe_add( _2850,_2857 )] = _ptr__2839[safe_add( _2835,_2858 )];
          ++ _2855;
          _ptr__2852[safe_add( safe_add( _2846,_2857 ),(int)1 )] = _2856;
        }
      }
    }
  }
  else
  {
    {
      int _2860 = _2820->alloci32(safe_add( _2829,(int)1 ));
      int _2861 = _2820->alloci64(_2830);
      int _2862 = _2820->allocf64(_2830);
      int _2863 = _2820->allocf64(_2829);
      _2820->pushi32((int)0);
      _2820->pushi32(_2830);
      _2820->pushi32(_2829);
      int _8075 = (int)0;
      int _8076 = _2823;
      for (int _2864 = _8075; _2864 < _8076; ++_2864)
      {
        {
          _2820->pushi32(_ptr__2837[safe_add( _2824,((*dperm)(_2864)) )]);
        }
      }
      _2820->pushi32(_2823);
      std::shared_ptr< monty::ndarray< int,1 > > _2865 = mosek::fusion::p_WorkStack::_get_impl(_2820)->i32;
      _checked_ptr_1<int> _ptr__2865(_2865 ? _2865->raw() : nullptr,_2865 ? _2865->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2866 = mosek::fusion::p_WorkStack::_get_impl(_2820)->i64;
      _checked_ptr_1<long long> _ptr__2866(_2866 ? _2866->raw() : nullptr,_2866 ? _2866->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2867 = mosek::fusion::p_WorkStack::_get_impl(_2820)->f64;
      _checked_ptr_1<double> _ptr__2867(_2867 ? _2867->raw() : nullptr,_2867 ? _2867->size(0) : 0);
      _ptr__2865[_2860] = (int)0;
      int _2868 = (int)0;
      int _2869 = (int)0;
      int _8077 = (int)0;
      int _8078 = _2829;
      for (int _2870 = _8077; _2870 < _8078; ++_2870)
      {
        {
          long long _2871 = (long long)0;
          int _8079 = (int)0;
          int _8080 = _2823;
          for (int _2872 = _8079; _2872 < _8080; ++_2872)
          {
            {
              _2871 += safe_mul( ((_2870 / _ptr__2825[((*dperm)(_2872))]) % _ptr__2837[safe_add( _2824,((*dperm)(_2872)) )]),_ptr__2827[_2872] );
            }
          }
          int _8081 = _ptr__2837[safe_add( _2832,_2871 )];
          int _8082 = _ptr__2837[safe_add( safe_add( _2832,_2871 ),(int)1 )];
          for (int _2873 = _8081; _2873 < _8082; ++_2873)
          {
            {
              _ptr__2866[safe_add( _2861,_2869 )] = _ptr__2838[safe_add( _2834,_2873 )];
              _ptr__2867[safe_add( _2862,_2869 )] = _ptr__2839[safe_add( _2836,_2873 )];
              ++ _2869;
            }
          }
          _ptr__2867[safe_add( _2863,_2868 )] = _ptr__2839[safe_add( _2835,_2871 )];
          ++ _2868;
          _ptr__2865[safe_add( _2860,_2868 )] = _2869;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2874,std::shared_ptr< monty::ndarray< int,1 > > _2875){
  _checked_ptr_1<int> _ptr__2874(_2874 ? _2874->raw() : nullptr, _2874 ? _2874->size(0) : 0);
  _checked_ptr_1<int> _ptr__2875(_2875 ? _2875->raw() : nullptr, _2875 ? _2875->size(0) : 0);
  std::vector<int> _8083;
  for (int _2876 = (int)0, _8084 = (int)((_2874)->size(0)); _2876 < _8084 ; ++_2876)
  {
    _8083.push_back(_ptr__2875[_ptr__2874[_2876]]);
  }
  auto _8085 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8083.size()),_8083.begin(),_8083.end()));
  return _8085;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2877){ return new mosek::fusion::ExprTranspose(_2877); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2877) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2877); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2877){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2877->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2877;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2878,monty::rc_ptr< ::mosek::fusion::WorkStack > _2879,monty::rc_ptr< ::mosek::fusion::WorkStack > _2880) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2878,_2879,_2880); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2878,monty::rc_ptr< ::mosek::fusion::WorkStack > _2879,monty::rc_ptr< ::mosek::fusion::WorkStack > _2880){
  expr->eval(_2879,_2878,_2880);
  _2879->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2879)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2881 = mosek::fusion::p_WorkStack::_get_impl(_2879)->shape_base;
      int _2882 = mosek::fusion::p_WorkStack::_get_impl(_2879)->nelem;
      int _2883 = mosek::fusion::p_WorkStack::_get_impl(_2879)->nnz;
      bool _2884 = mosek::fusion::p_WorkStack::_get_impl(_2879)->hassp;
      int _2885 = mosek::fusion::p_WorkStack::_get_impl(_2879)->ptr_base;
      int _2886 = mosek::fusion::p_WorkStack::_get_impl(_2879)->sp_base;
      int _2887 = mosek::fusion::p_WorkStack::_get_impl(_2879)->nidxs_base;
      int _2888 = mosek::fusion::p_WorkStack::_get_impl(_2879)->bfix_base;
      int _2889 = mosek::fusion::p_WorkStack::_get_impl(_2879)->cof_base;
      int _2890 = ((*mosek::fusion::p_WorkStack::_get_impl(_2879)->i32)(_2881));
      int _2891 = ((*mosek::fusion::p_WorkStack::_get_impl(_2879)->i32)(safe_add( _2881,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2892 = mosek::fusion::p_WorkStack::_get_impl(_2879)->i32;
      _checked_ptr_1<int> _ptr__2892(_2892 ? _2892->raw() : nullptr,_2892 ? _2892->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2893 = mosek::fusion::p_WorkStack::_get_impl(_2879)->i64;
      _checked_ptr_1<long long> _ptr__2893(_2893 ? _2893->raw() : nullptr,_2893 ? _2893->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2894 = mosek::fusion::p_WorkStack::_get_impl(_2879)->f64;
      _checked_ptr_1<double> _ptr__2894(_2894 ? _2894->raw() : nullptr,_2894 ? _2894->size(0) : 0);
      _2878->alloc_expr((int)2,_2882,_2883,_2884);
      int _2895 = mosek::fusion::p_WorkStack::_get_impl(_2878)->ptr_base;
      int _2896 = mosek::fusion::p_WorkStack::_get_impl(_2878)->nidxs_base;
      int _2897 = mosek::fusion::p_WorkStack::_get_impl(_2878)->sp_base;
      int _2898 = mosek::fusion::p_WorkStack::_get_impl(_2878)->cof_base;
      int _2899 = mosek::fusion::p_WorkStack::_get_impl(_2878)->bfix_base;
      int _2900 = mosek::fusion::p_WorkStack::_get_impl(_2878)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2901 = mosek::fusion::p_WorkStack::_get_impl(_2878)->i32;
      _checked_ptr_1<int> _ptr__2901(_2901 ? _2901->raw() : nullptr,_2901 ? _2901->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2902 = mosek::fusion::p_WorkStack::_get_impl(_2878)->i64;
      _checked_ptr_1<long long> _ptr__2902(_2902 ? _2902->raw() : nullptr,_2902 ? _2902->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2903 = mosek::fusion::p_WorkStack::_get_impl(_2878)->f64;
      _checked_ptr_1<double> _ptr__2903(_2903 ? _2903->raw() : nullptr,_2903 ? _2903->size(0) : 0);
      _ptr__2901[_2900] = _2891;
      _ptr__2901[safe_add( _2900,(int)1 )] = _2890;
      if (_2884)
      {
        {
          int _2904 = _2880->alloci32(_2882);
          int _2905 = _2880->alloci32(safe_add( _2891,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _2906 = mosek::fusion::p_WorkStack::_get_impl(_2880)->i32;
          _checked_ptr_1<int> _ptr__2906(_2906 ? _2906->raw() : nullptr,_2906 ? _2906->size(0) : 0);
          int _8086 = (int)0;
          int _8087 = safe_add( _2891,(int)1 );
          for (int _2907 = _8086; _2907 < _8087; ++_2907)
          {
            {
              _ptr__2906[safe_add( _2905,_2907 )] = (int)0;
            }
          }
          int _8088 = (int)0;
          int _8089 = _2882;
          for (int _2908 = _8088; _2908 < _8089; ++_2908)
          {
            {
              ++ _ptr__2906[safe_add( safe_add( _2905,(_ptr__2893[safe_add( _2886,_2908 )] % _2891) ),(int)1 )];
            }
          }
          int _8090 = (int)0;
          int _8091 = _2891;
          for (int _2909 = _8090; _2909 < _8091; ++_2909)
          {
            {
              _ptr__2906[safe_add( safe_add( _2905,_2909 ),(int)1 )] += _ptr__2906[safe_add( _2905,_2909 )];
            }
          }
          int _8092 = (int)0;
          int _8093 = _2882;
          for (int _2910 = _8092; _2910 < _8093; ++_2910)
          {
            {
              long long _2911 = (_ptr__2893[safe_add( _2886,_2910 )] % _2891);
              _ptr__2906[safe_add( _2904,_ptr__2906[safe_add( _2905,_2911 )] )] = _2910;
              ++ _ptr__2906[safe_add( _2905,_2911 )];
            }
          }
          _ptr__2901[_2895] = (int)0;
          int _2912 = (int)0;
          int _8094 = (int)0;
          int _8095 = _2882;
          for (int _2913 = _8094; _2913 < _8095; ++_2913)
          {
            {
              int _2914 = _ptr__2906[safe_add( _2904,_2913 )];
              int _8096 = _ptr__2892[safe_add( _2885,_2914 )];
              int _8097 = _ptr__2892[safe_add( safe_add( _2885,_2914 ),(int)1 )];
              for (int _2915 = _8096; _2915 < _8097; ++_2915)
              {
                {
                  _ptr__2902[safe_add( _2896,_2912 )] = _ptr__2893[safe_add( _2887,_2915 )];
                  _ptr__2903[safe_add( _2898,_2912 )] = _ptr__2894[safe_add( _2889,_2915 )];
                  ++ _2912;
                }
              }
              long long _2916 = (_ptr__2893[safe_add( _2886,_2914 )] / _2891);
              long long _2917 = (_ptr__2893[safe_add( _2886,_2914 )] % _2891);
              _ptr__2901[safe_add( safe_add( _2895,_2913 ),(int)1 )] = _2912;
              _ptr__2902[safe_add( _2897,_2913 )] = safe_add( safe_mul( _2917,_2891 ),_2916 );
              _ptr__2903[safe_add( _2899,_2913 )] = _ptr__2894[safe_add( _2888,_2914 )];
            }
          }
        }
      }
      else
      {
        {
          _ptr__2901[_2895] = (int)0;
          int _2918 = (int)0;
          int _2919 = (int)0;
          int _8098 = (int)0;
          int _8099 = _2891;
          for (int _2920 = _8098; _2920 < _8099; ++_2920)
          {
            {
              int _8100 = (int)0;
              int _8101 = _2890;
              for (int _2921 = _8100; _2921 < _8101; ++_2921)
              {
                {
                  int _2922 = safe_add( safe_mul( _2921,_2891 ),_2920 );
                  int _8102 = _ptr__2892[safe_add( _2885,_2922 )];
                  int _8103 = _ptr__2892[safe_add( safe_add( _2885,_2922 ),(int)1 )];
                  for (int _2923 = _8102; _2923 < _8103; ++_2923)
                  {
                    {
                      _ptr__2902[safe_add( _2896,_2918 )] = _ptr__2893[safe_add( _2887,_2923 )];
                      _ptr__2903[safe_add( _2898,_2918 )] = _ptr__2894[safe_add( _2889,_2923 )];
                      ++ _2918;
                    }
                  }
                  _ptr__2903[safe_add( _2899,_2919 )] = _ptr__2894[safe_add( _2888,_2922 )];
                  _ptr__2901[safe_add( safe_add( _2895,_2919 ),(int)1 )] = _2918;
                  ++ _2919;
                }
              }
            }
          }
        }
      }
      _2880->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2924){
  _checked_ptr_1<int> _ptr__2924(_2924 ? _2924->raw() : nullptr, _2924 ? _2924->size(0) : 0);
  if (((int)((_2924)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__2924[(int)1]),(int)(_ptr__2924[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2925,    int _2926){ return new mosek::fusion::ExprStack(_2925,_2926); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2925,    int _2926) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_2925,_2926); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2925,    int _2926){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_2925,_2926));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8104;
    for (int _2927 = (int)0, _8105 = (int)((_2925)->size(0)); _2927 < _8105 ; ++_2927)
    {
      _8104.push_back(((*_2925)(_2927)));
    }
    auto _8106 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8104.size()),_8104.begin(),_8104.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8106;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _2926;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2928,monty::rc_ptr< ::mosek::fusion::WorkStack > _2929,monty::rc_ptr< ::mosek::fusion::WorkStack > _2930) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_2928,_2929,_2930); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2928,monty::rc_ptr< ::mosek::fusion::WorkStack > _2929,monty::rc_ptr< ::mosek::fusion::WorkStack > _2930){
  int _2931 = (int)((exprs)->size(0));
  if ((_2931 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_2928,_2929,_2930);
    }
  }
  else
  {
    {
      int _8107 = (int)0;
      int _8108 = _2931;
      for (int _2932 = _8107; _2932 < _8108; ++_2932)
      {
        {
          ((*exprs)(((_2931 - _2932) - (int)1)))->eval(_2929,_2928,_2930);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2933 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2933(_2933 ? _2933->raw() : nullptr,_2933 ? _2933->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2934 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2934(_2934 ? _2934->raw() : nullptr,_2934 ? _2934->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2935 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2935(_2935 ? _2935->raw() : nullptr,_2935 ? _2935->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2936 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2936(_2936 ? _2936->raw() : nullptr,_2936 ? _2936->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _2937 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_2931)));
      std::shared_ptr< monty::ndarray< int,1 > > _2938 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2938(_2938 ? _2938->raw() : nullptr,_2938 ? _2938->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2939 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2939(_2939 ? _2939->raw() : nullptr,_2939 ? _2939->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2940 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2940(_2940 ? _2940->raw() : nullptr,_2940 ? _2940->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2941(_2941 ? _2941->raw() : nullptr,_2941 ? _2941->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2942 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2942(_2942 ? _2942->raw() : nullptr,_2942 ? _2942->size(0) : 0);
      int _8109 = (int)0;
      int _8110 = _2931;
      for (int _2943 = _8109; _2943 < _8110; ++_2943)
      {
        {
          _2929->pop_expr();
          _ptr__2933[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->nd;
          _ptr__2934[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->shape_base;
          _ptr__2935[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->nelem;
          _ptr__2936[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->nnz;
          ((*_2937)(_2943)) = mosek::fusion::p_WorkStack::_get_impl(_2929)->hassp;
          _ptr__2938[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->ptr_base;
          _ptr__2940[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->sp_base;
          _ptr__2939[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->nidxs_base;
          _ptr__2942[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->bfix_base;
          _ptr__2941[_2943] = mosek::fusion::p_WorkStack::_get_impl(_2929)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2944 = mosek::fusion::p_WorkStack::_get_impl(_2929)->i32;
      _checked_ptr_1<int> _ptr__2944(_2944 ? _2944->raw() : nullptr,_2944 ? _2944->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2945 = mosek::fusion::p_WorkStack::_get_impl(_2929)->i64;
      _checked_ptr_1<long long> _ptr__2945(_2945 ? _2945->raw() : nullptr,_2945 ? _2945->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2946 = mosek::fusion::p_WorkStack::_get_impl(_2929)->f64;
      _checked_ptr_1<double> _ptr__2946(_2946 ? _2946->raw() : nullptr,_2946 ? _2946->size(0) : 0);
      int _2947 = _ptr__2933[(int)0];
      int _2948 = _ptr__2934[(int)0];
      bool _2949 = (!((*_2937)((int)0)));
      bool _2950 = false;
      int _8111 = (int)1;
      int _8112 = _2931;
      for (int _2951 = _8111; _2951 < _8112; ++_2951)
      {
        {
          _2950 = (_2950 || ((dim != _2951) && (_ptr__2933[_2951] != _2947)));
          if ((!_2950))
          {
            {
              int _8113 = (int)0;
              int _8114 = dim;
              for (int _2952 = _8113; _2952 < _8114; ++_2952)
              {
                {
                  _2950 = (_2950 || (_ptr__2944[safe_add( _2948,_2952 )] != _ptr__2944[safe_add( _ptr__2934[_2951],_2952 )]));
                }
              }
            }
          }
          {}
          if ((!_2950))
          {
            {
              int _8115 = safe_add( dim,(int)1 );
              int _8116 = _2947;
              for (int _2953 = _8115; _2953 < _8116; ++_2953)
              {
                {
                  _2950 = (_2950 || (_ptr__2944[safe_add( _2948,_2953 )] != _ptr__2944[safe_add( _ptr__2934[_2951],_2953 )]));
                }
              }
            }
          }
          {}
          _2949 = (_2949 && (!((*_2937)(_2951))));
        }
      }
      if (_2950)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _2954 = (int)0;
      if ((dim < _2947))
      {
        {
          int _8117 = (int)0;
          int _8118 = _2931;
          for (int _2955 = _8117; _2955 < _8118; ++_2955)
          {
            {
              _2954 += _ptr__2944[safe_add( _ptr__2934[_2955],dim )];
            }
          }
        }
      }
      else
      {
        {
          _2954 = _2931;
        }
      }
      int _8119;
      bool _8120 = (dim < _2947);
      if (_8120)
      {
        _8119 = _2947;
      }
      else
      {
        _8119 = safe_add( _2947,(int)1 );
      }
      int _2956 = _8119;
      if ((_2956 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _2957 = (int)0;
      int _2958 = (int)0;
      {
        int _8121 = (int)0;
        int _8122 = _2931;
        for (int _2959 = _8121; _2959 < _8122; ++_2959)
        {
          {
            _2958 += _ptr__2936[_2959];
          }
        }
        int _8123 = (int)0;
        int _8124 = _2931;
        for (int _2960 = _8123; _2960 < _8124; ++_2960)
        {
          {
            _2957 += _ptr__2935[_2960];
          }
        }
      }
      int _2961 = (int)1;
      int _8125 = (int)0;
      int _8126 = dim;
      for (int _2962 = _8125; _2962 < _8126; ++_2962)
      {
        {
          _2961 *= _ptr__2944[safe_add( _2948,_2962 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8127;
      bool _8128 = (dim < _2947);
      if (_8128)
      {
        std::vector<int> _8129;
        for (int _2964 = (int)0, _8130 = _2931; _2964 < _8130 ; ++_2964)
        {
          _8129.push_back(_ptr__2944[safe_add( _ptr__2934[_2964],dim )]);
        }
        auto _8131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8129.size()),_8129.begin(),_8129.end()));
        _8127 = _8131;
      }
      else
      {
        std::vector<int> _8132;
        for (int _2965 = (int)0, _8133 = _2931; _2965 < _8133 ; ++_2965)
        {
          _8132.push_back((int)1);
        }
        auto _8134 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8132.size()),_8132.begin(),_8132.end()));
        _8127 = _8134;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2963 = _8127;
      _checked_ptr_1<int> _ptr__2963(_2963 ? _2963->raw() : nullptr,_2963 ? _2963->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2966 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2931)));
      _checked_ptr_1<int> _ptr__2966(_2966 ? _2966->raw() : nullptr,_2966 ? _2966->size(0) : 0);
      _ptr__2966[(int)0] = (int)0;
      int _8135 = (int)1;
      int _8136 = _2947;
      for (int _2967 = _8135; _2967 < _8136; ++_2967)
      {
        {
          _ptr__2966[_2967] = safe_add( _ptr__2966[(_2967 - (int)1)],_ptr__2963[(_2967 - (int)1)] );
        }
      }
      int _2968 = (int)0;
      int _8137 = (int)0;
      int _8138 = _2931;
      for (int _2969 = _8137; _2969 < _8138; ++_2969)
      {
        {
          _2968 += _ptr__2963[_2969];
        }
      }
      int _2970 = (int)1;
      int _8139 = safe_add( dim,(int)1 );
      int _8140 = _2947;
      for (int _2971 = _8139; _2971 < _8140; ++_2971)
      {
        {
          _2970 *= _ptr__2944[safe_add( _2948,_2971 )];
        }
      }
      if (_2949)
      {
        {
          _2928->alloc_expr(_2956,_2957,_2958,false);
          int _2972 = mosek::fusion::p_WorkStack::_get_impl(_2928)->ptr_base;
          int _2973 = mosek::fusion::p_WorkStack::_get_impl(_2928)->shape_base;
          int _2974 = mosek::fusion::p_WorkStack::_get_impl(_2928)->nidxs_base;
          int _2975 = mosek::fusion::p_WorkStack::_get_impl(_2928)->cof_base;
          int _2976 = mosek::fusion::p_WorkStack::_get_impl(_2928)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _2977 = mosek::fusion::p_WorkStack::_get_impl(_2928)->i32;
          _checked_ptr_1<int> _ptr__2977(_2977 ? _2977->raw() : nullptr,_2977 ? _2977->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2978 = mosek::fusion::p_WorkStack::_get_impl(_2928)->i64;
          _checked_ptr_1<long long> _ptr__2978(_2978 ? _2978->raw() : nullptr,_2978 ? _2978->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2979 = mosek::fusion::p_WorkStack::_get_impl(_2928)->f64;
          _checked_ptr_1<double> _ptr__2979(_2979 ? _2979->raw() : nullptr,_2979 ? _2979->size(0) : 0);
          int _8141 = (int)0;
          int _8142 = _2947;
          for (int _2980 = _8141; _2980 < _8142; ++_2980)
          {
            {
              _ptr__2977[safe_add( _2973,_2980 )] = _ptr__2944[safe_add( _2948,_2980 )];
            }
          }
          _ptr__2977[safe_add( _2973,dim )] = _2954;
          {
            _ptr__2977[_2972] = (int)0;
            {
              int _2981 = (int)0;
              int _8143 = (int)0;
              int _8144 = _2931;
              for (int _2982 = _8143; _2982 < _8144; ++_2982)
              {
                {
                  int _2983 = _ptr__2938[_2982];
                  int _2984 = (int)0;
                  int _8145 = (int)0;
                  int _8146 = _2961;
                  for (int _2985 = _8145; _2985 < _8146; ++_2985)
                  {
                    {
                      int _8147 = (int)0;
                      int _8148 = _ptr__2963[_2982];
                      for (int _2986 = _8147; _2986 < _8148; ++_2986)
                      {
                        {
                          int _8149 = (int)0;
                          int _8150 = _2970;
                          for (int _2987 = _8149; _2987 < _8150; ++_2987)
                          {
                            {
                              int _2988 = safe_add( safe_add( _2987,safe_mul( safe_add( _2986,_2981 ),_2970 ) ),safe_mul( safe_mul( _2985,_2968 ),_2970 ) );
                              int _2989 = (_ptr__2944[safe_add( safe_add( _2983,_2984 ),(int)1 )] - _ptr__2944[safe_add( _2983,_2984 )]);
                              _ptr__2977[safe_add( safe_add( _2972,_2988 ),(int)1 )] = _2989;
                              _ptr__2979[safe_add( _2976,_2988 )] = _ptr__2946[safe_add( _ptr__2942[_2982],_2984 )];
                              ++ _2984;
                            }
                          }
                        }
                      }
                    }
                  }
                  _2981 += _ptr__2963[_2982];
                }
              }
              int _8151 = (int)0;
              int _8152 = _2957;
              for (int _2990 = _8151; _2990 < _8152; ++_2990)
              {
                {
                  _ptr__2977[safe_add( safe_add( _2972,_2990 ),(int)1 )] += _ptr__2977[safe_add( _2972,_2990 )];
                }
              }
            }
            {
              int _2991 = (int)0;
              int _8153 = (int)0;
              int _8154 = _2931;
              for (int _2992 = _8153; _2992 < _8154; ++_2992)
              {
                {
                  int _2993 = _ptr__2938[_2992];
                  int _2994 = (int)0;
                  int _8155 = (int)0;
                  int _8156 = _2961;
                  for (int _2995 = _8155; _2995 < _8156; ++_2995)
                  {
                    {
                      int _8157 = (int)0;
                      int _8158 = _ptr__2963[_2992];
                      for (int _2996 = _8157; _2996 < _8158; ++_2996)
                      {
                        {
                          int _8159 = (int)0;
                          int _8160 = _2970;
                          for (int _2997 = _8159; _2997 < _8160; ++_2997)
                          {
                            {
                              int _2998 = safe_add( safe_add( _2997,safe_mul( safe_add( _2996,_2991 ),_2970 ) ),safe_mul( safe_mul( _2995,_2968 ),_2970 ) );
                              int _2999 = _ptr__2944[safe_add( _2993,_2994 )];
                              int _3000 = (_ptr__2944[safe_add( safe_add( _2993,_2994 ),(int)1 )] - _2999);
                              int _8161 = (int)0;
                              int _8162 = _3000;
                              for (int _3001 = _8161; _3001 < _8162; ++_3001)
                              {
                                {
                                  _ptr__2978[safe_add( safe_add( _2974,_ptr__2977[safe_add( _2972,_2998 )] ),_3001 )] = _ptr__2945[safe_add( safe_add( _ptr__2939[_2992],_2999 ),_3001 )];
                                }
                              }
                              int _8163 = (int)0;
                              int _8164 = _3000;
                              for (int _3002 = _8163; _3002 < _8164; ++_3002)
                              {
                                {
                                  _ptr__2979[safe_add( safe_add( _2975,_ptr__2977[safe_add( _2972,_2998 )] ),_3002 )] = _ptr__2946[safe_add( safe_add( _ptr__2941[_2992],_2999 ),_3002 )];
                                }
                              }
                              ++ _2994;
                            }
                          }
                        }
                      }
                    }
                  }
                  _2991 += _ptr__2963[_2992];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3003 = (int)1;
          int _8165 = (int)0;
          int _8166 = dim;
          for (int _3004 = _8165; _3004 < _8166; ++_3004)
          {
            {
              _3003 *= _ptr__2944[safe_add( _2948,_3004 )];
            }
          }
          _3003 *= _2954;
          int _8167 = safe_add( dim,(int)1 );
          int _8168 = _2947;
          for (int _3005 = _8167; _3005 < _8168; ++_3005)
          {
            {
              _3003 *= _ptr__2944[safe_add( _2948,_3005 )];
            }
          }
          bool _3006 = (_2957 < _3003);
          _2928->alloc_expr(_2956,_2957,_2958,_3006);
          int _3007 = mosek::fusion::p_WorkStack::_get_impl(_2928)->ptr_base;
          int _3008 = mosek::fusion::p_WorkStack::_get_impl(_2928)->nidxs_base;
          int _8169;
          bool _8170 = _3006;
          if (_8170)
          {
            _8169 = mosek::fusion::p_WorkStack::_get_impl(_2928)->sp_base;
          }
          else
          {
            _8169 = _2928->alloci64(_2957);
          }
          int _3009 = _8169;
          int _3010 = mosek::fusion::p_WorkStack::_get_impl(_2928)->cof_base;
          int _3011 = mosek::fusion::p_WorkStack::_get_impl(_2928)->bfix_base;
          int _3012 = mosek::fusion::p_WorkStack::_get_impl(_2928)->shape_base;
          int _8171 = (int)0;
          int _8172 = _2947;
          for (int _3013 = _8171; _3013 < _8172; ++_3013)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_2928)->i32)(safe_add( _3012,_3013 ))) = _ptr__2944[safe_add( _2948,_3013 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_2928)->i32)(safe_add( _3012,dim ))) = _2954;
          int _3014 = _2930->alloci32(safe_add( _2957,(int)1 ));
          int _3015 = _2930->alloci64(_2958);
          int _3016 = _2930->alloci64(_2957);
          int _3017 = _2930->allocf64(_2958);
          int _3018 = _2930->allocf64(_2957);
          std::shared_ptr< monty::ndarray< int,1 > > _3019 = mosek::fusion::p_WorkStack::_get_impl(_2928)->i32;
          _checked_ptr_1<int> _ptr__3019(_3019 ? _3019->raw() : nullptr,_3019 ? _3019->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3020 = mosek::fusion::p_WorkStack::_get_impl(_2928)->i64;
          _checked_ptr_1<long long> _ptr__3020(_3020 ? _3020->raw() : nullptr,_3020 ? _3020->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3021 = mosek::fusion::p_WorkStack::_get_impl(_2928)->f64;
          _checked_ptr_1<double> _ptr__3021(_3021 ? _3021->raw() : nullptr,_3021 ? _3021->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3022 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i32;
          _checked_ptr_1<int> _ptr__3022(_3022 ? _3022->raw() : nullptr,_3022 ? _3022->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3023 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i64;
          _checked_ptr_1<long long> _ptr__3023(_3023 ? _3023->raw() : nullptr,_3023 ? _3023->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3024 = mosek::fusion::p_WorkStack::_get_impl(_2930)->f64;
          _checked_ptr_1<double> _ptr__3024(_3024 ? _3024->raw() : nullptr,_3024 ? _3024->size(0) : 0);
          {
            int _3025 = (int)0;
            int _3026 = (int)0;
            int _8173 = (int)0;
            int _8174 = _2931;
            for (int _3027 = _8173; _3027 < _8174; ++_3027)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_2945,_ptr__2939[_3027],_3023,safe_add( _3015,_3026 ),_ptr__2936[_3027]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2946,_ptr__2941[_3027],_3024,safe_add( _3017,_3026 ),_ptr__2936[_3027]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2946,_ptr__2942[_3027],_3024,safe_add( _3018,_3025 ),_ptr__2935[_3027]);
                _3026 += _ptr__2936[_3027];
                _3025 += _ptr__2935[_3027];
              }
            }
          }
          {
            _ptr__3022[_3014] = (int)0;
            int _3028 = (int)0;
            int _3029 = (int)0;
            int _8175 = (int)0;
            int _8176 = _2931;
            for (int _3030 = _8175; _3030 < _8176; ++_3030)
            {
              {
                int _3031 = _ptr__2963[_3030];
                int _3032 = safe_mul( _3031,_2970 );
                int _3033 = _2970;
                if (((*_2937)(_3030)))
                {
                  {
                    int _8177 = (int)0;
                    int _8178 = _ptr__2935[_3030];
                    for (int _3034 = _8177; _3034 < _8178; ++_3034)
                    {
                      {
                        long long _3035 = (_ptr__2945[safe_add( _ptr__2940[_3030],_3034 )] / _3032);
                        long long _3036 = ((_ptr__2945[safe_add( _ptr__2940[_3030],_3034 )] / _3033) % _3031);
                        long long _3037 = (_ptr__2945[safe_add( _ptr__2940[_3030],_3034 )] % _2970);
                        _ptr__3023[safe_add( _3016,_3029 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3035,_2954 ),_3036 ),_ptr__2966[_3030] ),_2970 ),_3037 );
                        _ptr__3022[safe_add( safe_add( _3014,_3029 ),(int)1 )] = safe_add( _3028,_ptr__2944[safe_add( safe_add( _ptr__2938[_3030],_3034 ),(int)1 )] );
                        ++ _3029;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3038 = (int)0;
                    int _8179 = (int)0;
                    int _8180 = _2961;
                    for (int _3039 = _8179; _3039 < _8180; ++_3039)
                    {
                      {
                        int _8181 = (int)0;
                        int _8182 = _3031;
                        for (int _3040 = _8181; _3040 < _8182; ++_3040)
                        {
                          {
                            int _8183 = (int)0;
                            int _8184 = _2970;
                            for (int _3041 = _8183; _3041 < _8184; ++_3041)
                            {
                              {
                                _ptr__3023[safe_add( _3016,_3029 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3039,_2954 ),_3040 ),_ptr__2966[_3030] ),_2970 ),_3041 );
                                _ptr__3022[safe_add( safe_add( _3014,_3029 ),(int)1 )] = safe_add( _3028,_ptr__2944[safe_add( safe_add( _ptr__2938[_3030],_3038 ),(int)1 )] );
                                ++ _3029;
                                ++ _3038;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3028 += _ptr__2936[_3030];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3042 = (int)0;
              int _8185 = (int)0;
              int _8186 = _2947;
              for (int _3043 = _8185; _3043 < _8186; ++_3043)
              {
                {
                  if ((_3042 < _ptr__3019[safe_add( _3012,_3043 )]))
                  {
                    {
                      _3042 = _ptr__3019[safe_add( _3012,_3043 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3044 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2956)));
              _checked_ptr_1<long long> _ptr__3044(_3044 ? _3044->raw() : nullptr,_3044 ? _3044->size(0) : 0);
              _ptr__3044[(_2956 - (int)1)] = (int)1;
              int _8187 = (int)1;
              int _8188 = _2956;
              for (int _3045 = _8187; _3045 < _8188; ++_3045)
              {
                {
                  _ptr__3044[((_2956 - _3045) - (int)1)] = safe_mul( _ptr__3044[(_2956 - _3045)],_ptr__3019[(safe_add( _3012,_2956 ) - _3045)] );
                }
              }
              int _3046 = _2930->alloci32(_2957);
              int _3047 = _2930->alloci32(_2957);
              int _3048 = _2930->alloci32(safe_add( _3042,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3049 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i32;
              _checked_ptr_1<int> _ptr__3049(_3049 ? _3049->raw() : nullptr,_3049 ? _3049->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3050 = mosek::fusion::p_WorkStack::_get_impl(_2930)->i64;
              _checked_ptr_1<long long> _ptr__3050(_3050 ? _3050->raw() : nullptr,_3050 ? _3050->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3051 = mosek::fusion::p_WorkStack::_get_impl(_2930)->f64;
              _checked_ptr_1<double> _ptr__3051(_3051 ? _3051->raw() : nullptr,_3051 ? _3051->size(0) : 0);
              {
                int _8189 = (int)0;
                int _8190 = _2957;
                for (int _3052 = _8189; _3052 < _8190; ++_3052)
                {
                  {
                    _ptr__3049[safe_add( _3046,_3052 )] = _3052;
                  }
                }
                int _8191 = (int)0;
                int _8192 = _2956;
                for (int _3053 = _8191; _3053 < _8192; ++_3053)
                {
                  {
                    int _3054 = ((_2956 - _3053) - (int)1);
                    int _3055 = _ptr__3019[safe_add( _3012,_3054 )];
                    int _8193 = (int)0;
                    int _8194 = safe_add( _3055,(int)1 );
                    for (int _3056 = _8193; _3056 < _8194; ++_3056)
                    {
                      {
                        _ptr__3049[safe_add( _3048,_3056 )] = (int)0;
                      }
                    }
                    int _8195 = (int)0;
                    int _8196 = _2957;
                    for (int _3057 = _8195; _3057 < _8196; ++_3057)
                    {
                      {
                        int _3058 = _ptr__3049[safe_add( _3046,_3057 )];
                        long long _3059 = ((_ptr__3050[safe_add( _3016,_3058 )] / _ptr__3044[_3054]) % _3055);
                        ++ _ptr__3049[safe_add( safe_add( _3048,_3059 ),(int)1 )];
                      }
                    }
                    {
                      int _8197 = (int)0;
                      int _8198 = _3055;
                      for (int _3060 = _8197; _3060 < _8198; ++_3060)
                      {
                        {
                          _ptr__3049[safe_add( safe_add( _3048,_3060 ),(int)1 )] += _ptr__3049[safe_add( _3048,_3060 )];
                        }
                      }
                      int _8199 = (int)0;
                      int _8200 = _2957;
                      for (int _3061 = _8199; _3061 < _8200; ++_3061)
                      {
                        {
                          int _3062 = _ptr__3049[safe_add( _3046,_3061 )];
                          long long _3063 = ((_ptr__3050[safe_add( _3016,_3062 )] / _ptr__3044[_3054]) % _3055);
                          _ptr__3049[safe_add( _3047,_ptr__3049[safe_add( _3048,_3063 )] )] = _3062;
                          ++ _ptr__3049[safe_add( _3048,_3063 )];
                        }
                      }
                    }
                    int _3064 = _3046;
                    _3046 = _3047;
                    _3047 = _3064;
                  }
                }
                int _3065 = (int)0;
                _ptr__3019[_3007] = (int)0;
                int _8201 = (int)0;
                int _8202 = _2957;
                for (int _3066 = _8201; _3066 < _8202; ++_3066)
                {
                  {
                    int _3067 = _ptr__3049[safe_add( _3046,_3066 )];
                    int _3068 = _ptr__3049[safe_add( _3014,_3067 )];
                    int _3069 = _ptr__3049[safe_add( safe_add( _3014,_3067 ),(int)1 )];
                    int _3070 = (_3069 - _3068);
                    _ptr__3019[safe_add( safe_add( _3007,_3066 ),(int)1 )] = safe_add( _ptr__3019[safe_add( _3007,_3066 )],_3070 );
                    _ptr__3021[safe_add( _3011,_3066 )] = _ptr__3051[safe_add( _3018,_3067 )];
                    _ptr__3020[safe_add( _3009,_3066 )] = _ptr__3050[safe_add( _3016,_3067 )];
                    int _8203 = _3068;
                    int _8204 = _3069;
                    for (int _3071 = _8203; _3071 < _8204; ++_3071)
                    {
                      {
                        _ptr__3020[safe_add( _3008,_3065 )] = _ptr__3050[safe_add( _3015,_3071 )];
                        _ptr__3021[safe_add( _3010,_3065 )] = _ptr__3051[safe_add( _3017,_3071 )];
                        ++ _3065;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3072 = (int)0;
              _ptr__3019[_3007] = (int)0;
              int _8205 = (int)0;
              int _8206 = _2957;
              for (int _3073 = _8205; _3073 < _8206; ++_3073)
              {
                {
                  int _3074 = _ptr__3022[safe_add( _3014,_3073 )];
                  int _3075 = _ptr__3022[safe_add( safe_add( _3014,_3073 ),(int)1 )];
                  int _3076 = (_3075 - _3074);
                  _ptr__3019[safe_add( safe_add( _3007,_3073 ),(int)1 )] = safe_add( _ptr__3019[safe_add( _3007,_3073 )],_3076 );
                  _ptr__3021[safe_add( _3011,_3073 )] = _ptr__3024[safe_add( _3018,_3073 )];
                  _ptr__3020[safe_add( _3009,_3073 )] = _ptr__3023[safe_add( _3016,_3073 )];
                  int _8207 = _3074;
                  int _8208 = _3075;
                  for (int _3077 = _8207; _3077 < _8208; ++_3077)
                  {
                    {
                      _ptr__3020[safe_add( _3008,_3072 )] = _ptr__3023[safe_add( _3015,_3077 )];
                      _ptr__3021[safe_add( _3010,_3072 )] = _ptr__3024[safe_add( _3017,_3077 )];
                      ++ _3072;
                    }
                  }
                }
              }
            }
          }
          if ((!_3006))
          {
            {
              _2928->popi64(_2957);
            }
          }
          {}
          _2930->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3078,int _3079){
  if (((int)((_3078)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3078)->size(0)) == (int)1))
  {
    {
      return ((*_3078)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8209;
      for (int _3081 = (int)0, _8210 = (int)((_3078)->size(0)); _3081 < _8210 ; ++_3081)
      {
        _8209.push_back(((*_3078)(_3081))->getShape());
      }
      auto _8211 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8209.size()),_8209.begin(),_8209.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3080 = _8211;
      std::shared_ptr< monty::ndarray< int,1 > > _3082 = ((*_3080)((int)0));
      _checked_ptr_1<int> _ptr__3082(_3082 ? _3082->raw() : nullptr,_3082 ? _3082->size(0) : 0);
      int _3083 = (int)((_3082)->size(0));
      int _8212 = (int)1;
      int _8213 = (int)((_3080)->size(0));
      for (int _3084 = _8212; _3084 < _8213; ++_3084)
      {
        {
          if ((_3083 != (int)((((*_3080)(_3084)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8214 = (int)0;
          int _8215 = _3079;
          for (int _3085 = _8214; _3085 < _8215; ++_3085)
          {
            {
              if ((_ptr__3082[_3085] != ((*((*_3080)(_3084)))(_3085))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8216 = safe_add( _3079,(int)1 );
          int _8217 = _3083;
          for (int _3086 = _8216; _3086 < _8217; ++_3086)
          {
            {
              if ((_ptr__3082[_3086] != ((*((*_3080)(_3084)))(_3086))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3079 == _3083))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3087 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3083,(int)1 ))));
          _checked_ptr_1<int> _ptr__3087(_3087 ? _3087->raw() : nullptr,_3087 ? _3087->size(0) : 0);
          int _8218 = (int)0;
          int _8219 = _3083;
          for (int _3088 = _8218; _3088 < _8219; ++_3088)
          {
            {
              _ptr__3087[_3088] = _ptr__3082[_3088];
            }
          }
          _ptr__3087[_3083] = (int)((_3080)->size(0));
          return _3087;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3089 = _3082;
          _checked_ptr_1<int> _ptr__3089(_3089 ? _3089->raw() : nullptr,_3089 ? _3089->size(0) : 0);
          int _8220 = (int)1;
          int _8221 = (int)((_3080)->size(0));
          for (int _3090 = _8220; _3090 < _8221; ++_3090)
          {
            {
              _ptr__3089[_3079] += ((*((*_3080)(_3090)))(_3079));
            }
          }
          return _3089;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3091 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8222 = (int)1;
  int _8223 = (int)((exprs)->size(0));
  for (int _3092 = _8222; _3092 < _8223; ++_3092)
  {
    {
      _3091->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3092))->toString());
    }
  }
  _3091->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3091->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3093,    std::shared_ptr< monty::ndarray< long long,1 > > _3094,    std::shared_ptr< monty::ndarray< double,1 > > _3095){ return new mosek::fusion::ExprInner(_3093,_3094,_3095); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3093,    std::shared_ptr< monty::ndarray< long long,1 > > _3094,    std::shared_ptr< monty::ndarray< double,1 > > _3095) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3093,_3094,_3095); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3093,    std::shared_ptr< monty::ndarray< long long,1 > > _3094,    std::shared_ptr< monty::ndarray< double,1 > > _3095){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3094(_3094 ? _3094->raw() : nullptr, _3094 ? _3094->size(0) : 0);
    _checked_ptr_1<double> _ptr__3095(_3095 ? _3095->raw() : nullptr, _3095 ? _3095->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3093;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3094;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3095;
    if (((int)((_3094)->size(0)) != (int)((_3095)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3096 = _3093->getShape();
    _checked_ptr_1<int> _ptr__3096(_3096 ? _3096->raw() : nullptr,_3096 ? _3096->size(0) : 0);
    long long _3097 = ::mosek::fusion::p_Set::size(_3096);
    int _8224 = (int)1;
    int _8225 = (int)((_3094)->size(0));
    for (int _3098 = _8224; _3098 < _8225; ++_3098)
    {
      {
        if ((_ptr__3094[_3098] <= _ptr__3094[(_3098 - (int)1)]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
          }
        }
        {}
      }
    }
    if (((int)((_3094)->size(0)) > (int)0))
    {
      {
        if (((_ptr__3094[(int)0] < (int)0) || (_ptr__3094[((int)((_3094)->size(0)) - (int)1)] > _3097)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
          }
        }
        {}
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< double,1 > > _3100){ return new mosek::fusion::ExprInner(_3099,_3100); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< double,1 > > _3100) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3099,_3100); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< double,1 > > _3100){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3100(_3100 ? _3100->raw() : nullptr, _3100 ? _3100->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3099,::mosek::fusion::p_ExprInner::range((int)((_3100)->size(0))),_3100);
    std::shared_ptr< monty::ndarray< int,1 > > _3101 = _3099->getShape();
    _checked_ptr_1<int> _ptr__3101(_3101 ? _3101->raw() : nullptr,_3101 ? _3101->size(0) : 0);
    if ((((int)((_3101)->size(0)) != (int)1) || (_ptr__3101[(int)0] != (int)((_3100)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3102,    std::shared_ptr< monty::ndarray< int,2 > > _3103,    std::shared_ptr< monty::ndarray< double,1 > > _3104){ return new mosek::fusion::ExprInner(_3102,_3103,_3104); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3102,    std::shared_ptr< monty::ndarray< int,2 > > _3103,    std::shared_ptr< monty::ndarray< double,1 > > _3104) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3102,_3103,_3104); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3102,    std::shared_ptr< monty::ndarray< int,2 > > _3103,    std::shared_ptr< monty::ndarray< double,1 > > _3104){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3104(_3104 ? _3104->raw() : nullptr, _3104 ? _3104->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3102,::mosek::fusion::p_ExprInner::convert(_3102->getShape(),_3103),_3104);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3105,monty::rc_ptr< ::mosek::fusion::WorkStack > _3106,monty::rc_ptr< ::mosek::fusion::WorkStack > _3107) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3105,_3106,_3107); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3105,monty::rc_ptr< ::mosek::fusion::WorkStack > _3106,monty::rc_ptr< ::mosek::fusion::WorkStack > _3107){
  expr->eval(_3106,_3105,_3107);
  int _3108 = _3106->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3109 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3108)));
  _checked_ptr_1<int> _ptr__3109(_3109 ? _3109->raw() : nullptr,_3109 ? _3109->size(0) : 0);
  _3106->popi32(_3108,_3109,(int)0);
  int _3110 = _3106->popi32();
  int _3111 = _3106->popi32();
  bool _3112 = (_3106->popi32() != (int)0);
  int _3113 = _3106->popi32(safe_add( _3110,(int)1 ));
  int _8226;
  bool _8227 = _3112;
  if (_8227)
  {
    _8226 = _3106->popi64(_3110);
  }
  else
  {
    _8226 = (int)0;
  }
  int _3114 = _8226;
  int _3115 = _3106->popi64(_3111);
  int _3116 = _3106->popf64(_3110);
  int _3117 = _3106->popf64(_3111);
  std::shared_ptr< monty::ndarray< int,1 > > _3118 = mosek::fusion::p_WorkStack::_get_impl(_3106)->i32;
  _checked_ptr_1<int> _ptr__3118(_3118 ? _3118->raw() : nullptr,_3118 ? _3118->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3119 = mosek::fusion::p_WorkStack::_get_impl(_3106)->i64;
  _checked_ptr_1<long long> _ptr__3119(_3119 ? _3119->raw() : nullptr,_3119 ? _3119->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3120 = mosek::fusion::p_WorkStack::_get_impl(_3106)->f64;
  _checked_ptr_1<double> _ptr__3120(_3120 ? _3120->raw() : nullptr,_3120 ? _3120->size(0) : 0);
  int _3121 = (int)0;
  if (_3112)
  {
    {
      int _3122 = (int)0;
      int _3123 = (int)0;
      while ( ((_3123 < (int)((vsub)->size(0))) && (_3122 < _3110)) )
      {
        {
          if ((_ptr__3119[safe_add( _3114,_3122 )] < ((*vsub)(_3123))))
          {
            {
              ++ _3122;
            }
          }
          else if((_ptr__3119[safe_add( _3114,_3122 )] > ((*vsub)(_3123))))
          {
            {
              ++ _3123;
            }
          }
          else
          {
            {
              _3121 += (_ptr__3118[safe_add( safe_add( _3113,_3122 ),(int)1 )] - _ptr__3118[safe_add( _3113,_3122 )]);
              ++ _3123;
              ++ _3122;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8228 = (int)0;
      int _8229 = (int)((vsub)->size(0));
      for (int _3124 = _8228; _3124 < _8229; ++_3124)
      {
        {
          _3121 += (_ptr__3118[safe_add( safe_add( _3113,((*vsub)(_3124)) ),(int)1 )] - _ptr__3118[safe_add( _3113,((*vsub)(_3124)) )]);
        }
      }
    }
  }
  int _3125 = _3105->alloci32((int)2);
  int _3126 = _3105->alloci64(_3121);
  int _3127 = _3105->allocf64(_3121);
  int _3128 = _3105->allocf64((int)1);
  _3105->pushi32((int)0);
  _3105->pushi32(_3121);
  _3105->pushi32((int)1);
  _3105->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3129 = mosek::fusion::p_WorkStack::_get_impl(_3105)->i32;
  _checked_ptr_1<int> _ptr__3129(_3129 ? _3129->raw() : nullptr,_3129 ? _3129->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3130 = mosek::fusion::p_WorkStack::_get_impl(_3105)->i64;
  _checked_ptr_1<long long> _ptr__3130(_3130 ? _3130->raw() : nullptr,_3130 ? _3130->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3131 = mosek::fusion::p_WorkStack::_get_impl(_3105)->f64;
  _checked_ptr_1<double> _ptr__3131(_3131 ? _3131->raw() : nullptr,_3131 ? _3131->size(0) : 0);
  _ptr__3129[_3125] = (int)0;
  _ptr__3129[safe_add( _3125,(int)1 )] = _3121;
  int _3132 = (int)0;
  double _3133 = 0.0;
  if (_3112)
  {
    {
      int _3134 = (int)0;
      int _3135 = (int)0;
      while ( ((_3135 < (int)((vsub)->size(0))) && (_3134 < _3110)) )
      {
        {
          if ((_ptr__3119[safe_add( _3114,_3134 )] < ((*vsub)(_3135))))
          {
            {
              ++ _3134;
            }
          }
          else if((_ptr__3119[safe_add( _3114,_3134 )] > ((*vsub)(_3135))))
          {
            {
              ++ _3135;
            }
          }
          else
          {
            {
              int _3136 = _ptr__3118[safe_add( _3113,_3134 )];
              int _3137 = _ptr__3118[safe_add( safe_add( _3113,_3134 ),(int)1 )];
              int _8230 = _3136;
              int _8231 = _3137;
              for (int _3138 = _8230; _3138 < _8231; ++_3138)
              {
                {
                  _ptr__3130[safe_add( _3126,_3132 )] = _ptr__3119[safe_add( _3115,_3138 )];
                  _ptr__3131[safe_add( _3127,_3132 )] = (((*vcof)(_3135)) * _ptr__3120[safe_add( _3117,_3138 )]);
                  ++ _3132;
                }
              }
              _3133 += (((*vcof)(_3135)) * _ptr__3120[safe_add( _3116,_3134 )]);
              ++ _3135;
              ++ _3134;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8232 = (int)0;
      int _8233 = (int)((vsub)->size(0));
      for (int _3139 = _8232; _3139 < _8233; ++_3139)
      {
        {
          int _3140 = _ptr__3118[safe_add( _3113,((*vsub)(_3139)) )];
          int _3141 = _ptr__3118[safe_add( safe_add( _3113,((*vsub)(_3139)) ),(int)1 )];
          int _8234 = _3140;
          int _8235 = _3141;
          for (int _3142 = _8234; _3142 < _8235; ++_3142)
          {
            {
              _ptr__3130[safe_add( _3126,_3132 )] = _ptr__3119[safe_add( _3115,_3142 )];
              _ptr__3131[safe_add( _3127,_3132 )] = (((*vcof)(_3139)) * _ptr__3120[safe_add( _3117,_3142 )]);
              ++ _3132;
            }
          }
          _3133 += (((*vcof)(_3139)) * _ptr__3120[safe_add( _3116,((*vsub)(_3139)) )]);
        }
      }
    }
  }
  _ptr__3131[_3128] = _3133;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3143){
  std::vector<long long> _8236;
  for (int _3144 = (int)0, _8237 = _3143; _3144 < _8237 ; ++_3144)
  {
    _8236.push_back(_3144);
  }
  auto _8238 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8236.size()),_8236.begin(),_8236.end()));
  return _8238;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3145,std::shared_ptr< monty::ndarray< int,2 > > _3146){
  _checked_ptr_1<int> _ptr__3145(_3145 ? _3145->raw() : nullptr, _3145 ? _3145->size(0) : 0);
  int _3147 = (int)((_3145)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3148 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3147)));
  _checked_ptr_1<long long> _ptr__3148(_3148 ? _3148->raw() : nullptr,_3148 ? _3148->size(0) : 0);
  _ptr__3148[(_3147 - (int)1)] = (int)1;
  int _8239 = (int)1;
  int _8240 = _3147;
  for (int _3149 = _8239; _3149 < _8240; ++_3149)
  {
    {
      _ptr__3148[((_3147 - _3149) - (int)1)] = safe_mul( _ptr__3148[(_3147 - _3149)],_ptr__3145[(_3147 - _3149)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3150 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3146)->size(0)))));
  _checked_ptr_1<long long> _ptr__3150(_3150 ? _3150->raw() : nullptr,_3150 ? _3150->size(0) : 0);
  int _8241 = (int)0;
  int _8242 = (int)((_3146)->size(0));
  for (int _3151 = _8241; _3151 < _8242; ++_3151)
  {
    {
      int _8243 = (int)0;
      int _8244 = _3147;
      for (int _3152 = _8243; _3152 < _8244; ++_3152)
      {
        {
          _ptr__3150[_3151] += safe_mul( _ptr__3148[_3152],((*_3146)(_3151,_3152)) );
        }
      }
    }
  }
  return _3150;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3153,    int _3154,    std::shared_ptr< monty::ndarray< int,1 > > _3155,    std::shared_ptr< monty::ndarray< int,1 > > _3156,    std::shared_ptr< monty::ndarray< double,1 > > _3157,    monty::rc_ptr< ::mosek::fusion::Expression > _3158,    int _3159){ return new mosek::fusion::ExprMulDiagRight(_3153,_3154,_3155,_3156,_3157,_3158,_3159); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3153,    int _3154,    std::shared_ptr< monty::ndarray< int,1 > > _3155,    std::shared_ptr< monty::ndarray< int,1 > > _3156,    std::shared_ptr< monty::ndarray< double,1 > > _3157,    monty::rc_ptr< ::mosek::fusion::Expression > _3158,    int _3159) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3153,_3154,_3155,_3156,_3157,_3158,_3159); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3153,    int _3154,    std::shared_ptr< monty::ndarray< int,1 > > _3155,    std::shared_ptr< monty::ndarray< int,1 > > _3156,    std::shared_ptr< monty::ndarray< double,1 > > _3157,    monty::rc_ptr< ::mosek::fusion::Expression > _3158,    int _3159){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3155(_3155 ? _3155->raw() : nullptr, _3155 ? _3155->size(0) : 0);
    _checked_ptr_1<int> _ptr__3156(_3156 ? _3156->raw() : nullptr, _3156 ? _3156->size(0) : 0);
    _checked_ptr_1<double> _ptr__3157(_3157 ? _3157->raw() : nullptr, _3157 ? _3157->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3154)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3153;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3154;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3155;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3156;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3157;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3158;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3160,    int _3161,    std::shared_ptr< monty::ndarray< int,1 > > _3162,    std::shared_ptr< monty::ndarray< int,1 > > _3163,    std::shared_ptr< monty::ndarray< double,1 > > _3164,    monty::rc_ptr< ::mosek::fusion::Expression > _3165){ return new mosek::fusion::ExprMulDiagRight(_3160,_3161,_3162,_3163,_3164,_3165); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3160,    int _3161,    std::shared_ptr< monty::ndarray< int,1 > > _3162,    std::shared_ptr< monty::ndarray< int,1 > > _3163,    std::shared_ptr< monty::ndarray< double,1 > > _3164,    monty::rc_ptr< ::mosek::fusion::Expression > _3165) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3160,_3161,_3162,_3163,_3164,_3165); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3160,    int _3161,    std::shared_ptr< monty::ndarray< int,1 > > _3162,    std::shared_ptr< monty::ndarray< int,1 > > _3163,    std::shared_ptr< monty::ndarray< double,1 > > _3164,    monty::rc_ptr< ::mosek::fusion::Expression > _3165){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3162(_3162 ? _3162->raw() : nullptr, _3162 ? _3162->size(0) : 0);
    _checked_ptr_1<int> _ptr__3163(_3163 ? _3163->raw() : nullptr, _3163 ? _3163->size(0) : 0);
    _checked_ptr_1<double> _ptr__3164(_3164 ? _3164->raw() : nullptr, _3164 ? _3164->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3160,_3161,_3162,_3163,_3164,_3165,::mosek::fusion::p_ExprMulDiagRight::validate(_3160,_3161,_3162,_3163,_3164,_3165));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3166,monty::rc_ptr< ::mosek::fusion::WorkStack > _3167,monty::rc_ptr< ::mosek::fusion::WorkStack > _3168) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3166,_3167,_3168); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3166,monty::rc_ptr< ::mosek::fusion::WorkStack > _3167,monty::rc_ptr< ::mosek::fusion::WorkStack > _3168){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3167,_3166,_3168);
  int _3169 = (int)0;
  int _3170 = (int)99999;
  int _3171 = (int)0;
  bool _3172 = (_3167->peeki32((int)5) != (int)0);
  if (_3172)
  {
    {
      _3171 = _3167->peeki32((int)2);
      _3170 = _3167->alloci32(safe_add( _3171,(int)1 ));
      _3169 += safe_add( _3171,(int)1 );
    }
  }
  {}
  int _3173 = (int)((mval)->size(0));
  int _3174 = _3167->alloci32(_3173);
  int _3175 = _3167->alloci32(safe_add( mdim1,(int)1 ));
  _3169 += safe_add( safe_add( _3173,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3176 = mosek::fusion::p_WorkStack::_get_impl(_3167)->i32;
    _checked_ptr_1<int> _ptr__3176(_3176 ? _3176->raw() : nullptr,_3176 ? _3176->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3177 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3177(_3177 ? _3177->raw() : nullptr,_3177 ? _3177->size(0) : 0);
    {
      int _8245 = (int)0;
      int _8246 = safe_add( mdim1,(int)1 );
      for (int _3178 = _8245; _3178 < _8246; ++_3178)
      {
        {
          _ptr__3176[safe_add( _3175,_3178 )] = (int)0;
        }
      }
      int _8247 = (int)0;
      int _8248 = _3173;
      for (int _3179 = _8247; _3179 < _8248; ++_3179)
      {
        {
          ++ _ptr__3176[safe_add( safe_add( _3175,_ptr__3177[_3179] ),(int)1 )];
        }
      }
      int _8249 = (int)0;
      int _8250 = mdim1;
      for (int _3180 = _8249; _3180 < _8250; ++_3180)
      {
        {
          _ptr__3176[safe_add( safe_add( _3175,_3180 ),(int)1 )] += _ptr__3176[safe_add( _3175,_3180 )];
        }
      }
      int _8251 = (int)0;
      int _8252 = _3173;
      for (int _3181 = _8251; _3181 < _8252; ++_3181)
      {
        {
          _ptr__3176[safe_add( _3174,_ptr__3176[safe_add( _3175,_ptr__3177[_3181] )] )] = _3181;
          ++ _ptr__3176[safe_add( _3175,_ptr__3177[_3181] )];
        }
      }
      int _8253 = (int)0;
      int _8254 = mdim1;
      for (int _3182 = _8253; _3182 < _8254; ++_3182)
      {
        {
          _ptr__3176[(safe_add( _3175,mdim1 ) - _3182)] = _ptr__3176[((safe_add( _3175,mdim1 ) - _3182) - (int)1)];
        }
      }
      _ptr__3176[_3175] = (int)0;
    }
  }
  _3167->popi32(_3169);
  int _3183 = _3167->popi32();
  if ((_3183 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3184 = _3167->popi32();
  int _3185 = _3167->popi32();
  int _3186 = _3167->popi32();
  int _3187 = _3167->popi32();
  bool _3188 = (_3167->popi32() != (int)0);
  int _3189 = _3167->popi32(safe_add( _3186,(int)1 ));
  int _8255;
  bool _8256 = _3188;
  if (_8256)
  {
    _8255 = _3167->popi64(_3186);
  }
  else
  {
    _8255 = (int)9999;
  }
  int _3190 = _8255;
  int _3191 = _3167->popi64(_3187);
  int _3192 = _3167->popf64(_3186);
  int _3193 = _3167->popf64(_3187);
  std::shared_ptr< monty::ndarray< int,1 > > _3194 = mosek::fusion::p_WorkStack::_get_impl(_3167)->i32;
  _checked_ptr_1<int> _ptr__3194(_3194 ? _3194->raw() : nullptr,_3194 ? _3194->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3195 = mosek::fusion::p_WorkStack::_get_impl(_3167)->i64;
  _checked_ptr_1<long long> _ptr__3195(_3195 ? _3195->raw() : nullptr,_3195 ? _3195->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3196 = mosek::fusion::p_WorkStack::_get_impl(_3167)->f64;
  _checked_ptr_1<double> _ptr__3196(_3196 ? _3196->raw() : nullptr,_3196 ? _3196->size(0) : 0);
  if (_3188)
  {
    {
      int _8257 = (int)0;
      int _8258 = safe_add( _3185,(int)1 );
      for (int _3197 = _8257; _3197 < _8258; ++_3197)
      {
        {
          _ptr__3194[safe_add( _3170,_3197 )] = (int)0;
        }
      }
      int _8259 = (int)0;
      int _8260 = _3186;
      for (int _3198 = _8259; _3198 < _8260; ++_3198)
      {
        {
          ++ _ptr__3194[safe_add( safe_add( _3170,(_ptr__3195[safe_add( _3190,_3198 )] / _3184) ),(int)1 )];
        }
      }
      int _8261 = (int)0;
      int _8262 = _3185;
      for (int _3199 = _8261; _3199 < _8262; ++_3199)
      {
        {
          _ptr__3194[safe_add( safe_add( _3170,_3199 ),(int)1 )] += _ptr__3194[safe_add( _3170,_3199 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3200 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3200(_3200 ? _3200->raw() : nullptr,_3200 ? _3200->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3201 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3201(_3201 ? _3201->raw() : nullptr,_3201 ? _3201->size(0) : 0);
      int _3202 = (int)0;
      int _3203 = (int)0;
      {
        int _8263 = (int)0;
        int _8264 = _3185;
        for (int _3204 = _8263; _3204 < _8264; ++_3204)
        {
          {
            int _3205 = _ptr__3194[safe_add( safe_add( _3175,_3204 ),(int)1 )];
            int _3206 = _ptr__3194[safe_add( _3175,_3204 )];
            int _3207 = _ptr__3194[safe_add( safe_add( _3170,_3204 ),(int)1 )];
            int _3208 = _ptr__3194[safe_add( _3170,_3204 )];
            bool _3209 = false;
            while ( ((_3208 < _3207) && (_3206 < _3205)) )
            {
              {
                int _3210 = _ptr__3194[safe_add( _3174,_3206 )];
                long long _3211 = (_ptr__3195[safe_add( _3190,_3208 )] % _3184);
                if ((_ptr__3200[_3210] < _3211))
                {
                  {
                    ++ _3206;
                  }
                }
                else if((_ptr__3200[_3210] > _3211))
                {
                  {
                    ++ _3208;
                  }
                }
                else
                {
                  {
                    _3209 = true;
                    _3202 += (_ptr__3194[safe_add( safe_add( _3189,_3208 ),(int)1 )] - _ptr__3194[safe_add( _3189,_3208 )]);
                    ++ _3208;
                    ++ _3206;
                  }
                }
              }
            }
            if (_3209)
            {
              {
                ++ _3203;
              }
            }
            {}
          }
        }
      }
      bool _3212 = (_3203 < _3185);
      int _3213 = _3166->alloci32(safe_add( _3203,(int)1 ));
      int _3214 = _3166->alloci64(_3202);
      int _3215 = _3166->alloci64(_3203);
      int _3216 = _3166->allocf64(_3202);
      int _3217 = _3166->allocf64(_3203);
      int _8265;
      bool _8266 = _3212;
      if (_8266)
      {
        _8265 = (int)1;
      }
      else
      {
        _8265 = (int)0;
      }
      _3166->pushi32(_8265);
      _3166->pushi32(_3202);
      _3166->pushi32(_3203);
      _3166->pushi32(_3185);
      _3166->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3218 = mosek::fusion::p_WorkStack::_get_impl(_3166)->i32;
      _checked_ptr_1<int> _ptr__3218(_3218 ? _3218->raw() : nullptr,_3218 ? _3218->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3219 = mosek::fusion::p_WorkStack::_get_impl(_3166)->i64;
      _checked_ptr_1<long long> _ptr__3219(_3219 ? _3219->raw() : nullptr,_3219 ? _3219->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3220 = mosek::fusion::p_WorkStack::_get_impl(_3166)->f64;
      _checked_ptr_1<double> _ptr__3220(_3220 ? _3220->raw() : nullptr,_3220 ? _3220->size(0) : 0);
      {
        int _3221 = (int)0;
        int _3222 = (int)0;
        _ptr__3218[_3213] = (int)0;
        int _8267 = (int)0;
        int _8268 = _3185;
        for (int _3223 = _8267; _3223 < _8268; ++_3223)
        {
          {
            int _3224 = _ptr__3194[safe_add( safe_add( _3175,_3223 ),(int)1 )];
            int _3225 = _ptr__3194[safe_add( _3175,_3223 )];
            int _3226 = _ptr__3194[safe_add( safe_add( _3170,_3223 ),(int)1 )];
            int _3227 = _ptr__3194[safe_add( _3170,_3223 )];
            bool _3228 = false;
            double _3229 = 0.0;
            while ( ((_3227 < _3226) && (_3225 < _3224)) )
            {
              {
                int _3230 = _ptr__3194[safe_add( _3174,_3225 )];
                long long _3231 = (_ptr__3195[safe_add( _3190,_3227 )] % _3184);
                if ((_ptr__3200[_3230] < _3231))
                {
                  {
                    ++ _3225;
                  }
                }
                else if((_ptr__3200[_3230] > _3231))
                {
                  {
                    ++ _3227;
                  }
                }
                else
                {
                  {
                    _3228 = true;
                    int _8269 = _ptr__3194[safe_add( _3189,_3227 )];
                    int _8270 = _ptr__3194[safe_add( safe_add( _3189,_3227 ),(int)1 )];
                    for (int _3232 = _8269; _3232 < _8270; ++_3232)
                    {
                      {
                        _ptr__3219[safe_add( _3214,_3222 )] = _ptr__3195[safe_add( _3191,_3232 )];
                        _ptr__3220[safe_add( _3216,_3222 )] = (_ptr__3196[safe_add( _3193,_3232 )] * _ptr__3201[_3230]);
                        ++ _3222;
                      }
                    }
                    _3229 += (_ptr__3196[safe_add( _3192,_3227 )] * _ptr__3201[_3230]);
                    ++ _3227;
                    ++ _3225;
                  }
                }
              }
            }
            if (_3228)
            {
              {
                _ptr__3218[safe_add( safe_add( _3213,_3221 ),(int)1 )] = _3222;
                _ptr__3219[safe_add( _3215,_3221 )] = _3223;
                _ptr__3220[safe_add( _3217,_3221 )] = _3229;
                ++ _3221;
              }
            }
            {}
          }
        }
      }
      if ((!_3212))
      {
        {
          _3166->popi64(_3203);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3233 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3233(_3233 ? _3233->raw() : nullptr,_3233 ? _3233->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3234 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3234(_3234 ? _3234->raw() : nullptr,_3234 ? _3234->size(0) : 0);
      int _3235 = (int)0;
      int _3236 = (int)0;
      {
        int _8271 = (int)0;
        int _8272 = _3185;
        for (int _3237 = _8271; _3237 < _8272; ++_3237)
        {
          {
            bool _3238 = false;
            int _8273 = _ptr__3194[safe_add( _3175,_3237 )];
            int _8274 = _ptr__3194[safe_add( safe_add( _3175,_3237 ),(int)1 )];
            for (int _3239 = _8273; _3239 < _8274; ++_3239)
            {
              {
                int _3240 = _ptr__3194[safe_add( _3174,_3239 )];
                int _3241 = safe_add( safe_mul( _3237,_3184 ),_ptr__3233[_3240] );
                _3236 += (_ptr__3194[safe_add( safe_add( _3189,_3241 ),(int)1 )] - _ptr__3194[safe_add( _3189,_3241 )]);
                if ((_ptr__3194[safe_add( safe_add( _3189,_3241 ),(int)1 )] > _ptr__3194[safe_add( _3189,_3241 )]))
                {
                  {
                    _3238 = true;
                  }
                }
                {}
              }
            }
            if (_3238)
            {
              {
                ++ _3235;
              }
            }
            {}
          }
        }
      }
      bool _3242 = (_3235 < _3185);
      int _3243 = _3166->alloci32(safe_add( _3235,(int)1 ));
      int _3244 = _3166->alloci64(_3236);
      int _3245 = _3166->alloci64(_3235);
      int _3246 = _3166->allocf64(_3236);
      int _3247 = _3166->allocf64(_3235);
      int _8275;
      bool _8276 = _3242;
      if (_8276)
      {
        _8275 = (int)1;
      }
      else
      {
        _8275 = (int)0;
      }
      _3166->pushi32(_8275);
      _3166->pushi32(_3236);
      _3166->pushi32(_3235);
      _3166->pushi32(_3185);
      _3166->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3248 = mosek::fusion::p_WorkStack::_get_impl(_3166)->i32;
      _checked_ptr_1<int> _ptr__3248(_3248 ? _3248->raw() : nullptr,_3248 ? _3248->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3249 = mosek::fusion::p_WorkStack::_get_impl(_3166)->i64;
      _checked_ptr_1<long long> _ptr__3249(_3249 ? _3249->raw() : nullptr,_3249 ? _3249->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3250 = mosek::fusion::p_WorkStack::_get_impl(_3166)->f64;
      _checked_ptr_1<double> _ptr__3250(_3250 ? _3250->raw() : nullptr,_3250 ? _3250->size(0) : 0);
      {
        int _3251 = (int)0;
        int _3252 = (int)0;
        _ptr__3248[_3243] = (int)0;
        int _8277 = (int)0;
        int _8278 = _3185;
        for (int _3253 = _8277; _3253 < _8278; ++_3253)
        {
          {
            bool _3254 = false;
            double _3255 = 0.0;
            int _8279 = _ptr__3194[safe_add( _3175,_3253 )];
            int _8280 = _ptr__3194[safe_add( safe_add( _3175,_3253 ),(int)1 )];
            for (int _3256 = _8279; _3256 < _8280; ++_3256)
            {
              {
                int _3257 = _ptr__3194[safe_add( _3174,_3256 )];
                int _3258 = safe_add( safe_mul( _3253,_3184 ),_ptr__3233[_3257] );
                int _8281 = _ptr__3194[safe_add( _3189,_3258 )];
                int _8282 = _ptr__3194[safe_add( safe_add( _3189,_3258 ),(int)1 )];
                for (int _3259 = _8281; _3259 < _8282; ++_3259)
                {
                  {
                    _3254 = true;
                    _ptr__3249[safe_add( _3244,_3252 )] = _ptr__3195[safe_add( _3191,_3259 )];
                    _ptr__3250[safe_add( _3246,_3252 )] = (_ptr__3196[safe_add( _3193,_3259 )] * _ptr__3234[_3257]);
                    ++ _3252;
                  }
                }
                _3255 += (_ptr__3196[safe_add( _3192,_3258 )] * _ptr__3234[_3257]);
              }
            }
            if (_3254)
            {
              {
                _ptr__3250[safe_add( _3247,_3251 )] = _3255;
                _ptr__3249[safe_add( _3245,_3251 )] = _3253;
                _ptr__3248[safe_add( safe_add( _3243,_3251 ),(int)1 )] = _3252;
                ++ _3251;
              }
            }
            {}
          }
        }
      }
      if ((!_3242))
      {
        {
          _3166->popi64(_3235);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3260,int _3261,std::shared_ptr< monty::ndarray< int,1 > > _3262,std::shared_ptr< monty::ndarray< int,1 > > _3263,std::shared_ptr< monty::ndarray< double,1 > > _3264,monty::rc_ptr< ::mosek::fusion::Expression > _3265){
  _checked_ptr_1<int> _ptr__3262(_3262 ? _3262->raw() : nullptr, _3262 ? _3262->size(0) : 0);
  _checked_ptr_1<int> _ptr__3263(_3263 ? _3263->raw() : nullptr, _3263 ? _3263->size(0) : 0);
  _checked_ptr_1<double> _ptr__3264(_3264 ? _3264->raw() : nullptr, _3264 ? _3264->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3266 = _3265->getShape();
  _checked_ptr_1<int> _ptr__3266(_3266 ? _3266->raw() : nullptr,_3266 ? _3266->size(0) : 0);
  if (((int)((_3266)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3267 = _ptr__3266[(int)0];
  int _3268 = _ptr__3266[(int)1];
  if (((_3260 < (int)0) || ((_3261 < (int)0) || ((_3267 < (int)0) || (_3268 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3260 != _3268) || (_3261 != _3267)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3262)->size(0)) != (int)((_3263)->size(0))) || ((int)((_3262)->size(0)) != (int)((_3264)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3269 = (int)((_3262)->size(0));
  int _8283 = (int)0;
  int _8284 = _3269;
  for (int _3270 = _8283; _3270 < _8284; ++_3270)
  {
    {
      if (((_ptr__3262[_3270] < (int)0) || ((_ptr__3262[_3270] >= _3260) || ((_ptr__3263[_3270] < (int)0) || (_ptr__3263[_3270] >= _3261)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8285 = (int)0;
  int _8286 = (_3269 - (int)1);
  for (int _3271 = _8285; _3271 < _8286; ++_3271)
  {
    {
      if (((_ptr__3262[_3271] > _ptr__3262[safe_add( _3271,(int)1 )]) || ((_ptr__3262[_3271] == _ptr__3262[safe_add( _3271,(int)1 )]) && (_ptr__3263[_3271] >= _ptr__3263[safe_add( _3271,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8287 = (int)0;
  int _8288 = _3269;
  for (int _3272 = _8287; _3272 < _8288; ++_3272)
  {
    {
      if (((_ptr__3262[_3272] < (int)0) || ((_ptr__3262[_3272] >= _3260) || ((_ptr__3263[_3272] < (int)0) || (_ptr__3263[_3272] >= _3261)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3273,    int _3274,    std::shared_ptr< monty::ndarray< int,1 > > _3275,    std::shared_ptr< monty::ndarray< int,1 > > _3276,    std::shared_ptr< monty::ndarray< double,1 > > _3277,    monty::rc_ptr< ::mosek::fusion::Expression > _3278,    int _3279){ return new mosek::fusion::ExprMulDiagLeft(_3273,_3274,_3275,_3276,_3277,_3278,_3279); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3273,    int _3274,    std::shared_ptr< monty::ndarray< int,1 > > _3275,    std::shared_ptr< monty::ndarray< int,1 > > _3276,    std::shared_ptr< monty::ndarray< double,1 > > _3277,    monty::rc_ptr< ::mosek::fusion::Expression > _3278,    int _3279) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3273,_3274,_3275,_3276,_3277,_3278,_3279); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3273,    int _3274,    std::shared_ptr< monty::ndarray< int,1 > > _3275,    std::shared_ptr< monty::ndarray< int,1 > > _3276,    std::shared_ptr< monty::ndarray< double,1 > > _3277,    monty::rc_ptr< ::mosek::fusion::Expression > _3278,    int _3279){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3275(_3275 ? _3275->raw() : nullptr, _3275 ? _3275->size(0) : 0);
    _checked_ptr_1<int> _ptr__3276(_3276 ? _3276->raw() : nullptr, _3276 ? _3276->size(0) : 0);
    _checked_ptr_1<double> _ptr__3277(_3277 ? _3277->raw() : nullptr, _3277 ? _3277->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3273)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3273;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3274;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3275;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3276;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3277;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3278;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3280,    int _3281,    std::shared_ptr< monty::ndarray< int,1 > > _3282,    std::shared_ptr< monty::ndarray< int,1 > > _3283,    std::shared_ptr< monty::ndarray< double,1 > > _3284,    monty::rc_ptr< ::mosek::fusion::Expression > _3285){ return new mosek::fusion::ExprMulDiagLeft(_3280,_3281,_3282,_3283,_3284,_3285); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3280,    int _3281,    std::shared_ptr< monty::ndarray< int,1 > > _3282,    std::shared_ptr< monty::ndarray< int,1 > > _3283,    std::shared_ptr< monty::ndarray< double,1 > > _3284,    monty::rc_ptr< ::mosek::fusion::Expression > _3285) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3280,_3281,_3282,_3283,_3284,_3285); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3280,    int _3281,    std::shared_ptr< monty::ndarray< int,1 > > _3282,    std::shared_ptr< monty::ndarray< int,1 > > _3283,    std::shared_ptr< monty::ndarray< double,1 > > _3284,    monty::rc_ptr< ::mosek::fusion::Expression > _3285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3282(_3282 ? _3282->raw() : nullptr, _3282 ? _3282->size(0) : 0);
    _checked_ptr_1<int> _ptr__3283(_3283 ? _3283->raw() : nullptr, _3283 ? _3283->size(0) : 0);
    _checked_ptr_1<double> _ptr__3284(_3284 ? _3284->raw() : nullptr, _3284 ? _3284->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3280,_3281,_3282,_3283,_3284,_3285,::mosek::fusion::p_ExprMulDiagLeft::validate(_3280,_3281,_3282,_3283,_3284,_3285));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3286,monty::rc_ptr< ::mosek::fusion::WorkStack > _3287,monty::rc_ptr< ::mosek::fusion::WorkStack > _3288) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3286,_3287,_3288); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3286,monty::rc_ptr< ::mosek::fusion::WorkStack > _3287,monty::rc_ptr< ::mosek::fusion::WorkStack > _3288){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3287,_3286,_3288);
  if ((_3287->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3289 = (int)((msubi)->size(0));
  int _3290 = (int)9999;
  int _3291 = (int)9999;
  int _3292 = (int)0;
  int _3293 = _3287->peeki32((int)5);
  if ((_3293 != (int)0))
  {
    {
      int _3294 = _3287->peeki32((int)1);
      int _3295 = _3287->peeki32((int)3);
      _3290 = _3287->alloci32(safe_add( _3294,(int)1 ));
      _3291 = _3287->alloci32(_3295);
      _3292 += safe_add( safe_add( _3295,_3294 ),(int)1 );
    }
  }
  {}
  int _3296 = _3287->alloci32(safe_add( mdim0,(int)1 ));
  _3292 += safe_add( mdim0,(int)1 );
  _3287->popi32(_3292);
  std::shared_ptr< monty::ndarray< int,1 > > _3297 = mosek::fusion::p_WorkStack::_get_impl(_3287)->i32;
  _checked_ptr_1<int> _ptr__3297(_3297 ? _3297->raw() : nullptr,_3297 ? _3297->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3298 = mosek::fusion::p_WorkStack::_get_impl(_3287)->i64;
  _checked_ptr_1<long long> _ptr__3298(_3298 ? _3298->raw() : nullptr,_3298 ? _3298->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3299 = mosek::fusion::p_WorkStack::_get_impl(_3287)->f64;
  _checked_ptr_1<double> _ptr__3299(_3299 ? _3299->raw() : nullptr,_3299 ? _3299->size(0) : 0);
  int _8289 = (int)0;
  int _8290 = safe_add( mdim0,(int)1 );
  for (int _3300 = _8289; _3300 < _8290; ++_3300)
  {
    {
      _ptr__3297[safe_add( _3296,_3300 )] = (int)0;
    }
  }
  int _8291 = (int)0;
  int _8292 = _3289;
  for (int _3301 = _8291; _3301 < _8292; ++_3301)
  {
    {
      ++ _ptr__3297[safe_add( safe_add( _3296,((*msubi)(_3301)) ),(int)1 )];
    }
  }
  int _8293 = (int)0;
  int _8294 = mdim0;
  for (int _3302 = _8293; _3302 < _8294; ++_3302)
  {
    {
      _ptr__3297[safe_add( safe_add( _3296,_3302 ),(int)1 )] += _ptr__3297[safe_add( _3296,_3302 )];
    }
  }
  int _3303 = _3287->popi32();
  int _3304 = _3287->popi32();
  int _3305 = _3287->popi32();
  int _3306 = _3287->popi32();
  int _3307 = _3287->popi32();
  bool _3308 = (_3287->popi32() != (int)0);
  int _3309 = _3287->popi32(safe_add( _3306,(int)1 ));
  int _8295;
  bool _8296 = _3308;
  if (_8296)
  {
    _8295 = _3287->popi64(_3306);
  }
  else
  {
    _8295 = (int)9999;
  }
  int _3310 = _8295;
  int _3311 = _3287->popi64(_3307);
  int _3312 = _3287->popf64(_3306);
  int _3313 = _3287->popf64(_3307);
  if ((!_3308))
  {
    {
      int _3314 = (int)((msubi)->size(0));
      int _3315 = (int)0;
      int _8297 = (int)0;
      int _8298 = mdim0;
      for (int _3316 = _8297; _3316 < _8298; ++_3316)
      {
        {
          if ((_ptr__3297[safe_add( _3296,_3316 )] < _ptr__3297[safe_add( safe_add( _3296,_3316 ),(int)1 )]))
          {
            {
              ++ _3315;
            }
          }
          {}
        }
      }
      bool _3317 = (_3315 < mdim0);
      int _3318 = _3286->alloci32(safe_add( _3315,(int)1 ));
      int _3319 = _3286->alloci64(_3314);
      int _3320 = _3286->alloci64(_3315);
      int _3321 = _3286->allocf64(_3314);
      int _3322 = _3286->allocf64(_3315);
      int _8299;
      bool _8300 = _3317;
      if (_8300)
      {
        _8299 = (int)1;
      }
      else
      {
        _8299 = (int)0;
      }
      _3286->pushi32(_8299);
      _3286->pushi32(_3314);
      _3286->pushi32(_3315);
      _3286->pushi32(mdim0);
      _3286->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3323 = mosek::fusion::p_WorkStack::_get_impl(_3286)->i32;
      _checked_ptr_1<int> _ptr__3323(_3323 ? _3323->raw() : nullptr,_3323 ? _3323->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3324 = mosek::fusion::p_WorkStack::_get_impl(_3286)->i64;
      _checked_ptr_1<long long> _ptr__3324(_3324 ? _3324->raw() : nullptr,_3324 ? _3324->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3325 = mosek::fusion::p_WorkStack::_get_impl(_3286)->f64;
      _checked_ptr_1<double> _ptr__3325(_3325 ? _3325->raw() : nullptr,_3325 ? _3325->size(0) : 0);
      {
        _ptr__3323[_3318] = (int)0;
        int _3326 = (int)0;
        int _3327 = (int)0;
        int _8301 = (int)0;
        int _8302 = mdim0;
        for (int _3328 = _8301; _3328 < _8302; ++_3328)
        {
          {
            if ((_ptr__3297[safe_add( _3296,_3328 )] < _ptr__3297[safe_add( safe_add( _3296,_3328 ),(int)1 )]))
            {
              {
                int _3329 = (int)0;
                int _8303 = _ptr__3297[safe_add( _3296,_3328 )];
                int _8304 = _ptr__3297[safe_add( safe_add( _3296,_3328 ),(int)1 )];
                for (int _3330 = _8303; _3330 < _8304; ++_3330)
                {
                  {
                    int _3331 = ((*msubj)(_3330));
                    int _3332 = safe_add( safe_mul( _3331,_3304 ),_3328 );
                    int _8305 = _ptr__3297[safe_add( _3309,_3332 )];
                    int _8306 = _ptr__3297[safe_add( safe_add( _3309,_3332 ),(int)1 )];
                    for (int _3333 = _8305; _3333 < _8306; ++_3333)
                    {
                      {
                        _ptr__3324[safe_add( _3319,_3327 )] = _ptr__3298[safe_add( _3311,_3333 )];
                        _ptr__3325[safe_add( _3321,_3327 )] = (_ptr__3299[safe_add( _3313,_3333 )] * ((*mval)(_3330)));
                        ++ _3327;
                      }
                    }
                  }
                }
                _ptr__3325[safe_add( _3322,_3326 )] = _3329;
                _ptr__3324[safe_add( _3320,_3326 )] = _3328;
                _ptr__3323[safe_add( safe_add( _3318,_3326 ),(int)1 )] = _3327;
                ++ _3326;
              }
            }
            {}
          }
        }
      }
      if ((!_3317))
      {
        {
          _3286->popi64(_3315);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8307 = (int)0;
      int _8308 = safe_add( _3304,(int)1 );
      for (int _3334 = _8307; _3334 < _8308; ++_3334)
      {
        {
          _ptr__3297[safe_add( _3290,_3334 )] = (int)0;
        }
      }
      int _8309 = (int)0;
      int _8310 = _3306;
      for (int _3335 = _8309; _3335 < _8310; ++_3335)
      {
        {
          ++ _ptr__3297[safe_add( safe_add( _3290,(_ptr__3298[safe_add( _3310,_3335 )] % _3304) ),(int)1 )];
        }
      }
      int _8311 = (int)0;
      int _8312 = _3304;
      for (int _3336 = _8311; _3336 < _8312; ++_3336)
      {
        {
          _ptr__3297[safe_add( safe_add( _3290,_3336 ),(int)1 )] += _ptr__3297[safe_add( _3290,_3336 )];
        }
      }
      int _8313 = (int)0;
      int _8314 = _3306;
      for (int _3337 = _8313; _3337 < _8314; ++_3337)
      {
        {
          long long _3338 = (_ptr__3298[safe_add( _3310,_3337 )] % _3304);
          _ptr__3297[safe_add( _3291,_ptr__3297[safe_add( _3290,_3338 )] )] = _3337;
          ++ _ptr__3297[safe_add( _3290,_3338 )];
        }
      }
      int _8315 = (int)0;
      int _8316 = _3304;
      for (int _3339 = _8315; _3339 < _8316; ++_3339)
      {
        {
          _ptr__3297[(safe_add( _3290,_3304 ) - _3339)] = _ptr__3297[((safe_add( _3290,_3304 ) - _3339) - (int)1)];
        }
      }
      _ptr__3297[_3290] = (int)0;
      int _3340 = (int)0;
      int _3341 = (int)0;
      {
        int _8317 = (int)0;
        int _8318 = mdim0;
        for (int _3342 = _8317; _3342 < _8318; ++_3342)
        {
          {
            int _3343 = _ptr__3297[safe_add( safe_add( _3290,_3342 ),(int)1 )];
            int _3344 = _ptr__3297[safe_add( _3290,_3342 )];
            int _3345 = _ptr__3297[safe_add( safe_add( _3296,_3342 ),(int)1 )];
            int _3346 = _ptr__3297[safe_add( _3296,_3342 )];
            bool _3347 = false;
            while ( ((_3346 < _3345) && (_3344 < _3343)) )
            {
              {
                int _3348 = _ptr__3297[safe_add( _3291,_3344 )];
                long long _3349 = (_ptr__3298[safe_add( _3310,_3348 )] / _3304);
                if ((((*msubj)(_3346)) < _3349))
                {
                  {
                    ++ _3346;
                  }
                }
                else if((((*msubj)(_3346)) > _3349))
                {
                  {
                    ++ _3344;
                  }
                }
                else
                {
                  {
                    _3347 = true;
                    _3341 += (_ptr__3297[safe_add( safe_add( _3309,_3348 ),(int)1 )] - _ptr__3297[safe_add( _3309,_3348 )]);
                    ++ _3346;
                    ++ _3344;
                  }
                }
              }
            }
            if (_3347)
            {
              {
                ++ _3340;
              }
            }
            {}
          }
        }
      }
      int _3350 = _3340;
      int _3351 = _3341;
      bool _3352 = (_3350 < mdim0);
      int _3353 = _3286->alloci32(safe_add( _3350,(int)1 ));
      int _3354 = _3286->alloci64(_3351);
      int _3355 = _3286->alloci64(_3350);
      int _3356 = _3286->allocf64(_3351);
      int _3357 = _3286->allocf64(_3350);
      int _8319;
      bool _8320 = _3352;
      if (_8320)
      {
        _8319 = (int)1;
      }
      else
      {
        _8319 = (int)0;
      }
      _3286->pushi32(_8319);
      _3286->pushi32(_3351);
      _3286->pushi32(_3350);
      _3286->pushi32(mdim0);
      _3286->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3358 = mosek::fusion::p_WorkStack::_get_impl(_3286)->i32;
      _checked_ptr_1<int> _ptr__3358(_3358 ? _3358->raw() : nullptr,_3358 ? _3358->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3359 = mosek::fusion::p_WorkStack::_get_impl(_3286)->i64;
      _checked_ptr_1<long long> _ptr__3359(_3359 ? _3359->raw() : nullptr,_3359 ? _3359->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3360 = mosek::fusion::p_WorkStack::_get_impl(_3286)->f64;
      _checked_ptr_1<double> _ptr__3360(_3360 ? _3360->raw() : nullptr,_3360 ? _3360->size(0) : 0);
      {
        _ptr__3358[_3353] = (int)0;
        int _3361 = (int)0;
        int _3362 = (int)0;
        int _8321 = (int)0;
        int _8322 = mdim0;
        for (int _3363 = _8321; _3363 < _8322; ++_3363)
        {
          {
            int _3364 = _ptr__3297[safe_add( safe_add( _3290,_3363 ),(int)1 )];
            int _3365 = _ptr__3297[safe_add( _3290,_3363 )];
            int _3366 = _ptr__3297[safe_add( safe_add( _3296,_3363 ),(int)1 )];
            int _3367 = _ptr__3297[safe_add( _3296,_3363 )];
            bool _3368 = false;
            double _3369 = 0.0;
            while ( ((_3367 < _3366) && (_3365 < _3364)) )
            {
              {
                int _3370 = _ptr__3297[safe_add( _3291,_3365 )];
                long long _3371 = (_ptr__3298[safe_add( _3310,_3370 )] / _3304);
                if ((((*msubj)(_3367)) < _3371))
                {
                  {
                    ++ _3367;
                  }
                }
                else if((((*msubj)(_3367)) > _3371))
                {
                  {
                    ++ _3365;
                  }
                }
                else
                {
                  {
                    _3368 = true;
                    int _8323 = _ptr__3297[safe_add( _3309,_3370 )];
                    int _8324 = _ptr__3297[safe_add( safe_add( _3309,_3370 ),(int)1 )];
                    for (int _3372 = _8323; _3372 < _8324; ++_3372)
                    {
                      {
                        _ptr__3359[safe_add( _3354,_3362 )] = _ptr__3298[safe_add( _3311,_3372 )];
                        _ptr__3360[safe_add( _3356,_3362 )] = (_ptr__3299[safe_add( _3313,_3372 )] * ((*mval)(_3367)));
                        ++ _3362;
                      }
                    }
                    _3369 += _ptr__3299[safe_add( _3312,_3370 )];
                    ++ _3367;
                    ++ _3365;
                  }
                }
              }
            }
            if (_3368)
            {
              {
                _ptr__3359[safe_add( _3355,_3361 )] = _3363;
                _ptr__3360[safe_add( _3357,_3361 )] = (_3369 * ((*mval)(_3367)));
                _ptr__3358[safe_add( safe_add( _3353,_3361 ),(int)1 )] = _3362;
                ++ _3361;
              }
            }
            {}
          }
        }
      }
      if ((!_3352))
      {
        {
          _3286->popi64(_3350);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3373,int _3374,std::shared_ptr< monty::ndarray< int,1 > > _3375,std::shared_ptr< monty::ndarray< int,1 > > _3376,std::shared_ptr< monty::ndarray< double,1 > > _3377,monty::rc_ptr< ::mosek::fusion::Expression > _3378){
  _checked_ptr_1<int> _ptr__3375(_3375 ? _3375->raw() : nullptr, _3375 ? _3375->size(0) : 0);
  _checked_ptr_1<int> _ptr__3376(_3376 ? _3376->raw() : nullptr, _3376 ? _3376->size(0) : 0);
  _checked_ptr_1<double> _ptr__3377(_3377 ? _3377->raw() : nullptr, _3377 ? _3377->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3379 = _3378->getShape();
  _checked_ptr_1<int> _ptr__3379(_3379 ? _3379->raw() : nullptr,_3379 ? _3379->size(0) : 0);
  if (((int)((_3379)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3380 = _ptr__3379[(int)0];
  int _3381 = _ptr__3379[(int)1];
  if (((_3373 < (int)0) || (_3374 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3374 != _3380) || (_3373 != _3381)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3375)->size(0)) != (int)((_3376)->size(0))) || ((int)((_3375)->size(0)) != (int)((_3377)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3382 = (int)((_3375)->size(0));
  int _8325 = (int)0;
  int _8326 = _3382;
  for (int _3383 = _8325; _3383 < _8326; ++_3383)
  {
    {
      if (((_ptr__3375[_3383] < (int)0) || ((_ptr__3375[_3383] >= _3373) || ((_ptr__3376[_3383] < (int)0) || (_ptr__3376[_3383] >= _3374)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8327 = (int)0;
  int _8328 = (_3382 - (int)1);
  for (int _3384 = _8327; _3384 < _8328; ++_3384)
  {
    {
      if (((_ptr__3375[_3384] > _ptr__3375[safe_add( _3384,(int)1 )]) || ((_ptr__3375[_3384] == _ptr__3375[safe_add( _3384,(int)1 )]) && (_ptr__3376[_3384] >= _ptr__3376[safe_add( _3384,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8329 = (int)0;
  int _8330 = _3382;
  for (int _3385 = _8329; _3385 < _8330; ++_3385)
  {
    {
      if (((_ptr__3375[_3385] < (int)0) || ((_ptr__3375[_3385] >= _3373) || ((_ptr__3376[_3385] < (int)0) || (_ptr__3376[_3385] >= _3374)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3386,    std::shared_ptr< monty::ndarray< long long,1 > > _3387,    monty::rc_ptr< ::mosek::fusion::Expression > _3388){ return new mosek::fusion::ExprMulElement(_3386,_3387,_3388); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3386,    std::shared_ptr< monty::ndarray< long long,1 > > _3387,    monty::rc_ptr< ::mosek::fusion::Expression > _3388) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3386,_3387,_3388); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3386,    std::shared_ptr< monty::ndarray< long long,1 > > _3387,    monty::rc_ptr< ::mosek::fusion::Expression > _3388){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3386(_3386 ? _3386->raw() : nullptr, _3386 ? _3386->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3387(_3387 ? _3387->raw() : nullptr, _3387 ? _3387->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3386,_3387,_3388,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3389 = _3388->getShape();
    _checked_ptr_1<int> _ptr__3389(_3389 ? _3389->raw() : nullptr,_3389 ? _3389->size(0) : 0);
    if (((int)((_3386)->size(0)) != (int)((_3387)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3390 = ::mosek::fusion::p_Set::size(_3389);
    int _8331 = (int)0;
    int _8332 = (int)((_3387)->size(0));
    for (int _3391 = _8331; _3391 < _8332; ++_3391)
    {
      {
        if (((_ptr__3387[_3391] < (int)0) || (_ptr__3387[_3391] >= _3390)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
          }
        }
        {}
      }
    }
    int _8333 = (int)0;
    int _8334 = ((int)((_3387)->size(0)) - (int)1);
    for (int _3392 = _8333; _3392 < _8334; ++_3392)
    {
      {
        if ((_ptr__3387[_3392] >= _ptr__3387[safe_add( _3392,(int)1 )]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3393,    std::shared_ptr< monty::ndarray< long long,1 > > _3394,    monty::rc_ptr< ::mosek::fusion::Expression > _3395,    int _3396){ return new mosek::fusion::ExprMulElement(_3393,_3394,_3395,_3396); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3393,    std::shared_ptr< monty::ndarray< long long,1 > > _3394,    monty::rc_ptr< ::mosek::fusion::Expression > _3395,    int _3396) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3393,_3394,_3395,_3396); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3393,    std::shared_ptr< monty::ndarray< long long,1 > > _3394,    monty::rc_ptr< ::mosek::fusion::Expression > _3395,    int _3396){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3393(_3393 ? _3393->raw() : nullptr, _3393 ? _3393->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3394(_3394 ? _3394->raw() : nullptr, _3394 ? _3394->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3395->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3395;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3393;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3394;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3397,monty::rc_ptr< ::mosek::fusion::WorkStack > _3398,monty::rc_ptr< ::mosek::fusion::WorkStack > _3399) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3397,_3398,_3399); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3397,monty::rc_ptr< ::mosek::fusion::WorkStack > _3398,monty::rc_ptr< ::mosek::fusion::WorkStack > _3399){
  expr->eval(_3398,_3397,_3399);
  int _3400 = _3398->popi32();
  int _3401 = _3398->popi32(_3400);
  int _3402 = _3398->popi32();
  int _3403 = _3398->popi32();
  bool _3404 = (_3398->popi32() != (int)0);
  int _3405 = _3398->popi32(safe_add( _3402,(int)1 ));
  int _8335;
  bool _8336 = _3404;
  if (_8336)
  {
    _8335 = _3398->popi64(_3402);
  }
  else
  {
    _8335 = (-(int)1);
  }
  int _3406 = _8335;
  int _3407 = _3398->popi64(_3403);
  int _3408 = _3398->popf64(_3402);
  int _3409 = _3398->popf64(_3403);
  std::shared_ptr< monty::ndarray< int,1 > > _3410 = mosek::fusion::p_WorkStack::_get_impl(_3398)->i32;
  _checked_ptr_1<int> _ptr__3410(_3410 ? _3410->raw() : nullptr,_3410 ? _3410->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3411 = mosek::fusion::p_WorkStack::_get_impl(_3398)->i64;
  _checked_ptr_1<long long> _ptr__3411(_3411 ? _3411->raw() : nullptr,_3411 ? _3411->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3412 = mosek::fusion::p_WorkStack::_get_impl(_3398)->f64;
  _checked_ptr_1<double> _ptr__3412(_3412 ? _3412->raw() : nullptr,_3412 ? _3412->size(0) : 0);
  int _3413 = (int)0;
  int _3414 = (int)0;
  if ((!_3404))
  {
    {
      _3414 = (int)((msp)->size(0));
      int _8337 = (int)0;
      int _8338 = (int)((msp)->size(0));
      for (int _3415 = _8337; _3415 < _8338; ++_3415)
      {
        {
          _3413 += (_ptr__3410[safe_add( safe_add( _3405,((*msp)(_3415)) ),(int)1 )] - _ptr__3410[safe_add( _3405,((*msp)(_3415)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3416 = (int)((msp)->size(0));
      int _3417 = (int)0;
      int _3418 = _3402;
      int _3419 = (int)0;
      while ( ((_3417 < _3416) && (_3419 < _3418)) )
      {
        {
          if ((((*msp)(_3417)) < _ptr__3411[safe_add( _3406,_3419 )]))
          {
            {
              ++ _3417;
            }
          }
          else if((((*msp)(_3417)) > _ptr__3411[safe_add( _3406,_3419 )]))
          {
            {
              ++ _3419;
            }
          }
          else
          {
            {
              _3413 += (_ptr__3410[safe_add( safe_add( _3405,_3419 ),(int)1 )] - _ptr__3410[safe_add( _3405,_3419 )]);
              ++ _3417;
              ++ _3419;
              ++ _3414;
            }
          }
        }
      }
    }
  }
  int _3420 = _3397->alloci32(safe_add( _3414,(int)1 ));
  int _3421 = _3397->alloci64(_3413);
  int _3422 = _3397->alloci64(_3414);
  int _3423 = _3397->allocf64(_3413);
  int _3424 = _3397->allocf64(_3414);
  int _3425 = (int)1;
  int _8339 = (int)0;
  int _8340 = _3400;
  for (int _3426 = _8339; _3426 < _8340; ++_3426)
  {
    {
      _3425 *= _ptr__3410[safe_add( _3401,_3426 )];
    }
  }
  bool _3427 = (_3414 < _3425);
  int _8341;
  bool _8342 = _3427;
  if (_8342)
  {
    _8341 = (int)1;
  }
  else
  {
    _8341 = (int)0;
  }
  _3397->pushi32(_8341);
  _3397->pushi32(_3413);
  _3397->pushi32(_3414);
  int _3428 = _3397->alloci32(_3400);
  _3397->pushi32(_3400);
  std::shared_ptr< monty::ndarray< int,1 > > _3429 = mosek::fusion::p_WorkStack::_get_impl(_3397)->i32;
  _checked_ptr_1<int> _ptr__3429(_3429 ? _3429->raw() : nullptr,_3429 ? _3429->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3430 = mosek::fusion::p_WorkStack::_get_impl(_3397)->i64;
  _checked_ptr_1<long long> _ptr__3430(_3430 ? _3430->raw() : nullptr,_3430 ? _3430->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3431 = mosek::fusion::p_WorkStack::_get_impl(_3397)->f64;
  _checked_ptr_1<double> _ptr__3431(_3431 ? _3431->raw() : nullptr,_3431 ? _3431->size(0) : 0);
  {
    int _3432 = (int)0;
    int _3433 = (int)0;
    _ptr__3429[_3420] = (int)0;
    int _8343 = (int)0;
    int _8344 = _3400;
    for (int _3434 = _8343; _3434 < _8344; ++_3434)
    {
      {
        _ptr__3429[safe_add( _3428,_3434 )] = _ptr__3410[safe_add( _3401,_3434 )];
      }
    }
    if ((!_3404))
    {
      {
        int _8345 = (int)0;
        int _8346 = (int)((msp)->size(0));
        for (int _3435 = _8345; _3435 < _8346; ++_3435)
        {
          {
            int _3436 = _ptr__3410[safe_add( _3405,((*msp)(_3435)) )];
            int _3437 = _ptr__3410[safe_add( safe_add( _3405,((*msp)(_3435)) ),(int)1 )];
            int _8347 = _3436;
            int _8348 = _3437;
            for (int _3438 = _8347; _3438 < _8348; ++_3438)
            {
              {
                _ptr__3430[safe_add( _3421,_3433 )] = _ptr__3411[safe_add( _3407,_3438 )];
                _ptr__3431[safe_add( _3423,_3433 )] = (_ptr__3412[safe_add( _3409,_3438 )] * ((*mcof)(_3435)));
                ++ _3433;
              }
            }
            _ptr__3429[safe_add( safe_add( _3420,_3435 ),(int)1 )] = _3433;
            _ptr__3431[safe_add( _3424,_3435 )] = (_ptr__3412[safe_add( _3408,((*msp)(_3435)) )] * ((*mcof)(_3435)));
            _ptr__3430[safe_add( _3422,_3435 )] = ((*msp)(_3435));
          }
        }
      }
    }
    else
    {
      {
        int _3439 = (int)((msp)->size(0));
        int _3440 = (int)0;
        int _3441 = _3402;
        int _3442 = (int)0;
        while ( ((_3440 < _3439) && (_3442 < _3441)) )
        {
          {
            if ((((*msp)(_3440)) < _ptr__3411[safe_add( _3406,_3442 )]))
            {
              {
                ++ _3440;
              }
            }
            else if((((*msp)(_3440)) > _ptr__3411[safe_add( _3406,_3442 )]))
            {
              {
                ++ _3442;
              }
            }
            else
            {
              {
                int _3443 = _ptr__3410[safe_add( _3405,_3442 )];
                int _3444 = _ptr__3410[safe_add( safe_add( _3405,_3442 ),(int)1 )];
                int _8349 = _3443;
                int _8350 = _3444;
                for (int _3445 = _8349; _3445 < _8350; ++_3445)
                {
                  {
                    _ptr__3430[safe_add( _3421,_3433 )] = _ptr__3411[safe_add( _3407,_3445 )];
                    _ptr__3431[safe_add( _3421,_3433 )] = (_ptr__3412[safe_add( _3407,_3445 )] * ((*mcof)(_3440)));
                    ++ _3433;
                  }
                }
                _ptr__3429[safe_add( safe_add( _3420,_3432 ),(int)1 )] = _3433;
                _ptr__3431[safe_add( _3424,_3432 )] = (_ptr__3412[safe_add( _3408,_3442 )] * ((*mcof)(_3440)));
                _ptr__3430[safe_add( _3422,_3432 )] = ((*msp)(_3440));
                ++ _3432;
                ++ _3440;
                ++ _3442;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3427))
  {
    {
      _3397->popi64(_3414);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3446,    monty::rc_ptr< ::mosek::fusion::Expression > _3447){ return new mosek::fusion::ExprMulScalarConst(_3446,_3447); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3446,    monty::rc_ptr< ::mosek::fusion::Expression > _3447) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3446,_3447); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3446,    monty::rc_ptr< ::mosek::fusion::Expression > _3447){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3447->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3446;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3447;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3448,monty::rc_ptr< ::mosek::fusion::WorkStack > _3449,monty::rc_ptr< ::mosek::fusion::WorkStack > _3450) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3448,_3449,_3450); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3448,monty::rc_ptr< ::mosek::fusion::WorkStack > _3449,monty::rc_ptr< ::mosek::fusion::WorkStack > _3450){
  expr->eval(_3448,_3449,_3450);
  int _3451 = _3448->peeki32((int)0);
  int _3452 = _3448->peeki32(safe_add( _3451,(int)1 ));
  int _3453 = _3448->peeki32(safe_add( _3451,(int)2 ));
  int _3454 = (mosek::fusion::p_WorkStack::_get_impl(_3448)->pf64 - _3452);
  int _3455 = (_3454 - _3453);
  std::shared_ptr< monty::ndarray< double,1 > > _3456 = mosek::fusion::p_WorkStack::_get_impl(_3448)->f64;
  _checked_ptr_1<double> _ptr__3456(_3456 ? _3456->raw() : nullptr,_3456 ? _3456->size(0) : 0);
  int _8351 = (int)0;
  int _8352 = safe_add( _3453,_3452 );
  for (int _3457 = _8351; _3457 < _8352; ++_3457)
  {
    {
      _ptr__3456[safe_add( _3455,_3457 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3458,    int _3459,    std::shared_ptr< monty::ndarray< int,1 > > _3460,    std::shared_ptr< monty::ndarray< int,1 > > _3461,    std::shared_ptr< monty::ndarray< double,1 > > _3462,    monty::rc_ptr< ::mosek::fusion::Expression > _3463,    int _3464){ return new mosek::fusion::ExprScalarMul(_3458,_3459,_3460,_3461,_3462,_3463,_3464); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3458,    int _3459,    std::shared_ptr< monty::ndarray< int,1 > > _3460,    std::shared_ptr< monty::ndarray< int,1 > > _3461,    std::shared_ptr< monty::ndarray< double,1 > > _3462,    monty::rc_ptr< ::mosek::fusion::Expression > _3463,    int _3464) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3458,_3459,_3460,_3461,_3462,_3463,_3464); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3458,    int _3459,    std::shared_ptr< monty::ndarray< int,1 > > _3460,    std::shared_ptr< monty::ndarray< int,1 > > _3461,    std::shared_ptr< monty::ndarray< double,1 > > _3462,    monty::rc_ptr< ::mosek::fusion::Expression > _3463,    int _3464){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3460(_3460 ? _3460->raw() : nullptr, _3460 ? _3460->size(0) : 0);
    _checked_ptr_1<int> _ptr__3461(_3461 ? _3461->raw() : nullptr, _3461 ? _3461->size(0) : 0);
    _checked_ptr_1<double> _ptr__3462(_3462 ? _3462->raw() : nullptr, _3462 ? _3462->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3458),(int)(_3459)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3458;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3459;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3460;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3461;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3462;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3463;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3465,    int _3466,    std::shared_ptr< monty::ndarray< int,1 > > _3467,    std::shared_ptr< monty::ndarray< int,1 > > _3468,    std::shared_ptr< monty::ndarray< double,1 > > _3469,    monty::rc_ptr< ::mosek::fusion::Expression > _3470){ return new mosek::fusion::ExprScalarMul(_3465,_3466,_3467,_3468,_3469,_3470); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3465,    int _3466,    std::shared_ptr< monty::ndarray< int,1 > > _3467,    std::shared_ptr< monty::ndarray< int,1 > > _3468,    std::shared_ptr< monty::ndarray< double,1 > > _3469,    monty::rc_ptr< ::mosek::fusion::Expression > _3470) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3465,_3466,_3467,_3468,_3469,_3470); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3465,    int _3466,    std::shared_ptr< monty::ndarray< int,1 > > _3467,    std::shared_ptr< monty::ndarray< int,1 > > _3468,    std::shared_ptr< monty::ndarray< double,1 > > _3469,    monty::rc_ptr< ::mosek::fusion::Expression > _3470){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3467(_3467 ? _3467->raw() : nullptr, _3467 ? _3467->size(0) : 0);
    _checked_ptr_1<int> _ptr__3468(_3468 ? _3468->raw() : nullptr, _3468 ? _3468->size(0) : 0);
    _checked_ptr_1<double> _ptr__3469(_3469 ? _3469->raw() : nullptr, _3469 ? _3469->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3465,_3466,_3467,_3468,_3469,_3470,::mosek::fusion::p_ExprScalarMul::validate(_3465,_3466,_3467,_3468,_3469,_3470));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3471,monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3471,_3472,_3473); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3471,monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3472,_3471,_3473);
  _3472->pop_expr();
  int _3474 = mosek::fusion::p_WorkStack::_get_impl(_3472)->nd;
  int _3475 = mosek::fusion::p_WorkStack::_get_impl(_3472)->nelem;
  int _3476 = mosek::fusion::p_WorkStack::_get_impl(_3472)->nnz;
  bool _3477 = mosek::fusion::p_WorkStack::_get_impl(_3472)->hassp;
  int _3478 = mosek::fusion::p_WorkStack::_get_impl(_3472)->ptr_base;
  int _3479 = mosek::fusion::p_WorkStack::_get_impl(_3472)->sp_base;
  int _3480 = mosek::fusion::p_WorkStack::_get_impl(_3472)->nidxs_base;
  int _3481 = mosek::fusion::p_WorkStack::_get_impl(_3472)->bfix_base;
  int _3482 = mosek::fusion::p_WorkStack::_get_impl(_3472)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3483 = mosek::fusion::p_WorkStack::_get_impl(_3472)->i64;
  _checked_ptr_1<long long> _ptr__3483(_3483 ? _3483->raw() : nullptr,_3483 ? _3483->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3484 = mosek::fusion::p_WorkStack::_get_impl(_3472)->f64;
  _checked_ptr_1<double> _ptr__3484(_3484 ? _3484->raw() : nullptr,_3484 ? _3484->size(0) : 0);
  int _3485 = (int)((mval)->size(0));
  if ((_3474 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3475 == (int)0))
  {
    {
      _3471->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3471)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3471)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3471)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3471)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3471->alloc_expr((int)2,_3485,safe_mul( _3485,_3476 ),true);
      int _3486 = mosek::fusion::p_WorkStack::_get_impl(_3471)->ptr_base;
      int _3487 = mosek::fusion::p_WorkStack::_get_impl(_3471)->nidxs_base;
      int _3488 = mosek::fusion::p_WorkStack::_get_impl(_3471)->sp_base;
      int _3489 = mosek::fusion::p_WorkStack::_get_impl(_3471)->cof_base;
      int _3490 = mosek::fusion::p_WorkStack::_get_impl(_3471)->bfix_base;
      int _3491 = mosek::fusion::p_WorkStack::_get_impl(_3471)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3492 = mosek::fusion::p_WorkStack::_get_impl(_3471)->i32;
      _checked_ptr_1<int> _ptr__3492(_3492 ? _3492->raw() : nullptr,_3492 ? _3492->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3493 = mosek::fusion::p_WorkStack::_get_impl(_3471)->i64;
      _checked_ptr_1<long long> _ptr__3493(_3493 ? _3493->raw() : nullptr,_3493 ? _3493->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3494 = mosek::fusion::p_WorkStack::_get_impl(_3471)->f64;
      _checked_ptr_1<double> _ptr__3494(_3494 ? _3494->raw() : nullptr,_3494 ? _3494->size(0) : 0);
      _ptr__3492[_3491] = mdim0;
      _ptr__3492[safe_add( _3491,(int)1 )] = mdim1;
      int _3495 = (int)0;
      _ptr__3492[_3486] = (int)0;
      int _8353 = (int)0;
      int _8354 = _3485;
      for (int _3496 = _8353; _3496 < _8354; ++_3496)
      {
        {
          int _8355 = (int)0;
          int _8356 = _3476;
          for (int _3497 = _8355; _3497 < _8356; ++_3497)
          {
            {
              _ptr__3493[safe_add( _3487,_3495 )] = _ptr__3483[safe_add( _3480,_3497 )];
              _ptr__3494[safe_add( _3489,_3495 )] = (_ptr__3484[safe_add( _3482,_3497 )] * ((*mval)(_3496)));
              ++ _3495;
            }
          }
          _ptr__3493[safe_add( _3488,_3496 )] = safe_add( safe_mul( ((*msubi)(_3496)),mdim1 ),((*msubj)(_3496)) );
          _ptr__3494[safe_add( _3490,_3496 )] = (((*mval)(_3496)) * _ptr__3484[_3481]);
          _ptr__3492[safe_add( safe_add( _3486,_3496 ),(int)1 )] = _3495;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3498,int _3499,std::shared_ptr< monty::ndarray< int,1 > > _3500,std::shared_ptr< monty::ndarray< int,1 > > _3501,std::shared_ptr< monty::ndarray< double,1 > > _3502,monty::rc_ptr< ::mosek::fusion::Expression > _3503){
  _checked_ptr_1<int> _ptr__3500(_3500 ? _3500->raw() : nullptr, _3500 ? _3500->size(0) : 0);
  _checked_ptr_1<int> _ptr__3501(_3501 ? _3501->raw() : nullptr, _3501 ? _3501->size(0) : 0);
  _checked_ptr_1<double> _ptr__3502(_3502 ? _3502->raw() : nullptr, _3502 ? _3502->size(0) : 0);
  int _3504 = _3503->getND();
  if ((_3504 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3498 < (int)0) || (_3499 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3500)->size(0)) != (int)((_3501)->size(0))) || ((int)((_3500)->size(0)) != (int)((_3502)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3505 = (int)((_3500)->size(0));
  int _8357 = (int)0;
  int _8358 = _3505;
  for (int _3506 = _8357; _3506 < _8358; ++_3506)
  {
    {
      if (((_ptr__3500[_3506] < (int)0) || ((_ptr__3500[_3506] >= _3498) || ((_ptr__3501[_3506] < (int)0) || (_ptr__3501[_3506] >= _3499)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8359 = (int)0;
  int _8360 = (_3505 - (int)1);
  for (int _3507 = _8359; _3507 < _8360; ++_3507)
  {
    {
      if (((_ptr__3500[_3507] > _ptr__3500[safe_add( _3507,(int)1 )]) || ((_ptr__3500[_3507] == _ptr__3500[safe_add( _3507,(int)1 )]) && (_ptr__3501[_3507] >= _ptr__3501[safe_add( _3507,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8361 = (int)0;
  int _8362 = _3505;
  for (int _3508 = _8361; _3508 < _8362; ++_3508)
  {
    {
      if (((_ptr__3500[_3508] < (int)0) || ((_ptr__3500[_3508] >= _3498) || ((_ptr__3501[_3508] < (int)0) || (_ptr__3501[_3508] >= _3499)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3509,    int _3510,    std::shared_ptr< monty::ndarray< int,1 > > _3511,    std::shared_ptr< monty::ndarray< int,1 > > _3512,    std::shared_ptr< monty::ndarray< double,1 > > _3513,    monty::rc_ptr< ::mosek::fusion::Expression > _3514,    int _3515){ return new mosek::fusion::ExprMulRight(_3509,_3510,_3511,_3512,_3513,_3514,_3515); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3509,    int _3510,    std::shared_ptr< monty::ndarray< int,1 > > _3511,    std::shared_ptr< monty::ndarray< int,1 > > _3512,    std::shared_ptr< monty::ndarray< double,1 > > _3513,    monty::rc_ptr< ::mosek::fusion::Expression > _3514,    int _3515) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3509,_3510,_3511,_3512,_3513,_3514,_3515); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3509,    int _3510,    std::shared_ptr< monty::ndarray< int,1 > > _3511,    std::shared_ptr< monty::ndarray< int,1 > > _3512,    std::shared_ptr< monty::ndarray< double,1 > > _3513,    monty::rc_ptr< ::mosek::fusion::Expression > _3514,    int _3515){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3511(_3511 ? _3511->raw() : nullptr, _3511 ? _3511->size(0) : 0);
    _checked_ptr_1<int> _ptr__3512(_3512 ? _3512->raw() : nullptr, _3512 ? _3512->size(0) : 0);
    _checked_ptr_1<double> _ptr__3513(_3513 ? _3513->raw() : nullptr, _3513 ? _3513->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3510,_3514->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3509;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3510;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3511;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3512;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3513;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3514;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521){ return new mosek::fusion::ExprMulRight(_3516,_3517,_3518,_3519,_3520,_3521); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3516,_3517,_3518,_3519,_3520,_3521); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3516,    int _3517,    std::shared_ptr< monty::ndarray< int,1 > > _3518,    std::shared_ptr< monty::ndarray< int,1 > > _3519,    std::shared_ptr< monty::ndarray< double,1 > > _3520,    monty::rc_ptr< ::mosek::fusion::Expression > _3521){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3518(_3518 ? _3518->raw() : nullptr, _3518 ? _3518->size(0) : 0);
    _checked_ptr_1<int> _ptr__3519(_3519 ? _3519->raw() : nullptr, _3519 ? _3519->size(0) : 0);
    _checked_ptr_1<double> _ptr__3520(_3520 ? _3520->raw() : nullptr, _3520 ? _3520->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3516,_3517,_3518,_3519,_3520,_3521,::mosek::fusion::p_ExprMulRight::validate(_3516,_3517,_3518,_3519,_3520,_3521));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3522,monty::rc_ptr< ::mosek::fusion::WorkStack > _3523,monty::rc_ptr< ::mosek::fusion::WorkStack > _3524) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3522,_3523,_3524); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3522,monty::rc_ptr< ::mosek::fusion::WorkStack > _3523,monty::rc_ptr< ::mosek::fusion::WorkStack > _3524){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3523,_3522,_3524);
  int _3525 = _3523->peeki32();
  bool _3526 = (_3523->peeki32(safe_add( _3525,(int)3 )) != (int)0);
  int _3527 = (int)((mval)->size(0));
  bool _3528 = (_3527 < safe_mul( mdim0,mdim1 ));
  int _3529 = _3523->peeki32((int)2);
  if (_3528)
  {
    {
      int _3530 = _3523->alloci32(safe_add( mdim1,(int)1 ));
      int _3531 = _3523->alloci32(_3527);
      int _3532 = _3523->alloci32(safe_add( _3529,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3533 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i32;
      _checked_ptr_1<int> _ptr__3533(_3533 ? _3533->raw() : nullptr,_3533 ? _3533->size(0) : 0);
      int _8363 = (int)0;
      int _8364 = safe_add( mdim1,(int)1 );
      for (int _3534 = _8363; _3534 < _8364; ++_3534)
      {
        {
          _ptr__3533[safe_add( _3530,_3534 )] = (int)0;
        }
      }
      int _8365 = (int)0;
      int _8366 = _3527;
      for (int _3535 = _8365; _3535 < _8366; ++_3535)
      {
        {
          ++ _ptr__3533[safe_add( safe_add( _3530,((*msubj)(_3535)) ),(int)1 )];
        }
      }
      int _8367 = (int)0;
      int _8368 = mdim1;
      for (int _3536 = _8367; _3536 < _8368; ++_3536)
      {
        {
          _ptr__3533[safe_add( safe_add( _3530,_3536 ),(int)1 )] += _ptr__3533[safe_add( _3530,_3536 )];
        }
      }
      int _8369 = (int)0;
      int _8370 = _3527;
      for (int _3537 = _8369; _3537 < _8370; ++_3537)
      {
        {
          _ptr__3533[safe_add( _3531,_3537 )] = _ptr__3533[safe_add( _3530,((*msubj)(_3537)) )];
          ++ _ptr__3533[safe_add( _3530,((*msubj)(_3537)) )];
        }
      }
      int _8371 = (int)0;
      int _8372 = mdim1;
      for (int _3538 = _8371; _3538 < _8372; ++_3538)
      {
        {
          _ptr__3533[(safe_add( _3530,mdim1 ) - _3538)] = _ptr__3533[((safe_add( _3530,mdim1 ) - _3538) - (int)1)];
        }
      }
      _ptr__3533[_3530] = (int)0;
      int _8373 = (int)0;
      int _8374 = safe_add( _3529,(int)1 );
      for (int _3539 = _8373; _3539 < _8374; ++_3539)
      {
        {
          _ptr__3533[safe_add( _3532,_3539 )] = (int)0;
        }
      }
      _3523->popi32(safe_add( safe_add( safe_add( _3529,mdim1 ),(int)2 ),_3527 ));
      int _3540 = _3523->popi32();
      if ((_3540 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3541 = _3523->popi32();
      int _3542 = _3523->popi32();
      int _3543 = _3523->popi32();
      int _3544 = _3523->popi32();
      bool _3545 = (_3523->popi32() != (int)0);
      int _3546 = _3523->popi32(safe_add( _3543,(int)1 ));
      int _8375;
      bool _8376 = _3545;
      if (_8376)
      {
        _8375 = _3523->popi64(_3543);
      }
      else
      {
        _8375 = (int)999999;
      }
      int _3547 = _8375;
      int _3548 = _3523->popi64(_3544);
      int _3549 = _3523->popf64(_3543);
      int _3550 = _3523->popf64(_3544);
      std::shared_ptr< monty::ndarray< int,1 > > _3551 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i32;
      _checked_ptr_1<int> _ptr__3551(_3551 ? _3551->raw() : nullptr,_3551 ? _3551->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3552 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i64;
      _checked_ptr_1<long long> _ptr__3552(_3552 ? _3552->raw() : nullptr,_3552 ? _3552->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3553 = mosek::fusion::p_WorkStack::_get_impl(_3523)->f64;
      _checked_ptr_1<double> _ptr__3553(_3553 ? _3553->raw() : nullptr,_3553 ? _3553->size(0) : 0);
      if (_3545)
      {
        {
          int _8377 = (int)0;
          int _8378 = _3543;
          for (int _3554 = _8377; _3554 < _8378; ++_3554)
          {
            {
              ++ _ptr__3551[safe_add( safe_add( _3532,(_ptr__3552[safe_add( _3547,_3554 )] / _3541) ),(int)1 )];
            }
          }
          int _8379 = (int)0;
          int _8380 = _3542;
          for (int _3555 = _8379; _3555 < _8380; ++_3555)
          {
            {
              _ptr__3551[safe_add( safe_add( _3532,_3555 ),(int)1 )] += _ptr__3551[safe_add( _3532,_3555 )];
            }
          }
          int _3556 = (int)0;
          int _3557 = (int)0;
          int _8381 = (int)0;
          int _8382 = _3542;
          for (int _3558 = _8381; _3558 < _8382; ++_3558)
          {
            {
              int _8383 = (int)0;
              int _8384 = mdim1;
              for (int _3559 = _8383; _3559 < _8384; ++_3559)
              {
                {
                  bool _3560 = false;
                  int _3561 = _ptr__3551[safe_add( safe_add( _3532,_3558 ),(int)1 )];
                  int _3562 = _ptr__3551[safe_add( _3532,_3558 )];
                  int _3563 = _ptr__3551[safe_add( safe_add( _3530,_3559 ),(int)1 )];
                  int _3564 = _ptr__3551[safe_add( _3530,_3559 )];
                  while ( ((_3562 < _3561) && (_3564 < _3563)) )
                  {
                    {
                      int _3565 = _ptr__3551[safe_add( _3531,_3564 )];
                      if (((_ptr__3552[safe_add( _3547,_3562 )] % _3541) < ((*msubi)(_3565))))
                      {
                        {
                          ++ _3562;
                        }
                      }
                      else if(((_ptr__3552[safe_add( _3547,_3562 )] % _3541) > ((*msubi)(_3565))))
                      {
                        {
                          ++ _3564;
                        }
                      }
                      else
                      {
                        {
                          _3557 += (_ptr__3551[safe_add( safe_add( _3546,_3562 ),(int)1 )] - _ptr__3551[safe_add( _3546,_3562 )]);
                          ++ _3562;
                          ++ _3564;
                          _3560 = true;
                        }
                      }
                    }
                  }
                  if (_3560)
                  {
                    {
                      ++ _3556;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3566 = (_3556 < safe_mul( _3542,mdim1 ));
          _3522->alloc_expr((int)2,_3556,_3557,_3566);
          int _3567 = mosek::fusion::p_WorkStack::_get_impl(_3522)->ptr_base;
          int _3568 = mosek::fusion::p_WorkStack::_get_impl(_3522)->nidxs_base;
          int _8385;
          bool _8386 = _3566;
          if (_8386)
          {
            _8385 = mosek::fusion::p_WorkStack::_get_impl(_3522)->sp_base;
          }
          else
          {
            _8385 = _3522->alloci64(_3556);
          }
          int _3569 = _8385;
          int _3570 = mosek::fusion::p_WorkStack::_get_impl(_3522)->cof_base;
          int _3571 = mosek::fusion::p_WorkStack::_get_impl(_3522)->bfix_base;
          int _3572 = mosek::fusion::p_WorkStack::_get_impl(_3522)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3573 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i32;
          _checked_ptr_1<int> _ptr__3573(_3573 ? _3573->raw() : nullptr,_3573 ? _3573->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3574 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i64;
          _checked_ptr_1<long long> _ptr__3574(_3574 ? _3574->raw() : nullptr,_3574 ? _3574->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3575 = mosek::fusion::p_WorkStack::_get_impl(_3522)->f64;
          _checked_ptr_1<double> _ptr__3575(_3575 ? _3575->raw() : nullptr,_3575 ? _3575->size(0) : 0);
          _ptr__3573[_3572] = _3542;
          _ptr__3573[safe_add( _3572,(int)1 )] = mdim1;
          int _3576 = (int)0;
          int _3577 = (int)0;
          _ptr__3573[_3567] = (int)0;
          int _8387 = (int)0;
          int _8388 = _3542;
          for (int _3578 = _8387; _3578 < _8388; ++_3578)
          {
            {
              int _8389 = (int)0;
              int _8390 = mdim1;
              for (int _3579 = _8389; _3579 < _8390; ++_3579)
              {
                {
                  bool _3580 = false;
                  double _3581 = 0.0;
                  int _3582 = _ptr__3551[safe_add( safe_add( _3532,_3578 ),(int)1 )];
                  int _3583 = _ptr__3551[safe_add( _3532,_3578 )];
                  int _3584 = _ptr__3551[safe_add( safe_add( _3530,_3579 ),(int)1 )];
                  int _3585 = _ptr__3551[safe_add( _3530,_3579 )];
                  while ( ((_3583 < _3582) && (_3585 < _3584)) )
                  {
                    {
                      int _3586 = _ptr__3551[safe_add( _3531,_3585 )];
                      if (((_ptr__3552[safe_add( _3547,_3583 )] % _3541) < ((*msubi)(_3586))))
                      {
                        {
                          ++ _3583;
                        }
                      }
                      else if(((_ptr__3552[safe_add( _3547,_3583 )] % _3541) > ((*msubi)(_3586))))
                      {
                        {
                          ++ _3585;
                        }
                      }
                      else
                      {
                        {
                          int _3587 = (_ptr__3551[safe_add( safe_add( _3546,_3583 ),(int)1 )] - _ptr__3551[safe_add( _3546,_3583 )]);
                          _3581 += (((*mval)(_3586)) * _ptr__3553[safe_add( _3549,_3583 )]);
                          int _8391 = (int)0;
                          int _8392 = _3587;
                          for (int _3588 = _8391; _3588 < _8392; ++_3588)
                          {
                            {
                              _ptr__3574[safe_add( safe_add( _3568,_3577 ),_3588 )] = _ptr__3552[safe_add( safe_add( _3548,_ptr__3551[safe_add( _3546,_3583 )] ),_3588 )];
                            }
                          }
                          int _8393 = (int)0;
                          int _8394 = _3587;
                          for (int _3589 = _8393; _3589 < _8394; ++_3589)
                          {
                            {
                              _ptr__3575[safe_add( safe_add( _3570,_3577 ),_3589 )] = (_ptr__3553[safe_add( safe_add( _3550,_ptr__3551[safe_add( _3546,_3583 )] ),_3589 )] * ((*mval)(_3586)));
                            }
                          }
                          _3577 += _3587;
                          ++ _3583;
                          ++ _3585;
                          _3580 = true;
                        }
                      }
                      if (_3580)
                      {
                        {
                          _ptr__3573[safe_add( safe_add( _3567,_3576 ),(int)1 )] = _3577;
                          _ptr__3575[safe_add( _3571,_3576 )] = _3581;
                          _ptr__3574[safe_add( _3569,_3576 )] = safe_add( safe_mul( _3578,mdim1 ),_3579 );
                          ++ _3576;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((!_3566))
          {
            {
              _3522->popi64(_3556);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3590 = safe_mul( _3542,mdim1 );
          int _3591 = (int)0;
          int _8395 = (int)0;
          int _8396 = _3542;
          for (int _3592 = _8395; _3592 < _8396; ++_3592)
          {
            {
              int _8397 = (int)0;
              int _8398 = mdim1;
              for (int _3593 = _8397; _3593 < _8398; ++_3593)
              {
                {
                  int _8399 = _ptr__3551[safe_add( _3530,_3593 )];
                  int _8400 = _ptr__3551[safe_add( safe_add( _3530,_3593 ),(int)1 )];
                  for (int _3594 = _8399; _3594 < _8400; ++_3594)
                  {
                    {
                      int _3595 = _ptr__3551[safe_add( _3531,_3594 )];
                      int _3596 = safe_add( safe_mul( _3592,_3541 ),((*msubi)(_3595)) );
                      _3591 += (_ptr__3551[safe_add( safe_add( _3546,_3596 ),(int)1 )] - _ptr__3551[safe_add( _3546,_3596 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3597 = (_3590 < safe_mul( _3542,mdim1 ));
          int _3598 = _3522->alloci32(safe_add( _3590,(int)1 ));
          int _8401;
          bool _8402 = _3597;
          if (_8402)
          {
            _8401 = (int)1;
          }
          else
          {
            _8401 = (int)0;
          }
          _3522->pushi32(_8401);
          _3522->pushi32(_3591);
          _3522->pushi32(_3590);
          _3522->pushi32(_3542);
          _3522->pushi32(mdim1);
          _3522->pushi32((int)2);
          int _3599 = _3522->alloci64(_3591);
          int _3600 = _3522->alloci64(_3590);
          int _3601 = _3522->allocf64(_3591);
          int _3602 = _3522->allocf64(_3590);
          std::shared_ptr< monty::ndarray< int,1 > > _3603 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i32;
          _checked_ptr_1<int> _ptr__3603(_3603 ? _3603->raw() : nullptr,_3603 ? _3603->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3604 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i64;
          _checked_ptr_1<long long> _ptr__3604(_3604 ? _3604->raw() : nullptr,_3604 ? _3604->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3605 = mosek::fusion::p_WorkStack::_get_impl(_3522)->f64;
          _checked_ptr_1<double> _ptr__3605(_3605 ? _3605->raw() : nullptr,_3605 ? _3605->size(0) : 0);
          int _3606 = (int)0;
          int _3607 = (int)0;
          _ptr__3603[_3598] = (int)0;
          int _8403 = (int)0;
          int _8404 = _3542;
          for (int _3608 = _8403; _3608 < _8404; ++_3608)
          {
            {
              int _8405 = (int)0;
              int _8406 = mdim1;
              for (int _3609 = _8405; _3609 < _8406; ++_3609)
              {
                {
                  int _3610 = safe_mul( _3608,_3541 );
                  double _3611 = 0.0;
                  int _8407 = _ptr__3551[safe_add( _3530,_3609 )];
                  int _8408 = _ptr__3551[safe_add( safe_add( _3530,_3609 ),(int)1 )];
                  for (int _3612 = _8407; _3612 < _8408; ++_3612)
                  {
                    {
                      int _3613 = _ptr__3551[safe_add( _3531,_3612 )];
                      int _3614 = safe_add( _3610,((*msubi)(_3613)) );
                      int _3615 = _ptr__3551[safe_add( _3546,_3614 )];
                      int _3616 = (_ptr__3551[safe_add( safe_add( _3546,_3614 ),(int)1 )] - _ptr__3551[safe_add( _3546,_3614 )]);
                      int _8409 = (int)0;
                      int _8410 = _3616;
                      for (int _3617 = _8409; _3617 < _8410; ++_3617)
                      {
                        {
                          _ptr__3604[safe_add( safe_add( _3599,_3607 ),_3617 )] = _ptr__3552[safe_add( safe_add( _3548,_3615 ),_3617 )];
                        }
                      }
                      int _8411 = (int)0;
                      int _8412 = _3616;
                      for (int _3618 = _8411; _3618 < _8412; ++_3618)
                      {
                        {
                          _ptr__3605[safe_add( safe_add( _3601,_3607 ),_3618 )] = (_ptr__3553[safe_add( safe_add( _3550,_3615 ),_3618 )] * ((*mval)(_3613)));
                        }
                      }
                      _3611 += (_ptr__3553[safe_add( safe_add( _3549,_3610 ),((*msubi)(_3613)) )] * ((*mval)(_3613)));
                      _3607 += _3616;
                    }
                  }
                  _ptr__3603[safe_add( safe_add( _3598,_3606 ),(int)1 )] = _3607;
                  _ptr__3605[safe_add( _3602,_3606 )] = _3611;
                  _ptr__3604[safe_add( _3600,_3606 )] = safe_add( safe_mul( _3608,mdim1 ),_3609 );
                  ++ _3606;
                }
              }
            }
          }
          if ((!_3597))
          {
            {
              _3522->popi64(_3590);
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _3619 = _3523->alloci32(safe_add( _3529,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3620 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i32;
      _checked_ptr_1<int> _ptr__3620(_3620 ? _3620->raw() : nullptr,_3620 ? _3620->size(0) : 0);
      int _8413 = (int)0;
      int _8414 = safe_add( _3529,(int)1 );
      for (int _3621 = _8413; _3621 < _8414; ++_3621)
      {
        {
          _ptr__3620[safe_add( _3619,_3621 )] = (int)0;
        }
      }
      _3523->popi32(safe_add( _3529,(int)1 ));
      int _3622 = _3523->popi32();
      if ((_3622 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3623 = _3523->popi32();
      int _3624 = _3523->popi32();
      int _3625 = _3523->popi32();
      int _3626 = _3523->popi32();
      bool _3627 = (_3523->popi32() != (int)0);
      int _3628 = _3523->popi32(safe_add( _3625,(int)1 ));
      int _8415;
      bool _8416 = _3627;
      if (_8416)
      {
        _8415 = _3523->popi64(_3625);
      }
      else
      {
        _8415 = (int)999999;
      }
      int _3629 = _8415;
      int _3630 = _3523->popi64(_3626);
      int _3631 = _3523->popf64(_3625);
      int _3632 = _3523->popf64(_3626);
      std::shared_ptr< monty::ndarray< int,1 > > _3633 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i32;
      _checked_ptr_1<int> _ptr__3633(_3633 ? _3633->raw() : nullptr,_3633 ? _3633->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3634 = mosek::fusion::p_WorkStack::_get_impl(_3523)->i64;
      _checked_ptr_1<long long> _ptr__3634(_3634 ? _3634->raw() : nullptr,_3634 ? _3634->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3635 = mosek::fusion::p_WorkStack::_get_impl(_3523)->f64;
      _checked_ptr_1<double> _ptr__3635(_3635 ? _3635->raw() : nullptr,_3635 ? _3635->size(0) : 0);
      int _3636 = safe_mul( _3624,mdim1 );
      int _3637 = safe_mul( _3626,mdim1 );
      bool _3638 = false;
      int _3639 = _3522->alloci32(safe_add( _3636,(int)1 ));
      _3522->pushi32((int)0);
      _3522->pushi32(_3637);
      _3522->pushi32(_3636);
      _3522->pushi32(_3624);
      _3522->pushi32(mdim1);
      _3522->pushi32((int)2);
      int _3640 = _3522->alloci64(_3637);
      int _3641 = _3522->allocf64(_3637);
      int _3642 = _3522->allocf64(_3636);
      std::shared_ptr< monty::ndarray< int,1 > > _3643 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i32;
      _checked_ptr_1<int> _ptr__3643(_3643 ? _3643->raw() : nullptr,_3643 ? _3643->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3644 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i64;
      _checked_ptr_1<long long> _ptr__3644(_3644 ? _3644->raw() : nullptr,_3644 ? _3644->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3645 = mosek::fusion::p_WorkStack::_get_impl(_3522)->f64;
      _checked_ptr_1<double> _ptr__3645(_3645 ? _3645->raw() : nullptr,_3645 ? _3645->size(0) : 0);
      int _3646 = (int)0;
      int _3647 = (int)0;
      _ptr__3643[_3639] = (int)0;
      if (_3627)
      {
        {
          int _8417 = (int)0;
          int _8418 = _3625;
          for (int _3648 = _8417; _3648 < _8418; ++_3648)
          {
            {
              ++ _ptr__3633[safe_add( safe_add( _3619,(_ptr__3634[safe_add( _3629,_3648 )] / _3623) ),(int)1 )];
            }
          }
          int _8419 = (int)0;
          int _8420 = _3624;
          for (int _3649 = _8419; _3649 < _8420; ++_3649)
          {
            {
              _ptr__3633[safe_add( safe_add( _3619,_3649 ),(int)1 )] += _ptr__3633[safe_add( _3619,_3649 )];
            }
          }
          int _8421 = (int)0;
          int _8422 = _3624;
          for (int _3650 = _8421; _3650 < _8422; ++_3650)
          {
            {
              int _8423 = (int)0;
              int _8424 = mdim1;
              for (int _3651 = _8423; _3651 < _8424; ++_3651)
              {
                {
                  double _3652 = 0.0;
                  int _3653 = (int)0;
                  int _8425 = _ptr__3633[safe_add( _3619,_3650 )];
                  int _8426 = _ptr__3633[safe_add( safe_add( _3619,_3650 ),(int)1 )];
                  for (int _3654 = _8425; _3654 < _8426; ++_3654)
                  {
                    {
                      long long _3655 = safe_add( _3651,safe_mul( (_ptr__3634[safe_add( _3629,_3654 )] % _3623),mdim1 ) );
                      _3652 += (_ptr__3634[safe_add( _3631,_3654 )] * ((*mval)(_3655)));
                      int _8427 = _ptr__3633[safe_add( _3628,_3654 )];
                      int _8428 = _ptr__3633[safe_add( safe_add( _3628,_3654 ),(int)1 )];
                      for (int _3656 = _8427; _3656 < _8428; ++_3656)
                      {
                        {
                          _ptr__3644[safe_add( safe_add( _3640,_3646 ),_3653 )] = _ptr__3634[safe_add( _3630,_3656 )];
                          _ptr__3645[safe_add( safe_add( _3641,_3646 ),_3653 )] = (_ptr__3634[safe_add( _3632,_3656 )] * ((*mval)(_3655)));
                          ++ _3653;
                        }
                      }
                    }
                  }
                  _3646 += _3653;
                  _ptr__3643[safe_add( safe_add( _3639,_3647 ),(int)1 )] = _3646;
                  _ptr__3645[safe_add( _3642,_3647 )] = _3652;
                  ++ _3647;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8429 = (int)0;
          int _8430 = _3624;
          for (int _3657 = _8429; _3657 < _8430; ++_3657)
          {
            {
              int _8431 = (int)0;
              int _8432 = mdim1;
              for (int _3658 = _8431; _3658 < _8432; ++_3658)
              {
                {
                  double _3659 = 0.0;
                  int _3660 = (int)0;
                  int _8433 = (int)0;
                  int _8434 = _3623;
                  for (int _3661 = _8433; _3661 < _8434; ++_3661)
                  {
                    {
                      int _3662 = safe_add( safe_mul( _3657,_3623 ),_3661 );
                      int _3663 = safe_add( _3658,safe_mul( _3661,mdim1 ) );
                      _3659 += (_ptr__3635[safe_add( _3631,_3662 )] * ((*mval)(_3663)));
                      int _8435 = _ptr__3633[safe_add( _3628,_3662 )];
                      int _8436 = _ptr__3633[safe_add( safe_add( _3628,_3662 ),(int)1 )];
                      for (int _3664 = _8435; _3664 < _8436; ++_3664)
                      {
                        {
                          _ptr__3644[safe_add( safe_add( _3640,_3646 ),_3660 )] = _ptr__3634[safe_add( _3630,_3664 )];
                          _ptr__3645[safe_add( safe_add( _3641,_3646 ),_3660 )] = (_ptr__3635[safe_add( _3632,_3664 )] * ((*mval)(_3663)));
                          ++ _3660;
                        }
                      }
                    }
                  }
                  _3646 += _3660;
                  _ptr__3643[safe_add( safe_add( _3639,_3647 ),(int)1 )] = _3646;
                  _ptr__3645[safe_add( _3642,_3647 )] = _3659;
                  ++ _3647;
                }
              }
            }
          }
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3665,std::shared_ptr< monty::ndarray< int,1 > > _3666){
  _checked_ptr_1<int> _ptr__3666(_3666 ? _3666->raw() : nullptr, _3666 ? _3666->size(0) : 0);
  if (((int)((_3666)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3665)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3666[(int)0]),(int)(_3665)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3667,int _3668,std::shared_ptr< monty::ndarray< int,1 > > _3669,std::shared_ptr< monty::ndarray< int,1 > > _3670,std::shared_ptr< monty::ndarray< double,1 > > _3671,monty::rc_ptr< ::mosek::fusion::Expression > _3672){
  _checked_ptr_1<int> _ptr__3669(_3669 ? _3669->raw() : nullptr, _3669 ? _3669->size(0) : 0);
  _checked_ptr_1<int> _ptr__3670(_3670 ? _3670->raw() : nullptr, _3670 ? _3670->size(0) : 0);
  _checked_ptr_1<double> _ptr__3671(_3671 ? _3671->raw() : nullptr, _3671 ? _3671->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3673 = _3672->getShape();
  _checked_ptr_1<int> _ptr__3673(_3673 ? _3673->raw() : nullptr,_3673 ? _3673->size(0) : 0);
  if (((int)((_3673)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3674 = _ptr__3673[(int)0];
  int _3675 = _ptr__3673[(int)1];
  if (((_3667 < (int)0) || ((_3668 < (int)0) || ((_3674 < (int)0) || (_3675 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3667 != _3675))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3669)->size(0)) != (int)((_3670)->size(0))) || ((int)((_3669)->size(0)) != (int)((_3671)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3676 = (int)((_3669)->size(0));
  int _8437 = (int)0;
  int _8438 = _3676;
  for (int _3677 = _8437; _3677 < _8438; ++_3677)
  {
    {
      if (((_ptr__3669[_3677] < (int)0) || ((_ptr__3669[_3677] >= _3667) || ((_ptr__3670[_3677] < (int)0) || (_ptr__3670[_3677] >= _3668)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8439 = (int)0;
  int _8440 = (_3676 - (int)1);
  for (int _3678 = _8439; _3678 < _8440; ++_3678)
  {
    {
      if (((_ptr__3669[_3678] > _ptr__3669[safe_add( _3678,(int)1 )]) || ((_ptr__3669[_3678] == _ptr__3669[safe_add( _3678,(int)1 )]) && (_ptr__3670[_3678] >= _ptr__3670[safe_add( _3678,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8441 = (int)0;
  int _8442 = _3676;
  for (int _3679 = _8441; _3679 < _8442; ++_3679)
  {
    {
      if (((_ptr__3669[_3679] < (int)0) || ((_ptr__3669[_3679] >= _3667) || ((_ptr__3670[_3679] < (int)0) || (_ptr__3670[_3679] >= _3668)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3680,    int _3681,    std::shared_ptr< monty::ndarray< int,1 > > _3682,    std::shared_ptr< monty::ndarray< int,1 > > _3683,    std::shared_ptr< monty::ndarray< double,1 > > _3684,    monty::rc_ptr< ::mosek::fusion::Expression > _3685,    int _3686){ return new mosek::fusion::ExprMulLeft(_3680,_3681,_3682,_3683,_3684,_3685,_3686); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3680,    int _3681,    std::shared_ptr< monty::ndarray< int,1 > > _3682,    std::shared_ptr< monty::ndarray< int,1 > > _3683,    std::shared_ptr< monty::ndarray< double,1 > > _3684,    monty::rc_ptr< ::mosek::fusion::Expression > _3685,    int _3686) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3680,_3681,_3682,_3683,_3684,_3685,_3686); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3680,    int _3681,    std::shared_ptr< monty::ndarray< int,1 > > _3682,    std::shared_ptr< monty::ndarray< int,1 > > _3683,    std::shared_ptr< monty::ndarray< double,1 > > _3684,    monty::rc_ptr< ::mosek::fusion::Expression > _3685,    int _3686){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3682(_3682 ? _3682->raw() : nullptr, _3682 ? _3682->size(0) : 0);
    _checked_ptr_1<int> _ptr__3683(_3683 ? _3683->raw() : nullptr, _3683 ? _3683->size(0) : 0);
    _checked_ptr_1<double> _ptr__3684(_3684 ? _3684->raw() : nullptr, _3684 ? _3684->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3680,_3681,_3685->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3680;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3681;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3682;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3683;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3684;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3685;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3687,    int _3688,    std::shared_ptr< monty::ndarray< int,1 > > _3689,    std::shared_ptr< monty::ndarray< int,1 > > _3690,    std::shared_ptr< monty::ndarray< double,1 > > _3691,    monty::rc_ptr< ::mosek::fusion::Expression > _3692){ return new mosek::fusion::ExprMulLeft(_3687,_3688,_3689,_3690,_3691,_3692); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3687,    int _3688,    std::shared_ptr< monty::ndarray< int,1 > > _3689,    std::shared_ptr< monty::ndarray< int,1 > > _3690,    std::shared_ptr< monty::ndarray< double,1 > > _3691,    monty::rc_ptr< ::mosek::fusion::Expression > _3692) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3687,_3688,_3689,_3690,_3691,_3692); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3687,    int _3688,    std::shared_ptr< monty::ndarray< int,1 > > _3689,    std::shared_ptr< monty::ndarray< int,1 > > _3690,    std::shared_ptr< monty::ndarray< double,1 > > _3691,    monty::rc_ptr< ::mosek::fusion::Expression > _3692){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3689(_3689 ? _3689->raw() : nullptr, _3689 ? _3689->size(0) : 0);
    _checked_ptr_1<int> _ptr__3690(_3690 ? _3690->raw() : nullptr, _3690 ? _3690->size(0) : 0);
    _checked_ptr_1<double> _ptr__3691(_3691 ? _3691->raw() : nullptr, _3691 ? _3691->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3687,_3688,_3689,_3690,_3691,_3692,::mosek::fusion::p_ExprMulLeft::validate(_3687,_3688,_3689,_3690,_3691,_3692));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3693,monty::rc_ptr< ::mosek::fusion::WorkStack > _3694,monty::rc_ptr< ::mosek::fusion::WorkStack > _3695) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3693,_3694,_3695); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3693,monty::rc_ptr< ::mosek::fusion::WorkStack > _3694,monty::rc_ptr< ::mosek::fusion::WorkStack > _3695){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3694,_3693,_3695);
  _3694->pop_expr();
  int _3696 = mosek::fusion::p_WorkStack::_get_impl(_3694)->nd;
  int _3697 = mosek::fusion::p_WorkStack::_get_impl(_3694)->nnz;
  int _3698 = mosek::fusion::p_WorkStack::_get_impl(_3694)->nelem;
  bool _3699 = mosek::fusion::p_WorkStack::_get_impl(_3694)->hassp;
  int _3700 = mosek::fusion::p_WorkStack::_get_impl(_3694)->shape_base;
  int _3701 = mosek::fusion::p_WorkStack::_get_impl(_3694)->ptr_base;
  int _3702 = mosek::fusion::p_WorkStack::_get_impl(_3694)->sp_base;
  int _3703 = mosek::fusion::p_WorkStack::_get_impl(_3694)->nidxs_base;
  int _3704 = mosek::fusion::p_WorkStack::_get_impl(_3694)->bfix_base;
  int _3705 = mosek::fusion::p_WorkStack::_get_impl(_3694)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3706 = mosek::fusion::p_WorkStack::_get_impl(_3694)->i32;
  _checked_ptr_1<int> _ptr__3706(_3706 ? _3706->raw() : nullptr,_3706 ? _3706->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3707 = mosek::fusion::p_WorkStack::_get_impl(_3694)->i64;
  _checked_ptr_1<long long> _ptr__3707(_3707 ? _3707->raw() : nullptr,_3707 ? _3707->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3708 = mosek::fusion::p_WorkStack::_get_impl(_3694)->f64;
  _checked_ptr_1<double> _ptr__3708(_3708 ? _3708->raw() : nullptr,_3708 ? _3708->size(0) : 0);
  if ((_3696 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3709 = (int)9999;
  int _3710 = (int)9999;
  int _3711 = (int)9999;
  int _3712 = _ptr__3706[_3700];
  int _3713 = _ptr__3706[safe_add( _3700,(int)1 )];
  int _3714 = (int)((msubi)->size(0));
  bool _3715 = (_3714 < safe_mul( mdim0,mdim1 ));
  bool _3716 = false;
  int _3717 = (int)0;
  int _3718 = (int)0;
  if (_3699)
  {
    {
      _3709 = _3695->alloci32(_3698);
      _3710 = _3695->alloci32(_3698);
      _3711 = _3695->alloci32(safe_add( _3713,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3719 = mosek::fusion::p_WorkStack::_get_impl(_3695)->i32;
      _checked_ptr_1<int> _ptr__3719(_3719 ? _3719->raw() : nullptr,_3719 ? _3719->size(0) : 0);
      int _8443 = (int)0;
      int _8444 = safe_add( _3713,(int)1 );
      for (int _3720 = _8443; _3720 < _8444; ++_3720)
      {
        {
          _ptr__3719[safe_add( _3711,_3720 )] = (int)0;
        }
      }
      int _8445 = (int)0;
      int _8446 = _3698;
      for (int _3721 = _8445; _3721 < _8446; ++_3721)
      {
        {
          ++ _ptr__3719[safe_add( safe_add( _3711,(_ptr__3707[safe_add( _3702,_3721 )] % _3713) ),(int)1 )];
        }
      }
      int _8447 = (int)0;
      int _8448 = _3713;
      for (int _3722 = _8447; _3722 < _8448; ++_3722)
      {
        {
          _ptr__3719[safe_add( safe_add( _3711,_3722 ),(int)1 )] += _ptr__3719[safe_add( _3711,_3722 )];
        }
      }
      int _8449 = (int)0;
      int _8450 = _3698;
      for (int _3723 = _8449; _3723 < _8450; ++_3723)
      {
        {
          long long _3724 = (_ptr__3707[safe_add( _3702,_3723 )] % _3713);
          _ptr__3719[safe_add( _3709,_ptr__3719[safe_add( _3711,_3724 )] )] = _3723;
          ++ _ptr__3719[safe_add( _3711,_3724 )];
        }
      }
      int _8451 = (int)0;
      int _8452 = _3713;
      for (int _3725 = _8451; _3725 < _8452; ++_3725)
      {
        {
          _ptr__3719[(safe_add( _3711,_3713 ) - _3725)] = _ptr__3719[((safe_add( _3711,_3713 ) - _3725) - (int)1)];
        }
      }
      _ptr__3719[_3711] = (int)0;
      if (_3715)
      {
        {
          int _3726 = (int)0;
          while ( (_3726 < _3714) )
          {
            {
              int _3727 = ((*msubi)(_3726));
              int _3728 = safe_add( _3726,(int)1 );
              while ( ((_3728 < _3714) && (((*msubi)(_3728)) == ((*msubi)(_3726)))) )
              {
                {
                  ++ _3728;
                }
              }
              int _8453 = (int)0;
              int _8454 = _3713;
              for (int _3729 = _8453; _3729 < _8454; ++_3729)
              {
                {
                  bool _3730 = false;
                  int _3731 = _3728;
                  int _3732 = _3726;
                  int _3733 = _ptr__3719[safe_add( safe_add( _3711,_3729 ),(int)1 )];
                  int _3734 = _ptr__3719[safe_add( _3711,_3729 )];
                  while ( ((_3732 < _3731) && (_3734 < _3733)) )
                  {
                    {
                      int _3735 = _ptr__3719[safe_add( _3709,_3734 )];
                      if ((((*msubj)(_3732)) < (_ptr__3707[safe_add( _3702,_3735 )] / _3713)))
                      {
                        {
                          ++ _3732;
                        }
                      }
                      else if((((*msubj)(_3732)) > (_ptr__3707[safe_add( _3702,_3735 )] / _3713)))
                      {
                        {
                          ++ _3734;
                        }
                      }
                      else
                      {
                        {
                          _3730 = true;
                          _3718 += (_ptr__3706[safe_add( safe_add( _3701,_3735 ),(int)1 )] - _ptr__3706[safe_add( _3701,_3735 )]);
                          ++ _3734;
                          ++ _3732;
                        }
                      }
                    }
                  }
                  if (_3730)
                  {
                    {
                      ++ _3717;
                    }
                  }
                  {}
                }
              }
              _3726 = _3728;
            }
          }
        }
      }
      else
      {
        {
          _3717 = safe_mul( mdim0,_3713 );
          _3718 = safe_mul( _3697,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3715)
      {
        {
          int _3736 = (int)0;
          while ( (_3736 < _3714) )
          {
            {
              int _3737 = safe_add( _3736,(int)1 );
              while ( ((_3737 < _3714) && (((*msubi)(_3736)) == ((*msubi)(_3737)))) )
              {
                {
                  ++ _3737;
                }
              }
              int _3738 = ((*msubi)(_3736));
              int _8455 = (int)0;
              int _8456 = _3713;
              for (int _3739 = _8455; _3739 < _8456; ++_3739)
              {
                {
                  bool _3740 = false;
                  int _8457 = _3736;
                  int _8458 = _3737;
                  for (int _3741 = _8457; _3741 < _8458; ++_3741)
                  {
                    {
                      int _3742 = safe_add( safe_mul( ((*msubj)(_3741)),_3713 ),_3739 );
                      _3718 += (_ptr__3706[safe_add( safe_add( _3701,_3742 ),(int)1 )] - _ptr__3706[safe_add( _3701,_3742 )]);
                      _3740 = true;
                    }
                  }
                  if (_3740)
                  {
                    {
                      ++ _3717;
                    }
                  }
                  {}
                }
              }
              _3736 = _3737;
            }
          }
        }
      }
      else
      {
        {
          _3718 = safe_mul( _3697,mdim0 );
          _3717 = safe_mul( mdim0,_3713 );
        }
      }
    }
  }
  _3716 = (_3717 < safe_mul( mdim0,_3713 ));
  int _3743 = (int)2;
  _3693->alloc_expr(_3743,_3717,_3718,_3716);
  int _3744 = mosek::fusion::p_WorkStack::_get_impl(_3693)->ptr_base;
  int _3745 = mosek::fusion::p_WorkStack::_get_impl(_3693)->nidxs_base;
  int _8459;
  bool _8460 = _3716;
  if (_8460)
  {
    _8459 = mosek::fusion::p_WorkStack::_get_impl(_3693)->sp_base;
  }
  else
  {
    _8459 = _3693->alloci64(_3717);
  }
  int _3746 = _8459;
  int _3747 = mosek::fusion::p_WorkStack::_get_impl(_3693)->cof_base;
  int _3748 = mosek::fusion::p_WorkStack::_get_impl(_3693)->bfix_base;
  int _3749 = mosek::fusion::p_WorkStack::_get_impl(_3693)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3750 = mosek::fusion::p_WorkStack::_get_impl(_3693)->i64;
  _checked_ptr_1<long long> _ptr__3750(_3750 ? _3750->raw() : nullptr,_3750 ? _3750->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3751 = mosek::fusion::p_WorkStack::_get_impl(_3693)->f64;
  _checked_ptr_1<double> _ptr__3751(_3751 ? _3751->raw() : nullptr,_3751 ? _3751->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3752 = mosek::fusion::p_WorkStack::_get_impl(_3693)->i32;
  _checked_ptr_1<int> _ptr__3752(_3752 ? _3752->raw() : nullptr,_3752 ? _3752->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3753 = mosek::fusion::p_WorkStack::_get_impl(_3695)->i32;
  _checked_ptr_1<int> _ptr__3753(_3753 ? _3753->raw() : nullptr,_3753 ? _3753->size(0) : 0);
  _ptr__3752[_3749] = mdim0;
  _ptr__3752[safe_add( _3749,(int)1 )] = _3713;
  if (_3699)
  {
    {
      _ptr__3752[_3744] = (int)0;
      if (_3715)
      {
        {
          int _3754 = (int)0;
          int _3755 = (int)0;
          int _3756 = (int)0;
          while ( (_3756 < _3714) )
          {
            {
              int _3757 = ((*msubi)(_3756));
              int _3758 = safe_add( _3756,(int)1 );
              while ( ((_3758 < _3714) && (((*msubi)(_3758)) == ((*msubi)(_3756)))) )
              {
                {
                  ++ _3758;
                }
              }
              int _8461 = (int)0;
              int _8462 = _3713;
              for (int _3759 = _8461; _3759 < _8462; ++_3759)
              {
                {
                  bool _3760 = false;
                  double _3761 = 0.0;
                  int _3762 = _3758;
                  int _3763 = _3756;
                  int _3764 = _ptr__3753[safe_add( safe_add( _3711,_3759 ),(int)1 )];
                  int _3765 = _ptr__3753[safe_add( _3711,_3759 )];
                  while ( ((_3763 < _3762) && (_3765 < _3764)) )
                  {
                    {
                      int _3766 = _ptr__3753[safe_add( _3709,_3765 )];
                      if ((((*msubj)(_3763)) < (_ptr__3707[safe_add( _3702,_3766 )] / _3713)))
                      {
                        {
                          ++ _3763;
                        }
                      }
                      else if((((*msubj)(_3763)) > (_ptr__3707[safe_add( _3702,_3766 )] / _3713)))
                      {
                        {
                          ++ _3765;
                        }
                      }
                      else
                      {
                        {
                          _3760 = true;
                          _3761 += (_ptr__3708[safe_add( _3704,_3766 )] * ((*mval)(_3763)));
                          int _3767 = (_ptr__3706[safe_add( safe_add( _3701,_3766 ),(int)1 )] - _ptr__3706[safe_add( _3701,_3766 )]);
                          int _8463 = (int)0;
                          int _8464 = _3767;
                          for (int _3768 = _8463; _3768 < _8464; ++_3768)
                          {
                            {
                              _ptr__3750[safe_add( safe_add( _3745,_3755 ),_3768 )] = _ptr__3707[safe_add( safe_add( _3703,_ptr__3706[safe_add( _3701,_3766 )] ),_3768 )];
                            }
                          }
                          int _8465 = (int)0;
                          int _8466 = _3767;
                          for (int _3769 = _8465; _3769 < _8466; ++_3769)
                          {
                            {
                              _ptr__3751[safe_add( safe_add( _3747,_3755 ),_3769 )] = (_ptr__3708[safe_add( safe_add( _3705,_ptr__3706[safe_add( _3701,_3766 )] ),_3769 )] * ((*mval)(_3763)));
                            }
                          }
                          ++ _3763;
                          ++ _3765;
                          _3755 += _3767;
                        }
                      }
                    }
                  }
                  if (_3760)
                  {
                    {
                      _ptr__3752[safe_add( safe_add( _3744,_3754 ),(int)1 )] = _3755;
                      _ptr__3750[safe_add( _3746,_3754 )] = safe_add( safe_mul( _3757,_3713 ),_3759 );
                      _ptr__3751[safe_add( _3748,_3754 )] = _3761;
                      ++ _3754;
                    }
                  }
                  {}
                }
              }
              _3756 = _3758;
            }
          }
        }
      }
      else
      {
        {
          int _3770 = (int)0;
          int _3771 = (int)0;
          int _8467 = (int)0;
          int _8468 = mdim0;
          for (int _3772 = _8467; _3772 < _8468; ++_3772)
          {
            {
              int _8469 = (int)0;
              int _8470 = _3713;
              for (int _3773 = _8469; _3773 < _8470; ++_3773)
              {
                {
                  double _3774 = 0.0;
                  int _8471 = _ptr__3753[safe_add( _3711,_3773 )];
                  int _8472 = _ptr__3753[safe_add( safe_add( _3711,_3773 ),(int)1 )];
                  for (int _3775 = _8471; _3775 < _8472; ++_3775)
                  {
                    {
                      int _3776 = _ptr__3753[safe_add( _3709,_3775 )];
                      long long _3777 = safe_add( safe_mul( _3772,mdim1 ),(_ptr__3707[safe_add( _3702,_3776 )] / _3713) );
                      _3774 += (_ptr__3708[safe_add( _3704,_3776 )] * ((*mval)(_3777)));
                      int _3778 = (_ptr__3706[safe_add( safe_add( _3701,_3776 ),(int)1 )] - _ptr__3706[safe_add( _3701,_3776 )]);
                      int _8473 = (int)0;
                      int _8474 = _3778;
                      for (int _3779 = _8473; _3779 < _8474; ++_3779)
                      {
                        {
                          _ptr__3750[safe_add( safe_add( _3745,_3771 ),_3779 )] = _ptr__3707[safe_add( safe_add( _3703,_ptr__3706[safe_add( _3701,_3776 )] ),_3779 )];
                          _ptr__3751[safe_add( safe_add( _3747,_3771 ),_3779 )] = (_ptr__3708[safe_add( safe_add( _3705,_ptr__3706[safe_add( _3701,_3776 )] ),_3779 )] * ((*mval)(_3777)));
                        }
                      }
                      _3771 += _3778;
                    }
                  }
                  _ptr__3752[safe_add( safe_add( _3744,_3770 ),(int)1 )] = _3771;
                  _ptr__3751[safe_add( _3748,_3770 )] = _3774;
                  ++ _3770;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3752[_3744] = (int)0;
      int _3780 = (int)0;
      int _3781 = (int)0;
      int _3782 = (int)0;
      while ( (_3780 < _3714) )
      {
        {
          int _3783 = safe_add( _3780,(int)1 );
          while ( ((_3783 < _3714) && (((*msubi)(_3780)) == ((*msubi)(_3783)))) )
          {
            {
              ++ _3783;
            }
          }
          int _3784 = ((*msubi)(_3780));
          int _8475 = (int)0;
          int _8476 = _3713;
          for (int _3785 = _8475; _3785 < _8476; ++_3785)
          {
            {
              double _3786 = 0.0;
              bool _3787 = false;
              int _8477 = _3780;
              int _8478 = _3783;
              for (int _3788 = _8477; _3788 < _8478; ++_3788)
              {
                {
                  int _3789 = safe_add( safe_mul( ((*msubj)(_3788)),_3713 ),_3785 );
                  int _3790 = (_ptr__3706[safe_add( safe_add( _3701,_3789 ),(int)1 )] - _ptr__3706[safe_add( _3701,_3789 )]);
                  int _8479 = (int)0;
                  int _8480 = _3790;
                  for (int _3791 = _8479; _3791 < _8480; ++_3791)
                  {
                    {
                      _ptr__3750[safe_add( safe_add( _3745,_3782 ),_3791 )] = _ptr__3707[safe_add( safe_add( _3703,_ptr__3706[safe_add( _3701,_3789 )] ),_3791 )];
                    }
                  }
                  int _8481 = (int)0;
                  int _8482 = _3790;
                  for (int _3792 = _8481; _3792 < _8482; ++_3792)
                  {
                    {
                      _ptr__3751[safe_add( safe_add( _3747,_3782 ),_3792 )] = (_ptr__3708[safe_add( safe_add( _3705,_ptr__3706[safe_add( _3701,_3789 )] ),_3792 )] * ((*mval)(_3788)));
                    }
                  }
                  _3786 += (_ptr__3708[safe_add( _3704,_3789 )] * ((*mval)(_3788)));
                  _3787 = true;
                  _3782 += _3790;
                }
              }
              if (_3787)
              {
                {
                  _ptr__3750[safe_add( _3746,_3781 )] = safe_add( safe_mul( _3784,_3713 ),_3785 );
                  _ptr__3751[safe_add( _3748,_3781 )] = _3786;
                  _ptr__3752[safe_add( safe_add( _3744,_3781 ),(int)1 )] = _3782;
                  ++ _3781;
                }
              }
              {}
            }
          }
          _3780 = _3783;
        }
      }
    }
  }
  _3693->peek_expr();
  if ((!_3716))
  {
    {
      _3693->popi64(_3717);
    }
  }
  {}
  _3695->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3793,int _3794,std::shared_ptr< monty::ndarray< int,1 > > _3795){
  _checked_ptr_1<int> _ptr__3795(_3795 ? _3795->raw() : nullptr, _3795 ? _3795->size(0) : 0);
  if (((int)((_3795)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3794 != _ptr__3795[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3793),(int)(_ptr__3795[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3796,int _3797,std::shared_ptr< monty::ndarray< int,1 > > _3798,std::shared_ptr< monty::ndarray< int,1 > > _3799,std::shared_ptr< monty::ndarray< double,1 > > _3800,monty::rc_ptr< ::mosek::fusion::Expression > _3801){
  _checked_ptr_1<int> _ptr__3798(_3798 ? _3798->raw() : nullptr, _3798 ? _3798->size(0) : 0);
  _checked_ptr_1<int> _ptr__3799(_3799 ? _3799->raw() : nullptr, _3799 ? _3799->size(0) : 0);
  _checked_ptr_1<double> _ptr__3800(_3800 ? _3800->raw() : nullptr, _3800 ? _3800->size(0) : 0);
  if ((_3801->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3802 = _3801->getDim((int)0);
  int _3803 = _3801->getDim((int)0);
  if (((_3796 < (int)0) || (_3797 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3797 != _3802))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3798)->size(0)) != (int)((_3799)->size(0))) || ((int)((_3798)->size(0)) != (int)((_3800)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3804 = (int)((_3798)->size(0));
  int _8483 = (int)0;
  int _8484 = _3804;
  for (int _3805 = _8483; _3805 < _8484; ++_3805)
  {
    {
      if (((_ptr__3798[_3805] < (int)0) || ((_ptr__3798[_3805] >= _3796) || ((_ptr__3799[_3805] < (int)0) || (_ptr__3799[_3805] >= _3797)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8485 = (int)0;
  int _8486 = (_3804 - (int)1);
  for (int _3806 = _8485; _3806 < _8486; ++_3806)
  {
    {
      if (((_ptr__3798[_3806] > _ptr__3798[safe_add( _3806,(int)1 )]) || ((_ptr__3798[_3806] == _ptr__3798[safe_add( _3806,(int)1 )]) && (_ptr__3799[_3806] >= _ptr__3799[safe_add( _3806,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8487 = (int)0;
  int _8488 = _3804;
  for (int _3807 = _8487; _3807 < _8488; ++_3807)
  {
    {
      if (((_ptr__3798[_3807] < (int)0) || ((_ptr__3798[_3807] >= _3796) || ((_ptr__3799[_3807] < (int)0) || (_ptr__3799[_3807] >= _3797)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3808,    int _3809,    int _3810,    std::shared_ptr< monty::ndarray< int,1 > > _3811,    std::shared_ptr< monty::ndarray< int,1 > > _3812,    std::shared_ptr< monty::ndarray< double,1 > > _3813,    monty::rc_ptr< ::mosek::fusion::Variable > _3814){ return new mosek::fusion::ExprMulVar(_3808,_3809,_3810,_3811,_3812,_3813,_3814); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3808,    int _3809,    int _3810,    std::shared_ptr< monty::ndarray< int,1 > > _3811,    std::shared_ptr< monty::ndarray< int,1 > > _3812,    std::shared_ptr< monty::ndarray< double,1 > > _3813,    monty::rc_ptr< ::mosek::fusion::Variable > _3814) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3808,_3809,_3810,_3811,_3812,_3813,_3814); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3808,    int _3809,    int _3810,    std::shared_ptr< monty::ndarray< int,1 > > _3811,    std::shared_ptr< monty::ndarray< int,1 > > _3812,    std::shared_ptr< monty::ndarray< double,1 > > _3813,    monty::rc_ptr< ::mosek::fusion::Variable > _3814){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3811(_3811 ? _3811->raw() : nullptr, _3811 ? _3811->size(0) : 0);
    _checked_ptr_1<int> _ptr__3812(_3812 ? _3812->raw() : nullptr, _3812 ? _3812->size(0) : 0);
    _checked_ptr_1<double> _ptr__3813(_3813 ? _3813->raw() : nullptr, _3813 ? _3813->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3808,_3809,_3810,_3811,_3812,_3813,_3814,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3815 = _3814->getShape();
    _checked_ptr_1<int> _ptr__3815(_3815 ? _3815->raw() : nullptr,_3815 ? _3815->size(0) : 0);
    int _3816 = (int)((_3815)->size(0));
    if ((_3816 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3808 && (_ptr__3815[(int)0] != _3810)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3808) && (_ptr__3815[(int)1] != _3809)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3811)->size(0)) != (int)((_3812)->size(0))) || ((int)((_3811)->size(0)) != (int)((_3813)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3809,_3810,_3811,_3812,_3813);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3817,    int _3818,    int _3819,    std::shared_ptr< monty::ndarray< int,1 > > _3820,    std::shared_ptr< monty::ndarray< int,1 > > _3821,    std::shared_ptr< monty::ndarray< double,1 > > _3822,    monty::rc_ptr< ::mosek::fusion::Variable > _3823,    int _3824){ return new mosek::fusion::ExprMulVar(_3817,_3818,_3819,_3820,_3821,_3822,_3823,_3824); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3817,    int _3818,    int _3819,    std::shared_ptr< monty::ndarray< int,1 > > _3820,    std::shared_ptr< monty::ndarray< int,1 > > _3821,    std::shared_ptr< monty::ndarray< double,1 > > _3822,    monty::rc_ptr< ::mosek::fusion::Variable > _3823,    int _3824) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3817,_3818,_3819,_3820,_3821,_3822,_3823,_3824); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3817,    int _3818,    int _3819,    std::shared_ptr< monty::ndarray< int,1 > > _3820,    std::shared_ptr< monty::ndarray< int,1 > > _3821,    std::shared_ptr< monty::ndarray< double,1 > > _3822,    monty::rc_ptr< ::mosek::fusion::Variable > _3823,    int _3824){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3820(_3820 ? _3820->raw() : nullptr, _3820 ? _3820->size(0) : 0);
    _checked_ptr_1<int> _ptr__3821(_3821 ? _3821->raw() : nullptr, _3821 ? _3821->size(0) : 0);
    _checked_ptr_1<double> _ptr__3822(_3822 ? _3822->raw() : nullptr, _3822 ? _3822->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3818,_3819,_3823->getShape(),_3817));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3817;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3823;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3818;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3819;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3820);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3821);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3822);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3825,monty::rc_ptr< ::mosek::fusion::WorkStack > _3826,monty::rc_ptr< ::mosek::fusion::WorkStack > _3827) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3825,_3826,_3827); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3825,monty::rc_ptr< ::mosek::fusion::WorkStack > _3826,monty::rc_ptr< ::mosek::fusion::WorkStack > _3827){
  if (left)
  {
    {
      _pubthis->eval_left(_3825,_3826,_3827);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3825,_3826,_3827);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3828,monty::rc_ptr< ::mosek::fusion::WorkStack > _3829,monty::rc_ptr< ::mosek::fusion::WorkStack > _3830) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3828,_3829,_3830); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3828,monty::rc_ptr< ::mosek::fusion::WorkStack > _3829,monty::rc_ptr< ::mosek::fusion::WorkStack > _3830){
  int _3831 = mosek::fusion::p_WorkStack::_get_impl(_3829)->pi32;
  int _3832 = mosek::fusion::p_WorkStack::_get_impl(_3829)->pi64;
  int _3833 = x->numInst();
  int _3834 = _3829->alloci64(_3833);
  int _3835 = _3829->alloci64(_3833);
  int _3836 = _3829->alloci32(_3833);
  int _3837 = _3829->alloci32(_3833);
  std::shared_ptr< monty::ndarray< int,1 > > _3838 = x->getShape();
  _checked_ptr_1<int> _ptr__3838(_3838 ? _3838->raw() : nullptr,_3838 ? _3838->size(0) : 0);
  int _3839 = (int)((_3838)->size(0));
  long long _3840 = safe_mul( _ptr__3838[(int)0],_ptr__3838[(int)1] );
  int _3841 = _ptr__3838[(int)1];
  int _3842 = _ptr__3838[(int)0];
  int _3843 = _3829->alloci32(safe_add( _3842,(int)1 ));
  int _3844 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3845 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3845(_3845 ? _3845->raw() : nullptr,_3845 ? _3845->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3846 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3846(_3846 ? _3846->raw() : nullptr,_3846 ? _3846->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3847 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3847(_3847 ? _3847->raw() : nullptr,_3847 ? _3847->size(0) : 0);
  int _3848 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3849 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3850 = ((_3844 / _3848) == _3849);
  int _3851 = _3829->alloci32(_3844);
  int _3852 = _3829->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3853 = mosek::fusion::p_WorkStack::_get_impl(_3829)->i32;
  _checked_ptr_1<int> _ptr__3853(_3853 ? _3853->raw() : nullptr,_3853 ? _3853->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3854 = mosek::fusion::p_WorkStack::_get_impl(_3829)->i64;
  _checked_ptr_1<long long> _ptr__3854(_3854 ? _3854->raw() : nullptr,_3854 ? _3854->size(0) : 0);
  int _3855 = (int)0;
  int _3856 = (int)0;
  x->inst(_3835,_3854,_3834,_3854);
  if (_3850)
  {
    {
      int _3857 = (int)0;
      if ((_3833 > (int)0))
      {
        {
          _3857 = (int)1;
          if ((_3842 > (int)1))
          {
            {
              if ((_3841 == (int)1))
              {
                {
                  int _8489 = (int)1;
                  int _8490 = _3833;
                  for (int _3858 = _8489; _3858 < _8490; ++_3858)
                  {
                    {
                      if ((_ptr__3854[safe_add( _3835,_3858 )] > _ptr__3854[(safe_add( _3835,_3858 ) - (int)1)]))
                      {
                        {
                          ++ _3857;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8491 = (int)1;
                  int _8492 = _3833;
                  for (int _3859 = _8491; _3859 < _8492; ++_3859)
                  {
                    {
                      if (((_ptr__3854[safe_add( _3835,_3859 )] / _3841) > (_ptr__3854[(safe_add( _3835,_3859 ) - (int)1)] / _3841)))
                      {
                        {
                          ++ _3857;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3856 = safe_mul( _3857,_3849 );
      _3855 = safe_mul( _3833,_3849 );
      bool _3860 = (_3857 < _3842);
      int _3861 = _3828->alloci32(safe_add( _3856,(int)1 ));
      int _8493;
      bool _8494 = _3860;
      if (_8494)
      {
        _8493 = (int)1;
      }
      else
      {
        _8493 = (int)0;
      }
      _3828->pushi32(_8493);
      _3828->pushi32(_3855);
      _3828->pushi32(_3856);
      _3828->pushi32(_3842);
      _3828->pushi32(_3849);
      _3828->pushi32((int)2);
      int _3862 = _3828->alloci64(_3855);
      int _3863 = _3828->alloci64(_3856);
      int _3864 = _3828->allocf64(_3855);
      int _3865 = _3828->allocf64(_3856);
      std::shared_ptr< monty::ndarray< int,1 > > _3866 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i32;
      _checked_ptr_1<int> _ptr__3866(_3866 ? _3866->raw() : nullptr,_3866 ? _3866->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3867 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i64;
      _checked_ptr_1<long long> _ptr__3867(_3867 ? _3867->raw() : nullptr,_3867 ? _3867->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3868 = mosek::fusion::p_WorkStack::_get_impl(_3828)->f64;
      _checked_ptr_1<double> _ptr__3868(_3868 ? _3868->raw() : nullptr,_3868 ? _3868->size(0) : 0);
      {
        int _3869 = (int)0;
        int _3870 = (int)0;
        int _3871 = (int)0;
        _ptr__3866[_3861] = (int)0;
        while ( (_3869 < _3833) )
        {
          {
            int _3872 = _3869;
            ++ _3869;
            while ( ((_3869 < _3833) && ((_ptr__3854[safe_add( _3835,_3869 )] / _3841) == (_ptr__3854[safe_add( _3835,_3872 )] / _3841))) )
            {
              {
                ++ _3869;
              }
            }
            long long _3873 = (_ptr__3854[safe_add( _3835,_3872 )] / _3841);
            int _8495 = (int)0;
            int _8496 = _3849;
            for (int _3874 = _8495; _3874 < _8496; ++_3874)
            {
              {
                int _8497 = _3872;
                int _8498 = _3869;
                for (int _3875 = _8497; _3875 < _8498; ++_3875)
                {
                  {
                    long long _3876 = (_ptr__3854[safe_add( _3835,_3875 )] % _3841);
                    _ptr__3867[safe_add( _3862,_3871 )] = _ptr__3854[safe_add( _3834,_3875 )];
                    _ptr__3868[safe_add( _3864,_3871 )] = _ptr__3847[safe_add( safe_mul( _3876,_3849 ),_3874 )];
                    ++ _3871;
                  }
                }
                _ptr__3866[safe_add( safe_add( _3861,_3870 ),(int)1 )] = _3871;
                _ptr__3868[safe_add( _3865,_3870 )] = 0.0;
                _ptr__3867[safe_add( _3863,_3870 )] = safe_add( safe_mul( _3873,_3849 ),_3874 );
                ++ _3870;
              }
            }
          }
        }
      }
      if ((!_3860))
      {
        {
          _3828->popi64(_3856);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3849 == (int)1))
        {
          {
            int _8499 = (int)0;
            int _8500 = _3844;
            for (int _3877 = _8499; _3877 < _8500; ++_3877)
            {
              {
                _ptr__3853[safe_add( _3851,_3877 )] = _3877;
              }
            }
            _ptr__3853[_3852] = (int)0;
            _ptr__3853[safe_add( _3852,(int)1 )] = _3844;
          }
        }
        else
        {
          {
            _ptr__3853[_3852] = (int)0;
            int _8501 = (int)0;
            int _8502 = safe_add( _3849,(int)1 );
            for (int _3878 = _8501; _3878 < _8502; ++_3878)
            {
              {
                _ptr__3853[safe_add( _3852,_3878 )] = (int)0;
              }
            }
            int _8503 = (int)0;
            int _8504 = _3844;
            for (int _3879 = _8503; _3879 < _8504; ++_3879)
            {
              {
                ++ _ptr__3853[safe_add( safe_add( _3852,_ptr__3846[_3879] ),(int)1 )];
              }
            }
            int _8505 = (int)0;
            int _8506 = mdimj;
            for (int _3880 = _8505; _3880 < _8506; ++_3880)
            {
              {
                _ptr__3853[safe_add( safe_add( _3852,_3880 ),(int)1 )] += _ptr__3853[safe_add( _3852,_3880 )];
              }
            }
            int _8507 = (int)0;
            int _8508 = _3844;
            for (int _3881 = _8507; _3881 < _8508; ++_3881)
            {
              {
                _ptr__3853[safe_add( _3851,_ptr__3853[safe_add( _3852,_ptr__3846[_3881] )] )] = _3881;
                ++ _ptr__3853[safe_add( _3852,_ptr__3846[_3881] )];
              }
            }
            int _8509 = (int)0;
            int _8510 = _3849;
            for (int _3882 = _8509; _3882 < _8510; ++_3882)
            {
              {
                _ptr__3853[(safe_add( _3852,_3849 ) - _3882)] = _ptr__3853[((safe_add( _3852,_3849 ) - _3882) - (int)1)];
              }
            }
            _ptr__3853[_3852] = (int)0;
          }
        }
      }
      if (((_3833 / _3842) == _3841))
      {
        {
          int _3883 = (int)0;
          {
            int _3884 = (int)0;
            while ( (_3884 < _3844) )
            {
              {
                ++ _3884;
                while ( ((_3884 < _3844) && (_ptr__3846[_ptr__3853[(safe_add( _3851,_3884 ) - (int)1)]] == _ptr__3846[_ptr__3853[safe_add( _3851,_3884 )]])) )
                {
                  {
                    ++ _3884;
                  }
                }
                ++ _3883;
              }
            }
          }
          _3856 = safe_mul( _3883,_3842 );
          _3855 = safe_mul( _3844,_3842 );
          bool _3885 = (_3883 < _3849);
          int _3886 = _3828->alloci32(safe_add( _3856,(int)1 ));
          int _8511;
          bool _8512 = _3885;
          if (_8512)
          {
            _8511 = (int)1;
          }
          else
          {
            _8511 = (int)0;
          }
          _3828->pushi32(_8511);
          _3828->pushi32(_3855);
          _3828->pushi32(_3856);
          _3828->pushi32(_3842);
          _3828->pushi32(_3849);
          _3828->pushi32((int)2);
          int _3887 = _3828->alloci64(_3855);
          int _3888 = _3828->alloci64(_3856);
          int _3889 = _3828->allocf64(_3855);
          int _3890 = _3828->allocf64(_3856);
          std::shared_ptr< monty::ndarray< int,1 > > _3891 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i32;
          _checked_ptr_1<int> _ptr__3891(_3891 ? _3891->raw() : nullptr,_3891 ? _3891->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3892 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i64;
          _checked_ptr_1<long long> _ptr__3892(_3892 ? _3892->raw() : nullptr,_3892 ? _3892->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3893 = mosek::fusion::p_WorkStack::_get_impl(_3828)->f64;
          _checked_ptr_1<double> _ptr__3893(_3893 ? _3893->raw() : nullptr,_3893 ? _3893->size(0) : 0);
          _ptr__3891[_3886] = (int)0;
          int _3894 = (int)0;
          int _3895 = (int)0;
          int _8513 = (int)0;
          int _8514 = _3842;
          for (int _3896 = _8513; _3896 < _8514; ++_3896)
          {
            {
              int _3897 = (int)0;
              while ( (_3897 < _3844) )
              {
                {
                  int _3898 = _3897;
                  ++ _3897;
                  while ( ((_3897 < _3844) && (_ptr__3846[_ptr__3853[safe_add( _3851,_3898 )]] == _ptr__3846[_ptr__3853[safe_add( _3851,_3897 )]])) )
                  {
                    {
                      ++ _3897;
                    }
                  }
                  int _3899 = _ptr__3846[_ptr__3853[safe_add( _3851,_3898 )]];
                  int _8515 = _3898;
                  int _8516 = _3897;
                  for (int _3900 = _8515; _3900 < _8516; ++_3900)
                  {
                    {
                      int _3901 = _ptr__3845[_ptr__3853[safe_add( _3851,_3900 )]];
                      _ptr__3892[safe_add( _3887,_3895 )] = _ptr__3854[safe_add( safe_add( _3834,safe_mul( _3896,_3841 ) ),_3901 )];
                      _ptr__3893[safe_add( _3889,_3895 )] = _ptr__3847[_ptr__3853[safe_add( _3851,_3900 )]];
                      ++ _3895;
                    }
                  }
                  _ptr__3893[safe_add( _3890,_3894 )] = 0.0;
                  _ptr__3892[safe_add( _3888,_3894 )] = safe_add( safe_mul( _3896,_3849 ),_3899 );
                  _ptr__3891[safe_add( safe_add( _3886,_3894 ),(int)1 )] = _3895;
                  ++ _3894;
                }
              }
            }
          }
          if ((!_3885))
          {
            {
              _3828->popi64(_3856);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8517 = (int)0;
          int _8518 = safe_add( _3842,(int)1 );
          for (int _3902 = _8517; _3902 < _8518; ++_3902)
          {
            {
              _ptr__3853[safe_add( _3843,_3902 )] = (int)0;
            }
          }
          if ((_3839 == (int)1))
          {
            {
              int _8519 = (int)0;
              int _8520 = _3833;
              for (int _3903 = _8519; _3903 < _8520; ++_3903)
              {
                {
                  _ptr__3853[safe_add( _3836,_3903 )] = (int)0;
                }
              }
              int _8521 = (int)0;
              int _8522 = _3833;
              for (int _3904 = _8521; _3904 < _8522; ++_3904)
              {
                {
                  _ptr__3853[safe_add( _3837,_3904 )] = (int)_ptr__3854[safe_add( _3835,_3904 )];
                }
              }
              _ptr__3853[_3843] = (int)0;
              _ptr__3853[safe_add( _3843,(int)1 )] = _3833;
            }
          }
          else
          {
            {
              int _8523 = (int)0;
              int _8524 = _3833;
              for (int _3905 = _8523; _3905 < _8524; ++_3905)
              {
                {
                  _ptr__3853[safe_add( _3836,_3905 )] = (int)(_ptr__3854[safe_add( _3835,_3905 )] / _ptr__3838[(int)1]);
                }
              }
              int _8525 = (int)0;
              int _8526 = _3833;
              for (int _3906 = _8525; _3906 < _8526; ++_3906)
              {
                {
                  _ptr__3853[safe_add( _3837,_3906 )] = (int)(_ptr__3854[safe_add( _3835,_3906 )] % _ptr__3838[(int)1]);
                }
              }
              _ptr__3853[_3843] = (int)0;
              int _8527 = (int)0;
              int _8528 = _3833;
              for (int _3907 = _8527; _3907 < _8528; ++_3907)
              {
                {
                  ++ _ptr__3853[safe_add( safe_add( _3843,_ptr__3853[safe_add( _3836,_3907 )] ),(int)1 )];
                }
              }
              int _8529 = (int)0;
              int _8530 = _3842;
              for (int _3908 = _8529; _3908 < _8530; ++_3908)
              {
                {
                  _ptr__3853[safe_add( safe_add( _3843,_3908 ),(int)1 )] += _ptr__3853[safe_add( _3843,_3908 )];
                }
              }
            }
          }
          int _8531 = (int)0;
          int _8532 = _3842;
          for (int _3909 = _8531; _3909 < _8532; ++_3909)
          {
            {
              int _8533 = (int)0;
              int _8534 = mdimj;
              for (int _3910 = _8533; _3910 < _8534; ++_3910)
              {
                {
                  int _3911 = (int)0;
                  int _3912 = _ptr__3853[safe_add( safe_add( _3843,_3909 ),(int)1 )];
                  int _3913 = _ptr__3853[safe_add( safe_add( _3852,_3910 ),(int)1 )];
                  int _3914 = _ptr__3853[safe_add( _3843,_3909 )];
                  int _3915 = _ptr__3853[safe_add( _3852,_3910 )];
                  while ( ((_3915 < _3913) && (_3914 < _3912)) )
                  {
                    {
                      if ((_ptr__3845[_ptr__3853[safe_add( _3851,_3915 )]] < _ptr__3853[safe_add( _3837,_3914 )]))
                      {
                        {
                          ++ _3915;
                        }
                      }
                      else if((_ptr__3845[_ptr__3853[safe_add( _3851,_3915 )]] > _ptr__3853[safe_add( _3837,_3914 )]))
                      {
                        {
                          ++ _3914;
                        }
                      }
                      else
                      {
                        {
                          ++ _3911;
                          ++ _3915;
                          ++ _3914;
                        }
                      }
                    }
                  }
                  if ((_3911 > (int)0))
                  {
                    {
                      _3855 += _3911;
                      ++ _3856;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _3916 = _3828->alloci32(safe_add( _3856,(int)1 ));
          bool _8535;
          bool _8536 = (_3856 < safe_mul( _3841,mdimi ));
          if (_8536)
          {
            _8535 = true;
          }
          else
          {
            _8535 = false;
          }
          bool _3917 = _8535;
          int _8537;
          bool _8538 = _3917;
          if (_8538)
          {
            _8537 = (int)1;
          }
          else
          {
            _8537 = (int)0;
          }
          _3828->pushi32(_8537);
          _3828->pushi32(_3855);
          _3828->pushi32(_3856);
          _3828->pushi32(_3842);
          _3828->pushi32(mdimj);
          _3828->pushi32((int)2);
          int _3918 = _3828->alloci64(_3855);
          int _3919 = _3828->alloci64(_3856);
          int _3920 = _3828->allocf64(_3855);
          int _3921 = _3828->allocf64(_3856);
          std::shared_ptr< monty::ndarray< int,1 > > _3922 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i32;
          _checked_ptr_1<int> _ptr__3922(_3922 ? _3922->raw() : nullptr,_3922 ? _3922->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3923 = mosek::fusion::p_WorkStack::_get_impl(_3828)->i64;
          _checked_ptr_1<long long> _ptr__3923(_3923 ? _3923->raw() : nullptr,_3923 ? _3923->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3924 = mosek::fusion::p_WorkStack::_get_impl(_3828)->f64;
          _checked_ptr_1<double> _ptr__3924(_3924 ? _3924->raw() : nullptr,_3924 ? _3924->size(0) : 0);
          {
            int _3925 = (int)0;
            int _3926 = (int)0;
            int _3927 = (int)0;
            _ptr__3922[_3916] = (int)0;
            int _8539 = (int)0;
            int _8540 = _3856;
            for (int _3928 = _8539; _3928 < _8540; ++_3928)
            {
              {
                _ptr__3924[safe_add( _3921,_3928 )] = 0.0;
              }
            }
            int _8541 = (int)0;
            int _8542 = _3842;
            for (int _3929 = _8541; _3929 < _8542; ++_3929)
            {
              {
                int _8543 = (int)0;
                int _8544 = mdimj;
                for (int _3930 = _8543; _3930 < _8544; ++_3930)
                {
                  {
                    int _3931 = (int)0;
                    int _3932 = _ptr__3853[safe_add( safe_add( _3843,_3929 ),(int)1 )];
                    int _3933 = _ptr__3853[safe_add( safe_add( _3852,_3930 ),(int)1 )];
                    int _3934 = _ptr__3853[safe_add( _3843,_3929 )];
                    int _3935 = _ptr__3853[safe_add( _3852,_3930 )];
                    while ( ((_3935 < _3933) && (_3934 < _3932)) )
                    {
                      {
                        if ((_ptr__3845[_ptr__3853[safe_add( _3851,_3935 )]] < _ptr__3853[safe_add( _3837,_3934 )]))
                        {
                          {
                            ++ _3935;
                          }
                        }
                        else if((_ptr__3845[_ptr__3853[safe_add( _3851,_3935 )]] > _ptr__3853[safe_add( _3837,_3934 )]))
                        {
                          {
                            ++ _3934;
                          }
                        }
                        else
                        {
                          {
                            _ptr__3923[safe_add( _3918,_3927 )] = _ptr__3854[safe_add( _3834,_3934 )];
                            _ptr__3924[safe_add( _3920,_3927 )] = _ptr__3847[_ptr__3853[safe_add( _3851,_3935 )]];
                            ++ _3931;
                            ++ _3927;
                            ++ _3935;
                            ++ _3934;
                          }
                        }
                      }
                    }
                    if ((_3931 > (int)0))
                    {
                      {
                        _ptr__3922[safe_add( safe_add( _3916,_3926 ),(int)1 )] = _3927;
                        _ptr__3923[safe_add( _3919,_3926 )] = _3925;
                        ++ _3926;
                      }
                    }
                    {}
                    ++ _3925;
                  }
                }
              }
            }
          }
          if ((!_3917))
          {
            {
              _3828->popi64(_3856);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3829)->pi32 = _3831;
  mosek::fusion::p_WorkStack::_get_impl(_3829)->pi64 = _3832;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3936,monty::rc_ptr< ::mosek::fusion::WorkStack > _3937,monty::rc_ptr< ::mosek::fusion::WorkStack > _3938) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_3936,_3937,_3938); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3936,monty::rc_ptr< ::mosek::fusion::WorkStack > _3937,monty::rc_ptr< ::mosek::fusion::WorkStack > _3938){
  int _3939 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _3940 = x->getShape();
  _checked_ptr_1<int> _ptr__3940(_3940 ? _3940->raw() : nullptr,_3940 ? _3940->size(0) : 0);
  int _3941 = (int)((_3940)->size(0));
  int _3942 = _3938->alloci64(_3939);
  int _3943 = _3938->alloci64(_3939);
  int _3944 = _3938->alloci32(_3939);
  int _3945 = _3938->alloci32(_3939);
  int _3946 = _3938->alloci32(_3939);
  int _3947 = _3938->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3948 = x->getShape();
  _checked_ptr_1<int> _ptr__3948(_3948 ? _3948->raw() : nullptr,_3948 ? _3948->size(0) : 0);
  int _3949 = (int)((_3948)->size(0));
  int _8545;
  bool _8546 = (_3949 == (int)1);
  if (_8546)
  {
    _8545 = (int)1;
  }
  else
  {
    _8545 = _ptr__3948[(int)1];
  }
  int _3950 = _8545;
  int _3951 = _ptr__3948[(int)0];
  int _3952 = _3938->alloci32(safe_add( _3950,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3953 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3953(_3953 ? _3953->raw() : nullptr,_3953 ? _3953->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3954 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3954(_3954 ? _3954->raw() : nullptr,_3954 ? _3954->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3955 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3955(_3955 ? _3955->raw() : nullptr,_3955 ? _3955->size(0) : 0);
  int _3956 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3957 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _3958 = (int)0;
  int _3959 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _3960 = mosek::fusion::p_WorkStack::_get_impl(_3938)->i32;
  _checked_ptr_1<int> _ptr__3960(_3960 ? _3960->raw() : nullptr,_3960 ? _3960->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3961 = mosek::fusion::p_WorkStack::_get_impl(_3938)->i64;
  _checked_ptr_1<long long> _ptr__3961(_3961 ? _3961->raw() : nullptr,_3961 ? _3961->size(0) : 0);
  x->inst(_3943,_3961,_3942,_3961);
  {
    int _8547 = (int)0;
    int _8548 = safe_add( _3956,(int)1 );
    for (int _3962 = _8547; _3962 < _8548; ++_3962)
    {
      {
        _ptr__3960[safe_add( _3947,_3962 )] = (int)0;
      }
    }
    int _8549 = (int)0;
    int _8550 = (int)((_3953)->size(0));
    for (int _3963 = _8549; _3963 < _8550; ++_3963)
    {
      {
        ++ _ptr__3960[safe_add( safe_add( _3947,_ptr__3953[_3963] ),(int)1 )];
      }
    }
    int _8551 = (int)0;
    int _8552 = _3956;
    for (int _3964 = _8551; _3964 < _8552; ++_3964)
    {
      {
        _ptr__3960[safe_add( safe_add( _3947,_3964 ),(int)1 )] += _ptr__3960[safe_add( _3947,_3964 )];
      }
    }
    if ((_3949 == (int)1))
    {
      {
        int _8553 = (int)0;
        int _8554 = _3939;
        for (int _3965 = _8553; _3965 < _8554; ++_3965)
        {
          {
            _ptr__3960[safe_add( _3944,_3965 )] = (int)_ptr__3961[safe_add( _3943,_3965 )];
          }
        }
        int _8555 = (int)0;
        int _8556 = _3939;
        for (int _3966 = _8555; _3966 < _8556; ++_3966)
        {
          {
            _ptr__3960[safe_add( _3945,_3966 )] = (int)0;
          }
        }
      }
    }
    else
    {
      {
        int _8557 = (int)0;
        int _8558 = _3939;
        for (int _3967 = _8557; _3967 < _8558; ++_3967)
        {
          {
            _ptr__3960[safe_add( _3944,_3967 )] = (int)(_ptr__3961[safe_add( _3943,_3967 )] / _3950);
          }
        }
        int _8559 = (int)0;
        int _8560 = _3939;
        for (int _3968 = _8559; _3968 < _8560; ++_3968)
        {
          {
            _ptr__3960[safe_add( _3945,_3968 )] = (int)(_ptr__3961[safe_add( _3943,_3968 )] % _3950);
          }
        }
      }
    }
    if ((_3949 > (int)1))
    {
      {
        int _8561 = (int)0;
        int _8562 = safe_add( _3950,(int)1 );
        for (int _3969 = _8561; _3969 < _8562; ++_3969)
        {
          {
            _ptr__3960[safe_add( _3952,_3969 )] = (int)0;
          }
        }
        int _8563 = (int)0;
        int _8564 = _3939;
        for (int _3970 = _8563; _3970 < _8564; ++_3970)
        {
          {
            ++ _ptr__3960[safe_add( safe_add( _3952,_ptr__3960[safe_add( _3945,_3970 )] ),(int)1 )];
          }
        }
        int _8565 = (int)0;
        int _8566 = _3950;
        for (int _3971 = _8565; _3971 < _8566; ++_3971)
        {
          {
            _ptr__3960[safe_add( safe_add( _3952,_3971 ),(int)1 )] += _ptr__3960[safe_add( _3952,_3971 )];
          }
        }
        int _8567 = (int)0;
        int _8568 = _3939;
        for (int _3972 = _8567; _3972 < _8568; ++_3972)
        {
          {
            _ptr__3960[safe_add( _3946,_ptr__3960[safe_add( _3952,_ptr__3960[safe_add( _3945,_3972 )] )] )] = _3972;
            ++ _ptr__3960[safe_add( _3952,_ptr__3960[safe_add( _3945,_3972 )] )];
          }
        }
        int _8569 = (int)0;
        int _8570 = _3950;
        for (int _3973 = _8569; _3973 < _8570; ++_3973)
        {
          {
            _ptr__3960[(safe_add( _3952,_3950 ) - _3973)] = _ptr__3960[((safe_add( _3952,_3950 ) - _3973) - (int)1)];
          }
        }
        _ptr__3960[_3952] = (int)0;
      }
    }
    else
    {
      {
        _ptr__3960[_3952] = (int)0;
        _ptr__3960[safe_add( _3952,(int)1 )] = _3939;
        int _8571 = (int)0;
        int _8572 = _3939;
        for (int _3974 = _8571; _3974 < _8572; ++_3974)
        {
          {
            _ptr__3960[safe_add( _3946,_3974 )] = _3974;
          }
        }
      }
    }
    int _8573 = (int)0;
    int _8574 = _3956;
    for (int _3975 = _8573; _3975 < _8574; ++_3975)
    {
      {
        int _8575 = (int)0;
        int _8576 = _3950;
        for (int _3976 = _8575; _3976 < _8576; ++_3976)
        {
          {
            int _3977 = (int)0;
            int _3978 = _ptr__3960[safe_add( safe_add( _3952,_3976 ),(int)1 )];
            int _3979 = _ptr__3960[safe_add( safe_add( _3947,_3975 ),(int)1 )];
            int _3980 = _ptr__3960[safe_add( _3952,_3976 )];
            int _3981 = _ptr__3960[safe_add( _3947,_3975 )];
            while ( ((_3981 < _3979) && (_3980 < _3978)) )
            {
              {
                if ((_ptr__3954[_3981] < _ptr__3960[safe_add( _3944,_ptr__3960[safe_add( _3946,_3980 )] )]))
                {
                  {
                    ++ _3981;
                  }
                }
                else if((_ptr__3954[_3981] > _ptr__3960[safe_add( _3944,_ptr__3960[safe_add( _3946,_3980 )] )]))
                {
                  {
                    ++ _3980;
                  }
                }
                else
                {
                  {
                    ++ _3977;
                    ++ _3981;
                    ++ _3980;
                  }
                }
              }
            }
            if ((_3977 > (int)0))
            {
              {
                _3958 += _3977;
                ++ _3959;
              }
            }
            {}
          }
        }
      }
    }
  }
  bool _8577;
  bool _8578 = (_3959 < safe_mul( _3950,_3956 ));
  if (_8578)
  {
    _8577 = true;
  }
  else
  {
    _8577 = false;
  }
  bool _3982 = _8577;
  int _3983 = _3949;
  _3936->alloc_expr(_3983,_3959,_3958,_3982);
  int _3984 = mosek::fusion::p_WorkStack::_get_impl(_3936)->ptr_base;
  int _3985 = mosek::fusion::p_WorkStack::_get_impl(_3936)->shape_base;
  int _3986 = mosek::fusion::p_WorkStack::_get_impl(_3936)->nidxs_base;
  int _8579;
  bool _8580 = _3982;
  if (_8580)
  {
    _8579 = mosek::fusion::p_WorkStack::_get_impl(_3936)->sp_base;
  }
  else
  {
    _8579 = _3936->alloci64(_3959);
  }
  int _3987 = _8579;
  int _3988 = mosek::fusion::p_WorkStack::_get_impl(_3936)->cof_base;
  int _3989 = mosek::fusion::p_WorkStack::_get_impl(_3936)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3990 = mosek::fusion::p_WorkStack::_get_impl(_3936)->i32;
  _checked_ptr_1<int> _ptr__3990(_3990 ? _3990->raw() : nullptr,_3990 ? _3990->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3991 = mosek::fusion::p_WorkStack::_get_impl(_3936)->i64;
  _checked_ptr_1<long long> _ptr__3991(_3991 ? _3991->raw() : nullptr,_3991 ? _3991->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3992 = mosek::fusion::p_WorkStack::_get_impl(_3936)->f64;
  _checked_ptr_1<double> _ptr__3992(_3992 ? _3992->raw() : nullptr,_3992 ? _3992->size(0) : 0);
  _ptr__3990[_3985] = _3956;
  if ((_3949 > (int)1))
  {
    {
      _ptr__3990[safe_add( _3985,(int)1 )] = _3950;
    }
  }
  {}
  {
    int _3993 = (int)0;
    int _3994 = (int)0;
    int _3995 = (int)0;
    _ptr__3990[_3984] = (int)0;
    int _8581 = (int)0;
    int _8582 = _3959;
    for (int _3996 = _8581; _3996 < _8582; ++_3996)
    {
      {
        _ptr__3992[safe_add( _3989,_3996 )] = 0.0;
      }
    }
    int _8583 = (int)0;
    int _8584 = _3956;
    for (int _3997 = _8583; _3997 < _8584; ++_3997)
    {
      {
        int _8585 = (int)0;
        int _8586 = _3950;
        for (int _3998 = _8585; _3998 < _8586; ++_3998)
        {
          {
            int _3999 = (int)0;
            int _4000 = _ptr__3960[safe_add( safe_add( _3952,_3998 ),(int)1 )];
            int _4001 = _ptr__3960[safe_add( safe_add( _3947,_3997 ),(int)1 )];
            int _4002 = _ptr__3960[safe_add( _3952,_3998 )];
            int _4003 = _ptr__3960[safe_add( _3947,_3997 )];
            while ( ((_4003 < _4001) && (_4002 < _4000)) )
            {
              {
                if ((_ptr__3954[_4003] < _ptr__3960[safe_add( _3944,_ptr__3960[safe_add( _3946,_4002 )] )]))
                {
                  {
                    ++ _4003;
                  }
                }
                else if((_ptr__3954[_4003] > _ptr__3960[safe_add( _3944,_ptr__3960[safe_add( _3946,_4002 )] )]))
                {
                  {
                    ++ _4002;
                  }
                }
                else
                {
                  {
                    _ptr__3991[safe_add( _3986,_3995 )] = _ptr__3961[safe_add( _3942,_ptr__3960[safe_add( _3946,_4002 )] )];
                    _ptr__3992[safe_add( _3988,_3995 )] = _ptr__3955[_4003];
                    ++ _3999;
                    ++ _3995;
                    ++ _4003;
                    ++ _4002;
                  }
                }
              }
            }
            if ((_3999 > (int)0))
            {
              {
                _ptr__3990[safe_add( safe_add( _3984,_3994 ),(int)1 )] = _3995;
                _ptr__3991[safe_add( _3987,_3994 )] = _3993;
                ++ _3994;
              }
            }
            {}
            ++ _3993;
          }
        }
      }
    }
  }
  if ((!_3982))
  {
    {
      _3936->popi64(_3959);
    }
  }
  {}
  _3938->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4004,int _4005,std::shared_ptr< monty::ndarray< int,1 > > _4006,std::shared_ptr< monty::ndarray< int,1 > > _4007,std::shared_ptr< monty::ndarray< double,1 > > _4008){
  _checked_ptr_1<int> _ptr__4006(_4006 ? _4006->raw() : nullptr, _4006 ? _4006->size(0) : 0);
  _checked_ptr_1<int> _ptr__4007(_4007 ? _4007->raw() : nullptr, _4007 ? _4007->size(0) : 0);
  _checked_ptr_1<double> _ptr__4008(_4008 ? _4008->raw() : nullptr, _4008 ? _4008->size(0) : 0);
  bool _4009 = true;
  {
    int _8587 = (int)0;
    int _8588 = (int)((_4006)->size(0));
    for (int _4010 = _8587; _4010 < _8588; ++_4010)
    {
      {
        if (((_ptr__4006[_4010] < (int)0) || ((_ptr__4006[_4010] >= _4004) || ((_ptr__4007[_4010] < (int)0) || (_ptr__4007[_4010] >= _4005)))))
        {
          {
            _4009 = false;
          }
        }
        {}
      }
    }
    int _8589 = (int)1;
    int _8590 = (int)((_4006)->size(0));
    for (int _4011 = _8589; _4011 < _8590; ++_4011)
    {
      {
        if (((_ptr__4006[(_4011 - (int)1)] > _ptr__4006[_4011]) || ((_ptr__4006[(_4011 - (int)1)] == _ptr__4006[_4011]) && (_ptr__4007[(_4011 - (int)1)] >= _ptr__4007[_4011]))))
        {
          {
            _4009 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4009))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4012,int _4013,std::shared_ptr< monty::ndarray< int,1 > > _4014,bool _4015){
  _checked_ptr_1<int> _ptr__4014(_4014 ? _4014->raw() : nullptr, _4014 ? _4014->size(0) : 0);
  if (_4015)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4012),(int)(_ptr__4014[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4014[(int)0]),(int)(_4013)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4016,    int _4017,    std::shared_ptr< monty::ndarray< int,1 > > _4018,    std::shared_ptr< monty::ndarray< int,1 > > _4019,    std::shared_ptr< monty::ndarray< double,1 > > _4020,    monty::rc_ptr< ::mosek::fusion::Variable > _4021){ return new mosek::fusion::ExprMulScalarVar(_4016,_4017,_4018,_4019,_4020,_4021); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4016,    int _4017,    std::shared_ptr< monty::ndarray< int,1 > > _4018,    std::shared_ptr< monty::ndarray< int,1 > > _4019,    std::shared_ptr< monty::ndarray< double,1 > > _4020,    monty::rc_ptr< ::mosek::fusion::Variable > _4021) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4016,_4017,_4018,_4019,_4020,_4021); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4016,    int _4017,    std::shared_ptr< monty::ndarray< int,1 > > _4018,    std::shared_ptr< monty::ndarray< int,1 > > _4019,    std::shared_ptr< monty::ndarray< double,1 > > _4020,    monty::rc_ptr< ::mosek::fusion::Variable > _4021){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4018(_4018 ? _4018->raw() : nullptr, _4018 ? _4018->size(0) : 0);
    _checked_ptr_1<int> _ptr__4019(_4019 ? _4019->raw() : nullptr, _4019 ? _4019->size(0) : 0);
    _checked_ptr_1<double> _ptr__4020(_4020 ? _4020->raw() : nullptr, _4020 ? _4020->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4016,_4017,::mosek::fusion::Utils::Tools::arraycopy(_4018),::mosek::fusion::Utils::Tools::arraycopy(_4019),::mosek::fusion::Utils::Tools::arraycopy(_4020),_4021,(int)1);
    if ((_4021->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4016 < (int)0) || ((_4017 < (int)0) || (((int)((_4018)->size(0)) != (int)((_4019)->size(0))) || ((int)((_4018)->size(0)) != (int)((_4020)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    int _8591 = (int)0;
    int _8592 = (int)((_4018)->size(0));
    for (int _4022 = _8591; _4022 < _8592; ++_4022)
    {
      {
        if (((_ptr__4018[_4022] < (int)0) || ((_ptr__4018[_4022] >= _4016) || ((_ptr__4019[_4022] < (int)0) || (_ptr__4019[_4022] >= _4017)))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
          }
        }
        {}
      }
    }
    int _8593 = (int)1;
    int _8594 = (int)((_4018)->size(0));
    for (int _4023 = _8593; _4023 < _8594; ++_4023)
    {
      {
        if (((_ptr__4018[_4023] < _ptr__4018[(_4023 - (int)1)]) || ((_ptr__4018[_4023] == _ptr__4018[(_4023 - (int)1)]) && (_ptr__4019[_4023] <= _ptr__4019[(_4023 - (int)1)]))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4024,    int _4025,    std::shared_ptr< monty::ndarray< int,1 > > _4026,    std::shared_ptr< monty::ndarray< int,1 > > _4027,    std::shared_ptr< monty::ndarray< double,1 > > _4028,    monty::rc_ptr< ::mosek::fusion::Variable > _4029,    int _4030){ return new mosek::fusion::ExprMulScalarVar(_4024,_4025,_4026,_4027,_4028,_4029,_4030); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4024,    int _4025,    std::shared_ptr< monty::ndarray< int,1 > > _4026,    std::shared_ptr< monty::ndarray< int,1 > > _4027,    std::shared_ptr< monty::ndarray< double,1 > > _4028,    monty::rc_ptr< ::mosek::fusion::Variable > _4029,    int _4030) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4024,_4025,_4026,_4027,_4028,_4029,_4030); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4024,    int _4025,    std::shared_ptr< monty::ndarray< int,1 > > _4026,    std::shared_ptr< monty::ndarray< int,1 > > _4027,    std::shared_ptr< monty::ndarray< double,1 > > _4028,    monty::rc_ptr< ::mosek::fusion::Variable > _4029,    int _4030){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4026(_4026 ? _4026->raw() : nullptr, _4026 ? _4026->size(0) : 0);
    _checked_ptr_1<int> _ptr__4027(_4027 ? _4027->raw() : nullptr, _4027 ? _4027->size(0) : 0);
    _checked_ptr_1<double> _ptr__4028(_4028 ? _4028->raw() : nullptr, _4028 ? _4028->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4024),(int)(_4025)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4024;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4025;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4026;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4027;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4028;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4029;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4031,monty::rc_ptr< ::mosek::fusion::WorkStack > _4032,monty::rc_ptr< ::mosek::fusion::WorkStack > _4033) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4031,_4032,_4033); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4031,monty::rc_ptr< ::mosek::fusion::WorkStack > _4032,monty::rc_ptr< ::mosek::fusion::WorkStack > _4033){
  if ((x->numInst() == (int)0))
  {
    {
      _4031->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4031)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4031)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4031)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4031)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4034 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4034(_4034 ? _4034->raw() : nullptr,_4034 ? _4034->size(0) : 0);
      x->inst((int)0,_4034);
      long long _4035 = _ptr__4034[(int)0];
      int _4036 = (int)((msubi)->size(0));
      int _4037 = _4036;
      bool _4038 = (_4036 < safe_mul( mdimi,mdimj ));
      _4031->alloc_expr((int)2,_4036,_4037,_4038);
      int _4039 = mosek::fusion::p_WorkStack::_get_impl(_4031)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4031)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4031)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4031)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4031)->shape_base,(int)1 ))) = mdimj;
      int _4040 = mosek::fusion::p_WorkStack::_get_impl(_4031)->nidxs_base;
      int _4041 = mosek::fusion::p_WorkStack::_get_impl(_4031)->sp_base;
      int _4042 = mosek::fusion::p_WorkStack::_get_impl(_4031)->cof_base;
      int _4043 = mosek::fusion::p_WorkStack::_get_impl(_4031)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4044 = mosek::fusion::p_WorkStack::_get_impl(_4031)->i32;
      _checked_ptr_1<int> _ptr__4044(_4044 ? _4044->raw() : nullptr,_4044 ? _4044->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4045 = mosek::fusion::p_WorkStack::_get_impl(_4031)->i64;
      _checked_ptr_1<long long> _ptr__4045(_4045 ? _4045->raw() : nullptr,_4045 ? _4045->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4046 = mosek::fusion::p_WorkStack::_get_impl(_4031)->f64;
      _checked_ptr_1<double> _ptr__4046(_4046 ? _4046->raw() : nullptr,_4046 ? _4046->size(0) : 0);
      {
        int _8595 = (int)0;
        int _8596 = _4036;
        for (int _4047 = _8595; _4047 < _8596; ++_4047)
        {
          {
            _ptr__4046[safe_add( _4043,_4047 )] = (int)0;
          }
        }
        int _8597 = (int)0;
        int _8598 = _4037;
        for (int _4048 = _8597; _4048 < _8598; ++_4048)
        {
          {
            _ptr__4046[safe_add( _4042,_4048 )] = ((*mcof)(_4048));
          }
        }
        int _8599 = (int)0;
        int _8600 = _4037;
        for (int _4049 = _8599; _4049 < _8600; ++_4049)
        {
          {
            _ptr__4045[safe_add( _4040,_4049 )] = _4035;
          }
        }
        if (_4038)
        {
          {
            int _8601 = (int)0;
            int _8602 = _4036;
            for (int _4050 = _8601; _4050 < _8602; ++_4050)
            {
              {
                _ptr__4045[safe_add( _4041,_4050 )] = safe_add( safe_mul( ((*msubi)(_4050)),mdimj ),((*msubj)(_4050)) );
              }
            }
          }
        }
        {}
        int _8603 = (int)0;
        int _8604 = safe_add( _4036,(int)1 );
        for (int _4051 = _8603; _4051 < _8604; ++_4051)
        {
          {
            _ptr__4044[safe_add( _4039,_4051 )] = _4051;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4052,    double _4053){ return new mosek::fusion::ExprMulVarScalarConst(_4052,_4053); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4052,    double _4053) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4052,_4053); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4052,    double _4053){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4052->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4052;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4053;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4054,monty::rc_ptr< ::mosek::fusion::WorkStack > _4055,monty::rc_ptr< ::mosek::fusion::WorkStack > _4056) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4054,_4055,_4056); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4054,monty::rc_ptr< ::mosek::fusion::WorkStack > _4055,monty::rc_ptr< ::mosek::fusion::WorkStack > _4056){
  int _4057 = x->numInst();
  int _4058 = _4057;
  std::shared_ptr< monty::ndarray< int,1 > > _4059 = x->getShape();
  _checked_ptr_1<int> _ptr__4059(_4059 ? _4059->raw() : nullptr,_4059 ? _4059->size(0) : 0);
  int _4060 = (int)((_4059)->size(0));
  int _4061 = _4054->alloci32(safe_add( _4058,(int)1 ));
  int _4062 = _4054->alloci64(_4057);
  bool _4063 = (::mosek::fusion::p_Set::size(_4059) > _4058);
  int _8605;
  bool _8606 = _4063;
  if (_8606)
  {
    _8605 = _4054->alloci64(_4058);
  }
  else
  {
    _8605 = (int)0;
  }
  int _4064 = _8605;
  int _4065 = _4054->allocf64(_4057);
  int _4066 = _4054->allocf64(_4058);
  if (_4063)
  {
    {
      x->inst(_4064,mosek::fusion::p_WorkStack::_get_impl(_4054)->i64,_4062,mosek::fusion::p_WorkStack::_get_impl(_4054)->i64);
    }
  }
  else
  {
    {
      x->inst(_4062,mosek::fusion::p_WorkStack::_get_impl(_4054)->i64);
    }
  }
  int _8607;
  bool _8608 = _4063;
  if (_8608)
  {
    _8607 = (int)1;
  }
  else
  {
    _8607 = (int)0;
  }
  _4054->pushi32(_8607);
  _4054->pushi32(_4058);
  _4054->pushi32(_4057);
  int _8609 = (int)0;
  int _8610 = _4060;
  for (int _4067 = _8609; _4067 < _8610; ++_4067)
  {
    {
      _4054->pushi32(_ptr__4059[_4067]);
    }
  }
  _4054->pushi32(_4060);
  std::shared_ptr< monty::ndarray< int,1 > > _4068 = mosek::fusion::p_WorkStack::_get_impl(_4054)->i32;
  _checked_ptr_1<int> _ptr__4068(_4068 ? _4068->raw() : nullptr,_4068 ? _4068->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4069 = mosek::fusion::p_WorkStack::_get_impl(_4054)->i64;
  _checked_ptr_1<long long> _ptr__4069(_4069 ? _4069->raw() : nullptr,_4069 ? _4069->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4070 = mosek::fusion::p_WorkStack::_get_impl(_4054)->f64;
  _checked_ptr_1<double> _ptr__4070(_4070 ? _4070->raw() : nullptr,_4070 ? _4070->size(0) : 0);
  {
    int _8611 = (int)0;
    int _8612 = safe_add( _4058,(int)1 );
    for (int _4071 = _8611; _4071 < _8612; ++_4071)
    {
      {
        _ptr__4068[safe_add( _4061,_4071 )] = _4071;
      }
    }
    int _8613 = (int)0;
    int _8614 = _4057;
    for (int _4072 = _8613; _4072 < _8614; ++_4072)
    {
      {
        _ptr__4070[safe_add( _4065,_4072 )] = 1.0;
      }
    }
    int _8615 = (int)0;
    int _8616 = _4058;
    for (int _4073 = _8615; _4073 < _8616; ++_4073)
    {
      {
        _ptr__4070[safe_add( _4066,_4073 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4074,    monty::rc_ptr< ::mosek::fusion::Expression > _4075,    double _4076,    double _4077){ return new mosek::fusion::ExprAdd(_4074,_4075,_4076,_4077); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4074,    monty::rc_ptr< ::mosek::fusion::Expression > _4075,    double _4076,    double _4077) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4074,_4075,_4076,_4077); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4074,    monty::rc_ptr< ::mosek::fusion::Expression > _4075,    double _4076,    double _4077){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4074->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4074;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4075;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4076;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4077;
    if ((_4074->getND() != _4075->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8617 = (int)0;
    int _8618 = _4074->getND();
    for (int _4078 = _8617; _4078 < _8618; ++_4078)
    {
      {
        if ((_4074->getDim(_4078) != _4075->getDim(_4078)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4079,monty::rc_ptr< ::mosek::fusion::WorkStack > _4080,monty::rc_ptr< ::mosek::fusion::WorkStack > _4081) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4079,_4080,_4081); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4079,monty::rc_ptr< ::mosek::fusion::WorkStack > _4080,monty::rc_ptr< ::mosek::fusion::WorkStack > _4081){
  e1->eval(_4080,_4079,_4081);
  e2->eval(_4080,_4079,_4081);
  _4080->pop_expr();
  int _4082 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nd;
  int _4083 = mosek::fusion::p_WorkStack::_get_impl(_4080)->shape_base;
  int _4084 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nelem;
  int _4085 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nnz;
  bool _4086 = mosek::fusion::p_WorkStack::_get_impl(_4080)->hassp;
  int _4087 = mosek::fusion::p_WorkStack::_get_impl(_4080)->ptr_base;
  int _4088 = mosek::fusion::p_WorkStack::_get_impl(_4080)->sp_base;
  int _4089 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nidxs_base;
  int _4090 = mosek::fusion::p_WorkStack::_get_impl(_4080)->bfix_base;
  int _4091 = mosek::fusion::p_WorkStack::_get_impl(_4080)->cof_base;
  _4080->pop_expr();
  int _4092 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nd;
  int _4093 = mosek::fusion::p_WorkStack::_get_impl(_4080)->shape_base;
  int _4094 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nelem;
  int _4095 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nnz;
  bool _4096 = mosek::fusion::p_WorkStack::_get_impl(_4080)->hassp;
  int _4097 = mosek::fusion::p_WorkStack::_get_impl(_4080)->ptr_base;
  int _4098 = mosek::fusion::p_WorkStack::_get_impl(_4080)->sp_base;
  int _4099 = mosek::fusion::p_WorkStack::_get_impl(_4080)->nidxs_base;
  int _4100 = mosek::fusion::p_WorkStack::_get_impl(_4080)->bfix_base;
  int _4101 = mosek::fusion::p_WorkStack::_get_impl(_4080)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4102 = mosek::fusion::p_WorkStack::_get_impl(_4080)->i32;
  _checked_ptr_1<int> _ptr__4102(_4102 ? _4102->raw() : nullptr,_4102 ? _4102->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4103 = mosek::fusion::p_WorkStack::_get_impl(_4080)->i64;
  _checked_ptr_1<long long> _ptr__4103(_4103 ? _4103->raw() : nullptr,_4103 ? _4103->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4104 = mosek::fusion::p_WorkStack::_get_impl(_4080)->f64;
  _checked_ptr_1<double> _ptr__4104(_4104 ? _4104->raw() : nullptr,_4104 ? _4104->size(0) : 0);
  if ((_4092 != _4082))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8619 = (int)0;
  int _8620 = _4092;
  for (int _4105 = _8619; _4105 < _8620; ++_4105)
  {
    {
      if ((_ptr__4102[safe_add( _4093,_4105 )] != _ptr__4102[safe_add( _4083,_4105 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4096) && (!_4086)))
  {
    {
      int _4106 = _4094;
      int _4107 = safe_add( _4095,_4085 );
      int _4108 = _4092;
      _4079->alloc_expr(_4108,_4106,_4107,false);
      int _4109 = mosek::fusion::p_WorkStack::_get_impl(_4079)->shape_base;
      int _4110 = mosek::fusion::p_WorkStack::_get_impl(_4079)->ptr_base;
      int _4111 = mosek::fusion::p_WorkStack::_get_impl(_4079)->sp_base;
      int _4112 = mosek::fusion::p_WorkStack::_get_impl(_4079)->nidxs_base;
      int _4113 = mosek::fusion::p_WorkStack::_get_impl(_4079)->bfix_base;
      int _4114 = mosek::fusion::p_WorkStack::_get_impl(_4079)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4115 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i32;
      _checked_ptr_1<int> _ptr__4115(_4115 ? _4115->raw() : nullptr,_4115 ? _4115->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4116 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i64;
      _checked_ptr_1<long long> _ptr__4116(_4116 ? _4116->raw() : nullptr,_4116 ? _4116->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4117 = mosek::fusion::p_WorkStack::_get_impl(_4079)->f64;
      _checked_ptr_1<double> _ptr__4117(_4117 ? _4117->raw() : nullptr,_4117 ? _4117->size(0) : 0);
      int _8621 = (int)0;
      int _8622 = _4108;
      for (int _4118 = _8621; _4118 < _8622; ++_4118)
      {
        {
          _ptr__4115[safe_add( _4109,_4118 )] = _ptr__4102[safe_add( _4093,_4118 )];
        }
      }
      int _4119 = (int)0;
      _ptr__4115[_4110] = (int)0;
      int _8623 = (int)0;
      int _8624 = _4106;
      for (int _4120 = _8623; _4120 < _8624; ++_4120)
      {
        {
          int _8625 = _ptr__4102[safe_add( _4097,_4120 )];
          int _8626 = _ptr__4102[safe_add( safe_add( _4097,_4120 ),(int)1 )];
          for (int _4121 = _8625; _4121 < _8626; ++_4121)
          {
            {
              _ptr__4116[safe_add( _4112,_4119 )] = _ptr__4103[safe_add( _4099,_4121 )];
              _ptr__4117[safe_add( _4114,_4119 )] = (_ptr__4104[safe_add( _4101,_4121 )] * m1);
              ++ _4119;
            }
          }
          int _8627 = _ptr__4102[safe_add( _4087,_4120 )];
          int _8628 = _ptr__4102[safe_add( safe_add( _4087,_4120 ),(int)1 )];
          for (int _4122 = _8627; _4122 < _8628; ++_4122)
          {
            {
              _ptr__4116[safe_add( _4112,_4119 )] = _ptr__4103[safe_add( _4089,_4122 )];
              _ptr__4117[safe_add( _4114,_4119 )] = (_ptr__4104[safe_add( _4091,_4122 )] * m2);
              ++ _4119;
            }
          }
          _ptr__4115[safe_add( safe_add( _4110,_4120 ),(int)1 )] = _4119;
          _ptr__4117[safe_add( _4113,_4120 )] = ((_ptr__4104[safe_add( _4100,_4120 )] * m1) + (_ptr__4104[safe_add( _4090,_4120 )] * m2));
        }
      }
    }
  }
  else if(((!_4096) || (!_4086)))
  {
    {
      if ((!_4086))
      {
        {
          int _4123 = _4084;
          int _4124 = _4085;
          int _4125 = _4087;
          int _4126 = _4088;
          int _4127 = _4089;
          int _4128 = _4090;
          int _4129 = _4091;
          _4084 = _4094;
          _4085 = _4095;
          _4087 = _4097;
          _4088 = _4098;
          _4089 = _4099;
          _4090 = _4100;
          _4091 = _4101;
          _4094 = _4123;
          _4095 = _4124;
          _4097 = _4125;
          _4098 = _4126;
          _4099 = _4127;
          _4100 = _4128;
          _4101 = _4129;
        }
      }
      {}
      double _8629;
      bool _8630 = (!_4096);
      if (_8630)
      {
        _8629 = m1;
      }
      else
      {
        _8629 = m2;
      }
      double _4130 = _8629;
      double _8631;
      bool _8632 = (!_4096);
      if (_8632)
      {
        _8631 = m2;
      }
      else
      {
        _8631 = _4130;
      }
      double _4131 = _8631;
      int _4132 = _4094;
      int _4133 = safe_add( _4095,_4085 );
      int _4134 = _4092;
      _4079->alloc_expr(_4134,_4132,_4133,false);
      int _4135 = mosek::fusion::p_WorkStack::_get_impl(_4079)->shape_base;
      int _4136 = mosek::fusion::p_WorkStack::_get_impl(_4079)->ptr_base;
      int _4137 = mosek::fusion::p_WorkStack::_get_impl(_4079)->sp_base;
      int _4138 = mosek::fusion::p_WorkStack::_get_impl(_4079)->nidxs_base;
      int _4139 = mosek::fusion::p_WorkStack::_get_impl(_4079)->bfix_base;
      int _4140 = mosek::fusion::p_WorkStack::_get_impl(_4079)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4141 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i32;
      _checked_ptr_1<int> _ptr__4141(_4141 ? _4141->raw() : nullptr,_4141 ? _4141->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4142 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i64;
      _checked_ptr_1<long long> _ptr__4142(_4142 ? _4142->raw() : nullptr,_4142 ? _4142->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4143 = mosek::fusion::p_WorkStack::_get_impl(_4079)->f64;
      _checked_ptr_1<double> _ptr__4143(_4143 ? _4143->raw() : nullptr,_4143 ? _4143->size(0) : 0);
      {
        int _4144 = (int)0;
        int _8633 = (int)0;
        int _8634 = _4134;
        for (int _4145 = _8633; _4145 < _8634; ++_4145)
        {
          {
            _ptr__4141[safe_add( _4135,_4145 )] = _ptr__4102[safe_add( _4093,_4145 )];
          }
        }
        int _8635 = (int)0;
        int _8636 = safe_add( _4132,(int)1 );
        for (int _4146 = _8635; _4146 < _8636; ++_4146)
        {
          {
            _ptr__4141[safe_add( _4136,_4146 )] = (int)0;
          }
        }
        int _8637 = (int)0;
        int _8638 = _4094;
        for (int _4147 = _8637; _4147 < _8638; ++_4147)
        {
          {
            _ptr__4141[safe_add( safe_add( _4136,_4147 ),(int)1 )] += (_ptr__4102[safe_add( safe_add( _4097,_4147 ),(int)1 )] - _ptr__4102[safe_add( _4097,_4147 )]);
          }
        }
        int _8639 = (int)0;
        int _8640 = _4084;
        for (int _4148 = _8639; _4148 < _8640; ++_4148)
        {
          {
            long long _4149 = _ptr__4103[safe_add( _4088,_4148 )];
            _ptr__4141[safe_add( safe_add( _4136,_4149 ),(int)1 )] += (_ptr__4102[safe_add( safe_add( _4087,_4148 ),(int)1 )] - _ptr__4102[safe_add( _4087,_4148 )]);
          }
        }
        int _8641 = (int)0;
        int _8642 = _4132;
        for (int _4150 = _8641; _4150 < _8642; ++_4150)
        {
          {
            _ptr__4141[safe_add( safe_add( _4136,_4150 ),(int)1 )] += _ptr__4141[safe_add( _4136,_4150 )];
          }
        }
        int _8643 = (int)0;
        int _8644 = _4094;
        for (int _4151 = _8643; _4151 < _8644; ++_4151)
        {
          {
            int _4152 = _ptr__4141[safe_add( _4136,_4151 )];
            int _4153 = _ptr__4102[safe_add( _4097,_4151 )];
            int _4154 = (_ptr__4102[safe_add( safe_add( _4097,_4151 ),(int)1 )] - _ptr__4102[safe_add( _4097,_4151 )]);
            int _8645 = (int)0;
            int _8646 = _4154;
            for (int _4155 = _8645; _4155 < _8646; ++_4155)
            {
              {
                _ptr__4142[safe_add( safe_add( _4138,_4152 ),_4155 )] = _ptr__4103[safe_add( safe_add( _4099,_4153 ),_4155 )];
                _ptr__4143[safe_add( safe_add( _4140,_4152 ),_4155 )] = (_ptr__4104[safe_add( safe_add( _4101,_4153 ),_4155 )] * _4130);
              }
            }
            _ptr__4141[safe_add( _4136,_4151 )] += _4154;
            _ptr__4143[safe_add( _4139,_4151 )] = (_ptr__4104[safe_add( _4100,_4151 )] * _4130);
          }
        }
        int _8647 = (int)0;
        int _8648 = _4084;
        for (int _4156 = _8647; _4156 < _8648; ++_4156)
        {
          {
            long long _4157 = _ptr__4103[safe_add( _4088,_4156 )];
            int _4158 = _ptr__4141[safe_add( _4136,_4157 )];
            int _4159 = _ptr__4102[safe_add( _4087,_4156 )];
            int _4160 = (_ptr__4102[safe_add( safe_add( _4087,_4156 ),(int)1 )] - _ptr__4102[safe_add( _4087,_4156 )]);
            int _8649 = (int)0;
            int _8650 = _4160;
            for (int _4161 = _8649; _4161 < _8650; ++_4161)
            {
              {
                _ptr__4142[safe_add( safe_add( _4138,_4158 ),_4161 )] = _ptr__4103[safe_add( safe_add( _4089,_4159 ),_4161 )];
                _ptr__4143[safe_add( safe_add( _4140,_4158 ),_4161 )] = (_ptr__4104[safe_add( safe_add( _4091,_4159 ),_4161 )] * _4131);
              }
            }
            _ptr__4141[safe_add( _4136,_4157 )] += _4160;
            _ptr__4143[safe_add( _4139,_4157 )] += (_ptr__4104[safe_add( _4090,_4156 )] * _4131);
          }
        }
        int _8651 = (int)0;
        int _8652 = _4132;
        for (int _4162 = _8651; _4162 < _8652; ++_4162)
        {
          {
            _ptr__4141[(safe_add( _4136,_4132 ) - _4162)] = _ptr__4141[((safe_add( _4136,_4132 ) - _4162) - (int)1)];
          }
        }
        _ptr__4141[_4136] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4163 = safe_add( _4095,_4085 );
      int _4164 = (int)0;
      int _4165 = _4092;
      long long _4166 = (long long)1;
      int _8653 = (int)0;
      int _8654 = _4165;
      for (int _4167 = _8653; _4167 < _8654; ++_4167)
      {
        {
          _4166 *= _ptr__4102[safe_add( _4093,_4167 )];
        }
      }
      {
        int _4168 = (int)0;
        int _4169 = (int)0;
        while ( ((_4169 < _4094) && (_4168 < _4084)) )
        {
          {
            if ((_ptr__4103[safe_add( _4098,_4169 )] < _ptr__4103[safe_add( _4088,_4168 )]))
            {
              {
                ++ _4164;
                ++ _4169;
              }
            }
            else if((_ptr__4103[safe_add( _4098,_4169 )] > _ptr__4103[safe_add( _4088,_4168 )]))
            {
              {
                ++ _4164;
                ++ _4168;
              }
            }
            else
            {
              {
                ++ _4164;
                ++ _4169;
                ++ _4168;
              }
            }
          }
        }
        _4164 += (safe_add( (_4094 - _4169),_4084 ) - _4168);
      }
      bool _4170 = (_4164 < _4166);
      _4079->alloc_expr(_4165,_4164,_4163,_4170);
      int _4171 = mosek::fusion::p_WorkStack::_get_impl(_4079)->shape_base;
      int _4172 = mosek::fusion::p_WorkStack::_get_impl(_4079)->ptr_base;
      int _8655;
      bool _8656 = _4170;
      if (_8656)
      {
        _8655 = mosek::fusion::p_WorkStack::_get_impl(_4079)->sp_base;
      }
      else
      {
        _8655 = _4079->alloci64(_4164);
      }
      int _4173 = _8655;
      int _4174 = mosek::fusion::p_WorkStack::_get_impl(_4079)->nidxs_base;
      int _4175 = mosek::fusion::p_WorkStack::_get_impl(_4079)->bfix_base;
      int _4176 = mosek::fusion::p_WorkStack::_get_impl(_4079)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4177 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i32;
      _checked_ptr_1<int> _ptr__4177(_4177 ? _4177->raw() : nullptr,_4177 ? _4177->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4178 = mosek::fusion::p_WorkStack::_get_impl(_4079)->i64;
      _checked_ptr_1<long long> _ptr__4178(_4178 ? _4178->raw() : nullptr,_4178 ? _4178->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4179 = mosek::fusion::p_WorkStack::_get_impl(_4079)->f64;
      _checked_ptr_1<double> _ptr__4179(_4179 ? _4179->raw() : nullptr,_4179 ? _4179->size(0) : 0);
      int _8657 = (int)0;
      int _8658 = _4165;
      for (int _4180 = _8657; _4180 < _8658; ++_4180)
      {
        {
          _ptr__4177[safe_add( _4171,_4180 )] = _ptr__4102[safe_add( _4093,_4180 )];
        }
      }
      {
        _ptr__4177[_4172] = (int)0;
        int _4181 = (int)0;
        int _4182 = (int)0;
        int _4183 = (int)0;
        int _4184 = (int)0;
        while ( ((_4184 < _4094) && (_4183 < _4084)) )
        {
          {
            if ((_ptr__4103[safe_add( _4098,_4184 )] < _ptr__4103[safe_add( _4088,_4183 )]))
            {
              {
                int _8659 = _ptr__4102[safe_add( _4097,_4184 )];
                int _8660 = _ptr__4102[safe_add( safe_add( _4097,_4184 ),(int)1 )];
                for (int _4185 = _8659; _4185 < _8660; ++_4185)
                {
                  {
                    _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4099,_4185 )];
                    _ptr__4179[safe_add( _4176,_4182 )] = (m1 * _ptr__4104[safe_add( _4101,_4185 )]);
                    ++ _4182;
                  }
                }
                _ptr__4179[safe_add( _4175,_4181 )] = (m1 * _ptr__4104[safe_add( _4100,_4184 )]);
                _ptr__4178[safe_add( _4173,_4181 )] = _ptr__4103[safe_add( _4098,_4184 )];
                _ptr__4177[safe_add( safe_add( _4172,_4181 ),(int)1 )] = _4182;
                ++ _4181;
                ++ _4184;
              }
            }
            else if((_ptr__4103[safe_add( _4088,_4183 )] < _ptr__4103[safe_add( _4098,_4184 )]))
            {
              {
                int _8661 = _ptr__4102[safe_add( _4087,_4183 )];
                int _8662 = _ptr__4102[safe_add( safe_add( _4087,_4183 ),(int)1 )];
                for (int _4186 = _8661; _4186 < _8662; ++_4186)
                {
                  {
                    _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4089,_4186 )];
                    _ptr__4179[safe_add( _4176,_4182 )] = (m2 * _ptr__4104[safe_add( _4091,_4186 )]);
                    ++ _4182;
                  }
                }
                _ptr__4179[safe_add( _4175,_4181 )] = (m1 * _ptr__4104[safe_add( _4090,_4184 )]);
                _ptr__4178[safe_add( _4173,_4181 )] = _ptr__4103[safe_add( _4088,_4183 )];
                _ptr__4177[safe_add( safe_add( _4172,_4181 ),(int)1 )] = _4182;
                ++ _4181;
                ++ _4183;
              }
            }
            else
            {
              {
                int _8663 = _ptr__4102[safe_add( _4097,_4184 )];
                int _8664 = _ptr__4102[safe_add( safe_add( _4097,_4184 ),(int)1 )];
                for (int _4187 = _8663; _4187 < _8664; ++_4187)
                {
                  {
                    _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4099,_4187 )];
                    _ptr__4179[safe_add( _4176,_4182 )] = (m1 * _ptr__4104[safe_add( _4101,_4187 )]);
                    ++ _4182;
                  }
                }
                int _8665 = _ptr__4102[safe_add( _4087,_4183 )];
                int _8666 = _ptr__4102[safe_add( safe_add( _4087,_4183 ),(int)1 )];
                for (int _4188 = _8665; _4188 < _8666; ++_4188)
                {
                  {
                    _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4089,_4188 )];
                    _ptr__4179[safe_add( _4176,_4182 )] = (m2 * _ptr__4104[safe_add( _4091,_4188 )]);
                    ++ _4182;
                  }
                }
                _ptr__4179[safe_add( _4175,_4181 )] = ((m1 * _ptr__4104[safe_add( _4100,_4184 )]) + (m2 * _ptr__4104[safe_add( _4090,_4183 )]));
                _ptr__4178[safe_add( _4173,_4181 )] = _ptr__4103[safe_add( _4098,_4184 )];
                _ptr__4177[safe_add( safe_add( _4172,_4181 ),(int)1 )] = _4182;
                ++ _4181;
                ++ _4184;
                ++ _4183;
              }
            }
          }
        }
        while ( (_4184 < _4094) )
        {
          {
            int _8667 = _ptr__4102[safe_add( _4097,_4184 )];
            int _8668 = _ptr__4102[safe_add( safe_add( _4097,_4184 ),(int)1 )];
            for (int _4189 = _8667; _4189 < _8668; ++_4189)
            {
              {
                _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4099,_4189 )];
                _ptr__4179[safe_add( _4176,_4182 )] = (m1 * _ptr__4104[safe_add( _4101,_4189 )]);
                ++ _4182;
              }
            }
            _ptr__4179[safe_add( _4175,_4181 )] = (m1 * _ptr__4104[safe_add( _4100,_4184 )]);
            _ptr__4178[safe_add( _4173,_4181 )] = _ptr__4103[safe_add( _4098,_4184 )];
            _ptr__4177[safe_add( safe_add( _4172,_4181 ),(int)1 )] = _4182;
            ++ _4181;
            ++ _4184;
          }
        }
        while ( (_4183 < _4084) )
        {
          {
            int _8669 = _ptr__4102[safe_add( _4087,_4183 )];
            int _8670 = _ptr__4102[safe_add( safe_add( _4087,_4183 ),(int)1 )];
            for (int _4190 = _8669; _4190 < _8670; ++_4190)
            {
              {
                _ptr__4178[safe_add( _4174,_4182 )] = _ptr__4103[safe_add( _4089,_4190 )];
                _ptr__4179[safe_add( _4176,_4182 )] = (m2 * _ptr__4104[safe_add( _4091,_4190 )]);
                ++ _4182;
              }
            }
            _ptr__4179[safe_add( _4175,_4181 )] = (m1 * _ptr__4104[safe_add( _4090,_4183 )]);
            _ptr__4178[safe_add( _4173,_4181 )] = _ptr__4103[safe_add( _4088,_4183 )];
            _ptr__4177[safe_add( safe_add( _4172,_4181 ),(int)1 )] = _4182;
            ++ _4181;
            ++ _4183;
          }
        }
      }
      if ((!_4170))
      {
        {
          _4079->popi64(_4164);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4191,    std::shared_ptr< monty::ndarray< double,1 > > _4192){ return new mosek::fusion::ExprWSum(_4191,_4192); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4191,    std::shared_ptr< monty::ndarray< double,1 > > _4192) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4191,_4192); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4191,    std::shared_ptr< monty::ndarray< double,1 > > _4192){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4192(_4192 ? _4192->raw() : nullptr, _4192 ? _4192->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4191)((int)0))->getShape());
    if (((int)((_4192)->size(0)) != (int)((_4191)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4192);
    std::shared_ptr< monty::ndarray< int,1 > > _4193 = ((*_4191)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4193(_4193 ? _4193->raw() : nullptr,_4193 ? _4193->size(0) : 0);
    int _4194 = (int)((_4193)->size(0));
    int _8671 = (int)1;
    int _8672 = (int)((_4191)->size(0));
    for (int _4195 = _8671; _4195 < _8672; ++_4195)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4196 = ((*_4191)(_4195))->getShape();
        _checked_ptr_1<int> _ptr__4196(_4196 ? _4196->raw() : nullptr,_4196 ? _4196->size(0) : 0);
        if ((_4194 != (int)((_4196)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8673 = (int)0;
            int _8674 = _4194;
            for (int _4197 = _8673; _4197 < _8674; ++_4197)
            {
              {
                if ((_ptr__4193[_4197] != _ptr__4196[_4197]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8675;
    for (int _4198 = (int)0, _8676 = (int)((_4191)->size(0)); _4198 < _8676 ; ++_4198)
    {
      _8675.push_back(((*_4191)(_4198)));
    }
    auto _8677 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8675.size()),_8675.begin(),_8675.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8677;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4199,monty::rc_ptr< ::mosek::fusion::WorkStack > _4200,monty::rc_ptr< ::mosek::fusion::WorkStack > _4201) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4199,_4200,_4201); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4199,monty::rc_ptr< ::mosek::fusion::WorkStack > _4200,monty::rc_ptr< ::mosek::fusion::WorkStack > _4201){
  int _4202 = (int)((es)->size(0));
  int _8678 = (int)0;
  int _8679 = _4202;
  for (int _4203 = _8678; _4203 < _8679; ++_4203)
  {
    {
      ((*es)(_4203))->eval(_4200,_4199,_4201);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4204(_4204 ? _4204->raw() : nullptr,_4204 ? _4204->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4205 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4205(_4205 ? _4205->raw() : nullptr,_4205 ? _4205->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4206 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4206(_4206 ? _4206->raw() : nullptr,_4206 ? _4206->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4207 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4207(_4207 ? _4207->raw() : nullptr,_4207 ? _4207->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4208 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4208(_4208 ? _4208->raw() : nullptr,_4208 ? _4208->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4209 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4209(_4209 ? _4209->raw() : nullptr,_4209 ? _4209->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4210 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
  _checked_ptr_1<int> _ptr__4210(_4210 ? _4210->raw() : nullptr,_4210 ? _4210->size(0) : 0);
  int _4211 = _4200->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4211)));
  _checked_ptr_1<int> _ptr__4212(_4212 ? _4212->raw() : nullptr,_4212 ? _4212->size(0) : 0);
  _4200->popi32(_4211,_4212,(int)0);
  {
    _ptr__4204[(_4202 - (int)1)] = _4200->popi32();
    _ptr__4205[(_4202 - (int)1)] = _4200->popi32();
    bool _4213 = (_4200->popi32() != (int)0);
    _ptr__4206[(_4202 - (int)1)] = _4200->popi32(safe_add( _ptr__4204[(_4202 - (int)1)],(int)1 ));
    int _8680;
    bool _8681 = _4213;
    if (_8681)
    {
      _8680 = _4200->popi64(_ptr__4204[(_4202 - (int)1)]);
    }
    else
    {
      _8680 = (-(int)1);
    }
    _ptr__4208[(_4202 - (int)1)] = _8680;
    _ptr__4207[(_4202 - (int)1)] = _4200->popi64(_ptr__4205[(_4202 - (int)1)]);
    _ptr__4210[(_4202 - (int)1)] = _4200->popf64(_ptr__4204[(_4202 - (int)1)]);
    _ptr__4209[(_4202 - (int)1)] = _4200->popf64(_ptr__4205[(_4202 - (int)1)]);
  }
  int _8682 = (int)1;
  int _8683 = _4202;
  for (int _4214 = _8682; _4214 < _8683; ++_4214)
  {
    {
      int _4215 = ((_4202 - _4214) - (int)1);
      _4200->popi32();
      _4200->popi32(_4211);
      _ptr__4204[_4215] = _4200->popi32();
      _ptr__4205[_4215] = _4200->popi32();
      bool _4216 = (_4200->popi32() != (int)0);
      _ptr__4206[_4215] = _4200->popi32(safe_add( _ptr__4204[_4215],(int)1 ));
      int _8684;
      bool _8685 = _4216;
      if (_8685)
      {
        _8684 = _4200->popi64(_ptr__4204[_4215]);
      }
      else
      {
        _8684 = (-(int)1);
      }
      _ptr__4208[_4215] = _8684;
      _ptr__4207[_4215] = _4200->popi64(_ptr__4205[_4215]);
      _ptr__4210[_4215] = _4200->popf64(_ptr__4204[_4215]);
      _ptr__4209[_4215] = _4200->popf64(_ptr__4205[_4215]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4217 = mosek::fusion::p_WorkStack::_get_impl(_4200)->i32;
  _checked_ptr_1<int> _ptr__4217(_4217 ? _4217->raw() : nullptr,_4217 ? _4217->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4218 = mosek::fusion::p_WorkStack::_get_impl(_4200)->i64;
  _checked_ptr_1<long long> _ptr__4218(_4218 ? _4218->raw() : nullptr,_4218 ? _4218->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4219 = mosek::fusion::p_WorkStack::_get_impl(_4200)->f64;
  _checked_ptr_1<double> _ptr__4219(_4219 ? _4219->raw() : nullptr,_4219 ? _4219->size(0) : 0);
  bool _4220 = false;
  int _8686 = (int)0;
  int _8687 = _4202;
  for (int _4221 = _8686; _4221 < _8687; ++_4221)
  {
    {
      if ((_ptr__4208[_4221] < (int)0))
      {
        {
          _4220 = true;
        }
      }
      {}
    }
  }
  int _4222 = (int)0;
  int _4223 = (int)0;
  if (_4220)
  {
    {
      _4222 = (int)::mosek::fusion::p_Set::size(_4212);
      int _8688 = (int)0;
      int _8689 = _4202;
      for (int _4224 = _8688; _4224 < _8689; ++_4224)
      {
        {
          _4223 += _ptr__4205[_4224];
        }
      }
    }
  }
  else
  {
    {
      bool _4225 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4226 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
      _checked_ptr_1<int> _ptr__4226(_4226 ? _4226->raw() : nullptr,_4226 ? _4226->size(0) : 0);
      int _8690 = (int)0;
      int _8691 = _4202;
      for (int _4227 = _8690; _4227 < _8691; ++_4227)
      {
        {
          _4223 += _ptr__4205[_4227];
        }
      }
      while ( (!_4225) )
      {
        {
          long long _4228 = (-(int)1);
          int _8692 = (int)0;
          int _8693 = _4202;
          for (int _4229 = _8692; _4229 < _8693; ++_4229)
          {
            {
              if (((_ptr__4226[_4229] < _ptr__4204[_4229]) && ((_4228 < (int)0) || (_ptr__4218[safe_add( _ptr__4208[_4229],_ptr__4226[_4229] )] < _4228))))
              {
                {
                  _4228 = _ptr__4218[safe_add( _ptr__4208[_4229],_ptr__4226[_4229] )];
                }
              }
              {}
            }
          }
          if ((_4228 < (int)0))
          {
            {
              _4225 = true;
            }
          }
          else
          {
            {
              int _8694 = (int)0;
              int _8695 = _4202;
              for (int _4230 = _8694; _4230 < _8695; ++_4230)
              {
                {
                  if (((_ptr__4226[_4230] < _ptr__4204[_4230]) && (_4228 == _ptr__4218[safe_add( _ptr__4208[_4230],_ptr__4226[_4230] )])))
                  {
                    {
                      ++ _ptr__4226[_4230];
                    }
                  }
                  {}
                }
              }
              ++ _4222;
            }
          }
        }
      }
    }
  }
  int _4231 = _4199->alloci32(safe_add( _4222,(int)1 ));
  int _4232 = _4199->alloci64(_4223);
  int _8696;
  bool _8697 = (!_4220);
  if (_8697)
  {
    _8696 = _4199->alloci64(_4222);
  }
  else
  {
    _8696 = (-(int)1);
  }
  int _4233 = _8696;
  int _4234 = _4199->allocf64(_4223);
  int _4235 = _4199->allocf64(_4222);
  int _8698;
  bool _8699 = _4220;
  if (_8699)
  {
    _8698 = (int)0;
  }
  else
  {
    _8698 = (int)1;
  }
  _4199->pushi32(_8698);
  _4199->pushi32(_4223);
  _4199->pushi32(_4222);
  int _8700 = (int)0;
  int _8701 = _4211;
  for (int _4236 = _8700; _4236 < _8701; ++_4236)
  {
    {
      _4199->pushi32(_ptr__4212[_4236]);
    }
  }
  _4199->pushi32(_4211);
  std::shared_ptr< monty::ndarray< int,1 > > _4237 = mosek::fusion::p_WorkStack::_get_impl(_4199)->i32;
  _checked_ptr_1<int> _ptr__4237(_4237 ? _4237->raw() : nullptr,_4237 ? _4237->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4238 = mosek::fusion::p_WorkStack::_get_impl(_4199)->i64;
  _checked_ptr_1<long long> _ptr__4238(_4238 ? _4238->raw() : nullptr,_4238 ? _4238->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4239 = mosek::fusion::p_WorkStack::_get_impl(_4199)->f64;
  _checked_ptr_1<double> _ptr__4239(_4239 ? _4239->raw() : nullptr,_4239 ? _4239->size(0) : 0);
  _ptr__4237[_4231] = (int)0;
  int _8702 = (int)0;
  int _8703 = _4222;
  for (int _4240 = _8702; _4240 < _8703; ++_4240)
  {
    {
      _ptr__4239[safe_add( _4235,_4240 )] = 0.0;
    }
  }
  int _8704 = (int)0;
  int _8705 = safe_add( _4222,(int)1 );
  for (int _4241 = _8704; _4241 < _8705; ++_4241)
  {
    {
      _ptr__4237[safe_add( _4231,_4241 )] = (int)0;
    }
  }
  if (_4220)
  {
    {
      int _8706 = (int)0;
      int _8707 = _4202;
      for (int _4242 = _8706; _4242 < _8707; ++_4242)
      {
        {
          if ((_ptr__4208[_4242] >= (int)0))
          {
            {
              int _8708 = (int)0;
              int _8709 = _ptr__4204[_4242];
              for (int _4243 = _8708; _4243 < _8709; ++_4243)
              {
                {
                  _ptr__4237[safe_add( safe_add( _4231,_ptr__4218[safe_add( _ptr__4208[_4242],_4243 )] ),(int)1 )] += (_ptr__4217[safe_add( safe_add( _ptr__4206[_4242],_4243 ),(int)1 )] - _ptr__4217[safe_add( _ptr__4206[_4242],_4243 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8710 = (int)0;
              int _8711 = _ptr__4204[_4242];
              for (int _4244 = _8710; _4244 < _8711; ++_4244)
              {
                {
                  _ptr__4237[safe_add( safe_add( _4231,_4244 ),(int)1 )] += (_ptr__4217[safe_add( safe_add( _ptr__4206[_4242],_4244 ),(int)1 )] - _ptr__4217[safe_add( _ptr__4206[_4242],_4244 )]);
                }
              }
            }
          }
        }
      }
      int _8712 = (int)0;
      int _8713 = _4222;
      for (int _4245 = _8712; _4245 < _8713; ++_4245)
      {
        {
          _ptr__4237[safe_add( safe_add( _4231,_4245 ),(int)1 )] += _ptr__4237[safe_add( _4231,_4245 )];
        }
      }
      int _8714 = (int)0;
      int _8715 = _4202;
      for (int _4246 = _8714; _4246 < _8715; ++_4246)
      {
        {
          if ((_ptr__4208[_4246] >= (int)0))
          {
            {
              int _8716 = (int)0;
              int _8717 = _ptr__4204[_4246];
              for (int _4247 = _8716; _4247 < _8717; ++_4247)
              {
                {
                  int _4248 = _ptr__4217[safe_add( _ptr__4206[_4246],_4247 )];
                  int _4249 = _ptr__4217[safe_add( safe_add( _ptr__4206[_4246],_4247 ),(int)1 )];
                  long long _4250 = _ptr__4218[safe_add( _ptr__4208[_4246],_4247 )];
                  int _4251 = _ptr__4237[safe_add( _4231,_4250 )];
                  int _8718 = _4248;
                  int _8719 = _4249;
                  for (int _4252 = _8718; _4252 < _8719; ++_4252)
                  {
                    {
                      _ptr__4238[safe_add( _4232,_4251 )] = _ptr__4218[safe_add( _ptr__4207[_4246],_4252 )];
                      _ptr__4239[safe_add( _4234,_4251 )] = (((*w)(_4246)) * _ptr__4219[safe_add( _ptr__4209[_4246],_4252 )]);
                      ++ _4251;
                    }
                  }
                  _ptr__4239[safe_add( _4235,_4250 )] += (((*w)(_4246)) * _ptr__4219[safe_add( _ptr__4210[_4246],_4247 )]);
                  _ptr__4237[safe_add( _4231,_4250 )] += (_4249 - _4248);
                }
              }
            }
          }
          else
          {
            {
              int _8720 = (int)0;
              int _8721 = _ptr__4204[_4246];
              for (int _4253 = _8720; _4253 < _8721; ++_4253)
              {
                {
                  int _4254 = _ptr__4217[safe_add( _ptr__4206[_4246],_4253 )];
                  int _4255 = _ptr__4217[safe_add( safe_add( _ptr__4206[_4246],_4253 ),(int)1 )];
                  int _4256 = _4253;
                  int _4257 = _ptr__4237[safe_add( _4231,_4256 )];
                  int _8722 = _4254;
                  int _8723 = _4255;
                  for (int _4258 = _8722; _4258 < _8723; ++_4258)
                  {
                    {
                      _ptr__4238[safe_add( _4232,_4257 )] = _ptr__4218[safe_add( _ptr__4207[_4246],_4258 )];
                      _ptr__4239[safe_add( _4234,_4257 )] = (((*w)(_4246)) * _ptr__4219[safe_add( _ptr__4209[_4246],_4258 )]);
                      ++ _4257;
                    }
                  }
                  _ptr__4239[safe_add( _4235,_4256 )] += (((*w)(_4246)) * _ptr__4219[safe_add( _ptr__4210[_4246],_4253 )]);
                  _ptr__4237[safe_add( _4231,_4256 )] += (_4255 - _4254);
                }
              }
            }
          }
        }
      }
      int _8724 = (int)0;
      int _8725 = _4222;
      for (int _4259 = _8724; _4259 < _8725; ++_4259)
      {
        {
          _ptr__4237[(safe_add( _4231,_4222 ) - _4259)] = _ptr__4237[((safe_add( _4231,_4222 ) - _4259) - (int)1)];
        }
      }
      _ptr__4237[_4231] = (int)0;
    }
  }
  else
  {
    {
      bool _4260 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4261 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4202)));
      _checked_ptr_1<int> _ptr__4261(_4261 ? _4261->raw() : nullptr,_4261 ? _4261->size(0) : 0);
      int _4262 = (int)0;
      int _4263 = (int)0;
      while ( (!_4260) )
      {
        {
          long long _4264 = (-(int)1);
          int _8726 = (int)0;
          int _8727 = _4202;
          for (int _4265 = _8726; _4265 < _8727; ++_4265)
          {
            {
              if (((_ptr__4261[_4265] < _ptr__4204[_4265]) && ((_4264 < (int)0) || (_ptr__4218[safe_add( _ptr__4208[_4265],_ptr__4261[_4265] )] < _4264))))
              {
                {
                  _4264 = _ptr__4218[safe_add( _ptr__4208[_4265],_ptr__4261[_4265] )];
                }
              }
              {}
            }
          }
          if ((_4264 < (int)0))
          {
            {
              _4260 = true;
            }
          }
          else
          {
            {
              int _8728 = (int)0;
              int _8729 = _4202;
              for (int _4266 = _8728; _4266 < _8729; ++_4266)
              {
                {
                  if (((_ptr__4261[_4266] < _ptr__4204[_4266]) && (_4264 == _ptr__4218[safe_add( _ptr__4208[_4266],_ptr__4261[_4266] )])))
                  {
                    {
                      int _8730 = _ptr__4217[safe_add( _ptr__4206[_4266],_ptr__4261[_4266] )];
                      int _8731 = _ptr__4217[safe_add( safe_add( _ptr__4206[_4266],_ptr__4261[_4266] ),(int)1 )];
                      for (int _4267 = _8730; _4267 < _8731; ++_4267)
                      {
                        {
                          _ptr__4238[safe_add( _4232,_4263 )] = _ptr__4218[safe_add( _ptr__4207[_4266],_4267 )];
                          _ptr__4239[safe_add( _4234,_4263 )] = (((*w)(_4266)) * _ptr__4219[safe_add( _ptr__4209[_4266],_4267 )]);
                          ++ _4263;
                        }
                      }
                      _ptr__4239[safe_add( _4235,_4262 )] += (((*w)(_4266)) * _ptr__4219[safe_add( _ptr__4210[_4266],_ptr__4261[_4266] )]);
                      ++ _ptr__4261[_4266];
                    }
                  }
                  {}
                }
              }
              _ptr__4237[safe_add( safe_add( _4231,_4262 ),(int)1 )] = _4263;
              _ptr__4238[safe_add( _4233,_4262 )] = _4264;
            }
          }
          ++ _4262;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4268,    monty::rc_ptr< ::mosek::fusion::Expression > _4269){ return new mosek::fusion::ExprSumReduce(_4268,_4269); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4268,    monty::rc_ptr< ::mosek::fusion::Expression > _4269) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4268,_4269); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4268,    monty::rc_ptr< ::mosek::fusion::Expression > _4269){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4268,_4269->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4269;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4268;
    std::shared_ptr< monty::ndarray< int,1 > > _4270 = _4269->getShape();
    _checked_ptr_1<int> _ptr__4270(_4270 ? _4270->raw() : nullptr,_4270 ? _4270->size(0) : 0);
    if (((int)((_4270)->size(0)) <= _4268))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4271,monty::rc_ptr< ::mosek::fusion::WorkStack > _4272,monty::rc_ptr< ::mosek::fusion::WorkStack > _4273) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4271,_4272,_4273); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4271,monty::rc_ptr< ::mosek::fusion::WorkStack > _4272,monty::rc_ptr< ::mosek::fusion::WorkStack > _4273){
  expr->eval(_4272,_4271,_4273);
  _4272->pop_expr();
  int _4274 = mosek::fusion::p_WorkStack::_get_impl(_4272)->nd;
  int _4275 = mosek::fusion::p_WorkStack::_get_impl(_4272)->shape_base;
  int _4276 = mosek::fusion::p_WorkStack::_get_impl(_4272)->nelem;
  int _4277 = mosek::fusion::p_WorkStack::_get_impl(_4272)->nnz;
  bool _4278 = mosek::fusion::p_WorkStack::_get_impl(_4272)->hassp;
  int _4279 = mosek::fusion::p_WorkStack::_get_impl(_4272)->ptr_base;
  int _4280 = mosek::fusion::p_WorkStack::_get_impl(_4272)->sp_base;
  int _4281 = mosek::fusion::p_WorkStack::_get_impl(_4272)->nidxs_base;
  int _4282 = mosek::fusion::p_WorkStack::_get_impl(_4272)->bfix_base;
  int _4283 = mosek::fusion::p_WorkStack::_get_impl(_4272)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4284 = mosek::fusion::p_WorkStack::_get_impl(_4272)->i32;
  _checked_ptr_1<int> _ptr__4284(_4284 ? _4284->raw() : nullptr,_4284 ? _4284->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4285 = mosek::fusion::p_WorkStack::_get_impl(_4272)->i64;
  _checked_ptr_1<long long> _ptr__4285(_4285 ? _4285->raw() : nullptr,_4285 ? _4285->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4286 = mosek::fusion::p_WorkStack::_get_impl(_4272)->f64;
  _checked_ptr_1<double> _ptr__4286(_4286 ? _4286->raw() : nullptr,_4286 ? _4286->size(0) : 0);
  int _4287 = (int)99999;
  int _4288 = (int)99999;
  int _4289 = (int)99999;
  if (_4278)
  {
    {
      int _4290 = (int)0;
      int _8732 = (int)0;
      int _8733 = _4274;
      for (int _4291 = _8732; _4291 < _8733; ++_4291)
      {
        {
          if ((_4290 < _ptr__4284[safe_add( _4275,_4291 )]))
          {
            {
              _4290 = _ptr__4284[safe_add( _4275,_4291 )];
            }
          }
          {}
        }
      }
      _4287 = _4273->alloci32(safe_add( _4290,(int)1 ));
      _4288 = _4273->alloci32(_4276);
      _4289 = _4273->alloci32(_4276);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4292 = mosek::fusion::p_WorkStack::_get_impl(_4273)->i32;
  _checked_ptr_1<int> _ptr__4292(_4292 ? _4292->raw() : nullptr,_4292 ? _4292->size(0) : 0);
  if (_4278)
  {
    {
      int _4293 = _4288;
      int _4294 = _4289;
      int _8734 = (int)0;
      int _8735 = _4276;
      for (int _4295 = _8734; _4295 < _8735; ++_4295)
      {
        {
          _ptr__4292[safe_add( _4293,_4295 )] = _4295;
        }
      }
      if ((dim < (_4274 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4296 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4274)));
          _checked_ptr_1<long long> _ptr__4296(_4296 ? _4296->raw() : nullptr,_4296 ? _4296->size(0) : 0);
          _ptr__4296[(_4274 - (int)1)] = (int)1;
          int _8736 = (int)1;
          int _8737 = _4274;
          for (int _4297 = _8736; _4297 < _8737; ++_4297)
          {
            {
              _ptr__4296[((_4274 - _4297) - (int)1)] = safe_mul( _ptr__4296[(_4274 - _4297)],_ptr__4284[(safe_add( _4275,_4274 ) - _4297)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4298 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4274 - (int)1))));
          _checked_ptr_1<int> _ptr__4298(_4298 ? _4298->raw() : nullptr,_4298 ? _4298->size(0) : 0);
          int _8738 = (int)0;
          int _8739 = dim;
          for (int _4299 = _8738; _4299 < _8739; ++_4299)
          {
            {
              _ptr__4298[((_4274 - _4299) - (int)2)] = _4299;
            }
          }
          int _8740 = safe_add( dim,(int)1 );
          int _8741 = _4274;
          for (int _4300 = _8740; _4300 < _8741; ++_4300)
          {
            {
              _ptr__4298[((_4274 - _4300) - (int)1)] = _4300;
            }
          }
          int _8742 = (int)0;
          int _8743 = (_4274 - (int)1);
          for (int _4301 = _8742; _4301 < _8743; ++_4301)
          {
            {
              int _4302 = _ptr__4298[_4301];
              int _4303 = _ptr__4284[safe_add( _4275,_4302 )];
              int _8744 = (int)0;
              int _8745 = safe_add( _4303,(int)1 );
              for (int _4304 = _8744; _4304 < _8745; ++_4304)
              {
                {
                  _ptr__4292[safe_add( _4287,_4304 )] = (int)0;
                }
              }
              int _8746 = (int)0;
              int _8747 = _4276;
              for (int _4305 = _8746; _4305 < _8747; ++_4305)
              {
                {
                  ++ _ptr__4292[safe_add( safe_add( _4287,(int)1 ),((_ptr__4285[safe_add( _4280,_4305 )] / _ptr__4296[_4302]) % _4303) )];
                }
              }
              int _8748 = (int)0;
              int _8749 = _4303;
              for (int _4306 = _8748; _4306 < _8749; ++_4306)
              {
                {
                  _ptr__4292[safe_add( safe_add( _4287,_4306 ),(int)1 )] += _ptr__4292[safe_add( _4287,_4306 )];
                }
              }
              int _8750 = (int)0;
              int _8751 = _4276;
              for (int _4307 = _8750; _4307 < _8751; ++_4307)
              {
                {
                  int _4308 = _ptr__4292[safe_add( _4293,_4307 )];
                  long long _4309 = ((_ptr__4285[safe_add( _4280,_4308 )] / _ptr__4296[_4302]) % _4303);
                  _ptr__4292[safe_add( _4294,_ptr__4292[safe_add( _4287,_4309 )] )] = _4308;
                  ++ _ptr__4292[safe_add( _4287,_4309 )];
                }
              }
              int _4310 = _4294;
              _4294 = _4293;
              _4293 = _4310;
            }
          }
        }
      }
      {}
      int _4311 = (int)1;
      int _8752 = (int)0;
      int _8753 = dim;
      for (int _4312 = _8752; _4312 < _8753; ++_4312)
      {
        {
          _4311 *= _ptr__4284[safe_add( _4275,_4312 )];
        }
      }
      int _4313 = _ptr__4284[safe_add( _4275,dim )];
      int _4314 = (int)1;
      int _8754 = safe_add( dim,(int)1 );
      int _8755 = _4274;
      for (int _4315 = _8754; _4315 < _8755; ++_4315)
      {
        {
          _4314 *= _ptr__4284[safe_add( _4275,_4315 )];
        }
      }
      int _4316 = safe_mul( _4314,_4313 );
      int _4317 = _4314;
      int _4318 = (int)1;
      int _4319 = (int)0;
      long long _4320 = (-(int)1);
      long long _4321 = (-(int)1);
      int _8756 = (int)0;
      int _8757 = _4276;
      for (int _4322 = _8756; _4322 < _8757; ++_4322)
      {
        {
          int _4323 = _ptr__4292[safe_add( _4293,_4322 )];
          long long _4324 = ((_ptr__4285[safe_add( _4280,_4323 )] / _4316) % _4311);
          long long _4325 = (_ptr__4285[safe_add( _4280,_4323 )] % _4314);
          if (((_4321 != _4324) || (_4320 != _4325)))
          {
            {
              _4321 = _4324;
              _4320 = _4325;
              ++ _4319;
            }
          }
          {}
        }
      }
      int _4326 = (_4274 - (int)1);
      bool _4327 = (_4319 < safe_mul( _4311,_4314 ));
      int _4328 = _4277;
      _4271->alloc_expr(_4326,_4319,_4328,_4327);
      int _4329 = mosek::fusion::p_WorkStack::_get_impl(_4271)->ptr_base;
      int _4330 = mosek::fusion::p_WorkStack::_get_impl(_4271)->nidxs_base;
      int _8758;
      bool _8759 = _4327;
      if (_8759)
      {
        _8758 = mosek::fusion::p_WorkStack::_get_impl(_4271)->sp_base;
      }
      else
      {
        _8758 = _4271->alloci64(_4319);
      }
      int _4331 = _8758;
      int _4332 = mosek::fusion::p_WorkStack::_get_impl(_4271)->cof_base;
      int _4333 = mosek::fusion::p_WorkStack::_get_impl(_4271)->bfix_base;
      int _4334 = mosek::fusion::p_WorkStack::_get_impl(_4271)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4335 = mosek::fusion::p_WorkStack::_get_impl(_4271)->i32;
      _checked_ptr_1<int> _ptr__4335(_4335 ? _4335->raw() : nullptr,_4335 ? _4335->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4336 = mosek::fusion::p_WorkStack::_get_impl(_4271)->i64;
      _checked_ptr_1<long long> _ptr__4336(_4336 ? _4336->raw() : nullptr,_4336 ? _4336->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4337 = mosek::fusion::p_WorkStack::_get_impl(_4271)->f64;
      _checked_ptr_1<double> _ptr__4337(_4337 ? _4337->raw() : nullptr,_4337 ? _4337->size(0) : 0);
      int _8760 = (int)0;
      int _8761 = dim;
      for (int _4338 = _8760; _4338 < _8761; ++_4338)
      {
        {
          _ptr__4335[safe_add( _4334,_4338 )] = _ptr__4284[safe_add( _4275,_4338 )];
        }
      }
      int _8762 = safe_add( dim,(int)1 );
      int _8763 = _4274;
      for (int _4339 = _8762; _4339 < _8763; ++_4339)
      {
        {
          _ptr__4335[(safe_add( _4334,_4339 ) - (int)1)] = _ptr__4284[safe_add( _4275,_4339 )];
        }
      }
      _ptr__4335[_4329] = (int)0;
      int _4340 = (int)0;
      int _4341 = (int)0;
      int _4342 = (int)0;
      while ( (_4342 < _4276) )
      {
        {
          int _4343 = _4342;
          long long _4344 = ((_ptr__4285[safe_add( _4280,_ptr__4292[safe_add( _4293,_4343 )] )] / _4316) % _4311);
          long long _4345 = (_ptr__4285[safe_add( _4280,_ptr__4292[safe_add( _4293,_4343 )] )] % _4314);
          ++ _4342;
          while ( ((_4342 < _4276) && ((_4344 == ((_ptr__4285[safe_add( _4280,_ptr__4292[safe_add( _4293,_4342 )] )] / _4316) % _4311)) && (_4345 == (_ptr__4285[safe_add( _4280,_ptr__4292[safe_add( _4293,_4342 )] )] % _4314)))) )
          {
            {
              ++ _4342;
            }
          }
          double _4346 = 0.0;
          int _8764 = _4343;
          int _8765 = _4342;
          for (int _4347 = _8764; _4347 < _8765; ++_4347)
          {
            {
              int _4348 = _ptr__4292[safe_add( _4293,_4347 )];
              int _8766 = _ptr__4284[safe_add( _4279,_4348 )];
              int _8767 = _ptr__4284[safe_add( safe_add( _4279,_4348 ),(int)1 )];
              for (int _4349 = _8766; _4349 < _8767; ++_4349)
              {
                {
                  _ptr__4336[safe_add( _4330,_4341 )] = _ptr__4285[safe_add( _4281,_4349 )];
                  _ptr__4337[safe_add( _4332,_4341 )] = _ptr__4286[safe_add( _4283,_4349 )];
                  ++ _4341;
                }
              }
              _4346 += _ptr__4286[safe_add( _4282,_4348 )];
            }
          }
          _ptr__4336[safe_add( _4331,_4340 )] = safe_add( safe_mul( _4344,_4314 ),_4345 );
          _ptr__4335[safe_add( safe_add( _4329,_4340 ),(int)1 )] = _4341;
          _ptr__4337[safe_add( _4333,_4340 )] = _4346;
          ++ _4340;
        }
      }
      if ((!_4327))
      {
        {
          _4271->popi64(_4319);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4350 = (int)1;
      int _8768 = (int)0;
      int _8769 = dim;
      for (int _4351 = _8768; _4351 < _8769; ++_4351)
      {
        {
          _4350 *= _ptr__4284[safe_add( _4275,_4351 )];
        }
      }
      int _4352 = _ptr__4284[safe_add( _4275,dim )];
      int _4353 = (int)1;
      int _8770 = safe_add( dim,(int)1 );
      int _8771 = _4274;
      for (int _4354 = _8770; _4354 < _8771; ++_4354)
      {
        {
          _4353 *= _ptr__4284[safe_add( _4275,_4354 )];
        }
      }
      int _4355 = safe_mul( _4353,_4352 );
      int _4356 = _4353;
      int _4357 = (int)1;
      int _4358 = safe_mul( _4350,_4353 );
      int _4359 = _4271->alloci32(safe_add( _4358,(int)1 ));
      int _4360 = _4271->alloci64(_4277);
      int _4361 = _4271->allocf64(_4277);
      int _4362 = _4271->allocf64(_4358);
      _4271->pushi32((int)0);
      _4271->pushi32(_4277);
      _4271->pushi32(_4358);
      int _4363 = _4271->alloci32((_4274 - (int)1));
      _4271->pushi32((_4274 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4364 = mosek::fusion::p_WorkStack::_get_impl(_4271)->i32;
      _checked_ptr_1<int> _ptr__4364(_4364 ? _4364->raw() : nullptr,_4364 ? _4364->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4365 = mosek::fusion::p_WorkStack::_get_impl(_4271)->i64;
      _checked_ptr_1<long long> _ptr__4365(_4365 ? _4365->raw() : nullptr,_4365 ? _4365->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4366 = mosek::fusion::p_WorkStack::_get_impl(_4271)->f64;
      _checked_ptr_1<double> _ptr__4366(_4366 ? _4366->raw() : nullptr,_4366 ? _4366->size(0) : 0);
      int _8772 = (int)0;
      int _8773 = dim;
      for (int _4367 = _8772; _4367 < _8773; ++_4367)
      {
        {
          _ptr__4364[safe_add( _4363,_4367 )] = _ptr__4284[safe_add( _4275,_4367 )];
        }
      }
      int _8774 = safe_add( dim,(int)1 );
      int _8775 = _4274;
      for (int _4368 = _8774; _4368 < _8775; ++_4368)
      {
        {
          _ptr__4364[(safe_add( _4363,_4368 ) - (int)1)] = _ptr__4284[safe_add( _4275,_4368 )];
        }
      }
      int _4369 = (int)0;
      int _4370 = (int)0;
      _ptr__4364[_4359] = (int)0;
      int _8776 = (int)0;
      int _8777 = _4350;
      for (int _4371 = _8776; _4371 < _8777; ++_4371)
      {
        {
          int _8778 = (int)0;
          int _8779 = _4353;
          for (int _4372 = _8778; _4372 < _8779; ++_4372)
          {
            {
              double _4373 = 0.0;
              int _8780 = (int)0;
              int _8781 = _4352;
              for (int _4374 = _8780; _4374 < _8781; ++_4374)
              {
                {
                  int _4375 = safe_add( safe_add( safe_mul( _4371,_4355 ),safe_mul( _4374,_4356 ) ),_4372 );
                  int _8782 = _ptr__4284[safe_add( _4279,_4375 )];
                  int _8783 = _ptr__4284[safe_add( safe_add( _4279,_4375 ),(int)1 )];
                  for (int _4376 = _8782; _4376 < _8783; ++_4376)
                  {
                    {
                      _ptr__4365[safe_add( _4360,_4370 )] = _ptr__4285[safe_add( _4281,_4376 )];
                      _ptr__4366[safe_add( _4361,_4370 )] = _ptr__4286[safe_add( _4283,_4376 )];
                      ++ _4370;
                    }
                  }
                  _4373 += _ptr__4286[safe_add( _4282,_4375 )];
                }
              }
              _ptr__4364[safe_add( safe_add( _4359,_4369 ),(int)1 )] = _4370;
              _ptr__4366[safe_add( _4362,_4369 )] = _4373;
              ++ _4369;
            }
          }
        }
      }
    }
  }
  _4273->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4377,std::shared_ptr< monty::ndarray< int,1 > > _4378){
  _checked_ptr_1<int> _ptr__4378(_4378 ? _4378->raw() : nullptr, _4378 ? _4378->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4379 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4378)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4379(_4379 ? _4379->raw() : nullptr,_4379 ? _4379->size(0) : 0);
  int _8784 = (int)0;
  int _8785 = _4377;
  for (int _4380 = _8784; _4380 < _8785; ++_4380)
  {
    {
      _ptr__4379[_4380] = _ptr__4378[_4380];
    }
  }
  int _8786 = safe_add( _4377,(int)1 );
  int _8787 = (int)((_4378)->size(0));
  for (int _4381 = _8786; _4381 < _8787; ++_4381)
  {
    {
      _ptr__4379[(_4381 - (int)1)] = _ptr__4378[_4381];
    }
  }
  return _4379;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384,    int _4385){ return new mosek::fusion::ExprDenseTril(_4382,_4383,_4384,_4385); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384,    int _4385) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4382,_4383,_4384,_4385); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384,    int _4385){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4384->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4384;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4382;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4383;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4386,    int _4387,    monty::rc_ptr< ::mosek::fusion::Expression > _4388){ return new mosek::fusion::ExprDenseTril(_4386,_4387,_4388); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4386,    int _4387,    monty::rc_ptr< ::mosek::fusion::Expression > _4388) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4386,_4387,_4388); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4386,    int _4387,    monty::rc_ptr< ::mosek::fusion::Expression > _4388){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4386,_4387,_4388,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4389 = _4388->getShape();
    _checked_ptr_1<int> _ptr__4389(_4389 ? _4389->raw() : nullptr,_4389 ? _4389->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4389)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4389)->size(0))) || (_ptr__4389[dim0] != _ptr__4389[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4390,monty::rc_ptr< ::mosek::fusion::WorkStack > _4391,monty::rc_ptr< ::mosek::fusion::WorkStack > _4392) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4390,_4391,_4392); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4390,monty::rc_ptr< ::mosek::fusion::WorkStack > _4391,monty::rc_ptr< ::mosek::fusion::WorkStack > _4392){
  expr->eval(_4391,_4390,_4392);
  std::shared_ptr< monty::ndarray< int,1 > > _4393 = mosek::fusion::p_WorkStack::_get_impl(_4391)->i32;
  _checked_ptr_1<int> _ptr__4393(_4393 ? _4393->raw() : nullptr,_4393 ? _4393->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4394 = mosek::fusion::p_WorkStack::_get_impl(_4391)->i64;
  _checked_ptr_1<long long> _ptr__4394(_4394 ? _4394->raw() : nullptr,_4394 ? _4394->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4395 = mosek::fusion::p_WorkStack::_get_impl(_4391)->f64;
  _checked_ptr_1<double> _ptr__4395(_4395 ? _4395->raw() : nullptr,_4395 ? _4395->size(0) : 0);
  int _8788;
  bool _8789 = (dim0 < dim1);
  if (_8789)
  {
    _8788 = dim0;
  }
  else
  {
    _8788 = dim1;
  }
  int _4396 = _8788;
  int _8790;
  bool _8791 = (dim0 > dim1);
  if (_8791)
  {
    _8790 = dim0;
  }
  else
  {
    _8790 = dim1;
  }
  int _4397 = _8790;
  bool _4398 = (dim0 < dim1);
  int _4399 = _4391->popi32();
  int _4400 = _4391->popi32(_4399);
  int _4401 = _4391->popi32();
  int _4402 = _4391->popi32();
  bool _4403 = (_4391->popi32() != (int)0);
  int _4404 = _4391->popi32(safe_add( _4401,(int)1 ));
  int _8792;
  bool _8793 = _4403;
  if (_8793)
  {
    _8792 = _4391->popi64(_4401);
  }
  else
  {
    _8792 = (-(int)1);
  }
  int _4405 = _8792;
  int _4406 = _4391->popi64(_4402);
  int _4407 = _4391->popf64(_4401);
  int _4408 = _4391->popf64(_4402);
  std::vector<int> _8794;
  for (int _4410 = (int)0, _8795 = (int)5; _4410 < _8795 ; ++_4410)
  {
    _8794.push_back((int)1);
  }
  auto _8796 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8794.size()),_8794.begin(),_8794.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4409 = _8796;
  _checked_ptr_1<int> _ptr__4409(_4409 ? _4409->raw() : nullptr,_4409 ? _4409->size(0) : 0);
  int _8797 = (int)0;
  int _8798 = _4396;
  for (int _4411 = _8797; _4411 < _8798; ++_4411)
  {
    {
      _ptr__4409[(int)0] *= _ptr__4393[safe_add( _4400,_4411 )];
    }
  }
  _ptr__4409[(int)1] = _ptr__4393[safe_add( _4400,_4396 )];
  int _8799 = safe_add( _4396,(int)1 );
  int _8800 = _4397;
  for (int _4412 = _8799; _4412 < _8800; ++_4412)
  {
    {
      _ptr__4409[(int)2] *= _ptr__4393[safe_add( _4400,_4412 )];
    }
  }
  _ptr__4409[(int)3] = _ptr__4393[safe_add( _4400,_4397 )];
  int _8801 = safe_add( _4397,(int)1 );
  int _8802 = _4399;
  for (int _4413 = _8801; _4413 < _8802; ++_4413)
  {
    {
      _ptr__4409[(int)4] *= _ptr__4393[safe_add( _4400,_4413 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4414 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4414(_4414 ? _4414->raw() : nullptr,_4414 ? _4414->size(0) : 0);
  _ptr__4414[(int)4] = (int)1;
  int _8803 = (int)1;
  int _8804 = (int)5;
  for (int _4415 = _8803; _4415 < _8804; ++_4415)
  {
    {
      _ptr__4414[(((int)5 - _4415) - (int)1)] = safe_mul( _ptr__4414[((int)5 - _4415)],_ptr__4409[((int)5 - _4415)] );
    }
  }
  int _4416 = (int)0;
  int _4417 = (int)0;
  {
    if (_4403)
    {
      {
        if (_4398)
        {
          {
            int _8805 = (int)0;
            int _8806 = _4401;
            for (int _4418 = _8805; _4418 < _8806; ++_4418)
            {
              {
                long long _4419 = ((_ptr__4394[safe_add( _4405,_4418 )] / _ptr__4414[(int)1]) % _ptr__4409[(int)1]);
                long long _4420 = ((_ptr__4394[safe_add( _4405,_4418 )] / _ptr__4414[(int)3]) % _ptr__4409[(int)3]);
                if ((_4419 >= _4420))
                {
                  {
                    _4416 += (_ptr__4393[safe_add( safe_add( _4404,_4418 ),(int)1 )] - _ptr__4393[safe_add( _4404,_4418 )]);
                    ++ _4417;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8807 = (int)0;
            int _8808 = _4401;
            for (int _4421 = _8807; _4421 < _8808; ++_4421)
            {
              {
                long long _4422 = ((_ptr__4394[safe_add( _4405,_4421 )] / _ptr__4414[(int)1]) % _ptr__4409[(int)1]);
                long long _4423 = ((_ptr__4394[safe_add( _4405,_4421 )] / _ptr__4414[(int)3]) % _ptr__4409[(int)3]);
                if ((_4422 <= _4423))
                {
                  {
                    _4416 += (_ptr__4393[safe_add( safe_add( _4404,_4421 ),(int)1 )] - _ptr__4393[safe_add( _4404,_4421 )]);
                    ++ _4417;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4417 = safe_mul( safe_mul( safe_mul( _ptr__4409[(int)0],_ptr__4409[(int)2] ),_ptr__4409[(int)4] ),(safe_mul( _ptr__4409[(int)1],safe_add( _ptr__4409[(int)1],(int)1 ) ) / (int)2) );
        if (_4398)
        {
          {
            int _8809 = (int)0;
            int _8810 = _ptr__4409[(int)0];
            for (int _4424 = _8809; _4424 < _8810; ++_4424)
            {
              {
                int _8811 = (int)0;
                int _8812 = _ptr__4409[(int)1];
                for (int _4425 = _8811; _4425 < _8812; ++_4425)
                {
                  {
                    int _8813 = (int)0;
                    int _8814 = _ptr__4409[(int)2];
                    for (int _4426 = _8813; _4426 < _8814; ++_4426)
                    {
                      {
                        int _8815 = (int)0;
                        int _8816 = safe_add( _4425,(int)1 );
                        for (int _4427 = _8815; _4427 < _8816; ++_4427)
                        {
                          {
                            int _8817 = (int)0;
                            int _8818 = _ptr__4409[(int)4];
                            for (int _4428 = _8817; _4428 < _8818; ++_4428)
                            {
                              {
                                int _4429 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4424,_ptr__4414[(int)0] ),safe_mul( _4425,_ptr__4414[(int)1] ) ),safe_mul( _4426,_ptr__4414[(int)2] ) ),safe_mul( _4427,_ptr__4414[(int)3] ) ),safe_mul( _4428,_ptr__4414[(int)4] ) );
                                _4416 += (_ptr__4393[safe_add( safe_add( _4404,_4429 ),(int)1 )] - _ptr__4393[safe_add( _4404,_4429 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8819 = (int)0;
            int _8820 = _ptr__4409[(int)0];
            for (int _4430 = _8819; _4430 < _8820; ++_4430)
            {
              {
                int _8821 = (int)0;
                int _8822 = _ptr__4409[(int)1];
                for (int _4431 = _8821; _4431 < _8822; ++_4431)
                {
                  {
                    int _8823 = (int)0;
                    int _8824 = _ptr__4409[(int)2];
                    for (int _4432 = _8823; _4432 < _8824; ++_4432)
                    {
                      {
                        int _8825 = _4431;
                        int _8826 = _ptr__4409[(int)3];
                        for (int _4433 = _8825; _4433 < _8826; ++_4433)
                        {
                          {
                            int _8827 = (int)0;
                            int _8828 = _ptr__4409[(int)4];
                            for (int _4434 = _8827; _4434 < _8828; ++_4434)
                            {
                              {
                                int _4435 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4430,_ptr__4414[(int)0] ),safe_mul( _4431,_ptr__4414[(int)1] ) ),safe_mul( _4432,_ptr__4414[(int)2] ) ),safe_mul( _4433,_ptr__4414[(int)3] ) ),safe_mul( _4434,_ptr__4414[(int)4] ) );
                                _4416 += (_ptr__4393[safe_add( safe_add( _4404,_4435 ),(int)1 )] - _ptr__4393[safe_add( _4404,_4435 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4436 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4409[(int)0],_ptr__4409[(int)2] ),_ptr__4409[(int)4] ),_ptr__4409[(int)1] ),safe_add( _ptr__4409[(int)1],(int)1 ) ) / (int)2);
  int _4437 = _4390->alloci32(safe_add( _4436,(int)1 ));
  _4390->pushi32((int)1);
  _4390->pushi32(_4416);
  _4390->pushi32(_4436);
  int _8829 = (int)0;
  int _8830 = _4399;
  for (int _4438 = _8829; _4438 < _8830; ++_4438)
  {
    {
      _4390->pushi32(_ptr__4393[safe_add( _4400,_4438 )]);
    }
  }
  _4390->pushi32(_4399);
  int _4439 = _4390->alloci64(_4416);
  int _4440 = _4390->alloci64(_4436);
  int _4441 = _4390->allocf64(_4416);
  int _4442 = _4390->allocf64(_4436);
  std::shared_ptr< monty::ndarray< int,1 > > _4443 = mosek::fusion::p_WorkStack::_get_impl(_4390)->i32;
  _checked_ptr_1<int> _ptr__4443(_4443 ? _4443->raw() : nullptr,_4443 ? _4443->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4444 = mosek::fusion::p_WorkStack::_get_impl(_4390)->i64;
  _checked_ptr_1<long long> _ptr__4444(_4444 ? _4444->raw() : nullptr,_4444 ? _4444->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4445 = mosek::fusion::p_WorkStack::_get_impl(_4390)->f64;
  _checked_ptr_1<double> _ptr__4445(_4445 ? _4445->raw() : nullptr,_4445 ? _4445->size(0) : 0);
  _ptr__4443[_4437] = (int)0;
  if (_4398)
  {
    {
      int _4446 = (int)0;
      int _8831 = (int)0;
      int _8832 = _ptr__4409[(int)0];
      for (int _4447 = _8831; _4447 < _8832; ++_4447)
      {
        {
          int _8833 = (int)0;
          int _8834 = _ptr__4409[(int)1];
          for (int _4448 = _8833; _4448 < _8834; ++_4448)
          {
            {
              int _8835 = (int)0;
              int _8836 = _ptr__4409[(int)2];
              for (int _4449 = _8835; _4449 < _8836; ++_4449)
              {
                {
                  int _8837 = (int)0;
                  int _8838 = safe_add( _4448,(int)1 );
                  for (int _4450 = _8837; _4450 < _8838; ++_4450)
                  {
                    {
                      int _8839 = (int)0;
                      int _8840 = _ptr__4409[(int)4];
                      for (int _4451 = _8839; _4451 < _8840; ++_4451)
                      {
                        {
                          _ptr__4444[safe_add( _4440,_4446 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4447,_ptr__4414[(int)0] ),safe_mul( _4448,_ptr__4414[(int)1] ) ),safe_mul( _4449,_ptr__4414[(int)2] ) ),safe_mul( _4450,_ptr__4414[(int)3] ) ),safe_mul( _4451,_ptr__4414[(int)4] ) );
                          ++ _4446;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4452 = (int)0;
      int _8841 = (int)0;
      int _8842 = _ptr__4409[(int)0];
      for (int _4453 = _8841; _4453 < _8842; ++_4453)
      {
        {
          int _8843 = (int)0;
          int _8844 = _ptr__4409[(int)1];
          for (int _4454 = _8843; _4454 < _8844; ++_4454)
          {
            {
              int _8845 = (int)0;
              int _8846 = _ptr__4409[(int)2];
              for (int _4455 = _8845; _4455 < _8846; ++_4455)
              {
                {
                  int _8847 = _4454;
                  int _8848 = _ptr__4409[(int)3];
                  for (int _4456 = _8847; _4456 < _8848; ++_4456)
                  {
                    {
                      int _8849 = (int)0;
                      int _8850 = _ptr__4409[(int)4];
                      for (int _4457 = _8849; _4457 < _8850; ++_4457)
                      {
                        {
                          _ptr__4444[safe_add( _4440,_4452 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4453,_ptr__4414[(int)0] ),safe_mul( _4454,_ptr__4414[(int)1] ) ),safe_mul( _4455,_ptr__4414[(int)2] ) ),safe_mul( _4456,_ptr__4414[(int)3] ) ),safe_mul( _4457,_ptr__4414[(int)4] ) );
                          ++ _4452;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4458 = (int)0;
    if (_4403)
    {
      {
        int _4459 = (int)0;
        int _4460 = (int)0;
        while ( ((_4460 < _4401) && (_4459 < _4436)) )
        {
          {
            if ((_ptr__4394[safe_add( _4405,_4460 )] < _ptr__4444[safe_add( _4440,_4459 )]))
            {
              {
                ++ _4460;
              }
            }
            else if((_ptr__4394[safe_add( _4405,_4460 )] > _ptr__4444[safe_add( _4440,_4459 )]))
            {
              {
                _ptr__4445[safe_add( _4442,_4459 )] = 0.0;
                _ptr__4443[safe_add( safe_add( _4437,_4459 ),(int)1 )] = _4458;
                ++ _4459;
              }
            }
            else
            {
              {
                int _8851 = _ptr__4393[safe_add( _4404,_4460 )];
                int _8852 = _ptr__4393[safe_add( safe_add( _4404,_4460 ),(int)1 )];
                for (int _4461 = _8851; _4461 < _8852; ++_4461)
                {
                  {
                    _ptr__4444[safe_add( _4439,_4458 )] = _ptr__4394[safe_add( _4406,_4461 )];
                    _ptr__4445[safe_add( _4441,_4458 )] = _ptr__4395[safe_add( _4408,_4461 )];
                    ++ _4458;
                  }
                }
                _ptr__4445[safe_add( _4442,_4459 )] = _ptr__4395[safe_add( _4407,_4460 )];
                _ptr__4443[safe_add( safe_add( _4437,_4459 ),(int)1 )] = _4458;
                ++ _4460;
                ++ _4459;
              }
            }
          }
        }
        while ( (_4459 < _4436) )
        {
          {
            _ptr__4443[safe_add( safe_add( _4437,_4459 ),(int)1 )] = _4458;
            _ptr__4445[safe_add( _4442,_4459 )] = 0.0;
            ++ _4459;
          }
        }
      }
    }
    else
    {
      {
        int _8853 = (int)0;
        int _8854 = _4436;
        for (int _4462 = _8853; _4462 < _8854; ++_4462)
        {
          {
            long long _4463 = _ptr__4444[safe_add( _4440,_4462 )];
            _ptr__4445[safe_add( _4442,_4462 )] = _ptr__4395[safe_add( _4407,_4463 )];
            int _8855 = _ptr__4393[safe_add( _4404,_4463 )];
            int _8856 = _ptr__4393[safe_add( safe_add( _4404,_4463 ),(int)1 )];
            for (int _4464 = _8855; _4464 < _8856; ++_4464)
            {
              {
                _ptr__4444[safe_add( _4439,_4458 )] = _ptr__4394[safe_add( _4406,_4464 )];
                _ptr__4445[safe_add( _4441,_4458 )] = _ptr__4395[safe_add( _4408,_4464 )];
                ++ _4458;
              }
            }
            _ptr__4443[safe_add( safe_add( _4437,_4462 ),(int)1 )] = _4458;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4465){ return new mosek::fusion::ExprDense(_4465); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4465) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4465); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4465){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4465->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4465;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4466,monty::rc_ptr< ::mosek::fusion::WorkStack > _4467,monty::rc_ptr< ::mosek::fusion::WorkStack > _4468) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4466,_4467,_4468); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4466,monty::rc_ptr< ::mosek::fusion::WorkStack > _4467,monty::rc_ptr< ::mosek::fusion::WorkStack > _4468){
  expr->eval(_4466,_4467,_4468);
  _4466->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4466)->hassp)
  {
    {
      int _4469 = mosek::fusion::p_WorkStack::_get_impl(_4466)->nd;
      int _4470 = mosek::fusion::p_WorkStack::_get_impl(_4466)->nnz;
      int _4471 = mosek::fusion::p_WorkStack::_get_impl(_4466)->nelem;
      int _4472 = mosek::fusion::p_WorkStack::_get_impl(_4466)->sp_base;
      std::vector<int> _8857;
      for (int _4474 = (int)0, _8858 = _4469; _4474 < _8858 ; ++_4474)
      {
        _8857.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4466)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4466)->shape_base,_4474 ))));
      }
      auto _8859 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8857.size()),_8857.begin(),_8857.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4473 = _8859;
      _checked_ptr_1<int> _ptr__4473(_4473 ? _4473->raw() : nullptr,_4473 ? _4473->size(0) : 0);
      int _4475 = (int)::mosek::fusion::p_Set::size(_4473);
      _4466->popi32(safe_add( (int)4,_4469 ));
      if ((_4475 == _4471))
      {
        {
          _4466->popi64(_4471);
          _4466->pushi32((int)0);
          _4466->pushi32(_4470);
          _4466->pushi32(_4471);
          int _4476 = _4466->alloci32(_4469);
          int _8860 = (int)0;
          int _8861 = _4469;
          for (int _4477 = _8860; _4477 < _8861; ++_4477)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4466)->i32)(safe_add( _4476,_4477 ))) = _ptr__4473[_4477];
            }
          }
          _4466->pushi32(_4469);
          _4466->peek_expr();
        }
      }
      else
      {
        {
          int _4478 = _4468->alloci32(safe_add( _4475,(int)1 ));
          int _4479 = _4468->allocf64(_4475);
          std::shared_ptr< monty::ndarray< int,1 > > _4480 = mosek::fusion::p_WorkStack::_get_impl(_4468)->i32;
          _checked_ptr_1<int> _ptr__4480(_4480 ? _4480->raw() : nullptr,_4480 ? _4480->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4481 = mosek::fusion::p_WorkStack::_get_impl(_4468)->f64;
          _checked_ptr_1<double> _ptr__4481(_4481 ? _4481->raw() : nullptr,_4481 ? _4481->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4466)->f64,mosek::fusion::p_WorkStack::_get_impl(_4466)->bfix_base,_4481,_4479,_4471);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4466)->i32,mosek::fusion::p_WorkStack::_get_impl(_4466)->ptr_base,_4480,_4478,safe_add( _4471,(int)1 ));
          _4466->popi32(safe_add( _4471,(int)1 ));
          _4466->popf64(_4471);
          int _4482 = _4466->alloci32(safe_add( _4475,(int)1 ));
          int _4483 = _4466->allocf64(_4475);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4484 = mosek::fusion::p_WorkStack::_get_impl(_4466)->i32;
            _checked_ptr_1<int> _ptr__4484(_4484 ? _4484->raw() : nullptr,_4484 ? _4484->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4485 = mosek::fusion::p_WorkStack::_get_impl(_4466)->i64;
            _checked_ptr_1<long long> _ptr__4485(_4485 ? _4485->raw() : nullptr,_4485 ? _4485->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4486 = mosek::fusion::p_WorkStack::_get_impl(_4466)->f64;
            _checked_ptr_1<double> _ptr__4486(_4486 ? _4486->raw() : nullptr,_4486 ? _4486->size(0) : 0);
            _ptr__4484[_4482] = (int)0;
            int _4487 = (int)0;
            if ((_4471 > (int)0))
            {
              {
                int _8862 = (int)0;
                int _8863 = _4475;
                for (int _4488 = _8862; _4488 < _8863; ++_4488)
                {
                  {
                    if ((_ptr__4485[safe_add( _4472,_4487 )] == _4488))
                    {
                      {
                        _ptr__4486[safe_add( _4483,_4488 )] = _ptr__4481[safe_add( _4479,_4487 )];
                        ++ _4487;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4486[safe_add( _4483,_4488 )] = (int)0;
                      }
                    }
                    _ptr__4484[safe_add( safe_add( _4482,_4488 ),(int)1 )] = _ptr__4480[safe_add( _4478,_4487 )];
                  }
                }
              }
            }
            else
            {
              {
                int _8864 = (int)0;
                int _8865 = _4475;
                for (int _4489 = _8864; _4489 < _8865; ++_4489)
                {
                  {
                    _ptr__4486[safe_add( _4483,_4489 )] = (int)0;
                    _ptr__4484[safe_add( safe_add( _4482,_4489 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4466->popi64(_4471);
          _4466->pushi32((int)0);
          _4466->pushi32(_4470);
          _4466->pushi32(_4475);
          int _8866 = (int)0;
          int _8867 = _4469;
          for (int _4490 = _8866; _4490 < _8867; ++_4490)
          {
            {
              _4466->pushi32(_ptr__4473[_4490]);
            }
          }
          _4466->pushi32(_4469);
        }
      }
      _4466->peek_expr();
    }
  }
  {}
  _4468->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493,    int _4494){ return new mosek::fusion::ExprSymmetrize(_4491,_4492,_4493,_4494); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493,    int _4494) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4491,_4492,_4493,_4494); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493,    int _4494){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4493->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4493;
    if ((_4491 < _4492))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4491;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4492;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4492;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4491;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4495,    int _4496,    monty::rc_ptr< ::mosek::fusion::Expression > _4497){ return new mosek::fusion::ExprSymmetrize(_4495,_4496,_4497); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4495,    int _4496,    monty::rc_ptr< ::mosek::fusion::Expression > _4497) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4495,_4496,_4497); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4495,    int _4496,    monty::rc_ptr< ::mosek::fusion::Expression > _4497){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4495,_4496,_4497,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4498 = _4497->getShape();
    _checked_ptr_1<int> _ptr__4498(_4498 ? _4498->raw() : nullptr,_4498 ? _4498->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4498)->size(0))) || (_ptr__4498[dim0] != _ptr__4498[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4499,_4500,_4501); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501){
  expr->eval(_4500,_4499,_4501);
  int _4502 = (int)0;
  int _4503 = _4500->peeki32();
  int _4504 = _4500->peeki32(safe_add( _4503,(int)3 ));
  int _4505 = _4500->peeki32(safe_add( _4503,(int)2 ));
  int _8868 = (int)0;
  int _8869 = _4503;
  for (int _4506 = _8868; _4506 < _8869; ++_4506)
  {
    {
      int _4507 = _4500->peeki32(safe_add( _4506,(int)1 ));
      if ((_4507 > _4502))
      {
        {
          _4507 = _4502;
        }
      }
      {}
    }
  }
  int _4508 = _4500->alloci32(_4505);
  int _4509 = _4500->alloci32(_4505);
  int _4510 = _4500->alloci32(safe_add( _4502,(int)1 ));
  int _4511 = _4500->alloci64(_4505);
  _4500->popi32(safe_add( safe_add( safe_mul( (int)2,_4505 ),_4502 ),(int)1 ));
  _4500->popi64(_4505);
  int _4512 = _4500->popi32();
  int _4513 = _4500->popi32(_4512);
  int _4514 = _4500->popi32();
  int _4515 = _4500->popi32();
  bool _4516 = (_4500->popi32() != (int)0);
  int _4517 = _4500->popi32(safe_add( _4514,(int)1 ));
  int _8870;
  bool _8871 = _4516;
  if (_8871)
  {
    _8870 = _4500->popi64(_4514);
  }
  else
  {
    _8870 = (-(int)1);
  }
  int _4518 = _8870;
  int _4519 = _4500->popi64(_4515);
  int _4520 = _4500->popf64(_4514);
  int _4521 = _4500->popf64(_4515);
  int _4522 = (int)0;
  int _4523 = (int)0;
  std::vector<int> _8872;
  for (int _4525 = (int)0, _8873 = (int)5; _4525 < _8873 ; ++_4525)
  {
    _8872.push_back((int)1);
  }
  auto _8874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8872.size()),_8872.begin(),_8872.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4524 = _8874;
  _checked_ptr_1<int> _ptr__4524(_4524 ? _4524->raw() : nullptr,_4524 ? _4524->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4526 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4526(_4526 ? _4526->raw() : nullptr,_4526 ? _4526->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4527 = mosek::fusion::p_WorkStack::_get_impl(_4500)->i32;
  _checked_ptr_1<int> _ptr__4527(_4527 ? _4527->raw() : nullptr,_4527 ? _4527->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4528 = mosek::fusion::p_WorkStack::_get_impl(_4500)->i64;
  _checked_ptr_1<long long> _ptr__4528(_4528 ? _4528->raw() : nullptr,_4528 ? _4528->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4529 = mosek::fusion::p_WorkStack::_get_impl(_4500)->f64;
  _checked_ptr_1<double> _ptr__4529(_4529 ? _4529->raw() : nullptr,_4529 ? _4529->size(0) : 0);
  int _8875 = (int)0;
  int _8876 = dim0;
  for (int _4530 = _8875; _4530 < _8876; ++_4530)
  {
    {
      _ptr__4524[(int)0] *= _ptr__4527[safe_add( _4513,_4530 )];
    }
  }
  _ptr__4524[(int)1] = _ptr__4527[safe_add( _4513,dim0 )];
  int _8877 = safe_add( dim0,(int)1 );
  int _8878 = dim1;
  for (int _4531 = _8877; _4531 < _8878; ++_4531)
  {
    {
      _ptr__4524[(int)2] *= _ptr__4527[safe_add( _4513,_4531 )];
    }
  }
  _ptr__4524[(int)3] = _ptr__4527[safe_add( _4513,dim1 )];
  int _8879 = safe_add( dim1,(int)1 );
  int _8880 = _4512;
  for (int _4532 = _8879; _4532 < _8880; ++_4532)
  {
    {
      _ptr__4524[(int)4] *= _ptr__4527[safe_add( _4513,_4532 )];
    }
  }
  _ptr__4526[(int)4] = (int)1;
  int _8881 = (int)1;
  int _8882 = (int)5;
  for (int _4533 = _8881; _4533 < _8882; ++_4533)
  {
    {
      _ptr__4526[(((int)5 - _4533) - (int)1)] = safe_mul( _ptr__4526[((int)5 - _4533)],_ptr__4524[((int)5 - _4533)] );
    }
  }
  if (_4516)
  {
    {
      int _4534 = _4508;
      int _8883 = (int)0;
      int _8884 = _4514;
      for (int _4535 = _8883; _4535 < _8884; ++_4535)
      {
        {
          _ptr__4527[safe_add( _4534,_4535 )] = _4535;
        }
      }
      int _4536 = _4509;
      std::shared_ptr< monty::ndarray< int,1 > > _4537 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4537(_4537 ? _4537->raw() : nullptr,_4537 ? _4537->size(0) : 0);
      int _8885 = (int)0;
      int _8886 = (int)4;
      for (int _4538 = _8885; _4538 < _8886; ++_4538)
      {
        {
          long long _4539 = _ptr__4526[_ptr__4537[_4538]];
          int _4540 = _ptr__4524[_ptr__4537[_4538]];
          if ((_4540 > (int)1))
          {
            {
              int _8887 = (int)0;
              int _8888 = safe_add( _4540,(int)1 );
              for (int _4541 = _8887; _4541 < _8888; ++_4541)
              {
                {
                  _ptr__4527[safe_add( _4510,_4541 )] = (int)0;
                }
              }
              int _8889 = (int)0;
              int _8890 = _4514;
              for (int _4542 = _8889; _4542 < _8890; ++_4542)
              {
                {
                  ++ _ptr__4527[safe_add( safe_add( _4510,((_ptr__4528[safe_add( _4518,_ptr__4527[safe_add( _4534,_4542 )] )] / _4539) % _4540) ),(int)1 )];
                }
              }
              int _8891 = (int)0;
              int _8892 = _ptr__4524[(int)3];
              for (int _4543 = _8891; _4543 < _8892; ++_4543)
              {
                {
                  _ptr__4527[safe_add( safe_add( _4510,_4543 ),(int)1 )] += _ptr__4527[safe_add( _4510,_4543 )];
                }
              }
              int _8893 = (int)0;
              int _8894 = _4514;
              for (int _4544 = _8893; _4544 < _8894; ++_4544)
              {
                {
                  int _4545 = _ptr__4527[safe_add( _4534,_4544 )];
                  long long _4546 = ((_ptr__4528[safe_add( _4518,_4545 )] / _4539) % _4540);
                  _ptr__4527[safe_add( _4536,_ptr__4527[safe_add( _4510,_4546 )] )] = _4545;
                  ++ _ptr__4527[safe_add( _4510,_4546 )];
                }
              }
              int _4547 = _4534;
              _4534 = _4536;
              _4536 = _4547;
            }
          }
          {}
        }
      }
      int _8895 = (int)0;
      int _8896 = _4514;
      for (int _4548 = _8895; _4548 < _8896; ++_4548)
      {
        {
          _ptr__4528[safe_add( _4511,_4548 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4528[safe_add( _4518,_4548 )] / _ptr__4526[(int)0]) % _ptr__4524[(int)0]),_ptr__4526[(int)0] ),safe_mul( ((_ptr__4528[safe_add( _4518,_4548 )] / _ptr__4526[(int)1]) % _ptr__4524[(int)1]),_ptr__4526[(int)3] ) ),safe_mul( ((_ptr__4528[safe_add( _4518,_4548 )] / _ptr__4526[(int)2]) % _ptr__4524[(int)2]),_ptr__4526[(int)2] ) ),safe_mul( ((_ptr__4528[safe_add( _4518,_4548 )] / _ptr__4526[(int)3]) % _ptr__4524[(int)3]),_ptr__4526[(int)1] ) ),safe_mul( ((_ptr__4528[safe_add( _4518,_4548 )] / _ptr__4526[(int)4]) % _ptr__4524[(int)4]),_ptr__4526[(int)4] ) );
        }
      }
      {
        int _4549 = (int)0;
        int _4550 = (int)0;
        while ( ((_4550 < _4514) && (_4549 < _4514)) )
        {
          {
            int _4551 = _ptr__4527[safe_add( _4534,_4549 )];
            if ((_ptr__4528[safe_add( _4518,_4550 )] < _ptr__4528[safe_add( _4511,_4551 )]))
            {
              {
                _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4550 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4550 )]);
                ++ _4522;
                ++ _4550;
              }
            }
            else if((_ptr__4528[safe_add( _4518,_4550 )] > _ptr__4528[safe_add( _4511,_4551 )]))
            {
              {
                _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4551 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4551 )]);
                ++ _4522;
                ++ _4549;
              }
            }
            else if((_ptr__4528[safe_add( _4518,_4550 )] != _ptr__4528[safe_add( _4518,_4551 )]))
            {
              {
                _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4550 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4550 )]);
                _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4551 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4551 )]);
                ++ _4522;
                ++ _4549;
                ++ _4550;
              }
            }
            else
            {
              {
                _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4550 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4550 )]);
                ++ _4522;
                ++ _4549;
                ++ _4550;
              }
            }
          }
        }
        while ( (_4550 < _4514) )
        {
          {
            _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4550 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4550 )]);
            ++ _4522;
            ++ _4550;
          }
        }
        while ( (_4549 < _4514) )
        {
          {
            int _4552 = _ptr__4527[safe_add( _4534,_4549 )];
            _4523 += (_ptr__4527[safe_add( safe_add( _4517,_4552 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4552 )]);
            ++ _4522;
            ++ _4549;
          }
        }
      }
      int _4553 = _4499->alloci32(safe_add( _4522,(int)1 ));
      _4499->pushi32((int)1);
      _4499->pushi32(_4523);
      _4499->pushi32(_4522);
      int _8897 = (int)0;
      int _8898 = _4512;
      for (int _4554 = _8897; _4554 < _8898; ++_4554)
      {
        {
          _4499->pushi32(_ptr__4527[safe_add( _4513,_4554 )]);
        }
      }
      _4499->pushi32(_4512);
      int _4555 = _4499->alloci64(_4523);
      int _4556 = _4499->alloci64(_4522);
      int _4557 = _4499->allocf64(_4523);
      int _4558 = _4499->allocf64(_4522);
      std::shared_ptr< monty::ndarray< int,1 > > _4559 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i32;
      _checked_ptr_1<int> _ptr__4559(_4559 ? _4559->raw() : nullptr,_4559 ? _4559->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4560 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i64;
      _checked_ptr_1<long long> _ptr__4560(_4560 ? _4560->raw() : nullptr,_4560 ? _4560->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4561 = mosek::fusion::p_WorkStack::_get_impl(_4499)->f64;
      _checked_ptr_1<double> _ptr__4561(_4561 ? _4561->raw() : nullptr,_4561 ? _4561->size(0) : 0);
      _ptr__4559[_4553] = (int)0;
      {
        int _4562 = (int)0;
        int _4563 = (int)0;
        int _4564 = (int)0;
        int _4565 = (int)0;
        _ptr__4527[_4553] = (int)0;
        while ( ((_4565 < _4514) && (_4564 < _4514)) )
        {
          {
            int _4566 = _ptr__4527[safe_add( _4534,_4564 )];
            if ((_ptr__4528[safe_add( _4518,_4565 )] < _ptr__4528[safe_add( _4511,_4566 )]))
            {
              {
                int _8899 = _ptr__4527[safe_add( _4517,_4565 )];
                int _8900 = _ptr__4527[safe_add( safe_add( _4517,_4565 ),(int)1 )];
                for (int _4567 = _8899; _4567 < _8900; ++_4567)
                {
                  {
                    _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4567 )];
                    _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4567 )] * 0.5);
                    ++ _4562;
                  }
                }
                _ptr__4561[safe_add( _4558,_4563 )] = (_ptr__4529[safe_add( _4520,_4565 )] * 0.5);
                _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4518,_4565 )];
                _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
                ++ _4563;
                ++ _4565;
              }
            }
            else if((_ptr__4528[safe_add( _4518,_4565 )] > _ptr__4528[safe_add( _4511,_4566 )]))
            {
              {
                int _8901 = _ptr__4527[safe_add( _4517,_4566 )];
                int _8902 = _ptr__4527[safe_add( safe_add( _4517,_4566 ),(int)1 )];
                for (int _4568 = _8901; _4568 < _8902; ++_4568)
                {
                  {
                    _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4568 )];
                    _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4568 )] * 0.5);
                    ++ _4562;
                  }
                }
                _ptr__4561[safe_add( _4558,_4563 )] = (_ptr__4529[safe_add( _4520,_4566 )] * 0.5);
                _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4511,_4566 )];
                _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
                ++ _4563;
                ++ _4564;
              }
            }
            else if((_ptr__4528[safe_add( _4518,_4565 )] != _ptr__4528[safe_add( _4518,_4566 )]))
            {
              {
                int _8903 = _ptr__4527[safe_add( _4517,_4565 )];
                int _8904 = _ptr__4527[safe_add( safe_add( _4517,_4565 ),(int)1 )];
                for (int _4569 = _8903; _4569 < _8904; ++_4569)
                {
                  {
                    _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4569 )];
                    _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4569 )] * 0.5);
                    ++ _4562;
                  }
                }
                int _8905 = _ptr__4527[safe_add( _4517,_4566 )];
                int _8906 = _ptr__4527[safe_add( safe_add( _4517,_4566 ),(int)1 )];
                for (int _4570 = _8905; _4570 < _8906; ++_4570)
                {
                  {
                    _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4570 )];
                    _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4570 )] * 0.5);
                    ++ _4562;
                  }
                }
                _ptr__4561[safe_add( _4558,_4563 )] = (0.5 * (_ptr__4529[safe_add( _4520,_4565 )] + _ptr__4529[safe_add( _4520,_4566 )]));
                _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4518,_4565 )];
                _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
                ++ _4563;
                ++ _4564;
                ++ _4565;
              }
            }
            else
            {
              {
                int _8907 = _ptr__4527[safe_add( _4517,_4565 )];
                int _8908 = _ptr__4527[safe_add( safe_add( _4517,_4565 ),(int)1 )];
                for (int _4571 = _8907; _4571 < _8908; ++_4571)
                {
                  {
                    _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4571 )];
                    _ptr__4561[safe_add( _4557,_4562 )] = _ptr__4529[safe_add( _4521,_4571 )];
                    ++ _4562;
                  }
                }
                _ptr__4561[safe_add( _4558,_4563 )] = _ptr__4529[safe_add( _4520,_4565 )];
                _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4518,_4565 )];
                _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
                ++ _4563;
                ++ _4564;
                ++ _4565;
              }
            }
          }
        }
        while ( (_4565 < _4514) )
        {
          {
            int _8909 = _ptr__4527[safe_add( _4517,_4565 )];
            int _8910 = _ptr__4527[safe_add( safe_add( _4517,_4565 ),(int)1 )];
            for (int _4572 = _8909; _4572 < _8910; ++_4572)
            {
              {
                _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4572 )];
                _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4572 )] * 0.5);
                ++ _4562;
              }
            }
            _ptr__4561[safe_add( _4558,_4563 )] = (_ptr__4529[safe_add( _4520,_4565 )] * 0.5);
            _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4518,_4565 )];
            _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
            ++ _4563;
            ++ _4565;
          }
        }
        while ( (_4564 < _4514) )
        {
          {
            int _4573 = _ptr__4527[safe_add( _4534,_4564 )];
            int _8911 = _ptr__4527[safe_add( _4517,_4573 )];
            int _8912 = _ptr__4527[safe_add( safe_add( _4517,_4573 ),(int)1 )];
            for (int _4574 = _8911; _4574 < _8912; ++_4574)
            {
              {
                _ptr__4560[safe_add( _4555,_4562 )] = _ptr__4528[safe_add( _4519,_4574 )];
                _ptr__4561[safe_add( _4557,_4562 )] = (_ptr__4529[safe_add( _4521,_4574 )] * 0.5);
                ++ _4562;
              }
            }
            _ptr__4561[safe_add( _4558,_4563 )] = (_ptr__4529[safe_add( _4520,_4573 )] * 0.5);
            _ptr__4560[safe_add( _4556,_4563 )] = _ptr__4528[safe_add( _4511,_4573 )];
            _ptr__4559[safe_add( safe_add( _4553,_4563 ),(int)1 )] = _4562;
            ++ _4563;
            ++ _4564;
          }
        }
      }
    }
  }
  else
  {
    {
      _4522 = _4514;
      _4523 = safe_mul( _4515,(int)2 );
      int _8913 = (int)0;
      int _8914 = _ptr__4524[(int)0];
      for (int _4575 = _8913; _4575 < _8914; ++_4575)
      {
        {
          int _8915 = (int)0;
          int _8916 = _ptr__4524[(int)2];
          for (int _4576 = _8915; _4576 < _8916; ++_4576)
          {
            {
              int _8917 = (int)0;
              int _8918 = _ptr__4524[(int)4];
              for (int _4577 = _8917; _4577 < _8918; ++_4577)
              {
                {
                  int _8919 = (int)0;
                  int _8920 = _ptr__4524[(int)1];
                  for (int _4578 = _8919; _4578 < _8920; ++_4578)
                  {
                    {
                      long long _4579 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4526[(int)0],_4575 ),safe_mul( _ptr__4526[(int)1],_4578 ) ),safe_mul( _ptr__4526[(int)2],_4576 ) ),safe_mul( _ptr__4526[(int)3],_4578 ) ),safe_mul( _ptr__4526[(int)4],_4577 ) );
                      _4523 -= (_ptr__4527[safe_add( safe_add( _4517,_4579 ),(int)1 )] - _ptr__4527[safe_add( _4517,_4579 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4580 = _4499->alloci32(safe_add( _4522,(int)1 ));
      _4499->pushi32((int)0);
      _4499->pushi32(_4523);
      _4499->pushi32(_4522);
      int _8921 = (int)0;
      int _8922 = _4512;
      for (int _4581 = _8921; _4581 < _8922; ++_4581)
      {
        {
          _4499->pushi32(_ptr__4527[safe_add( _4513,_4581 )]);
        }
      }
      _4499->pushi32(_4512);
      int _4582 = _4499->alloci64(_4523);
      int _4583 = _4499->allocf64(_4523);
      int _4584 = _4499->allocf64(_4522);
      std::shared_ptr< monty::ndarray< int,1 > > _4585 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i32;
      _checked_ptr_1<int> _ptr__4585(_4585 ? _4585->raw() : nullptr,_4585 ? _4585->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4586 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i64;
      _checked_ptr_1<long long> _ptr__4586(_4586 ? _4586->raw() : nullptr,_4586 ? _4586->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4587 = mosek::fusion::p_WorkStack::_get_impl(_4499)->f64;
      _checked_ptr_1<double> _ptr__4587(_4587 ? _4587->raw() : nullptr,_4587 ? _4587->size(0) : 0);
      int _4588 = (int)0;
      int _4589 = (int)0;
      _ptr__4585[_4580] = (int)0;
      int _4590 = (int)0;
      int _8923 = (int)0;
      int _8924 = _ptr__4524[(int)0];
      for (int _4591 = _8923; _4591 < _8924; ++_4591)
      {
        {
          int _8925 = (int)0;
          int _8926 = _ptr__4524[(int)1];
          for (int _4592 = _8925; _4592 < _8926; ++_4592)
          {
            {
              int _8927 = (int)0;
              int _8928 = _ptr__4524[(int)2];
              for (int _4593 = _8927; _4593 < _8928; ++_4593)
              {
                {
                  int _8929 = (int)0;
                  int _8930 = _ptr__4524[(int)3];
                  for (int _4594 = _8929; _4594 < _8930; ++_4594)
                  {
                    {
                      int _8931 = (int)0;
                      int _8932 = _ptr__4524[(int)4];
                      for (int _4595 = _8931; _4595 < _8932; ++_4595)
                      {
                        {
                          if ((_4592 == _4594))
                          {
                            {
                              int _8933 = _ptr__4527[safe_add( _4517,_4590 )];
                              int _8934 = _ptr__4527[safe_add( safe_add( _4517,_4590 ),(int)1 )];
                              for (int _4596 = _8933; _4596 < _8934; ++_4596)
                              {
                                {
                                  _ptr__4586[safe_add( _4582,_4588 )] = _ptr__4528[safe_add( _4519,_4596 )];
                                  _ptr__4587[safe_add( _4583,_4588 )] = _ptr__4529[safe_add( _4521,_4596 )];
                                  ++ _4588;
                                }
                              }
                              _ptr__4587[safe_add( _4584,_4589 )] = _ptr__4529[safe_add( _4520,_4591 )];
                              _ptr__4585[safe_add( safe_add( _4580,_4589 ),(int)1 )] = _4588;
                              ++ _4590;
                            }
                          }
                          else
                          {
                            {
                              long long _4597 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4591,_ptr__4526[(int)0] ),safe_mul( _4594,_ptr__4526[(int)1] ) ),safe_mul( _4593,_ptr__4526[(int)2] ) ),safe_mul( _4592,_ptr__4526[(int)3] ) ),_4595 );
                              int _8935 = _ptr__4527[safe_add( _4517,_4590 )];
                              int _8936 = _ptr__4527[safe_add( safe_add( _4517,_4590 ),(int)1 )];
                              for (int _4598 = _8935; _4598 < _8936; ++_4598)
                              {
                                {
                                  _ptr__4586[safe_add( _4582,_4588 )] = _ptr__4528[safe_add( _4519,_4598 )];
                                  _ptr__4587[safe_add( _4583,_4588 )] = (_ptr__4529[safe_add( _4521,_4598 )] * 0.5);
                                  ++ _4588;
                                }
                              }
                              int _8937 = _ptr__4527[safe_add( _4517,_4597 )];
                              int _8938 = _ptr__4527[safe_add( safe_add( _4517,_4597 ),(int)1 )];
                              for (int _4599 = _8937; _4599 < _8938; ++_4599)
                              {
                                {
                                  _ptr__4586[safe_add( _4582,_4588 )] = _ptr__4528[safe_add( _4519,_4599 )];
                                  _ptr__4587[safe_add( _4583,_4588 )] = (_ptr__4529[safe_add( _4521,_4599 )] * 0.5);
                                  ++ _4588;
                                }
                              }
                              _ptr__4587[safe_add( _4584,_4589 )] = (0.5 * (_ptr__4529[safe_add( _4520,_4590 )] + _ptr__4529[safe_add( _4520,_4597 )]));
                              _ptr__4585[safe_add( safe_add( _4580,_4589 ),(int)1 )] = _4588;
                              ++ _4590;
                            }
                          }
                          ++ _4589;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4600){ return new mosek::fusion::ExprCompress(_4600); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4600) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4600); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4600){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4600->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4600;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4601,    double _4602){ return new mosek::fusion::ExprCompress(_4601,_4602); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4601,    double _4602) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4601,_4602); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4601,    double _4602){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4601->getShape());
    eps = _4602;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4601;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4603,monty::rc_ptr< ::mosek::fusion::WorkStack > _4604,monty::rc_ptr< ::mosek::fusion::WorkStack > _4605) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4603,_4604,_4605); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4603,monty::rc_ptr< ::mosek::fusion::WorkStack > _4604,monty::rc_ptr< ::mosek::fusion::WorkStack > _4605){
  expr->eval(_4604,_4603,_4605);
  _4604->pop_expr();
  int _4606 = mosek::fusion::p_WorkStack::_get_impl(_4604)->nd;
  int _4607 = mosek::fusion::p_WorkStack::_get_impl(_4604)->shape_base;
  int _4608 = mosek::fusion::p_WorkStack::_get_impl(_4604)->nelem;
  int _4609 = mosek::fusion::p_WorkStack::_get_impl(_4604)->nnz;
  bool _4610 = mosek::fusion::p_WorkStack::_get_impl(_4604)->hassp;
  int _4611 = mosek::fusion::p_WorkStack::_get_impl(_4604)->ptr_base;
  int _4612 = mosek::fusion::p_WorkStack::_get_impl(_4604)->sp_base;
  int _4613 = mosek::fusion::p_WorkStack::_get_impl(_4604)->nidxs_base;
  int _4614 = mosek::fusion::p_WorkStack::_get_impl(_4604)->bfix_base;
  int _4615 = mosek::fusion::p_WorkStack::_get_impl(_4604)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4616 = mosek::fusion::p_WorkStack::_get_impl(_4604)->i32;
  _checked_ptr_1<int> _ptr__4616(_4616 ? _4616->raw() : nullptr,_4616 ? _4616->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4617 = mosek::fusion::p_WorkStack::_get_impl(_4604)->i64;
  _checked_ptr_1<long long> _ptr__4617(_4617 ? _4617->raw() : nullptr,_4617 ? _4617->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4618 = mosek::fusion::p_WorkStack::_get_impl(_4604)->f64;
  _checked_ptr_1<double> _ptr__4618(_4618 ? _4618->raw() : nullptr,_4618 ? _4618->size(0) : 0);
  std::vector<int> _8939;
  for (int _4620 = (int)0, _8940 = _4606; _4620 < _8940 ; ++_4620)
  {
    _8939.push_back(_ptr__4616[safe_add( _4607,_4620 )]);
  }
  auto _8941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8939.size()),_8939.begin(),_8939.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4619 = _8941;
  _checked_ptr_1<int> _ptr__4619(_4619 ? _4619->raw() : nullptr,_4619 ? _4619->size(0) : 0);
  bool _4621 = true;
  int _8942 = (int)0;
  int _8943 = _4608;
  for (int _4622 = _8942; _4622 < _8943; ++_4622)
  {
    {
      int _8944 = safe_add( _ptr__4616[safe_add( _4611,_4622 )],(int)1 );
      int _8945 = _ptr__4616[safe_add( safe_add( _4611,_4622 ),(int)1 )];
      for (int _4623 = _8944; _4623 < _8945; ++_4623)
      {
        {
          _4621 = (_4621 && (_ptr__4617[(safe_add( _4613,_4623 ) - (int)1)] < _ptr__4617[safe_add( _4613,_4623 )]));
        }
      }
    }
  }
  if (_4621)
  {
    {
      int _8946 = (int)0;
      int _8947 = _4609;
      for (int _4624 = _8946; _4624 < _8947; ++_4624)
      {
        {
          _4621 = (_4621 && ((_ptr__4618[safe_add( _4615,_4624 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4618[safe_add( _4615,_4624 )])));
        }
      }
    }
  }
  {}
  if (_4621)
  {
    {
      _4603->alloc_expr(_4606,_4608,_4609,_4610);
      int _4625 = mosek::fusion::p_WorkStack::_get_impl(_4603)->ptr_base;
      int _4626 = mosek::fusion::p_WorkStack::_get_impl(_4603)->nidxs_base;
      int _4627 = mosek::fusion::p_WorkStack::_get_impl(_4603)->sp_base;
      int _4628 = mosek::fusion::p_WorkStack::_get_impl(_4603)->cof_base;
      int _4629 = mosek::fusion::p_WorkStack::_get_impl(_4603)->bfix_base;
      int _4630 = mosek::fusion::p_WorkStack::_get_impl(_4603)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4631 = mosek::fusion::p_WorkStack::_get_impl(_4603)->i32;
      _checked_ptr_1<int> _ptr__4631(_4631 ? _4631->raw() : nullptr,_4631 ? _4631->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4632 = mosek::fusion::p_WorkStack::_get_impl(_4603)->i64;
      _checked_ptr_1<long long> _ptr__4632(_4632 ? _4632->raw() : nullptr,_4632 ? _4632->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4633 = mosek::fusion::p_WorkStack::_get_impl(_4603)->f64;
      _checked_ptr_1<double> _ptr__4633(_4633 ? _4633->raw() : nullptr,_4633 ? _4633->size(0) : 0);
      {
        int _8948 = (int)0;
        int _8949 = _4606;
        for (int _4634 = _8948; _4634 < _8949; ++_4634)
        {
          {
            _ptr__4631[safe_add( _4630,_4634 )] = _ptr__4619[_4634];
          }
        }
        int _8950 = (int)0;
        int _8951 = safe_add( _4608,(int)1 );
        for (int _4635 = _8950; _4635 < _8951; ++_4635)
        {
          {
            _ptr__4631[safe_add( _4625,_4635 )] = _ptr__4616[safe_add( _4611,_4635 )];
          }
        }
        if (_4610)
        {
          {
            int _8952 = (int)0;
            int _8953 = _4608;
            for (int _4636 = _8952; _4636 < _8953; ++_4636)
            {
              {
                _ptr__4632[safe_add( _4627,_4636 )] = _ptr__4617[safe_add( _4612,_4636 )];
              }
            }
          }
        }
        {}
        int _8954 = (int)0;
        int _8955 = _4608;
        for (int _4637 = _8954; _4637 < _8955; ++_4637)
        {
          {
            _ptr__4633[safe_add( _4629,_4637 )] = _ptr__4618[safe_add( _4614,_4637 )];
          }
        }
        int _8956 = (int)0;
        int _8957 = _4609;
        for (int _4638 = _8956; _4638 < _8957; ++_4638)
        {
          {
            _ptr__4632[safe_add( _4626,_4638 )] = _ptr__4617[safe_add( _4613,_4638 )];
          }
        }
        int _8958 = (int)0;
        int _8959 = _4609;
        for (int _4639 = _8958; _4639 < _8959; ++_4639)
        {
          {
            _ptr__4633[safe_add( _4628,_4639 )] = _ptr__4618[safe_add( _4615,_4639 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4640 = _4605->alloci32(_4609);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4604,_4605,_4640,_4608,_4609,_4611,_4613);
      std::shared_ptr< monty::ndarray< int,1 > > _4641 = mosek::fusion::p_WorkStack::_get_impl(_4605)->i32;
      _checked_ptr_1<int> _ptr__4641(_4641 ? _4641->raw() : nullptr,_4641 ? _4641->size(0) : 0);
      int _4642 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4643 = mosek::fusion::p_WorkStack::_get_impl(_4603)->i32;
        _checked_ptr_1<int> _ptr__4643(_4643 ? _4643->raw() : nullptr,_4643 ? _4643->size(0) : 0);
        {
          int _8960 = (int)0;
          int _8961 = _4608;
          for (int _4644 = _8960; _4644 < _8961; ++_4644)
          {
            {
              int _4645 = _ptr__4616[safe_add( safe_add( _4611,_4644 ),(int)1 )];
              int _4646 = _ptr__4616[safe_add( _4611,_4644 )];
              if ((_4646 < _4645))
              {
                {
                  int _4647 = _4646;
                  while ( (_4647 < _4645) )
                  {
                    {
                      double _4648 = 0.0;
                      long long _4649 = _ptr__4617[safe_add( _4613,_ptr__4641[safe_add( _4640,_4647 )] )];
                      while ( ((_4647 < _4645) && (_ptr__4617[safe_add( _4613,_ptr__4641[safe_add( _4640,_4647 )] )] == _4649)) )
                      {
                        {
                          _4648 += _ptr__4618[safe_add( _4615,_ptr__4641[safe_add( _4640,_4647 )] )];
                          ++ _4647;
                        }
                      }
                      {
                      }
                      if (((_4649 != (int)0) && ((_4648 < (-eps)) || (eps < _4648))))
                      {
                        {
                          ++ _4642;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      _4603->alloc_expr(_4606,_4608,_4642,_4610);
      int _4650 = mosek::fusion::p_WorkStack::_get_impl(_4603)->nidxs_base;
      int _4651 = mosek::fusion::p_WorkStack::_get_impl(_4603)->shape_base;
      int _4652 = mosek::fusion::p_WorkStack::_get_impl(_4603)->sp_base;
      int _4653 = mosek::fusion::p_WorkStack::_get_impl(_4603)->cof_base;
      int _4654 = mosek::fusion::p_WorkStack::_get_impl(_4603)->bfix_base;
      int _4655 = mosek::fusion::p_WorkStack::_get_impl(_4603)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4656 = mosek::fusion::p_WorkStack::_get_impl(_4603)->i32;
      _checked_ptr_1<int> _ptr__4656(_4656 ? _4656->raw() : nullptr,_4656 ? _4656->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4657 = mosek::fusion::p_WorkStack::_get_impl(_4603)->i64;
      _checked_ptr_1<long long> _ptr__4657(_4657 ? _4657->raw() : nullptr,_4657 ? _4657->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4658 = mosek::fusion::p_WorkStack::_get_impl(_4603)->f64;
      _checked_ptr_1<double> _ptr__4658(_4658 ? _4658->raw() : nullptr,_4658 ? _4658->size(0) : 0);
      int _8962 = (int)0;
      int _8963 = _4606;
      for (int _4659 = _8962; _4659 < _8963; ++_4659)
      {
        {
          _ptr__4656[safe_add( _4651,_4659 )] = _ptr__4619[_4659];
        }
      }
      {
        int _8964 = (int)0;
        int _8965 = _4608;
        for (int _4660 = _8964; _4660 < _8965; ++_4660)
        {
          {
            _ptr__4658[safe_add( _4653,_4660 )] = 0.0;
          }
        }
        int _8966 = (int)0;
        int _8967 = _4608;
        for (int _4661 = _8966; _4661 < _8967; ++_4661)
        {
          {
            _ptr__4658[safe_add( _4654,_4661 )] = _ptr__4618[safe_add( _4614,_4661 )];
          }
        }
        if (_4610)
        {
          {
            int _8968 = (int)0;
            int _8969 = _4608;
            for (int _4662 = _8968; _4662 < _8969; ++_4662)
            {
              {
                _ptr__4657[safe_add( _4652,_4662 )] = _ptr__4617[safe_add( _4652,_4662 )];
              }
            }
          }
        }
        {}
        int _4663 = (int)0;
        {
          int _4664 = (_4653 - _4650);
          _ptr__4656[_4655] = (int)0;
          int _8970 = (int)0;
          int _8971 = _4608;
          for (int _4665 = _8970; _4665 < _8971; ++_4665)
          {
            {
              int _4666 = _ptr__4616[safe_add( safe_add( _4611,_4665 ),(int)1 )];
              int _4667 = _ptr__4616[safe_add( _4611,_4665 )];
              if ((_4667 < _4666))
              {
                {
                  int _4668 = _4667;
                  while ( (_4668 < _4666) )
                  {
                    {
                      double _4669 = 0.0;
                      long long _4670 = _ptr__4617[safe_add( _4613,_ptr__4641[safe_add( _4640,_4668 )] )];
                      while ( ((_4668 < _4666) && (_ptr__4617[safe_add( _4613,_ptr__4641[safe_add( _4640,_4668 )] )] == _4670)) )
                      {
                        {
                          _4669 += _ptr__4618[safe_add( _4615,_ptr__4641[safe_add( _4640,_4668 )] )];
                          ++ _4668;
                        }
                      }
                      {
                      }
                      if (((_4670 != (int)0) && ((_4669 < (-eps)) || (eps < _4669))))
                      {
                        {
                          _ptr__4657[safe_add( _4650,_4663 )] = _4670;
                          _ptr__4658[safe_add( _4653,_4663 )] = _4669;
                          ++ _4663;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4656[safe_add( safe_add( _4655,_4665 ),(int)1 )] = _4663;
            }
          }
        }
      }
    }
  }
  _4605->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4671,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4672,    int _4673,    int _4674,    int _4675,    int _4676,    int _4677) { mosek::fusion::p_ExprCompress::arg_sort(_4671,_4672,_4673,_4674,_4675,_4676,_4677); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4671,monty::rc_ptr< ::mosek::fusion::WorkStack > _4672,int _4673,int _4674,int _4675,int _4676,int _4677){
  int _4678 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4679 = mosek::fusion::p_WorkStack::_get_impl(_4671)->i32;
  _checked_ptr_1<int> _ptr__4679(_4679 ? _4679->raw() : nullptr,_4679 ? _4679->size(0) : 0);
  int _8972 = (int)0;
  int _8973 = _4674;
  for (int _4680 = _8972; _4680 < _8973; ++_4680)
  {
    {
      if (((_ptr__4679[safe_add( safe_add( _4676,_4680 ),(int)1 )] - _ptr__4679[safe_add( _4676,_4680 )]) > _4678))
      {
        {
          _4678 = (_ptr__4679[safe_add( safe_add( _4676,_4680 ),(int)1 )] - _ptr__4679[safe_add( _4676,_4680 )]);
        }
      }
      {}
    }
  }
  int _8974;
  bool _8975 = (_4678 > (int)2);
  if (_8975)
  {
    _8974 = _4672->alloci32(safe_mul( _4678,(int)2 ));
  }
  else
  {
    _8974 = (int)99999;
  }
  int _4681 = _8974;
  std::shared_ptr< monty::ndarray< int,1 > > _4682 = mosek::fusion::p_WorkStack::_get_impl(_4672)->i32;
  _checked_ptr_1<int> _ptr__4682(_4682 ? _4682->raw() : nullptr,_4682 ? _4682->size(0) : 0);
  _4679 = mosek::fusion::p_WorkStack::_get_impl(_4671)->i32;
  _ptr__4679.update(_4679 ? _4679->raw() : nullptr, _4679 ? _4679->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4683 = mosek::fusion::p_WorkStack::_get_impl(_4671)->i64;
  _checked_ptr_1<long long> _ptr__4683(_4683 ? _4683->raw() : nullptr,_4683 ? _4683->size(0) : 0);
  int _8976 = (int)0;
  int _8977 = _4674;
  for (int _4684 = _8976; _4684 < _8977; ++_4684)
  {
    {
      int _4685 = _ptr__4679[safe_add( _4676,_4684 )];
      int _4686 = _ptr__4679[safe_add( safe_add( _4676,_4684 ),(int)1 )];
      int _4687 = (_4686 - _4685);
      if ((_4687 == (int)0))
      {
        {
        }
      }
      else if((_4687 == (int)1))
      {
        {
          _ptr__4682[safe_add( _4673,_4685 )] = _4685;
        }
      }
      else if((_4687 == (int)2))
      {
        {
          if ((_ptr__4683[safe_add( _4677,_4685 )] <= _ptr__4683[safe_add( safe_add( _4677,_4685 ),(int)1 )]))
          {
            {
              _ptr__4682[safe_add( _4673,_4685 )] = _4685;
              _ptr__4682[safe_add( safe_add( _4673,_4685 ),(int)1 )] = safe_add( _4685,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4682[safe_add( _4673,_4685 )] = safe_add( _4685,(int)1 );
              _ptr__4682[safe_add( safe_add( _4673,_4685 ),(int)1 )] = _4685;
            }
          }
        }
      }
      else
      {
        {
          long long _4688 = _ptr__4683[safe_add( _4677,_4685 )];
          long long _4689 = _ptr__4683[safe_add( _4677,_4685 )];
          bool _4690 = false;
          int _8978 = safe_add( _4685,(int)1 );
          int _8979 = _4686;
          for (int _4691 = _8978; _4691 < _8979; ++_4691)
          {
            {
              _4690 = (_4690 && (_ptr__4683[(safe_add( _4677,_4691 ) - (int)1)] <= _ptr__4683[safe_add( _4677,_4691 )]));
              if ((_4688 > _ptr__4683[safe_add( _4677,_4691 )]))
              {
                {
                  _4688 = _ptr__4683[safe_add( _4677,_4691 )];
                }
              }
              {}
              if ((_4689 < _ptr__4683[safe_add( _4677,_4691 )]))
              {
                {
                  _4689 = _ptr__4683[safe_add( _4677,_4691 )];
                }
              }
              {}
            }
          }
          if (_4690)
          {
            {
              int _8980 = _4685;
              int _8981 = _4686;
              for (int _4692 = _8980; _4692 < _8981; ++_4692)
              {
                {
                  _ptr__4682[safe_add( _4673,_4692 )] = _4692;
                }
              }
            }
          }
          else if((safe_add( (_4689 - _4688),(int)1 ) <= _4687))
          {
            {
              long long _4693 = safe_add( (_4689 - _4688),(int)1 );
              int _8982 = (int)0;
              long long _8983 = safe_add( _4693,(int)1 );
              for (long long _4694 = _8982; _4694 < _8983; ++_4694)
              {
                {
                  _ptr__4682[safe_add( _4681,_4694 )] = (int)0;
                }
              }
              int _8984 = _4685;
              int _8985 = _4686;
              for (int _4695 = _8984; _4695 < _8985; ++_4695)
              {
                {
                  ++ _ptr__4682[safe_add( (safe_add( _4681,_ptr__4683[safe_add( _4677,_4695 )] ) - _4688),(int)1 )];
                }
              }
              int _8986 = (int)0;
              long long _8987 = _4693;
              for (long long _4696 = _8986; _4696 < _8987; ++_4696)
              {
                {
                  _ptr__4682[safe_add( safe_add( _4681,_4696 ),(int)1 )] += _ptr__4682[safe_add( _4681,_4696 )];
                }
              }
              int _8988 = _4685;
              int _8989 = _4686;
              for (int _4697 = _8988; _4697 < _8989; ++_4697)
              {
                {
                  _ptr__4682[safe_add( safe_add( _4673,_4685 ),_ptr__4682[(safe_add( _4681,_ptr__4683[safe_add( _4677,_4697 )] ) - _4688)] )] = _4697;
                  ++ _ptr__4682[(safe_add( _4681,_ptr__4683[safe_add( _4677,_4697 )] ) - _4688)];
                }
              }
            }
          }
          else
          {
            {
              int _4698 = (int)1;
              int _4699 = _4681;
              int _4700 = safe_add( _4681,_4687 );
              int _8990 = (int)0;
              int _8991 = _4687;
              for (int _4701 = _8990; _4701 < _8991; ++_4701)
              {
                {
                  _ptr__4682[safe_add( _4699,_4701 )] = _4701;
                }
              }
              while ( (_4698 < _4687) )
              {
                {
                  int _4702 = safe_mul( _4698,(int)2 );
                  int _4703 = (_4687 / _4702);
                  if ((safe_add( safe_mul( _4703,_4702 ),_4698 ) < _4687))
                  {
                    {
                      ++ _4703;
                    }
                  }
                  {}
                  int _4704 = (int)0;
                  int _8992 = (int)0;
                  int _8993 = _4703;
                  for (int _4705 = _8992; _4705 < _8993; ++_4705)
                  {
                    {
                      int _4706 = safe_mul( _4705,_4702 );
                      int _4707 = safe_add( _4706,_4698 );
                      int _4708 = _4707;
                      int _4709 = safe_add( _4708,_4698 );
                      if ((_4709 > _4687))
                      {
                        {
                          _4709 = _4687;
                        }
                      }
                      {}
                      while ( ((_4706 < _4707) && (_4708 < _4709)) )
                      {
                        {
                          if ((_ptr__4683[safe_add( safe_add( _4677,_ptr__4682[safe_add( _4699,_4706 )] ),_4685 )] <= _ptr__4683[safe_add( safe_add( _4677,_ptr__4682[safe_add( _4699,_4708 )] ),_4685 )]))
                          {
                            {
                              _ptr__4682[safe_add( _4700,_4704 )] = _ptr__4682[safe_add( _4699,_4706 )];
                              ++ _4704;
                              ++ _4706;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4682[safe_add( _4700,_4704 )] = _ptr__4682[safe_add( _4699,_4708 )];
                              ++ _4704;
                              ++ _4708;
                            }
                          }
                        }
                      }
                      while ( (_4706 < _4707) )
                      {
                        {
                          _ptr__4682[safe_add( _4700,_4704 )] = _ptr__4682[safe_add( _4699,_4706 )];
                          ++ _4704;
                          ++ _4706;
                        }
                      }
                      while ( (_4708 < _4709) )
                      {
                        {
                          _ptr__4682[safe_add( _4700,_4704 )] = _ptr__4682[safe_add( _4699,_4708 )];
                          ++ _4704;
                          ++ _4708;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4703,_4702 ) < _4687))
                  {
                    {
                      int _4710 = safe_mul( _4703,_4702 );
                      while ( (_4710 < _4687) )
                      {
                        {
                          _ptr__4682[safe_add( _4700,_4704 )] = _ptr__4682[safe_add( _4699,_4710 )];
                          ++ _4710;
                          ++ _4704;
                        }
                      }
                    }
                  }
                  {}
                  int _4711 = _4699;
                  _4699 = _4700;
                  _4700 = _4711;
                  _4698 *= (int)2;
                }
              }
              int _8994 = (int)0;
              int _8995 = _4687;
              for (int _4712 = _8994; _4712 < _8995; ++_4712)
              {
                {
                  _ptr__4682[safe_add( safe_add( _4673,_4685 ),_4712 )] = safe_add( _ptr__4682[safe_add( _4699,_4712 )],_4685 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4713,    int _4714,    int _4715,    int _4716,    int _4717,    int _4718,    std::shared_ptr< monty::ndarray< int,1 > > _4719,    std::shared_ptr< monty::ndarray< long long,1 > > _4720) { mosek::fusion::p_ExprCompress::merge_sort(_4713,_4714,_4715,_4716,_4717,_4718,_4719,_4720); }void mosek::fusion::p_ExprCompress::merge_sort(int _4713,int _4714,int _4715,int _4716,int _4717,int _4718,std::shared_ptr< monty::ndarray< int,1 > > _4719,std::shared_ptr< monty::ndarray< long long,1 > > _4720){
  _checked_ptr_1<int> _ptr__4719(_4719 ? _4719->raw() : nullptr, _4719 ? _4719->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4720(_4720 ? _4720->raw() : nullptr, _4720 ? _4720->size(0) : 0);
  int _4721 = _4713;
  int _4722 = _4714;
  int _8996 = (int)0;
  int _8997 = _4716;
  for (int _4723 = _8996; _4723 < _8997; ++_4723)
  {
    {
      _ptr__4719[safe_add( _4721,_4723 )] = _4723;
    }
  }
  int _8998 = (int)0;
  int _8999 = _4715;
  for (int _4724 = _8998; _4724 < _8999; ++_4724)
  {
    {
      _4721 = _4713;
      _4722 = _4714;
      int _4725 = _ptr__4719[safe_add( safe_add( _4717,_4724 ),(int)1 )];
      int _4726 = _ptr__4719[safe_add( _4717,_4724 )];
      if ((safe_add( _4726,(int)1 ) < _4725))
      {
        {
          int _4727 = (_4725 - _4726);
          int _4728 = (int)0;
          while ( (_4727 > (int)1) )
          {
            {
              ++ _4728;
              _4727 /= (int)2;
            }
          }
          _4727 = (_4725 - _4726);
          int _4729 = (int)1;
          int _9000 = (int)0;
          int _9001 = safe_add( _4728,(int)1 );
          for (int _4730 = _9000; _4730 < _9001; ++_4730)
          {
            {
              int _4731 = ((safe_add( _4727,_4729 ) - (int)1) / _4729);
              int _4732 = (_4731 / (int)2);
              int _4733 = _4726;
              int _9002 = (int)0;
              int _9003 = _4732;
              for (int _4734 = _9002; _4734 < _9003; ++_4734)
              {
                {
                  int _4735 = safe_mul( safe_mul( _4734,_4729 ),(int)2 );
                  int _9004;
                  bool _9005 = (safe_add( safe_add( _4726,_4735 ),safe_mul( (int)2,_4729 ) ) < _4725);
                  if (_9005)
                  {
                    _9004 = safe_add( safe_add( _4726,_4735 ),safe_mul( (int)2,_4729 ) );
                  }
                  else
                  {
                    _9004 = _4725;
                  }
                  int _4736 = _9004;
                  int _4737 = safe_add( safe_add( _4726,_4735 ),_4729 );
                  int _4738 = safe_add( safe_add( _4726,_4735 ),_4729 );
                  int _4739 = safe_add( _4726,_4735 );
                  while ( ((_4739 < _4738) && (_4737 < _4736)) )
                  {
                    {
                      if ((_ptr__4720[safe_add( _4718,_ptr__4719[safe_add( _4721,_4739 )] )] <= _ptr__4720[safe_add( _4718,_ptr__4719[safe_add( _4721,_4737 )] )]))
                      {
                        {
                          _ptr__4719[safe_add( _4722,_4733 )] = _ptr__4719[safe_add( _4721,_4739 )];
                          ++ _4733;
                          ++ _4739;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4719[safe_add( _4722,_4733 )] = _ptr__4719[safe_add( _4721,_4737 )];
                          ++ _4733;
                          ++ _4737;
                        }
                      }
                    }
                  }
                  while ( (_4739 < _4738) )
                  {
                    {
                      _ptr__4719[safe_add( _4722,_4733 )] = _ptr__4719[safe_add( _4721,_4739 )];
                      ++ _4733;
                      ++ _4739;
                    }
                  }
                  while ( (_4737 < _4736) )
                  {
                    {
                      _ptr__4719[safe_add( _4722,_4733 )] = _ptr__4719[safe_add( _4721,_4737 )];
                      ++ _4733;
                      ++ _4737;
                    }
                  }
                }
              }
              int _9006 = _4733;
              int _9007 = _4725;
              for (int _4740 = _9006; _4740 < _9007; ++_4740)
              {
                {
                  _ptr__4719[safe_add( _4722,_4740 )] = _ptr__4719[safe_add( _4721,_4740 )];
                }
              }
              int _4741 = _4721;
              _4721 = _4722;
              _4722 = _4741;
              _4729 *= (int)2;
            }
          }
        }
      }
      {}
      int _9008 = _4726;
      int _9009 = _4725;
      for (int _4742 = _9008; _4742 < _9009; ++_4742)
      {
        {
          _ptr__4719[safe_add( _4713,_4742 )] = _ptr__4719[safe_add( _4721,_4742 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4743){ return new mosek::fusion::ExprCondense(_4743); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4743) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4743); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4743){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4743->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4743;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4744,monty::rc_ptr< ::mosek::fusion::WorkStack > _4745,monty::rc_ptr< ::mosek::fusion::WorkStack > _4746) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4744,_4745,_4746); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4744,monty::rc_ptr< ::mosek::fusion::WorkStack > _4745,monty::rc_ptr< ::mosek::fusion::WorkStack > _4746){
  expr->eval(_4744,_4745,_4746);
  int _4747 = _4744->popi32();
  long long _4748 = (int)1;
  int _9010 = (int)0;
  int _9011 = _4747;
  for (int _4749 = _9010; _4749 < _9011; ++_4749)
  {
    {
      _4748 *= _4744->popi32();
    }
  }
  int _4750 = _4744->popi32();
  int _4751 = _4744->popi32();
  bool _4752 = (_4744->popi32() != (int)0);
  if (_4752)
  {
    {
      _4744->popi64(_4750);
    }
  }
  {}
  _4744->pushi32((int)0);
  _4744->pushi32(_4751);
  _4744->pushi32(_4750);
  _4744->pushi32(_4750);
  _4744->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4753){ return new mosek::fusion::ExprFromVar(_4753); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4753) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4753); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4753){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4753->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4753;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4754,monty::rc_ptr< ::mosek::fusion::WorkStack > _4755,monty::rc_ptr< ::mosek::fusion::WorkStack > _4756) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4754,_4755,_4756); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4754,monty::rc_ptr< ::mosek::fusion::WorkStack > _4755,monty::rc_ptr< ::mosek::fusion::WorkStack > _4756){
  std::shared_ptr< monty::ndarray< int,1 > > _4757 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4757(_4757 ? _4757->raw() : nullptr,_4757 ? _4757->size(0) : 0);
  long long _4758 = ::mosek::fusion::p_Set::size(_4757);
  int _4759 = x->numInst();
  int _4760 = _4759;
  bool _4761 = (_4758 > _4759);
  int _4762 = _4754->alloci32(safe_add( _4759,(int)1 ));
  int _4763 = _4754->alloci64(_4760);
  int _9012;
  bool _9013 = _4761;
  if (_9013)
  {
    _9012 = _4754->alloci64(_4759);
  }
  else
  {
    _9012 = (-(int)1);
  }
  int _4764 = _9012;
  int _4765 = _4754->allocf64(_4760);
  int _4766 = _4754->allocf64(_4759);
  int _9014;
  bool _9015 = _4761;
  if (_9015)
  {
    _9014 = (int)1;
  }
  else
  {
    _9014 = (int)0;
  }
  _4754->pushi32(_9014);
  _4754->pushi32(_4760);
  _4754->pushi32(_4759);
  int _9016 = (int)0;
  int _9017 = (int)((_4757)->size(0));
  for (int _4767 = _9016; _4767 < _9017; ++_4767)
  {
    {
      _4754->pushi32(_ptr__4757[_4767]);
    }
  }
  _4754->pushi32((int)((_4757)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4768 = mosek::fusion::p_WorkStack::_get_impl(_4754)->i32;
  _checked_ptr_1<int> _ptr__4768(_4768 ? _4768->raw() : nullptr,_4768 ? _4768->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4769 = mosek::fusion::p_WorkStack::_get_impl(_4754)->i64;
  _checked_ptr_1<long long> _ptr__4769(_4769 ? _4769->raw() : nullptr,_4769 ? _4769->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4770 = mosek::fusion::p_WorkStack::_get_impl(_4754)->f64;
  _checked_ptr_1<double> _ptr__4770(_4770 ? _4770->raw() : nullptr,_4770 ? _4770->size(0) : 0);
  int _9018 = (int)0;
  int _9019 = safe_add( _4759,(int)1 );
  for (int _4771 = _9018; _4771 < _9019; ++_4771)
  {
    {
      _ptr__4768[safe_add( _4762,_4771 )] = _4771;
    }
  }
  int _9020 = (int)0;
  int _9021 = _4759;
  for (int _4772 = _9020; _4772 < _9021; ++_4772)
  {
    {
      _ptr__4770[safe_add( _4766,_4772 )] = 0.0;
    }
  }
  int _9022 = (int)0;
  int _9023 = _4760;
  for (int _4773 = _9022; _4773 < _9023; ++_4773)
  {
    {
      _ptr__4770[safe_add( _4765,_4773 )] = 1.0;
    }
  }
  if (_4761)
  {
    {
      x->inst(_4764,_4769,_4763,_4769);
    }
  }
  else
  {
    {
      x->inst(_4763,_4769);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4774,    monty::rc_ptr< ::mosek::fusion::Expression > _4775){ return new mosek::fusion::ExprReshape(_4774,_4775); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4774,    monty::rc_ptr< ::mosek::fusion::Expression > _4775) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4774,_4775); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4774,    monty::rc_ptr< ::mosek::fusion::Expression > _4775){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4774(_4774 ? _4774->raw() : nullptr, _4774 ? _4774->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4774));
    long long _4776 = _4775->getSize();
    if ((::mosek::fusion::p_Set::size(_4774) != _4775->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4775;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4777,_4778,_4779); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779){
  std::shared_ptr< monty::ndarray< int,1 > > _4780 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4780(_4780 ? _4780->raw() : nullptr,_4780 ? _4780->size(0) : 0);
  e->eval(_4777,_4778,_4779);
  _4777->peek_expr();
  int _4781 = _4777->popi32();
  long long _4782 = (int)1;
  int _9024 = (int)0;
  int _9025 = _4781;
  for (int _4783 = _9024; _4783 < _9025; ++_4783)
  {
    {
      _4782 *= _4777->popi32();
    }
  }
  if ((_4782 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9026 = (int)0;
  int _9027 = (int)((_4780)->size(0));
  for (int _4784 = _9026; _4784 < _9027; ++_4784)
  {
    {
      _4777->pushi32(_ptr__4780[_4784]);
    }
  }
  _4777->pushi32((int)((_4780)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4785 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4785->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9028 = (int)1;
      int _9029 = _pubthis->getND();
      for (int _4786 = _9028; _4786 < _9029; ++_4786)
      {
        {
          _4785->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4786));
        }
      }
    }
  }
  {}
  _4785->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4785->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4787){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4787(_4787 ? _4787->raw() : nullptr, _4787 ? _4787->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4787;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4788 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4789 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4790 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4788,_4789,_4790);
  int _4791 = _4788->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4792 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4791)));
  _checked_ptr_1<int> _ptr__4792(_4792 ? _4792->raw() : nullptr,_4792 ? _4792->size(0) : 0);
  _4788->popi32(_4791,_4792,(int)0);
  int _4793 = _4788->popi32();
  int _4794 = _4788->popi32();
  int _4795 = (int)1;
  int _9030 = (int)0;
  int _9031 = _4791;
  for (int _4796 = _9030; _4796 < _9031; ++_4796)
  {
    {
      _4795 *= _ptr__4792[_4796];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4797 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4794)));
  _checked_ptr_1<long long> _ptr__4797(_4797 ? _4797->raw() : nullptr,_4797 ? _4797->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4798 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4793,(int)1 ))));
  _checked_ptr_1<int> _ptr__4798(_4798 ? _4798->raw() : nullptr,_4798 ? _4798->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4799 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4793)));
  _checked_ptr_1<double> _ptr__4799(_4799 ? _4799->raw() : nullptr,_4799 ? _4799->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4800 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4794)));
  _checked_ptr_1<double> _ptr__4800(_4800 ? _4800->raw() : nullptr,_4800 ? _4800->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4801 = nullptr;
  _checked_ptr_1<long long> _ptr__4801(_4801 ? _4801->raw() : nullptr,_4801 ? _4801->size(0) : 0);
  if ((_4795 < _4793))
  {
    {
      _4801 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4793)));
      _ptr__4801.update(_4801 ? _4801->raw() : nullptr, _4801 ? _4801->size(0) : 0);
      _4788->popi64(_4793,_4801,(int)0);
    }
  }
  {}
  _4788->popi32(_4793,_4798,(int)1);
  _4788->popi64(_4794,_4797,(int)0);
  _4788->popf64(_4793,_4799,(int)0);
  _4788->popf64(_4794,_4800,(int)0);
  std::vector<long long> _9032;
  for (int _4802 = (int)0, _9033 = safe_add( _4793,(int)1 ); _4802 < _9033 ; ++_4802)
  {
    _9032.push_back(_ptr__4798[_4802]);
  }
  auto _9034 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9032.size()),_9032.begin(),_9032.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4799,_9034,_4797,_4800,_4792,_4801);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4803,    std::shared_ptr< monty::ndarray< int,1 > > _4804,    std::shared_ptr< monty::ndarray< int,1 > > _4805,    std::shared_ptr< monty::ndarray< long long,1 > > _4806,    std::shared_ptr< monty::ndarray< long long,1 > > _4807,    std::shared_ptr< monty::ndarray< double,1 > > _4808,    std::shared_ptr< monty::ndarray< double,1 > > _4809) { mosek::fusion::p_BaseExpression::storeexpr(_4803,_4804,_4805,_4806,_4807,_4808,_4809); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4803,std::shared_ptr< monty::ndarray< int,1 > > _4804,std::shared_ptr< monty::ndarray< int,1 > > _4805,std::shared_ptr< monty::ndarray< long long,1 > > _4806,std::shared_ptr< monty::ndarray< long long,1 > > _4807,std::shared_ptr< monty::ndarray< double,1 > > _4808,std::shared_ptr< monty::ndarray< double,1 > > _4809){
  _checked_ptr_1<int> _ptr__4804(_4804 ? _4804->raw() : nullptr, _4804 ? _4804->size(0) : 0);
  _checked_ptr_1<int> _ptr__4805(_4805 ? _4805->raw() : nullptr, _4805 ? _4805->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4806(_4806 ? _4806->raw() : nullptr, _4806 ? _4806->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4807(_4807 ? _4807->raw() : nullptr, _4807 ? _4807->size(0) : 0);
  _checked_ptr_1<double> _ptr__4808(_4808 ? _4808->raw() : nullptr, _4808 ? _4808->size(0) : 0);
  _checked_ptr_1<double> _ptr__4809(_4809 ? _4809->raw() : nullptr, _4809 ? _4809->size(0) : 0);
  int _4810 = _ptr__4805[((int)((_4805)->size(0)) - (int)1)];
  int _4811 = ((int)((_4805)->size(0)) - (int)1);
  int _4812 = (int)((_4804)->size(0));
  {
    int _4813 = _4803->alloci32(safe_add( _4811,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4805,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->i32,_4813,safe_add( _4811,(int)1 ));
  }
  int _9035;
  bool _9036 = (NULL != _4806.get());
  if (_9036)
  {
    _9035 = (int)1;
  }
  else
  {
    _9035 = (int)0;
  }
  _4803->pushi32(_9035);
  _4803->pushi32(_4810);
  _4803->pushi32(_4811);
  {
    int _4814 = _4803->alloci32(_4812);
    ::mosek::fusion::Utils::Tools::arraycopy(_4804,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->i32,_4814,_4812);
  }
  _4803->pushi32(_4812);
  {
    int _4815 = _4803->alloci64(_4810);
    ::mosek::fusion::Utils::Tools::arraycopy(_4807,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->i64,_4815,_4810);
  }
  if ((NULL != _4806.get()))
  {
    {
      int _4816 = _4803->alloci64(_4811);
      ::mosek::fusion::Utils::Tools::arraycopy(_4806,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->i64,_4816,_4811);
    }
  }
  {}
  {
    int _4817 = _4803->allocf64(_4810);
    ::mosek::fusion::Utils::Tools::arraycopy(_4808,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->f64,_4817,_4810);
  }
  {
    int _4818 = _4803->allocf64(_4811);
    if ((NULL != _4809.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4809,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4803)->f64,_4818,_4811);
      }
    }
    else
    {
      {
        int _9037 = (int)0;
        int _9038 = _4811;
        for (int _4819 = _9037; _4819 < _9038; ++_4819)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4803)->f64)(safe_add( _4818,_4819 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4823) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4823); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4823) { return __mosek_2fusion_2BaseExpression__pick(_4823); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4823) { return __mosek_2fusion_2BaseExpression__pick(_4823); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4823){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4823)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4824) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4824); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4824) { return __mosek_2fusion_2BaseExpression__pick(_4824); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4824) { return __mosek_2fusion_2BaseExpression__pick(_4824); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4824){
  _checked_ptr_1<int> _ptr__4824(_4824 ? _4824->raw() : nullptr, _4824 ? _4824->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4825 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4824)->size(0)),(int)1)));
  int _9039 = (int)0;
  int _9040 = (int)((_4824)->size(0));
  for (int _4826 = _9039; _4826 < _9040; ++_4826)
  {
    {
      ((*_4825)(_4826,(int)0)) = _ptr__4824[_4826];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4825)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4827) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4827); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4827) { return __mosek_2fusion_2BaseExpression__index(_4827); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4827) { return __mosek_2fusion_2BaseExpression__index(_4827); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4827){
  _checked_ptr_1<int> _ptr__4827(_4827 ? _4827->raw() : nullptr, _4827 ? _4827->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4828 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4827)->size(0)))));
  int _9041 = (int)0;
  int _9042 = (int)((_4827)->size(0));
  for (int _4829 = _9041; _4829 < _9042; ++_4829)
  {
    {
      ((*_4828)((int)0,_4829)) = _ptr__4827[_4829];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4828)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4830) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4830); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4830) { return __mosek_2fusion_2BaseExpression__index(_4830); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4830) { return __mosek_2fusion_2BaseExpression__index(_4830); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4830){
  std::shared_ptr< monty::ndarray< int,2 > > _4831 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4831)((int)0,(int)0)) = _4830;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4831)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4832,_4833); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833) { return __mosek_2fusion_2BaseExpression__slice(_4832,_4833); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833) { return __mosek_2fusion_2BaseExpression__slice(_4832,_4833); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833){
  _checked_ptr_1<int> _ptr__4832(_4832 ? _4832->raw() : nullptr, _4832 ? _4832->size(0) : 0);
  _checked_ptr_1<int> _ptr__4833(_4833 ? _4833->raw() : nullptr, _4833 ? _4833->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4832,_4833)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4834,int _4835) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4834,_4835); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4834,int _4835) { return __mosek_2fusion_2BaseExpression__slice(_4834,_4835); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4834,int _4835) { return __mosek_2fusion_2BaseExpression__slice(_4834,_4835); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4834,int _4835){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4834)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4835)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4836) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4836); }int mosek::fusion::p_BaseExpression::getDim(int _4836){
  return ((*shape)(_4836));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4837) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4837); }int mosek::fusion::p_WorkStack::peek_dim(int _4837){
  return _pubthis->peeki32(safe_add( _4837,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4838,int _4839,int _4840,bool _4841) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4838,_4839,_4840,_4841); }void mosek::fusion::p_WorkStack::alloc_expr(int _4838,int _4839,int _4840,bool _4841){
  cof_base = _pubthis->allocf64(_4840);
  bfix_base = _pubthis->allocf64(_4839);
  nidxs_base = _pubthis->alloci64(_4840);
  int _9043;
  bool _9044 = _4841;
  if (_9044)
  {
    _9043 = _pubthis->alloci64(_4839);
  }
  else
  {
    _9043 = (-(int)9999);
  }
  sp_base = _9043;
  ptr_base = _pubthis->alloci32(safe_add( _4839,(int)1 ));
  int _9045;
  bool _9046 = _4841;
  if (_9046)
  {
    _9045 = (int)1;
  }
  else
  {
    _9045 = (int)0;
  }
  _pubthis->pushi32(_9045);
  _pubthis->pushi32(_4840);
  _pubthis->pushi32(_4839);
  shape_base = _pubthis->alloci32(_4838);
  _pubthis->pushi32(_4838);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4838;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4839;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4840;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4841;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4842) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4842); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4842){
  int _4843 = pi32;
  int _4844 = pi64;
  int _4845 = pf64;
  _pubthis->pop_expr();
  int _4846 = _4842->alloci32((_4843 - pi32));
  int _4847 = _4842->alloci64((_4844 - pi64));
  int _4848 = _4842->allocf64((_4845 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4842)->i32,_4846,(_4843 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4842)->i64,_4847,(_4844 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4842)->f64,_4848,(_4845 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4849 = pi32;
  int _4850 = pi64;
  int _4851 = pf64;
  _pubthis->pop_expr();
  pi32 = _4849;
  pi64 = _4850;
  pf64 = _4851;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9047;
  bool _9048 = hassp;
  if (_9048)
  {
    _9047 = _pubthis->popi64(nelem);
  }
  else
  {
    _9047 = (-(int)9999);
  }
  sp_base = _9047;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4852 = ((*i32)((pi32 - (int)1)));
  bool _4853 = (((*i32)(((pi32 - _4852) - (int)3))) != (int)0);
  int _4854 = ((*i32)(((pi32 - _4852) - (int)1)));
  if ((!_4853))
  {
    {
      ((*i32)(((pi32 - _4852) - (int)3))) = (int)1;
      int _4855 = _pubthis->alloci64(_4854);
      int _9049 = (int)0;
      int _9050 = _4854;
      for (int _4856 = _9049; _4856 < _9050; ++_4856)
      {
        {
          ((*i64)(_4855)) = _4856;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4857) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4857); }int mosek::fusion::p_WorkStack::allocf64(int _4857){
  _pubthis->ensuref64(_4857);
  int _4858 = pf64;
  int _9051 = pf64;
  int _9052 = safe_add( pf64,_4857 );
  for (int _4859 = _9051; _4859 < _9052; ++_4859)
  {
    {
      ((*f64)(_4859)) = (int)99997;
    }
  }
  pf64 += _4857;
  return _4858;
}
int mosek::fusion::WorkStack :: alloci64(int _4860) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4860); }int mosek::fusion::p_WorkStack::alloci64(int _4860){
  _pubthis->ensurei64(_4860);
  int _4861 = pi64;
  int _9053 = pi64;
  int _9054 = safe_add( pi64,_4860 );
  for (int _4862 = _9053; _4862 < _9054; ++_4862)
  {
    {
      ((*i64)(_4862)) = (int)99998;
    }
  }
  pi64 += _4860;
  return _4861;
}
int mosek::fusion::WorkStack :: alloci32(int _4863) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4863); }int mosek::fusion::p_WorkStack::alloci32(int _4863){
  if ((_4863 > (int)0))
  {
    {
      _pubthis->ensurei32(_4863);
      int _4864 = pi32;
      int _9055 = pi32;
      int _9056 = safe_add( pi32,_4863 );
      for (int _4865 = _9055; _4865 < _9056; ++_4865)
      {
        {
          ((*i32)(_4865)) = (int)99999;
        }
      }
      pi32 += _4863;
      return _4864;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4866) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4866); }void mosek::fusion::p_WorkStack::pushf64(double _4866){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4866;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4867) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4867); }void mosek::fusion::p_WorkStack::pushi64(long long _4867){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4867;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4868) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4868); }void mosek::fusion::p_WorkStack::pushi32(int _4868){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4868;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4869) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4869); }void mosek::fusion::p_WorkStack::ensuref64(int _4869){
  if ((safe_add( pf64,_4869 ) > (int)((f64)->size(0))))
  {
    {
      int _9057;
      bool _9058 = (_4869 < (int)((f64)->size(0)));
      if (_9058)
      {
        _9057 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9057 = safe_add( (int)((f64)->size(0)),_4869 );
      }
      int _4870 = _9057;
      std::shared_ptr< monty::ndarray< double,1 > > _4871 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4870)));
      _checked_ptr_1<double> _ptr__4871(_4871 ? _4871->raw() : nullptr,_4871 ? _4871->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4871,(int)0,pf64);
      f64 = _4871;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4872) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4872); }void mosek::fusion::p_WorkStack::ensurei64(int _4872){
  if ((safe_add( pi64,_4872 ) > (int)((i64)->size(0))))
  {
    {
      int _9059;
      bool _9060 = (_4872 < (int)((i64)->size(0)));
      if (_9060)
      {
        _9059 = (int)((i64)->size(0));
      }
      else
      {
        _9059 = _4872;
      }
      int _4873 = safe_add( (int)((i64)->size(0)),_9059 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4874 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4873)));
      _checked_ptr_1<long long> _ptr__4874(_4874 ? _4874->raw() : nullptr,_4874 ? _4874->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4874,(int)0,pi64);
      i64 = _4874;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4875) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4875); }void mosek::fusion::p_WorkStack::ensurei32(int _4875){
  if ((safe_add( pi32,_4875 ) > (int)((i32)->size(0))))
  {
    {
      int _9061;
      bool _9062 = (_4875 < (int)((i32)->size(0)));
      if (_9062)
      {
        _9061 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9061 = safe_add( (int)((i32)->size(0)),_4875 );
      }
      int _4876 = _9061;
      std::shared_ptr< monty::ndarray< int,1 > > _4877 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4876)));
      _checked_ptr_1<int> _ptr__4877(_4877 ? _4877->raw() : nullptr,_4877 ? _4877->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_4877,(int)0,pi32);
      i32 = _4877;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _4878) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4878); }int mosek::fusion::p_WorkStack::popf64(int _4878){
  pf64 -= _4878;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _4879) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4879); }int mosek::fusion::p_WorkStack::popi64(int _4879){
  pi64 -= _4879;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _4880) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4880); }int mosek::fusion::p_WorkStack::popi32(int _4880){
  pi32 -= _4880;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _4881,std::shared_ptr< monty::ndarray< double,1 > > _4882,int _4883) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4881,_4882,_4883); }void mosek::fusion::p_WorkStack::popf64(int _4881,std::shared_ptr< monty::ndarray< double,1 > > _4882,int _4883){
  _checked_ptr_1<double> _ptr__4882(_4882 ? _4882->raw() : nullptr, _4882 ? _4882->size(0) : 0);
  pf64 -= _4881;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_4882,_4883,_4881);
}
void mosek::fusion::WorkStack :: popi64(int _4884,std::shared_ptr< monty::ndarray< long long,1 > > _4885,int _4886) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4884,_4885,_4886); }void mosek::fusion::p_WorkStack::popi64(int _4884,std::shared_ptr< monty::ndarray< long long,1 > > _4885,int _4886){
  _checked_ptr_1<long long> _ptr__4885(_4885 ? _4885->raw() : nullptr, _4885 ? _4885->size(0) : 0);
  pi64 -= _4884;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_4885,_4886,_4884);
}
void mosek::fusion::WorkStack :: popi32(int _4887,std::shared_ptr< monty::ndarray< int,1 > > _4888,int _4889) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4887,_4888,_4889); }void mosek::fusion::p_WorkStack::popi32(int _4887,std::shared_ptr< monty::ndarray< int,1 > > _4888,int _4889){
  _checked_ptr_1<int> _ptr__4888(_4888 ? _4888->raw() : nullptr, _4888 ? _4888->size(0) : 0);
  pi32 -= _4887;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_4888,_4889,_4887);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _4890) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_4890); }double mosek::fusion::p_WorkStack::peekf64(int _4890){
  return ((*f64)(((pf64 - _4890) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _4891) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_4891); }long long mosek::fusion::p_WorkStack::peeki64(int _4891){
  return ((*i64)(((pi64 - _4891) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _4892) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_4892); }int mosek::fusion::p_WorkStack::peeki32(int _4892){
  return ((*i32)(((pi32 - _4892) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _4893,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4894,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4895,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4896){ return new mosek::fusion::SymmetricExpr(_4893,_4894,_4895,_4896); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _4893,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4894,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4895,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4896) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_4893,_4894,_4895,_4896); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _4893,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4894,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4895,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4896){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _4893;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _4894;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _4895;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _4896;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4897,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4898){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->n != _4898->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9063;
  bool _9064 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->b.get());
  if (_9064)
  {
    _9063 = mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->b->__mosek_2fusion_2SymmetricMatrix__add(_4898);
  }
  else
  {
    _9063 = _4898;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_4897)->xs,_9063);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4899,double _4900){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9065;
  for (int _4901 = (int)0, _9066 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->Ms)->size(0)); _4901 < _9066 ; ++_4901)
  {
    _9065.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->Ms)(_4901))->__mosek_2fusion_2SymmetricMatrix__mul(_4900));
  }
  auto _9067 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9065.size()),_9065.begin(),_9065.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9068;
  bool _9069 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b.get());
  if (_9069)
  {
    _9068 = mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b->__mosek_2fusion_2SymmetricMatrix__mul(_4900);
  }
  else
  {
    _9068 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->n,_9067,mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->xs,_9068);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4902,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4903){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4904 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4905 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->xs)->size(0)) ))));
  int _4906 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->Ms)->size(0));
  int _9070 = (int)0;
  int _9071 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->Ms)->size(0));
  for (int _4907 = _9070; _4907 < _9071; ++_4907)
  {
    {
      ((*_4904)(_4907)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->Ms)(_4907));
    }
  }
  int _9072 = (int)0;
  int _9073 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->Ms)->size(0));
  for (int _4908 = _9072; _4908 < _9073; ++_4908)
  {
    {
      ((*_4904)(safe_add( _4908,_4906 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->Ms)(_4908));
    }
  }
  int _4909 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->xs)->size(0));
  int _9074 = (int)0;
  int _9075 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->xs)->size(0));
  for (int _4910 = _9074; _4910 < _9075; ++_4910)
  {
    {
      ((*_4905)(_4910)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->xs)(_4910));
    }
  }
  int _9076 = (int)0;
  int _9077 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->xs)->size(0));
  for (int _4911 = _9076; _4911 < _9077; ++_4911)
  {
    {
      ((*_4905)(safe_add( _4911,_4909 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->xs)(_4911));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9078;
  bool _9079 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->b.get()));
  if (_9079)
  {
    _9078 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9080;
    bool _9081 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->b.get()));
    if (_9081)
    {
      _9080 = mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9082;
      bool _9083 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->b.get());
      if (_9083)
      {
        _9082 = mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->b;
      }
      else
      {
        _9082 = mosek::fusion::p_SymmetricExpr::_get_impl(_4903)->b;
      }
      _9080 = _9082;
    }
    _9078 = _9080;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4912 = _9078;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4902)->n,_4904,_4905,_4912);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4913 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _4913->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _4913->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915,    std::shared_ptr< monty::ndarray< double,1 > > _4916,    std::shared_ptr< monty::ndarray< double,1 > > _4917,    std::shared_ptr< monty::ndarray< int,1 > > _4918,    std::shared_ptr< monty::ndarray< long long,1 > > _4919){ return new mosek::fusion::Expr(_4914,_4915,_4916,_4917,_4918,_4919); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915,    std::shared_ptr< monty::ndarray< double,1 > > _4916,    std::shared_ptr< monty::ndarray< double,1 > > _4917,    std::shared_ptr< monty::ndarray< int,1 > > _4918,    std::shared_ptr< monty::ndarray< long long,1 > > _4919) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4914,_4915,_4916,_4917,_4918,_4919); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915,    std::shared_ptr< monty::ndarray< double,1 > > _4916,    std::shared_ptr< monty::ndarray< double,1 > > _4917,    std::shared_ptr< monty::ndarray< int,1 > > _4918,    std::shared_ptr< monty::ndarray< long long,1 > > _4919){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4914(_4914 ? _4914->raw() : nullptr, _4914 ? _4914->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4915(_4915 ? _4915->raw() : nullptr, _4915 ? _4915->size(0) : 0);
    _checked_ptr_1<double> _ptr__4916(_4916 ? _4916->raw() : nullptr, _4916 ? _4916->size(0) : 0);
    _checked_ptr_1<double> _ptr__4917(_4917 ? _4917->raw() : nullptr, _4917 ? _4917->size(0) : 0);
    _checked_ptr_1<int> _ptr__4918(_4918 ? _4918->raw() : nullptr, _4918 ? _4918->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4919(_4919 ? _4919->raw() : nullptr, _4919 ? _4919->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9084;
    bool _9085 = (NULL != _4918.get());
    if (_9085)
    {
      _9084 = ::mosek::fusion::Utils::Tools::arraycopy(_4918);
    }
    else
    {
      _9084 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_4914)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9086;
    bool _9087 = (NULL != _4919.get());
    if (_9087)
    {
      _9086 = ::mosek::fusion::Utils::Tools::arraycopy(_4919);
    }
    else
    {
      _9086 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4914),::mosek::fusion::Utils::Tools::arraycopy(_4915),::mosek::fusion::Utils::Tools::arraycopy(_4916),::mosek::fusion::Utils::Tools::arraycopy(_4917),_9084,_9086,(int)1);
    int _4920 = ((int)((_4914)->size(0)) - (int)1);
    if ((_4920 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _4921 = _ptr__4914[_4920];
    if (((_4921 < (int)0) || ((_4921 != (int)((_4916)->size(0))) || (_4921 != (int)((_4915)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _4922 = true;
    bool _4923 = true;
    bool _4924 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _4925 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__4925(_4925 ? _4925->raw() : nullptr,_4925 ? _4925->size(0) : 0);
    long long _4926 = ::mosek::fusion::p_Set::size(_4925);
    {
      int _9088 = (int)0;
      int _9089 = (int)((_4925)->size(0));
      for (int _4927 = _9088; _4927 < _9089; ++_4927)
      {
        {
          _4923 = (_4923 && (_ptr__4925[_4927] >= (int)0));
        }
      }
      int _9090 = (int)0;
      int _9091 = _4920;
      for (int _4928 = _9090; _4928 < _9091; ++_4928)
      {
        {
          _4922 = (_4922 && (_ptr__4914[_4928] <= _ptr__4914[safe_add( _4928,(int)1 )]));
        }
      }
      if (((NULL != _4919.get()) && ((int)((_4919)->size(0)) > (int)0)))
      {
        {
          _4924 = ((_ptr__4919[(int)0] >= (int)0) && (_ptr__4919[(_4920 - (int)1)] < _4926));
          int _9092 = (int)0;
          int _9093 = (_4920 - (int)1);
          for (int _4929 = _9092; _4929 < _9093; ++_4929)
          {
            {
              _4924 = (_4924 && (_ptr__4919[_4929] < _ptr__4919[safe_add( _4929,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_4923))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_4922))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_4924))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    std::shared_ptr< monty::ndarray< double,1 > > _4932,    std::shared_ptr< monty::ndarray< double,1 > > _4933,    std::shared_ptr< monty::ndarray< int,1 > > _4934,    std::shared_ptr< monty::ndarray< long long,1 > > _4935,    int _4936){ return new mosek::fusion::Expr(_4930,_4931,_4932,_4933,_4934,_4935,_4936); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    std::shared_ptr< monty::ndarray< double,1 > > _4932,    std::shared_ptr< monty::ndarray< double,1 > > _4933,    std::shared_ptr< monty::ndarray< int,1 > > _4934,    std::shared_ptr< monty::ndarray< long long,1 > > _4935,    int _4936) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4930,_4931,_4932,_4933,_4934,_4935,_4936); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    std::shared_ptr< monty::ndarray< double,1 > > _4932,    std::shared_ptr< monty::ndarray< double,1 > > _4933,    std::shared_ptr< monty::ndarray< int,1 > > _4934,    std::shared_ptr< monty::ndarray< long long,1 > > _4935,    int _4936){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4930(_4930 ? _4930->raw() : nullptr, _4930 ? _4930->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4931(_4931 ? _4931->raw() : nullptr, _4931 ? _4931->size(0) : 0);
    _checked_ptr_1<double> _ptr__4932(_4932 ? _4932->raw() : nullptr, _4932 ? _4932->size(0) : 0);
    _checked_ptr_1<double> _ptr__4933(_4933 ? _4933->raw() : nullptr, _4933 ? _4933->size(0) : 0);
    _checked_ptr_1<int> _ptr__4934(_4934 ? _4934->raw() : nullptr, _4934 ? _4934->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4935(_4935 ? _4935->raw() : nullptr, _4935 ? _4935->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4934);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _4934;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _4930;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _4931;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _4932;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _4933;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _4935;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4937){ return new mosek::fusion::Expr(_4937); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4937) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4937); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4937){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4937->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9094 = _4937;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9094.get()))
    {
      ::mosek::fusion::Expr::t _4938 (dynamic_cast<::mosek::fusion::Expr*>(_9094.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_4938)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_4938)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_4938)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_4938)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_4938)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_4938)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _4939 = _9094;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4940 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4941 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4942 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _4939->eval(_4942,_4941,_4940);
        int _4943 = _4942->popi32();
        int _4944 = _4942->popi32(_4943);
        int _4945 = _4942->popi32();
        int _4946 = _4942->popi32();
        bool _4947 = (_4942->popi32() != (int)0);
        int _4948 = _4942->popi32(safe_add( _4945,(int)1 ));
        int _9095;
        bool _9096 = _4947;
        if (_9096)
        {
          _9095 = _4942->popi64(_4945);
        }
        else
        {
          _9095 = (int)0;
        }
        int _4949 = _9095;
        int _4950 = _4942->popi64(_4946);
        int _4951 = _4942->popf64(_4945);
        int _4952 = _4942->popf64(_4946);
        std::shared_ptr< monty::ndarray< int,1 > > _4953 = mosek::fusion::p_WorkStack::_get_impl(_4942)->i32;
        _checked_ptr_1<int> _ptr__4953(_4953 ? _4953->raw() : nullptr,_4953 ? _4953->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _4954 = mosek::fusion::p_WorkStack::_get_impl(_4942)->i64;
        _checked_ptr_1<long long> _ptr__4954(_4954 ? _4954->raw() : nullptr,_4954 ? _4954->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _4955 = mosek::fusion::p_WorkStack::_get_impl(_4942)->f64;
        _checked_ptr_1<double> _ptr__4955(_4955 ? _4955->raw() : nullptr,_4955 ? _4955->size(0) : 0);
        std::vector<int> _9097;
        for (int _4956 = (int)0, _9098 = _4943; _4956 < _9098 ; ++_4956)
        {
          _9097.push_back(_ptr__4953[safe_add( _4944,_4956 )]);
        }
        auto _9099 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9097.size()),_9097.begin(),_9097.end()));
        shape = _9099;
        std::vector<long long> _9100;
        for (int _4957 = (int)0, _9101 = safe_add( _4945,(int)1 ); _4957 < _9101 ; ++_4957)
        {
          _9100.push_back(_ptr__4953[safe_add( _4948,_4957 )]);
        }
        auto _9102 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9100.size()),_9100.begin(),_9100.end()));
        ptrb = _9102;
        std::vector<long long> _9103;
        for (int _4958 = (int)0, _9104 = _4946; _4958 < _9104 ; ++_4958)
        {
          _9103.push_back(_ptr__4954[safe_add( _4950,_4958 )]);
        }
        auto _9105 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9103.size()),_9103.begin(),_9103.end()));
        subj = _9105;
        std::vector<double> _9106;
        for (int _4959 = (int)0, _9107 = _4946; _4959 < _9107 ; ++_4959)
        {
          _9106.push_back(_ptr__4955[safe_add( _4952,_4959 )]);
        }
        auto _9108 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9106.size()),_9106.begin(),_9106.end()));
        cof_v = _9108;
        std::vector<double> _9109;
        for (int _4960 = (int)0, _9110 = _4946; _4960 < _9110 ; ++_4960)
        {
          _9109.push_back(_ptr__4955[safe_add( _4951,_4960 )]);
        }
        auto _9111 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9109.size()),_9109.begin(),_9109.end()));
        bfix = _9111;
        std::shared_ptr< monty::ndarray< long long,1 > > _9112;
        bool _9113 = _4947;
        if (_9113)
        {
          std::vector<long long> _9114;
          for (int _4961 = (int)0, _9115 = _4946; _4961 < _9115 ; ++_4961)
          {
            _9114.push_back(_ptr__4954[safe_add( _4949,_4961 )]);
          }
          auto _9116 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9114.size()),_9114.begin(),_9114.end()));
          _9112 = _9116;
        }
        else
        {
          _9112 = nullptr;
        }
        inst = _9112;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _4962){
  _checked_ptr_1<int> _ptr__4962(_4962 ? _4962->raw() : nullptr, _4962 ? _4962->size(0) : 0);
  int _4963 = (int)1;
  int _9117 = (int)0;
  int _9118 = (int)((_4962)->size(0));
  for (int _4964 = _9117; _4964 < _9118; ++_4964)
  {
    {
      _4963 *= _ptr__4962[_4964];
    }
  }
  return _4963;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _4965){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9119;
  for (int _4966 = (int)0, _9120 = (int)((_4965)->size(0)); _4966 < _9120 ; ++_4966)
  {
    for (int _4967 = (int)0, _9121 = (int)((((*_4965)(_4966)))->size(0)); _4967 < _9121 ; ++_4967)
    {
      _9119.push_back(((*((*_4965)(_4966)))(_4967)));
    }
  }
  auto _9122 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9119.size()),_9119.begin(),_9119.end()));
  return _9122;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4968,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4969){
  if ((NULL == _4968.get()))
  {
    {
      return _4969;
    }
  }
  else if((NULL == _4969.get()))
  {
    {
      return _4968;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4970 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_4968)->size(0)),(int)((_4969)->size(0)) ))));
      int _9123 = (int)0;
      int _9124 = (int)((_4968)->size(0));
      for (int _4971 = _9123; _4971 < _9124; ++_4971)
      {
        {
          ((*_4970)(_4971)) = ((*_4968)(_4971));
        }
      }
      int _9125 = (int)0;
      int _9126 = (int)((_4969)->size(0));
      for (int _4972 = _9125; _4972 < _9126; ++_4972)
      {
        {
          ((*_4970)(safe_add( _4972,(int)((_4968)->size(0)) ))) = ((*_4969)(_4972));
        }
      }
      return _4970;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _4973) { return mosek::fusion::p_Expr::condense(_4973); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _4973){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_4973)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _4974) { return mosek::fusion::p_Expr::flatten(_4974); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _4974){
  if ((NULL == _4974.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4974,(int)_4974->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4975,    int _4976,    int _4977) { return mosek::fusion::p_Expr::reshape(_4975,_4976,_4977); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4975,int _4976,int _4977){
  if ((NULL == _4975.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4975,::mosek::fusion::p_Set::make(_4976,_4977));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4978,    int _4979) { return mosek::fusion::p_Expr::reshape(_4978,_4979); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4978,int _4979){
  if ((NULL == _4978.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4978,::mosek::fusion::p_Set::make(_4979));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4980,    std::shared_ptr< monty::ndarray< int,1 > > _4981) { return mosek::fusion::p_Expr::reshape(_4980,_4981); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4980,std::shared_ptr< monty::ndarray< int,1 > > _4981){
  _checked_ptr_1<int> _ptr__4981(_4981 ? _4981->raw() : nullptr, _4981 ? _4981->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_4981,_4980)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9127;
  bool _9128 = (NULL == bfix.get());
  if (_9128)
  {
    _9127 = nullptr;
  }
  else
  {
    _9127 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _4982 = _9127;
  _checked_ptr_1<double> _ptr__4982(_4982 ? _4982->raw() : nullptr,_4982 ? _4982->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9129;
  bool _9130 = (NULL == inst.get());
  if (_9130)
  {
    _9129 = nullptr;
  }
  else
  {
    _9129 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4983 = _9129;
  _checked_ptr_1<long long> _ptr__4983(_4983 ? _4983->raw() : nullptr,_4983 ? _4983->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4982,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _4984) { return mosek::fusion::p_Expr::zeros(_4984); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _4984){
  _checked_ptr_1<int> _ptr__4984(_4984 ? _4984->raw() : nullptr, _4984 ? _4984->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_4984,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _4985) { return mosek::fusion::p_Expr::zeros(_4985); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _4985){
  return ::mosek::fusion::p_Expr::constTerm(_4985,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _4986,    std::shared_ptr< monty::ndarray< int,2 > > _4987) { return mosek::fusion::p_Expr::ones(_4986,_4987); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _4986,std::shared_ptr< monty::ndarray< int,2 > > _4987){
  _checked_ptr_1<int> _ptr__4986(_4986 ? _4986->raw() : nullptr, _4986 ? _4986->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_4986,_4987,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _4988) { return mosek::fusion::p_Expr::ones(_4988); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _4988){
  _checked_ptr_1<int> _ptr__4988(_4988 ? _4988->raw() : nullptr, _4988 ? _4988->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_4988,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _4989) { return mosek::fusion::p_Expr::ones(_4989); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _4989){
  return ::mosek::fusion::p_Expr::constTerm(_4989,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _4990) { return mosek::fusion::p_Expr::constTerm(_4990); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _4990){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_4990)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_4990)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_4990)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _4991) { return mosek::fusion::p_Expr::constTerm(_4991); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _4991){
  int _4992 = _4991->numRows();
  int _4993 = _4991->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _4994 = ::mosek::fusion::p_Set::make(_4992,_4993);
  _checked_ptr_1<int> _ptr__4994(_4994 ? _4994->raw() : nullptr,_4994 ? _4994->size(0) : 0);
  if (_4991->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _4995 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4991->numNonzeros())));
      _checked_ptr_1<double> _ptr__4995(_4995 ? _4995->raw() : nullptr,_4995 ? _4995->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4996 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4991->numNonzeros())));
      _checked_ptr_1<int> _ptr__4996(_4996 ? _4996->raw() : nullptr,_4996 ? _4996->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4997 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4991->numNonzeros())));
      _checked_ptr_1<int> _ptr__4997(_4997 ? _4997->raw() : nullptr,_4997 ? _4997->size(0) : 0);
      _4991->getDataAsTriplets(_4997,_4996,_4995);
      std::vector<long long> _9131;
      for (int _4999 = (int)0, _9132 = (int)((_4996)->size(0)); _4999 < _9132 ; ++_4999)
      {
        _9131.push_back(safe_add( safe_mul( _ptr__4997[_4999],_4993 ),_ptr__4996[_4999] ));
      }
      auto _9133 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9131.size()),_9131.begin(),_9131.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _4998 = _9133;
      _checked_ptr_1<long long> _ptr__4998(_4998 ? _4998->raw() : nullptr,_4998 ? _4998->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4994,_4998,_4995)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4994,nullptr,_4991->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _5000) { return mosek::fusion::p_Expr::constTerm(_5000); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _5000){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_5000)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5001,    std::shared_ptr< monty::ndarray< int,2 > > _5002,    double _5003) { return mosek::fusion::p_Expr::constTerm(_5001,_5002,_5003); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5001,std::shared_ptr< monty::ndarray< int,2 > > _5002,double _5003){
  _checked_ptr_1<int> _ptr__5001(_5001 ? _5001->raw() : nullptr, _5001 ? _5001->size(0) : 0);
  int _5004 = (int)((_5002)->size(0));
  int _5005 = (int)((_5001)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5006 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5004)));
  _checked_ptr_1<long long> _ptr__5006(_5006 ? _5006->raw() : nullptr,_5006 ? _5006->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5007 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5005)));
  _checked_ptr_1<long long> _ptr__5007(_5007 ? _5007->raw() : nullptr,_5007 ? _5007->size(0) : 0);
  _ptr__5007[(_5005 - (int)1)] = (int)1;
  int _9134 = (int)1;
  int _9135 = _5005;
  for (int _5008 = _9134; _5008 < _9135; ++_5008)
  {
    {
      _ptr__5007[((_5005 - _5008) - (int)1)] = safe_mul( _ptr__5007[(_5005 - _5008)],_ptr__5001[(_5005 - _5008)] );
    }
  }
  int _9136 = (int)0;
  int _9137 = _5004;
  for (int _5009 = _9136; _5009 < _9137; ++_5009)
  {
    {
      int _9138 = (int)0;
      int _9139 = _5005;
      for (int _5010 = _9138; _5010 < _9139; ++_5010)
      {
        {
          _ptr__5006[_5009] += safe_mul( _ptr__5007[_5010],((*_5002)(_5009,_5010)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5001,_5006,_5003)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5011,    std::shared_ptr< monty::ndarray< int,2 > > _5012,    std::shared_ptr< monty::ndarray< double,1 > > _5013) { return mosek::fusion::p_Expr::constTerm(_5011,_5012,_5013); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5011,std::shared_ptr< monty::ndarray< int,2 > > _5012,std::shared_ptr< monty::ndarray< double,1 > > _5013){
  _checked_ptr_1<int> _ptr__5011(_5011 ? _5011->raw() : nullptr, _5011 ? _5011->size(0) : 0);
  _checked_ptr_1<double> _ptr__5013(_5013 ? _5013->raw() : nullptr, _5013 ? _5013->size(0) : 0);
  int _5014 = (int)((_5012)->size(0));
  int _5015 = (int)((_5011)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5016 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5014)));
  _checked_ptr_1<long long> _ptr__5016(_5016 ? _5016->raw() : nullptr,_5016 ? _5016->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5017 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5015)));
  _checked_ptr_1<long long> _ptr__5017(_5017 ? _5017->raw() : nullptr,_5017 ? _5017->size(0) : 0);
  _ptr__5017[(_5015 - (int)1)] = (int)1;
  int _9140 = (int)1;
  int _9141 = _5015;
  for (int _5018 = _9140; _5018 < _9141; ++_5018)
  {
    {
      _ptr__5017[((_5015 - _5018) - (int)1)] = safe_mul( _ptr__5017[(_5015 - _5018)],_ptr__5011[(_5015 - _5018)] );
    }
  }
  int _9142 = (int)0;
  int _9143 = _5014;
  for (int _5019 = _9142; _5019 < _9143; ++_5019)
  {
    {
      int _9144 = (int)0;
      int _9145 = _5015;
      for (int _5020 = _9144; _5020 < _9145; ++_5020)
      {
        {
          _ptr__5016[_5019] += safe_mul( _ptr__5017[_5020],((*_5012)(_5019,_5020)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5011,_5016,_5013)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5021,    double _5022) { return mosek::fusion::p_Expr::constTerm(_5021,_5022); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5021,double _5022){
  _checked_ptr_1<int> _ptr__5021(_5021 ? _5021->raw() : nullptr, _5021 ? _5021->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5021,nullptr,_5022)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5023,    double _5024) { return mosek::fusion::p_Expr::constTerm(_5023,_5024); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5023,double _5024){
  std::vector<double> _9146;
  for (int _5025 = (int)0, _9147 = _5023; _5025 < _9147 ; ++_5025)
  {
    _9146.push_back(_5024);
  }
  auto _9148 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9146.size()),_9146.begin(),_9146.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5023)}),nullptr,_9148)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5026) { return mosek::fusion::p_Expr::constTerm(_5026); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5026){
  std::vector<double> _9149;
  for (int _5027 = (int)0, _9150 = (int)((_5026)->size(0)); _5027 < _9150 ; ++_5027)
  {
    for (int _5028 = (int)0, _9151 = (int)((_5026)->size(1)); _5028 < _9151 ; ++_5028)
    {
      _9149.push_back(((*_5026)(_5027,_5028)));
    }
  }
  auto _9152 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9149.size()),_9149.begin(),_9149.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5026)->size(0))),(int)((int)((_5026)->size(1)))}),nullptr,_9152)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5029) { return mosek::fusion::p_Expr::constTerm(_5029); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5029){
  _checked_ptr_1<double> _ptr__5029(_5029 ? _5029->raw() : nullptr, _5029 ? _5029->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5029)->size(0)))}),nullptr,_5029)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5030,    int _5031) { return mosek::fusion::p_Expr::sum(_5030,_5031); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5030,int _5031){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5031,_5030)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5032) { return mosek::fusion::p_Expr::sum(_5032); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5032){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5032))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5033) { return mosek::fusion::p_Expr::neg(_5033); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5033){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5033)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5034,monty::rc_ptr< ::mosek::fusion::Matrix > _5035,monty::rc_ptr< ::mosek::fusion::Expression > _5036){
  long long _5037 = _5035->numNonzeros();
  int _5038 = _5035->numRows();
  int _5039 = _5035->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5040 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5037)));
  _checked_ptr_1<double> _ptr__5040(_5040 ? _5040->raw() : nullptr,_5040 ? _5040->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5041 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5037)));
  _checked_ptr_1<int> _ptr__5041(_5041 ? _5041->raw() : nullptr,_5041 ? _5041->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5042 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5037)));
  _checked_ptr_1<int> _ptr__5042(_5042 ? _5042->raw() : nullptr,_5042 ? _5042->size(0) : 0);
  _5035->getDataAsTriplets(_5042,_5041,_5040);
  if (_5034)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5038,_5039,_5042,_5041,_5040,_5036)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5038,_5039,_5042,_5041,_5040,_5036)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5043,    monty::rc_ptr< ::mosek::fusion::Matrix > _5044) { return mosek::fusion::p_Expr::mulDiag(_5043,_5044); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5043,monty::rc_ptr< ::mosek::fusion::Matrix > _5044){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5044,_5043->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5045,    monty::rc_ptr< ::mosek::fusion::Variable > _5046) { return mosek::fusion::p_Expr::mulDiag(_5045,_5046); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5045,monty::rc_ptr< ::mosek::fusion::Variable > _5046){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5045,_5046->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5047,    monty::rc_ptr< ::mosek::fusion::Matrix > _5048) { return mosek::fusion::p_Expr::mulDiag(_5047,_5048); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5047,monty::rc_ptr< ::mosek::fusion::Matrix > _5048){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5048,_5047);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5049,    monty::rc_ptr< ::mosek::fusion::Expression > _5050) { return mosek::fusion::p_Expr::mulDiag(_5049,_5050); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5049,monty::rc_ptr< ::mosek::fusion::Expression > _5050){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5049,_5050);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5051,    std::shared_ptr< monty::ndarray< double,2 > > _5052) { return mosek::fusion::p_Expr::mulDiag(_5051,_5052); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5051,std::shared_ptr< monty::ndarray< double,2 > > _5052){
  std::vector<int> _9153;
  for (int _5053 = (int)0, _9154 = (int)((_5052)->size(0)); _5053 < _9154 ; ++_5053)
  {
    for (int _5054 = (int)0, _9155 = (int)((_5052)->size(1)); _5054 < _9155 ; ++_5054)
    {
      _9153.push_back(_5053);
    }
  }
  auto _9156 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9153.size()),_9153.begin(),_9153.end()));
  std::vector<int> _9157;
  for (int _5055 = (int)0, _9158 = (int)((_5052)->size(0)); _5055 < _9158 ; ++_5055)
  {
    for (int _5056 = (int)0, _9159 = (int)((_5052)->size(1)); _5056 < _9159 ; ++_5056)
    {
      _9157.push_back(_5056);
    }
  }
  auto _9160 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9157.size()),_9157.begin(),_9157.end()));
  std::vector<double> _9161;
  for (int _5057 = (int)0, _9162 = (int)((_5052)->size(0)); _5057 < _9162 ; ++_5057)
  {
    for (int _5058 = (int)0, _9163 = (int)((_5052)->size(1)); _5058 < _9163 ; ++_5058)
    {
      _9161.push_back(((*_5052)(_5057,_5058)));
    }
  }
  auto _9164 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9161.size()),_9161.begin(),_9161.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5052)->size(0)),(int)((_5052)->size(1)),_9156,_9160,_9164,_5051->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5059,    std::shared_ptr< monty::ndarray< double,2 > > _5060) { return mosek::fusion::p_Expr::mulDiag(_5059,_5060); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5059,std::shared_ptr< monty::ndarray< double,2 > > _5060){
  std::vector<int> _9165;
  for (int _5061 = (int)0, _9166 = (int)((_5060)->size(0)); _5061 < _9166 ; ++_5061)
  {
    for (int _5062 = (int)0, _9167 = (int)((_5060)->size(1)); _5062 < _9167 ; ++_5062)
    {
      _9165.push_back(_5061);
    }
  }
  auto _9168 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9165.size()),_9165.begin(),_9165.end()));
  std::vector<int> _9169;
  for (int _5063 = (int)0, _9170 = (int)((_5060)->size(0)); _5063 < _9170 ; ++_5063)
  {
    for (int _5064 = (int)0, _9171 = (int)((_5060)->size(1)); _5064 < _9171 ; ++_5064)
    {
      _9169.push_back(_5064);
    }
  }
  auto _9172 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9169.size()),_9169.begin(),_9169.end()));
  std::vector<double> _9173;
  for (int _5065 = (int)0, _9174 = (int)((_5060)->size(0)); _5065 < _9174 ; ++_5065)
  {
    for (int _5066 = (int)0, _9175 = (int)((_5060)->size(1)); _5066 < _9175 ; ++_5066)
    {
      _9173.push_back(((*_5060)(_5065,_5066)));
    }
  }
  auto _9176 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9173.size()),_9173.begin(),_9173.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5060)->size(0)),(int)((_5060)->size(1)),_9168,_9172,_9176,_5059)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5067,    monty::rc_ptr< ::mosek::fusion::Variable > _5068) { return mosek::fusion::p_Expr::mulDiag(_5067,_5068); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5067,monty::rc_ptr< ::mosek::fusion::Variable > _5068){
  std::vector<int> _9177;
  for (int _5069 = (int)0, _9178 = (int)((_5067)->size(0)); _5069 < _9178 ; ++_5069)
  {
    for (int _5070 = (int)0, _9179 = (int)((_5067)->size(1)); _5070 < _9179 ; ++_5070)
    {
      _9177.push_back(_5069);
    }
  }
  auto _9180 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9177.size()),_9177.begin(),_9177.end()));
  std::vector<int> _9181;
  for (int _5071 = (int)0, _9182 = (int)((_5067)->size(0)); _5071 < _9182 ; ++_5071)
  {
    for (int _5072 = (int)0, _9183 = (int)((_5067)->size(1)); _5072 < _9183 ; ++_5072)
    {
      _9181.push_back(_5072);
    }
  }
  auto _9184 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9181.size()),_9181.begin(),_9181.end()));
  std::vector<double> _9185;
  for (int _5073 = (int)0, _9186 = (int)((_5067)->size(0)); _5073 < _9186 ; ++_5073)
  {
    for (int _5074 = (int)0, _9187 = (int)((_5067)->size(1)); _5074 < _9187 ; ++_5074)
    {
      _9185.push_back(((*_5067)(_5073,_5074)));
    }
  }
  auto _9188 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9185.size()),_9185.begin(),_9185.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5067)->size(0)),(int)((_5067)->size(1)),_9180,_9184,_9188,_5068->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5075,    monty::rc_ptr< ::mosek::fusion::Expression > _5076) { return mosek::fusion::p_Expr::mulDiag(_5075,_5076); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5075,monty::rc_ptr< ::mosek::fusion::Expression > _5076){
  std::vector<int> _9189;
  for (int _5077 = (int)0, _9190 = (int)((_5075)->size(0)); _5077 < _9190 ; ++_5077)
  {
    for (int _5078 = (int)0, _9191 = (int)((_5075)->size(1)); _5078 < _9191 ; ++_5078)
    {
      _9189.push_back(_5077);
    }
  }
  auto _9192 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9189.size()),_9189.begin(),_9189.end()));
  std::vector<int> _9193;
  for (int _5079 = (int)0, _9194 = (int)((_5075)->size(0)); _5079 < _9194 ; ++_5079)
  {
    for (int _5080 = (int)0, _9195 = (int)((_5075)->size(1)); _5080 < _9195 ; ++_5080)
    {
      _9193.push_back(_5080);
    }
  }
  auto _9196 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9193.size()),_9193.begin(),_9193.end()));
  std::vector<double> _9197;
  for (int _5081 = (int)0, _9198 = (int)((_5075)->size(0)); _5081 < _9198 ; ++_5081)
  {
    for (int _5082 = (int)0, _9199 = (int)((_5075)->size(1)); _5082 < _9199 ; ++_5082)
    {
      _9197.push_back(((*_5075)(_5081,_5082)));
    }
  }
  auto _9200 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9197.size()),_9197.begin(),_9197.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5075)->size(0)),(int)((_5075)->size(1)),_9192,_9196,_9200,_5076)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5083,monty::rc_ptr< ::mosek::fusion::Expression > _5084){
  std::shared_ptr< monty::ndarray< int,1 > > _5085 = _5084->getShape();
  _checked_ptr_1<int> _ptr__5085(_5085 ? _5085->raw() : nullptr,_5085 ? _5085->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5086 = _5084;
  if (((int)((_5085)->size(0)) == (int)1))
  {
    {
      _5085 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5085[(int)0]),(int)((int)1)});
      _ptr__5085.update(_5085 ? _5085->raw() : nullptr, _5085 ? _5085->size(0) : 0);
      _5086 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5085,_5084)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5085)->size(0)) != (int)2) || ((_5083->numRows() != _ptr__5085[(int)0]) || (_5083->numColumns() != _ptr__5085[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5087 = _5083->numColumns();
  long long _5088 = _5083->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5089 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5088)));
  _checked_ptr_1<int> _ptr__5089(_5089 ? _5089->raw() : nullptr,_5089 ? _5089->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5090 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5088)));
  _checked_ptr_1<int> _ptr__5090(_5090 ? _5090->raw() : nullptr,_5090 ? _5090->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5091 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5088)));
  _checked_ptr_1<double> _ptr__5091(_5091 ? _5091->raw() : nullptr,_5091 ? _5091->size(0) : 0);
  _5083->getDataAsTriplets(_5089,_5090,_5091);
  std::vector<long long> _9201;
  for (long long _5092 = (int)0, _9202 = _5088; _5092 < _9202 ; ++_5092)
  {
    _9201.push_back(safe_add( safe_mul( _ptr__5089[_5092],_5087 ),_ptr__5090[_5092] ));
  }
  auto _9203 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9201.size()),_9201.begin(),_9201.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5091,_9203,_5086,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5093,monty::rc_ptr< ::mosek::fusion::Expression > _5094){
  _checked_ptr_1<double> _ptr__5093(_5093 ? _5093->raw() : nullptr, _5093 ? _5093->size(0) : 0);
  if (((NULL == _5093.get()) || (NULL == _5094.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5094->getND() == (int)0) && ((int)((_5093)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5093[(int)0],_5094)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5094->getND() != (int)1) || (_5094->getDim((int)0) != (int)((_5093)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9204;
      for (int _5095 = (int)0, _9205 = (int)((_5093)->size(0)); _5095 < _9205 ; ++_5095)
      {
        _9204.push_back(_5095);
      }
      auto _9206 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9204.size()),_9204.begin(),_9204.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5093,_9206,_5094)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5096,monty::rc_ptr< ::mosek::fusion::Expression > _5097){
  if (((NULL == _5096.get()) || (NULL == _5097.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5098 = _5097->getShape();
  _checked_ptr_1<int> _ptr__5098(_5098 ? _5098->raw() : nullptr,_5098 ? _5098->size(0) : 0);
  if (((int)((_5098)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5096)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9207 = (int)0;
  int _9208 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5096)->dims)->size(0));
  for (int _5099 = _9207; _5099 < _9208; ++_5099)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5096)->dims)(_5099)) != _ptr__5098[_5099]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5096)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5096)->inst,_5097)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5100,    double _5101) { return mosek::fusion::p_Expr::mul(_5100,_5101); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5100,double _5101){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5101,_5100)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5102,    monty::rc_ptr< ::mosek::fusion::Expression > _5103) { return mosek::fusion::p_Expr::mul(_5102,_5103); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5102,monty::rc_ptr< ::mosek::fusion::Expression > _5103){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5102,_5103)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5104,    std::shared_ptr< monty::ndarray< double,1 > > _5105) { return mosek::fusion::p_Expr::mul(_5104,_5105); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5104,std::shared_ptr< monty::ndarray< double,1 > > _5105){
  _checked_ptr_1<double> _ptr__5105(_5105 ? _5105->raw() : nullptr, _5105 ? _5105->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5105,_5104);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5106,    monty::rc_ptr< ::mosek::fusion::Expression > _5107) { return mosek::fusion::p_Expr::mul(_5106,_5107); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5106,monty::rc_ptr< ::mosek::fusion::Expression > _5107){
  _checked_ptr_1<double> _ptr__5106(_5106 ? _5106->raw() : nullptr, _5106 ? _5106->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5106,_5107);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5108,    std::shared_ptr< monty::ndarray< double,2 > > _5109) { return mosek::fusion::p_Expr::mul(_5108,_5109); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5108,std::shared_ptr< monty::ndarray< double,2 > > _5109){
  return ::mosek::fusion::p_Expr::mul(false,_5109,_5108);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5110,    monty::rc_ptr< ::mosek::fusion::Expression > _5111) { return mosek::fusion::p_Expr::mul(_5110,_5111); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5110,monty::rc_ptr< ::mosek::fusion::Expression > _5111){
  return ::mosek::fusion::p_Expr::mul(true,_5110,_5111);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5112,    monty::rc_ptr< ::mosek::fusion::Matrix > _5113) { return mosek::fusion::p_Expr::mul(_5112,_5113); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5112,monty::rc_ptr< ::mosek::fusion::Matrix > _5113){
  return ::mosek::fusion::p_Expr::mul(false,_5113,_5112);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5114,    monty::rc_ptr< ::mosek::fusion::Expression > _5115) { return mosek::fusion::p_Expr::mul(_5114,_5115); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5114,monty::rc_ptr< ::mosek::fusion::Expression > _5115){
  return ::mosek::fusion::p_Expr::mul(true,_5114,_5115);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5116,std::shared_ptr< monty::ndarray< double,1 > > _5117,monty::rc_ptr< ::mosek::fusion::Expression > _5118){
  _checked_ptr_1<double> _ptr__5117(_5117 ? _5117->raw() : nullptr, _5117 ? _5117->size(0) : 0);
  int _5119 = (int)((_5117)->size(0));
  int _5120 = _5119;
  std::shared_ptr< monty::ndarray< double,1 > > _5121 = ::mosek::fusion::Utils::Tools::arraycopy(_5117);
  _checked_ptr_1<double> _ptr__5121(_5121 ? _5121->raw() : nullptr,_5121 ? _5121->size(0) : 0);
  int _5122 = _5118->getND();
  if ((_5122 == (int)0))
  {
    {
      std::vector<int> _9209;
      for (int _5123 = (int)0, _9210 = _5119; _5123 < _9210 ; ++_5123)
      {
        _9209.push_back(_5123);
      }
      auto _9211 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9209.size()),_9209.begin(),_9209.end()));
      std::vector<int> _9212;
      for (int _5124 = (int)0, _9213 = _5119; _5124 < _9213 ; ++_5124)
      {
        _9212.push_back((int)0);
      }
      auto _9214 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9212.size()),_9212.begin(),_9212.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5119)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5119,(int)1,_9211,_9214,_5121,_5118,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5122 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5116 && (_5118->getDim((int)0) == (int)((_5117)->size(0)))))
  {
    {
      std::vector<int> _9215;
      for (int _5125 = (int)0, _9216 = _5119; _5125 < _9216 ; ++_5125)
      {
        _9215.push_back((int)0);
      }
      auto _9217 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9215.size()),_9215.begin(),_9215.end()));
      std::vector<int> _9218;
      for (int _5126 = (int)0, _9219 = _5119; _5126 < _9219 ; ++_5126)
      {
        _9218.push_back(_5126);
      }
      auto _9220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9218.size()),_9218.begin(),_9218.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5118->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5119,_9217,_9220,_5121,_5118)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5116 && (_5118->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9221;
      for (int _5127 = (int)0, _9222 = _5119; _5127 < _9222 ; ++_5127)
      {
        _9221.push_back(_5127);
      }
      auto _9223 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9221.size()),_9221.begin(),_9221.end()));
      std::vector<int> _9224;
      for (int _5128 = (int)0, _9225 = _5119; _5128 < _9225 ; ++_5128)
      {
        _9224.push_back((int)0);
      }
      auto _9226 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9224.size()),_9224.begin(),_9224.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5119,(int)1,_9223,_9226,_5121,_5118,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5116) && (_5118->getDim((int)1) == _5119)))
  {
    {
      std::vector<int> _9227;
      for (int _5129 = (int)0, _9228 = _5119; _5129 < _9228 ; ++_5129)
      {
        _9227.push_back(_5129);
      }
      auto _9229 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9227.size()),_9227.begin(),_9227.end()));
      std::vector<int> _9230;
      for (int _5130 = (int)0, _9231 = _5119; _5130 < _9231 ; ++_5130)
      {
        _9230.push_back((int)0);
      }
      auto _9232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9230.size()),_9230.begin(),_9230.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5118->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5119,(int)1,_9229,_9232,_5121,_5118)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5116) && (_5118->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9233;
      for (int _5131 = (int)0, _9234 = _5119; _5131 < _9234 ; ++_5131)
      {
        _9233.push_back((int)0);
      }
      auto _9235 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9233.size()),_9233.begin(),_9233.end()));
      std::vector<int> _9236;
      for (int _5132 = (int)0, _9237 = _5119; _5132 < _9237 ; ++_5132)
      {
        _9236.push_back(_5132);
      }
      auto _9238 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9236.size()),_9236.begin(),_9236.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5119,_9235,_9238,_5121,_5118,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5133,std::shared_ptr< monty::ndarray< double,2 > > _5134,monty::rc_ptr< ::mosek::fusion::Expression > _5135){
  int _5136 = (int)((_5134)->size(0));
  int _5137 = (int)((_5134)->size(1));
  int _5138 = safe_mul( _5136,_5137 );
  std::vector<int> _9239;
  for (int _5140 = (int)0, _9240 = _5136; _5140 < _9240 ; ++_5140)
  {
    for (int _5141 = (int)0, _9241 = _5137; _5141 < _9241 ; ++_5141)
    {
      _9239.push_back(_5140);
    }
  }
  auto _9242 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9239.size()),_9239.begin(),_9239.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5139 = _9242;
  _checked_ptr_1<int> _ptr__5139(_5139 ? _5139->raw() : nullptr,_5139 ? _5139->size(0) : 0);
  std::vector<int> _9243;
  for (int _5143 = (int)0, _9244 = _5136; _5143 < _9244 ; ++_5143)
  {
    for (int _5144 = (int)0, _9245 = _5137; _5144 < _9245 ; ++_5144)
    {
      _9243.push_back(_5144);
    }
  }
  auto _9246 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9243.size()),_9243.begin(),_9243.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5142 = _9246;
  _checked_ptr_1<int> _ptr__5142(_5142 ? _5142->raw() : nullptr,_5142 ? _5142->size(0) : 0);
  std::vector<double> _9247;
  for (int _5146 = (int)0, _9248 = _5136; _5146 < _9248 ; ++_5146)
  {
    for (int _5147 = (int)0, _9249 = _5137; _5147 < _9249 ; ++_5147)
    {
      _9247.push_back(((*_5134)(_5146,_5147)));
    }
  }
  auto _9250 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9247.size()),_9247.begin(),_9247.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5145 = _9250;
  _checked_ptr_1<double> _ptr__5145(_5145 ? _5145->raw() : nullptr,_5145 ? _5145->size(0) : 0);
  long long _5148 = _5135->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5149 = _5135->getShape();
  _checked_ptr_1<int> _ptr__5149(_5149 ? _5149->raw() : nullptr,_5149 ? _5149->size(0) : 0);
  if (((int)((_5149)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5136,_5137,_5139,_5142,_5145,_5135,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5133)
  {
    {
      if (((int)((_5149)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5134)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5136,_5137,_5139,_5142,_5145,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5149[(int)0]),(int)((int)1)}),_5135)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5149)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5136,_5137,_5139,_5142,_5145,_5135)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5149)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5134)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5136,_5137,_5139,_5142,_5145,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5149[(int)0])}),_5135)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5149)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((_5136 - (int)1),_5137,_5139,_5142,_5145,_5135)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5150,monty::rc_ptr< ::mosek::fusion::Matrix > _5151,monty::rc_ptr< ::mosek::fusion::Expression > _5152){
  long long _5153 = _5151->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5153)));
  _checked_ptr_1<int> _ptr__5154(_5154 ? _5154->raw() : nullptr,_5154 ? _5154->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5155 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5153)));
  _checked_ptr_1<int> _ptr__5155(_5155 ? _5155->raw() : nullptr,_5155 ? _5155->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5156 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5153)));
  _checked_ptr_1<double> _ptr__5156(_5156 ? _5156->raw() : nullptr,_5156 ? _5156->size(0) : 0);
  int _5157 = _5151->numRows();
  int _5158 = _5151->numColumns();
  _5151->getDataAsTriplets(_5154,_5155,_5156);
  int _5159 = _5152->getND();
  if ((_5159 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5157,_5158,_5154,_5155,_5156,_5152)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5159 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5160 = _5152->getShape();
      _checked_ptr_1<int> _ptr__5160(_5160 ? _5160->raw() : nullptr,_5160 ? _5160->size(0) : 0);
      if (_5150)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5157)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5157,_5158,_5154,_5155,_5156,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5160[(int)0]),(int)((int)1)}),_5152)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5158)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5157,_5158,_5154,_5155,_5156,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5160[(int)0])}),_5152)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5159 == (int)2))
  {
    {
      if (_5150)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5157,_5158,_5154,_5155,_5156,_5152)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5157,_5158,_5154,_5155,_5156,_5152)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5161,    monty::rc_ptr< ::mosek::fusion::Matrix > _5162) { return mosek::fusion::p_Expr::mul(_5161,_5162); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5161,monty::rc_ptr< ::mosek::fusion::Matrix > _5162){
  int _5163 = _5162->numRows();
  int _5164 = _5162->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5165 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5162->numNonzeros())));
  _checked_ptr_1<double> _ptr__5165(_5165 ? _5165->raw() : nullptr,_5165 ? _5165->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5166 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5162->numNonzeros())));
  _checked_ptr_1<int> _ptr__5166(_5166 ? _5166->raw() : nullptr,_5166 ? _5166->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5167 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5162->numNonzeros())));
  _checked_ptr_1<int> _ptr__5167(_5167 ? _5167->raw() : nullptr,_5167 ? _5167->size(0) : 0);
  _5162->getDataAsTriplets(_5167,_5166,_5165);
  return ::mosek::fusion::p_Expr::mul(false,_5163,_5164,_5167,_5166,_5165,_5161);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5168,    monty::rc_ptr< ::mosek::fusion::Variable > _5169) { return mosek::fusion::p_Expr::mul(_5168,_5169); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5168,monty::rc_ptr< ::mosek::fusion::Variable > _5169){
  int _5170 = _5168->numRows();
  int _5171 = _5168->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5172 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5168->numNonzeros())));
  _checked_ptr_1<double> _ptr__5172(_5172 ? _5172->raw() : nullptr,_5172 ? _5172->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5168->numNonzeros())));
  _checked_ptr_1<int> _ptr__5173(_5173 ? _5173->raw() : nullptr,_5173 ? _5173->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5174 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5168->numNonzeros())));
  _checked_ptr_1<int> _ptr__5174(_5174 ? _5174->raw() : nullptr,_5174 ? _5174->size(0) : 0);
  _5168->getDataAsTriplets(_5174,_5173,_5172);
  return ::mosek::fusion::p_Expr::mul(true,_5170,_5171,_5174,_5173,_5172,_5169);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5175,int _5176,int _5177,std::shared_ptr< monty::ndarray< int,1 > > _5178,std::shared_ptr< monty::ndarray< int,1 > > _5179,std::shared_ptr< monty::ndarray< double,1 > > _5180,monty::rc_ptr< ::mosek::fusion::Variable > _5181){
  _checked_ptr_1<int> _ptr__5178(_5178 ? _5178->raw() : nullptr, _5178 ? _5178->size(0) : 0);
  _checked_ptr_1<int> _ptr__5179(_5179 ? _5179->raw() : nullptr, _5179 ? _5179->size(0) : 0);
  _checked_ptr_1<double> _ptr__5180(_5180 ? _5180->raw() : nullptr, _5180 ? _5180->size(0) : 0);
  if ((_5181->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5176,_5177,_5178,_5179,_5180,_5181)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5181->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5182 = _5181->getShape();
      _checked_ptr_1<int> _ptr__5182(_5182 ? _5182->raw() : nullptr,_5182 ? _5182->size(0) : 0);
      int _9251;
      bool _9252 = _5175;
      if (_9252)
      {
        _9251 = _5176;
      }
      else
      {
        _9251 = _5177;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9253;
      bool _9254 = _5175;
      if (_9254)
      {
        _9253 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5182[(int)0]),(int)((int)1)});
      }
      else
      {
        _9253 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5182[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9251)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5175,_5176,_5177,_5178,_5179,_5180,::mosek::fusion::p_Var::reshape(_5181,_9253))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5175,_5176,_5177,_5178,_5179,_5180,_5181)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5183,    monty::rc_ptr< ::mosek::fusion::Matrix > _5184) { return mosek::fusion::p_Expr::dot(_5183,_5184); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5183,monty::rc_ptr< ::mosek::fusion::Matrix > _5184){
  long long _5185 = _5184->numNonzeros();
  if ((!_5184->isSparse()))
  {
    {
      std::vector<long long> _9255;
      for (long long _5186 = (int)0, _9256 = _5185; _5186 < _9256 ; ++_5186)
      {
        _9255.push_back(_5186);
      }
      auto _9257 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9255.size()),_9255.begin(),_9255.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5183,_9257,_5184->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5187 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5185)));
      _checked_ptr_1<int> _ptr__5187(_5187 ? _5187->raw() : nullptr,_5187 ? _5187->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5188 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5185)));
      _checked_ptr_1<int> _ptr__5188(_5188 ? _5188->raw() : nullptr,_5188 ? _5188->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5189 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5185)));
      _checked_ptr_1<double> _ptr__5189(_5189 ? _5189->raw() : nullptr,_5189 ? _5189->size(0) : 0);
      int _5190 = _5184->numColumns();
      _5184->getDataAsTriplets(_5187,_5188,_5189);
      std::vector<long long> _9258;
      for (int _5191 = (int)0, _9259 = (int)((_5187)->size(0)); _5191 < _9259 ; ++_5191)
      {
        _9258.push_back(safe_add( safe_mul( _ptr__5187[_5191],_5190 ),_ptr__5188[_5191] ));
      }
      auto _9260 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9258.size()),_9258.begin(),_9258.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5183,_9260,_5189)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5192,    std::shared_ptr< monty::ndarray< double,2 > > _5193) { return mosek::fusion::p_Expr::dot(_5192,_5193); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5192,std::shared_ptr< monty::ndarray< double,2 > > _5193){
  std::vector<long long> _9261;
  for (int _5194 = (int)0, _9262 = safe_mul( (int)((_5193)->size(0)),(int)((_5193)->size(1)) ); _5194 < _9262 ; ++_5194)
  {
    _9261.push_back(_5194);
  }
  auto _9263 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9261.size()),_9261.begin(),_9261.end()));
  std::vector<double> _9264;
  for (int _5195 = (int)0, _9265 = (int)((_5193)->size(0)); _5195 < _9265 ; ++_5195)
  {
    for (int _5196 = (int)0, _9266 = (int)((_5193)->size(1)); _5196 < _9266 ; ++_5196)
    {
      _9264.push_back(((*_5193)(_5195,_5196)));
    }
  }
  auto _9267 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9264.size()),_9264.begin(),_9264.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5192,_9263,_9267)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5197,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5198) { return mosek::fusion::p_Expr::dot(_5197,_5198); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5197,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5198){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5197,mosek::fusion::p_NDSparseArray::_get_impl(_5198)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5198)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5199,    std::shared_ptr< monty::ndarray< double,1 > > _5200) { return mosek::fusion::p_Expr::dot(_5199,_5200); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5199,std::shared_ptr< monty::ndarray< double,1 > > _5200){
  _checked_ptr_1<double> _ptr__5200(_5200 ? _5200->raw() : nullptr, _5200 ? _5200->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5201 = _5199->getShape();
  _checked_ptr_1<int> _ptr__5201(_5201 ? _5201->raw() : nullptr,_5201 ? _5201->size(0) : 0);
  if (((_5199->getSize() == (int)((_5200)->size(0))) && ((int)((_5201)->size(0)) > (int)1)))
  {
    {
      int _5202 = (int)0;
      int _9268 = (int)0;
      int _9269 = (int)((_5201)->size(0));
      for (int _5203 = _9268; _5203 < _9269; ++_5203)
      {
        {
          if ((_ptr__5201[_5203] > (int)1))
          {
            {
              ++ _5202;
            }
          }
          {}
        }
      }
      if ((_5202 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5199->getSize())});
          _checked_ptr_1<int> _ptr__5204(_5204 ? _5204->raw() : nullptr,_5204 ? _5204->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5204,_5199)).as<::mosek::fusion::Expression>(),_5200)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5199,_5200)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5205,    monty::rc_ptr< ::mosek::fusion::Expression > _5206) { return mosek::fusion::p_Expr::dot(_5205,_5206); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5205,monty::rc_ptr< ::mosek::fusion::Expression > _5206){
  return ::mosek::fusion::p_Expr::dot(_5206,_5205);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5207,    monty::rc_ptr< ::mosek::fusion::Expression > _5208) { return mosek::fusion::p_Expr::dot(_5207,_5208); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5207,monty::rc_ptr< ::mosek::fusion::Expression > _5208){
  return ::mosek::fusion::p_Expr::dot(_5208,_5207);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5209,    monty::rc_ptr< ::mosek::fusion::Expression > _5210) { return mosek::fusion::p_Expr::dot(_5209,_5210); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5209,monty::rc_ptr< ::mosek::fusion::Expression > _5210){
  return ::mosek::fusion::p_Expr::dot(_5210,_5209);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5211,    monty::rc_ptr< ::mosek::fusion::Expression > _5212) { return mosek::fusion::p_Expr::dot(_5211,_5212); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5211,monty::rc_ptr< ::mosek::fusion::Expression > _5212){
  _checked_ptr_1<double> _ptr__5211(_5211 ? _5211->raw() : nullptr, _5211 ? _5211->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5212,_5211);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5213,    monty::rc_ptr< ::mosek::fusion::Expression > _5214) { return mosek::fusion::p_Expr::outer(_5213,_5214); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5213,monty::rc_ptr< ::mosek::fusion::Expression > _5214){
  _checked_ptr_1<double> _ptr__5213(_5213 ? _5213->raw() : nullptr, _5213 ? _5213->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5215 = _5214->getShape();
  _checked_ptr_1<int> _ptr__5215(_5215 ? _5215->raw() : nullptr,_5215 ? _5215->size(0) : 0);
  if (((int)((_5215)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5215[(int)0] != (int)((_5213)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5216 = _5214->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9270;
  for (int _5217 = (int)0, _9271 = (int)((_5213)->size(0)); _5217 < _9271 ; ++_5217)
  {
    _9270.push_back(_5217);
  }
  auto _9272 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9270.size()),_9270.begin(),_9270.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5216)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5216)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5216)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5216)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5216)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5216)->inst,_5213,_9272,(int)((_5213)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5218,    std::shared_ptr< monty::ndarray< double,1 > > _5219) { return mosek::fusion::p_Expr::outer(_5218,_5219); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5218,std::shared_ptr< monty::ndarray< double,1 > > _5219){
  _checked_ptr_1<double> _ptr__5219(_5219 ? _5219->raw() : nullptr, _5219 ? _5219->size(0) : 0);
  if (((_5218->getND() != (int)1) || (_5218->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5220 = _5218->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9273;
  for (int _5221 = (int)0, _9274 = (int)((_5219)->size(0)); _5221 < _9274 ; ++_5221)
  {
    _9273.push_back(_5221);
  }
  auto _9275 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9273.size()),_9273.begin(),_9273.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5220)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5220)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5220)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5220)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5220)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5220)->inst,_5219,_9275,(int)((_5219)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5222,    monty::rc_ptr< ::mosek::fusion::Variable > _5223) { return mosek::fusion::p_Expr::outer(_5222,_5223); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5222,monty::rc_ptr< ::mosek::fusion::Variable > _5223){
  std::shared_ptr< monty::ndarray< int,1 > > _5224 = _5223->getShape();
  _checked_ptr_1<int> _ptr__5224(_5224 ? _5224->raw() : nullptr,_5224 ? _5224->size(0) : 0);
  if ((!(((int)((_5224)->size(0)) == (int)1) || (((int)((_5224)->size(0)) == (int)2) && (_ptr__5224[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5222)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9276 = _5222;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9276.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5225 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9276.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5223,_ptr__5224[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5225)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5225)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5226 = _9276;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5227 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5226->numNonzeros())));
      _checked_ptr_1<double> _ptr__5227(_5227 ? _5227->raw() : nullptr,_5227 ? _5227->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5228 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5226->numNonzeros())));
      _checked_ptr_1<int> _ptr__5228(_5228 ? _5228->raw() : nullptr,_5228 ? _5228->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5229 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5226->numNonzeros())));
      _checked_ptr_1<int> _ptr__5229(_5229 ? _5229->raw() : nullptr,_5229 ? _5229->size(0) : 0);
      _5226->getDataAsTriplets(_5229,_5228,_5227);
      return ::mosek::fusion::p_Expr::outer_(_5223,_ptr__5224[(int)0],_5227,_5229,mosek::fusion::p_Matrix::_get_impl(_5226)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5230,    monty::rc_ptr< ::mosek::fusion::Matrix > _5231) { return mosek::fusion::p_Expr::outer(_5230,_5231); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5230,monty::rc_ptr< ::mosek::fusion::Matrix > _5231){
  std::shared_ptr< monty::ndarray< int,1 > > _5232 = _5230->getShape();
  _checked_ptr_1<int> _ptr__5232(_5232 ? _5232->raw() : nullptr,_5232 ? _5232->size(0) : 0);
  if ((!((_5230->getND() == (int)1) || ((_5230->getND() == (int)2) && (_ptr__5232[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5231)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9277 = _5231;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9277.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5233 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9277.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5230,_ptr__5232[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5233)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5233)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5234 = _9277;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5235 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5234->numNonzeros())));
      _checked_ptr_1<double> _ptr__5235(_5235 ? _5235->raw() : nullptr,_5235 ? _5235->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5236 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5234->numNonzeros())));
      _checked_ptr_1<int> _ptr__5236(_5236 ? _5236->raw() : nullptr,_5236 ? _5236->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5237 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5231->numNonzeros())));
      _checked_ptr_1<int> _ptr__5237(_5237 ? _5237->raw() : nullptr,_5237 ? _5237->size(0) : 0);
      _5234->getDataAsTriplets(_5237,_5236,_5235);
      return ::mosek::fusion::p_Expr::outer_(_5230,((*_5230->getShape())((int)0)),_5235,_5237,mosek::fusion::p_Matrix::_get_impl(_5234)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5238,    monty::rc_ptr< ::mosek::fusion::Variable > _5239) { return mosek::fusion::p_Expr::outer(_5238,_5239); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5238,monty::rc_ptr< ::mosek::fusion::Variable > _5239){
  _checked_ptr_1<double> _ptr__5238(_5238 ? _5238->raw() : nullptr, _5238 ? _5238->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5240 = _5239->getShape();
  _checked_ptr_1<int> _ptr__5240(_5240 ? _5240->raw() : nullptr,_5240 ? _5240->size(0) : 0);
  if ((!((_5239->getND() == (int)1) || ((_5239->getND() == (int)2) && (_ptr__5240[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5239,_ptr__5240[(int)0],_5238,nullptr,(int)((_5238)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5241,    std::shared_ptr< monty::ndarray< double,1 > > _5242) { return mosek::fusion::p_Expr::outer(_5241,_5242); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5241,std::shared_ptr< monty::ndarray< double,1 > > _5242){
  _checked_ptr_1<double> _ptr__5242(_5242 ? _5242->raw() : nullptr, _5242 ? _5242->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5243 = _5241->getShape();
  _checked_ptr_1<int> _ptr__5243(_5243 ? _5243->raw() : nullptr,_5243 ? _5243->size(0) : 0);
  if ((!((_5241->getND() == (int)1) || ((_5241->getND() == (int)2) && (_ptr__5243[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5241,_ptr__5243[(int)0],_5242,nullptr,(int)((_5242)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5244,std::shared_ptr< monty::ndarray< long long,1 > > _5245,std::shared_ptr< monty::ndarray< long long,1 > > _5246,std::shared_ptr< monty::ndarray< double,1 > > _5247,std::shared_ptr< monty::ndarray< double,1 > > _5248,std::shared_ptr< monty::ndarray< long long,1 > > _5249,std::shared_ptr< monty::ndarray< double,1 > > _5250,std::shared_ptr< monty::ndarray< int,1 > > _5251,int _5252,bool _5253){
  _checked_ptr_1<long long> _ptr__5245(_5245 ? _5245->raw() : nullptr, _5245 ? _5245->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5246(_5246 ? _5246->raw() : nullptr, _5246 ? _5246->size(0) : 0);
  _checked_ptr_1<double> _ptr__5247(_5247 ? _5247->raw() : nullptr, _5247 ? _5247->size(0) : 0);
  _checked_ptr_1<double> _ptr__5248(_5248 ? _5248->raw() : nullptr, _5248 ? _5248->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5249(_5249 ? _5249->raw() : nullptr, _5249 ? _5249->size(0) : 0);
  _checked_ptr_1<double> _ptr__5250(_5250 ? _5250->raw() : nullptr, _5250 ? _5250->size(0) : 0);
  _checked_ptr_1<int> _ptr__5251(_5251 ? _5251->raw() : nullptr, _5251 ? _5251->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9278;
  bool _9279 = (!_5253);
  if (_9279)
  {
    _9278 = ::mosek::fusion::p_Set::make(_5244,_5252);
  }
  else
  {
    _9278 = ::mosek::fusion::p_Set::make(_5252,_5244);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5254 = _9278;
  _checked_ptr_1<int> _ptr__5254(_5254 ? _5254->raw() : nullptr,_5254 ? _5254->size(0) : 0);
  int _5255 = safe_mul( (int)((_5250)->size(0)),(int)((_5249)->size(0)) );
  int _5256 = safe_mul( (int)((_5250)->size(0)),(int)((_5246)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5257 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5255)));
  _checked_ptr_1<long long> _ptr__5257(_5257 ? _5257->raw() : nullptr,_5257 ? _5257->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9280;
  bool _9281 = (NULL != _5248.get());
  if (_9281)
  {
    _9280 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5255)));
  }
  else
  {
    _9280 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5258 = _9280;
  _checked_ptr_1<double> _ptr__5258(_5258 ? _5258->raw() : nullptr,_5258 ? _5258->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5259 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5256)));
  _checked_ptr_1<double> _ptr__5259(_5259 ? _5259->raw() : nullptr,_5259 ? _5259->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5260 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5256)));
  _checked_ptr_1<long long> _ptr__5260(_5260 ? _5260->raw() : nullptr,_5260 ? _5260->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5261 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5255,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5261(_5261 ? _5261->raw() : nullptr,_5261 ? _5261->size(0) : 0);
  int _5262 = (int)_ptr__5261[((int)((_5261)->size(0)) - (int)1)];
  if ((!_5253))
  {
    {
      long long _5263 = (long long)0;
      long long _5264 = (long long)0;
      int _9282 = (int)0;
      int _9283 = (int)((_5249)->size(0));
      for (int _5265 = _9282; _5265 < _9283; ++_5265)
      {
        {
          long long _5266 = (_ptr__5245[safe_add( _5265,(int)1 )] - _ptr__5245[_5265]);
          int _9284 = (int)0;
          int _9285 = (int)((_5250)->size(0));
          for (int _5267 = _9284; _5267 < _9285; ++_5267)
          {
            {
              _ptr__5249[_5263] = safe_add( safe_mul( _ptr__5249[_5265],_5252 ),_ptr__5251[_5267] );
              _ptr__5261[safe_add( _5263,(int)1 )] = safe_add( _ptr__5261[_5263],_5266 );
              ++ _5263;
              long long _9286 = _ptr__5245[_5265];
              long long _9287 = _ptr__5245[safe_add( _5265,(int)1 )];
              for (long long _5268 = _9286; _5268 < _9287; ++_5268)
              {
                {
                  _ptr__5260[_5264] = _ptr__5246[_5268];
                  _ptr__5259[_5264] = (_ptr__5247[_5268] * _ptr__5250[_5267]);
                  ++ _5264;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5258.get()))
      {
        {
          int _5269 = (int)0;
          int _9288 = (int)0;
          int _9289 = (int)((_5249)->size(0));
          for (int _5270 = _9288; _5270 < _9289; ++_5270)
          {
            {
              int _9290 = (int)0;
              int _9291 = (int)((_5250)->size(0));
              for (int _5271 = _9290; _5271 < _9291; ++_5271)
              {
                {
                  _ptr__5258[_5269] = (_ptr__5250[_5271] * _ptr__5248[_5270]);
                  ++ _5269;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5272 = (long long)0;
      long long _5273 = (long long)0;
      int _9292 = (int)0;
      int _9293 = (int)((_5250)->size(0));
      for (int _5274 = _9292; _5274 < _9293; ++_5274)
      {
        {
          double _5275 = _ptr__5250[_5274];
          ::mosek::fusion::Utils::Tools::arraycopy(_5246,(long long)((int)0),_5260,_5273,(long long)(_5262));
          int _9294 = (int)0;
          int _9295 = _5262;
          for (int _5276 = _9294; _5276 < _9295; ++_5276)
          {
            {
              _ptr__5259[safe_add( _5273,_5276 )] = (_ptr__5247[_5276] * _ptr__5250[_5274]);
            }
          }
          int _9296 = (int)0;
          int _9297 = (int)((_5249)->size(0));
          for (int _5277 = _9296; _5277 < _9297; ++_5277)
          {
            {
              long long _5278 = (_ptr__5245[safe_add( _5277,(int)1 )] - _ptr__5245[_5277]);
              _ptr__5249[_5272] = safe_add( safe_mul( _ptr__5249[_5277],_5252 ),_ptr__5251[_5274] );
              _ptr__5261[safe_add( _5272,(int)1 )] = safe_add( _ptr__5261[_5272],_5278 );
              ++ _5272;
            }
          }
          _5273 += _5262;
        }
      }
      if ((NULL != _5258.get()))
      {
        {
          int _5279 = (int)0;
          int _9298 = (int)0;
          int _9299 = (int)((_5250)->size(0));
          for (int _5280 = _9298; _5280 < _9299; ++_5280)
          {
            {
              double _5281 = _ptr__5250[_5280];
              int _9300 = (int)0;
              int _9301 = (int)((_5249)->size(0));
              for (int _5282 = _9300; _5282 < _9301; ++_5282)
              {
                {
                  _ptr__5258[_5279] = (_ptr__5248[_5282] * _5281);
                  ++ _5279;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5261,_5260,_5259,_5258,_5254,_5257)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5283,int _5284,std::shared_ptr< monty::ndarray< double,1 > > _5285,std::shared_ptr< monty::ndarray< int,1 > > _5286,int _5287,bool _5288){
  _checked_ptr_1<double> _ptr__5285(_5285 ? _5285->raw() : nullptr, _5285 ? _5285->size(0) : 0);
  _checked_ptr_1<int> _ptr__5286(_5286 ? _5286->raw() : nullptr, _5286 ? _5286->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9302;
  bool _9303 = (!_5288);
  if (_9303)
  {
    _9302 = ::mosek::fusion::p_Set::make(_5284,_5287);
  }
  else
  {
    _9302 = ::mosek::fusion::p_Set::make(_5287,_5284);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5289 = _9302;
  _checked_ptr_1<int> _ptr__5289(_5289 ? _5289->raw() : nullptr,_5289 ? _5289->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9304;
  bool _9305 = (_5287 == (int)((_5285)->size(0)));
  if (_9305)
  {
    _9304 = nullptr;
  }
  else
  {
    _9304 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5285)->size(0)),_5284 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5290 = _9304;
  _checked_ptr_1<long long> _ptr__5290(_5290 ? _5290->raw() : nullptr,_5290 ? _5290->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5291 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5285)->size(0)),_5284 ))));
  _checked_ptr_1<double> _ptr__5291(_5291 ? _5291->raw() : nullptr,_5291 ? _5291->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5292 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5285)->size(0)),_5284 ))));
  _checked_ptr_1<double> _ptr__5292(_5292 ? _5292->raw() : nullptr,_5292 ? _5292->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5285)->size(0)),_5284 ))));
  _checked_ptr_1<long long> _ptr__5293(_5293 ? _5293->raw() : nullptr,_5293 ? _5293->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5294 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5285)->size(0)),_5284 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5294(_5294 ? _5294->raw() : nullptr,_5294 ? _5294->size(0) : 0);
  if ((_5287 == (int)((_5285)->size(0))))
  {
    {
      long long _5295 = (long long)0;
      if ((!_5288))
      {
        {
          int _9306 = (int)0;
          int _9307 = _5284;
          for (int _5296 = _9306; _5296 < _9307; ++_5296)
          {
            {
              int _9308 = (int)0;
              int _9309 = _5287;
              for (int _5297 = _9308; _5297 < _9309; ++_5297)
              {
                {
                  _ptr__5294[safe_add( _5295,(int)1 )] = safe_add( _5295,(int)1 );
                  _ptr__5293[_5295] = (long long)_5296;
                  _ptr__5292[_5295] = _ptr__5285[_5297];
                  ++ _5295;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9310 = (int)0;
          int _9311 = _5287;
          for (int _5298 = _9310; _5298 < _9311; ++_5298)
          {
            {
              int _9312 = (int)0;
              int _9313 = _5284;
              for (int _5299 = _9312; _5299 < _9313; ++_5299)
              {
                {
                  _ptr__5294[safe_add( _5295,(int)1 )] = safe_add( _5295,(int)1 );
                  _ptr__5293[_5295] = (long long)_5299;
                  _ptr__5292[_5295] = _ptr__5285[_5298];
                  ++ _5295;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5300 = (long long)0;
      if ((!_5288))
      {
        {
          int _9314 = (int)0;
          int _9315 = _5284;
          for (int _5301 = _9314; _5301 < _9315; ++_5301)
          {
            {
              int _9316 = (int)0;
              int _9317 = (int)((_5285)->size(0));
              for (int _5302 = _9316; _5302 < _9317; ++_5302)
              {
                {
                  _ptr__5294[safe_add( _5300,(int)1 )] = safe_add( _5300,(int)1 );
                  _ptr__5293[_5300] = (long long)_5301;
                  _ptr__5292[_5300] = _ptr__5285[_5302];
                  _ptr__5290[_5300] = safe_add( safe_mul( _5301,_5287 ),_ptr__5286[_5302] );
                  ++ _5300;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9318 = (int)0;
          int _9319 = (int)((_5285)->size(0));
          for (int _5303 = _9318; _5303 < _9319; ++_5303)
          {
            {
              int _9320 = (int)0;
              int _9321 = _5284;
              for (int _5304 = _9320; _5304 < _9321; ++_5304)
              {
                {
                  _ptr__5294[safe_add( _5300,(int)1 )] = safe_add( _5300,(int)1 );
                  _ptr__5293[_5300] = (long long)_5304;
                  _ptr__5292[_5300] = _ptr__5285[_5303];
                  _ptr__5290[_5300] = safe_add( safe_mul( _ptr__5286[_5303],_5284 ),_5304 );
                  ++ _5300;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5294,_5293,_5292,_5291,_5289,_5290)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5305) { return mosek::fusion::p_Expr::stack(_5305); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5305){
  if ((NULL == _5305.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9322 = (int)0;
  int _9323 = (int)((_5305)->size(0));
  for (int _5306 = _9322; _5306 < _9323; ++_5306)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5307 = ((*_5305)(_5306));
      if ((NULL == _5307.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9324 = (int)0;
      int _9325 = (int)((_5307)->size(0));
      for (int _5308 = _9324; _5308 < _9325; ++_5308)
      {
        {
          if ((NULL == ((*_5307)(_5308)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9326;
  for (int _5310 = (int)0, _9327 = (int)((_5305)->size(0)); _5310 < _9327 ; ++_5310)
  {
    _9326.push_back(::mosek::fusion::p_Expr::stack_(((*_5305)(_5310)),(int)1));
  }
  auto _9328 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9326.size()),_9326.begin(),_9326.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5309 = _9328;
  return ::mosek::fusion::p_Expr::stack_(_5309,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5311,    double _5312,    double _5313) { return mosek::fusion::p_Expr::vstack(_5311,_5312,_5313); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5311,double _5312,double _5313){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5311).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5312).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5313).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5314,    double _5315,    monty::rc_ptr< ::mosek::fusion::Expression > _5316) { return mosek::fusion::p_Expr::vstack(_5314,_5315,_5316); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5314,double _5315,monty::rc_ptr< ::mosek::fusion::Expression > _5316){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5314).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5315).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5316.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5317,    monty::rc_ptr< ::mosek::fusion::Expression > _5318,    double _5319) { return mosek::fusion::p_Expr::vstack(_5317,_5318,_5319); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5317,monty::rc_ptr< ::mosek::fusion::Expression > _5318,double _5319){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5317).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5318.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5319).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5320,    monty::rc_ptr< ::mosek::fusion::Expression > _5321,    monty::rc_ptr< ::mosek::fusion::Expression > _5322) { return mosek::fusion::p_Expr::vstack(_5320,_5321,_5322); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5320,monty::rc_ptr< ::mosek::fusion::Expression > _5321,monty::rc_ptr< ::mosek::fusion::Expression > _5322){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5320).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5321.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5322.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5323,    double _5324,    double _5325) { return mosek::fusion::p_Expr::vstack(_5323,_5324,_5325); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5323,double _5324,double _5325){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5323.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5324).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5325).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5326,    double _5327,    monty::rc_ptr< ::mosek::fusion::Expression > _5328) { return mosek::fusion::p_Expr::vstack(_5326,_5327,_5328); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5326,double _5327,monty::rc_ptr< ::mosek::fusion::Expression > _5328){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5326.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5327).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5328.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5329,    monty::rc_ptr< ::mosek::fusion::Expression > _5330,    double _5331) { return mosek::fusion::p_Expr::vstack(_5329,_5330,_5331); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5329,monty::rc_ptr< ::mosek::fusion::Expression > _5330,double _5331){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5329.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5330.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5331).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5332,    monty::rc_ptr< ::mosek::fusion::Expression > _5333,    monty::rc_ptr< ::mosek::fusion::Expression > _5334) { return mosek::fusion::p_Expr::vstack(_5332,_5333,_5334); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5332,monty::rc_ptr< ::mosek::fusion::Expression > _5333,monty::rc_ptr< ::mosek::fusion::Expression > _5334){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5332.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5333.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5334.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5335,    monty::rc_ptr< ::mosek::fusion::Expression > _5336) { return mosek::fusion::p_Expr::vstack(_5335,_5336); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5335,monty::rc_ptr< ::mosek::fusion::Expression > _5336){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5335).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5336.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5337,    double _5338) { return mosek::fusion::p_Expr::vstack(_5337,_5338); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5337,double _5338){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5337.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5338).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5339,    monty::rc_ptr< ::mosek::fusion::Expression > _5340) { return mosek::fusion::p_Expr::vstack(_5339,_5340); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5339,monty::rc_ptr< ::mosek::fusion::Expression > _5340){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5339.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5340.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5341) { return mosek::fusion::p_Expr::vstack(_5341); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5341){
  if ((NULL == _5341.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9329 = (int)0;
  int _9330 = (int)((_5341)->size(0));
  for (int _5342 = _9329; _5342 < _9330; ++_5342)
  {
    {
      if ((NULL == ((*_5341)(_5342)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5341,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5343,    monty::rc_ptr< ::mosek::fusion::Expression > _5344,    monty::rc_ptr< ::mosek::fusion::Expression > _5345) { return mosek::fusion::p_Expr::hstack(_5343,_5344,_5345); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5343,monty::rc_ptr< ::mosek::fusion::Expression > _5344,monty::rc_ptr< ::mosek::fusion::Expression > _5345){
  if (((NULL == _5343.get()) || ((NULL == _5344.get()) || (NULL == _5345.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5343.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5344.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5345.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5346,    monty::rc_ptr< ::mosek::fusion::Expression > _5347,    double _5348) { return mosek::fusion::p_Expr::hstack(_5346,_5347,_5348); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5346,monty::rc_ptr< ::mosek::fusion::Expression > _5347,double _5348){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5346.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5347.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5348).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5349,    double _5350,    monty::rc_ptr< ::mosek::fusion::Expression > _5351) { return mosek::fusion::p_Expr::hstack(_5349,_5350,_5351); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5349,double _5350,monty::rc_ptr< ::mosek::fusion::Expression > _5351){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5349.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5350).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5351.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5352,    double _5353,    double _5354) { return mosek::fusion::p_Expr::hstack(_5352,_5353,_5354); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5352,double _5353,double _5354){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5352.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5353).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5354).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5355,    monty::rc_ptr< ::mosek::fusion::Expression > _5356,    monty::rc_ptr< ::mosek::fusion::Expression > _5357) { return mosek::fusion::p_Expr::hstack(_5355,_5356,_5357); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5355,monty::rc_ptr< ::mosek::fusion::Expression > _5356,monty::rc_ptr< ::mosek::fusion::Expression > _5357){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5355).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5356.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5357.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5358,    monty::rc_ptr< ::mosek::fusion::Expression > _5359,    double _5360) { return mosek::fusion::p_Expr::hstack(_5358,_5359,_5360); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5358,monty::rc_ptr< ::mosek::fusion::Expression > _5359,double _5360){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5358).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5359.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5360).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5361,    double _5362,    monty::rc_ptr< ::mosek::fusion::Expression > _5363) { return mosek::fusion::p_Expr::hstack(_5361,_5362,_5363); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5361,double _5362,monty::rc_ptr< ::mosek::fusion::Expression > _5363){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5361).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5362).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5363.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5364,    monty::rc_ptr< ::mosek::fusion::Expression > _5365) { return mosek::fusion::p_Expr::hstack(_5364,_5365); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5364,monty::rc_ptr< ::mosek::fusion::Expression > _5365){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5364).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5365.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5366,    double _5367) { return mosek::fusion::p_Expr::hstack(_5366,_5367); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5366,double _5367){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5366.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5367).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5368,    monty::rc_ptr< ::mosek::fusion::Expression > _5369) { return mosek::fusion::p_Expr::hstack(_5368,_5369); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5368,monty::rc_ptr< ::mosek::fusion::Expression > _5369){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5368.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5369.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5370) { return mosek::fusion::p_Expr::hstack(_5370); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5370){
  if ((NULL == _5370.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9331 = (int)0;
  int _9332 = (int)((_5370)->size(0));
  for (int _5371 = _9331; _5371 < _9332; ++_5371)
  {
    {
      if ((NULL == ((*_5370)(_5371)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5370,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5372,    monty::rc_ptr< ::mosek::fusion::Expression > _5373,    monty::rc_ptr< ::mosek::fusion::Expression > _5374,    monty::rc_ptr< ::mosek::fusion::Expression > _5375) { return mosek::fusion::p_Expr::stack(_5372,_5373,_5374,_5375); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373,monty::rc_ptr< ::mosek::fusion::Expression > _5374,monty::rc_ptr< ::mosek::fusion::Expression > _5375){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5373.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5374.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5375.get())}),_5372);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5376,    monty::rc_ptr< ::mosek::fusion::Expression > _5377,    monty::rc_ptr< ::mosek::fusion::Expression > _5378,    double _5379) { return mosek::fusion::p_Expr::stack(_5376,_5377,_5378,_5379); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377,monty::rc_ptr< ::mosek::fusion::Expression > _5378,double _5379){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5377.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5378.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5379).get())}),_5376);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5380,    monty::rc_ptr< ::mosek::fusion::Expression > _5381,    double _5382,    monty::rc_ptr< ::mosek::fusion::Expression > _5383) { return mosek::fusion::p_Expr::stack(_5380,_5381,_5382,_5383); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5380,monty::rc_ptr< ::mosek::fusion::Expression > _5381,double _5382,monty::rc_ptr< ::mosek::fusion::Expression > _5383){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5381.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5382).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5383.get())}),_5380);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5384,    monty::rc_ptr< ::mosek::fusion::Expression > _5385,    double _5386,    double _5387) { return mosek::fusion::p_Expr::stack(_5384,_5385,_5386,_5387); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5384,monty::rc_ptr< ::mosek::fusion::Expression > _5385,double _5386,double _5387){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5385.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5386).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5387).get())}),_5384);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5388,    double _5389,    monty::rc_ptr< ::mosek::fusion::Expression > _5390,    monty::rc_ptr< ::mosek::fusion::Expression > _5391) { return mosek::fusion::p_Expr::stack(_5388,_5389,_5390,_5391); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5388,double _5389,monty::rc_ptr< ::mosek::fusion::Expression > _5390,monty::rc_ptr< ::mosek::fusion::Expression > _5391){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5389).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5390.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5391.get())}),_5388);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5392,    double _5393,    monty::rc_ptr< ::mosek::fusion::Expression > _5394,    double _5395) { return mosek::fusion::p_Expr::stack(_5392,_5393,_5394,_5395); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5392,double _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394,double _5395){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5393).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5394.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5395).get())}),_5392);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5396,    double _5397,    double _5398,    monty::rc_ptr< ::mosek::fusion::Expression > _5399) { return mosek::fusion::p_Expr::stack(_5396,_5397,_5398,_5399); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5396,double _5397,double _5398,monty::rc_ptr< ::mosek::fusion::Expression > _5399){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5397).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5398).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5399.get())}),_5396);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5400,    double _5401,    monty::rc_ptr< ::mosek::fusion::Expression > _5402) { return mosek::fusion::p_Expr::stack(_5400,_5401,_5402); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5400,double _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5401).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5402.get())}),_5400);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5403,    monty::rc_ptr< ::mosek::fusion::Expression > _5404,    double _5405) { return mosek::fusion::p_Expr::stack(_5403,_5404,_5405); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5403,monty::rc_ptr< ::mosek::fusion::Expression > _5404,double _5405){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5404.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5405).get())}),_5403);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5406,    monty::rc_ptr< ::mosek::fusion::Expression > _5407,    monty::rc_ptr< ::mosek::fusion::Expression > _5408) { return mosek::fusion::p_Expr::stack(_5406,_5407,_5408); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5406,monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5407.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5408.get())}),_5406);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5409,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5410) { return mosek::fusion::p_Expr::stack(_5409,_5410); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5409,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5410){
  return ::mosek::fusion::p_Expr::stack_(_5410,_5409);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5411,int _5412){
  if (((int)((_5411)->size(0)) == (int)1))
  {
    {
      return ((*_5411)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5411,_5412),_5412)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5413,int _5414){
  int _5415 = (int)((_5413)->size(0));
  std::vector<int> _9333;
  for (int _5417 = (int)0, _9334 = _5415; _5417 < _9334 ; ++_5417)
  {
    _9333.push_back(((*_5413)(_5417))->getND());
  }
  auto _9335 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9333.size()),_9333.begin(),_9333.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5416 = _9335;
  _checked_ptr_1<int> _ptr__5416(_5416 ? _5416->raw() : nullptr,_5416 ? _5416->size(0) : 0);
  int _5418 = _ptr__5416[(int)0];
  int _5419 = _ptr__5416[(int)0];
  int _9336 = (int)1;
  int _9337 = _5415;
  for (int _5420 = _9336; _5420 < _9337; ++_5420)
  {
    {
      if ((_ptr__5416[_5420] < _5419))
      {
        {
          _5419 = _ptr__5416[_5420];
        }
      }
      {}
      if ((_ptr__5416[_5420] > _5418))
      {
        {
          _5418 = _ptr__5416[_5420];
        }
      }
      {}
    }
  }
  if ((_5418 < _5414))
  {
    {
      _5418 = _5414;
    }
  }
  {}
  if ((_5419 < _5418))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5421 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5415)));
      std::shared_ptr< monty::ndarray< int,1 > > _5422 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5418)));
      _checked_ptr_1<int> _ptr__5422(_5422 ? _5422->raw() : nullptr,_5422 ? _5422->size(0) : 0);
      int _9338 = (int)0;
      int _9339 = _5415;
      for (int _5423 = _9338; _5423 < _9339; ++_5423)
      {
        {
          if ((((*_5413)(_5423))->getND() == _5418))
          {
            {
              ((*_5421)(_5423)) = ((*_5413)(_5423));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5424 = ((*_5413)(_5423))->getShape();
              _checked_ptr_1<int> _ptr__5424(_5424 ? _5424->raw() : nullptr,_5424 ? _5424->size(0) : 0);
              int _9340 = (int)0;
              int _9341 = (int)((_5424)->size(0));
              for (int _5425 = _9340; _5425 < _9341; ++_5425)
              {
                {
                  _ptr__5422[_5425] = _ptr__5424[_5425];
                }
              }
              int _9342 = (int)((_5424)->size(0));
              int _9343 = _5418;
              for (int _5426 = _9342; _5426 < _9343; ++_5426)
              {
                {
                  _ptr__5422[_5426] = (int)1;
                }
              }
              ((*_5421)(_5423)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5422,((*_5413)(_5423)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5421;
    }
  }
  else
  {
    {
      return _5413;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5427,    int _5428,    int _5429) { return mosek::fusion::p_Expr::repeat(_5427,_5428,_5429); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5427,int _5428,int _5429){
  if ((_5428 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9344;
  for (int _5430 = (int)0, _9345 = _5428; _5430 < _9345 ; ++_5430)
  {
    _9344.push_back(_5427);
  }
  auto _9346 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9344.size()),_9344.begin(),_9344.end()));
  return ::mosek::fusion::p_Expr::stack_(_9346,_5429);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5431) { return mosek::fusion::p_Expr::add(_5431); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5431){
  std::vector<double> _9347;
  for (int _5432 = (int)0, _9348 = (int)((_5431)->size(0)); _5432 < _9348 ; ++_5432)
  {
    _9347.push_back(1.0);
  }
  auto _9349 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9347.size()),_9347.begin(),_9347.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5431,_9349)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5433) { return mosek::fusion::p_Expr::add(_5433); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5433){
  if ((NULL == _5433.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5433)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5433)->size(0)) > (int)0) && (NULL == ((*_5433)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5434 = ((*_5433)((int)0))->getND();
  int _9350 = (int)1;
  int _9351 = (int)((_5433)->size(0));
  for (int _5435 = _9350; _5435 < _9351; ++_5435)
  {
    {
      if ((_5434 < ((*_5433)(_5435))->getND()))
      {
        {
          _5434 = ((*_5433)(_5435))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5436 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5433)->size(0)),_5434)));
  int _9352 = (int)0;
  int _9353 = (int)((_5433)->size(0));
  for (int _5437 = _9352; _5437 < _9353; ++_5437)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5438 = ((*_5433)(_5437))->getShape();
      _checked_ptr_1<int> _ptr__5438(_5438 ? _5438->raw() : nullptr,_5438 ? _5438->size(0) : 0);
      int _9354 = (int)0;
      int _9355 = (int)((_5438)->size(0));
      for (int _5439 = _9354; _5439 < _9355; ++_5439)
      {
        {
          ((*_5436)(_5437,_5439)) = _ptr__5438[_5439];
        }
      }
      int _9356 = (int)((_5438)->size(0));
      int _9357 = _5434;
      for (int _5440 = _9356; _5440 < _9357; ++_5440)
      {
        {
          ((*_5436)(_5437,_5440)) = (int)1;
        }
      }
    }
  }
  int _9358 = (int)1;
  int _9359 = (int)((_5433)->size(0));
  for (int _5441 = _9358; _5441 < _9359; ++_5441)
  {
    {
      int _9360 = (int)0;
      int _9361 = _5434;
      for (int _5442 = _9360; _5442 < _9361; ++_5442)
      {
        {
          if ((((*_5436)((int)0,_5442)) != ((*_5436)(_5441,_5442))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9362;
  for (int _5444 = (int)0, _9363 = _5434; _5444 < _9363 ; ++_5444)
  {
    _9362.push_back(((*_5436)((int)0,_5444)));
  }
  auto _9364 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9362.size()),_9362.begin(),_9362.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5443 = _9364;
  _checked_ptr_1<int> _ptr__5443(_5443 ? _5443->raw() : nullptr,_5443 ? _5443->size(0) : 0);
  int _5445 = (int)1;
  int _9365 = (int)0;
  int _9366 = _5434;
  for (int _5446 = _9365; _5446 < _9366; ++_5446)
  {
    {
      _5445 *= _ptr__5443[_5446];
    }
  }
  int _5447 = (int)0;
  int _5448 = (int)0;
  int _9367 = (int)0;
  int _9368 = (int)((_5433)->size(0));
  for (int _5449 = _9367; _5449 < _9368; ++_5449)
  {
    {
      int _5450 = ((*_5433)(_5449))->numInst();
      _5447 += _5450;
      int _9369;
      bool _9370 = (_5448 > _5450);
      if (_9370)
      {
        _9369 = _5448;
      }
      else
      {
        _9369 = _5450;
      }
      _5448 = _9369;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5451 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5445,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5451(_5451 ? _5451->raw() : nullptr,_5451 ? _5451->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5452 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5447)));
  _checked_ptr_1<long long> _ptr__5452(_5452 ? _5452->raw() : nullptr,_5452 ? _5452->size(0) : 0);
  std::vector<double> _9371;
  for (int _5454 = (int)0, _9372 = _5447; _5454 < _9372 ; ++_5454)
  {
    _9371.push_back(1.0);
  }
  auto _9373 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9371.size()),_9371.begin(),_9371.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5453 = _9373;
  _checked_ptr_1<double> _ptr__5453(_5453 ? _5453->raw() : nullptr,_5453 ? _5453->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5455 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5448)));
    _checked_ptr_1<long long> _ptr__5455(_5455 ? _5455->raw() : nullptr,_5455 ? _5455->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5456 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5448)));
    _checked_ptr_1<long long> _ptr__5456(_5456 ? _5456->raw() : nullptr,_5456 ? _5456->size(0) : 0);
    int _9374 = (int)0;
    int _9375 = (int)((_5433)->size(0));
    for (int _5457 = _9374; _5457 < _9375; ++_5457)
    {
      {
        int _5458 = ((*_5433)(_5457))->inst((int)0,_5455,(int)0,_5456);
        int _9376 = (int)0;
        int _9377 = _5458;
        for (int _5459 = _9376; _5459 < _9377; ++_5459)
        {
          {
            _ptr__5451[safe_add( _ptr__5455[_5459],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9378 = (int)0;
    int _9379 = _5445;
    for (int _5460 = _9378; _5460 < _9379; ++_5460)
    {
      {
        _ptr__5451[safe_add( _5460,(int)1 )] += _ptr__5451[_5460];
      }
    }
    int _9380 = (int)0;
    int _9381 = (int)((_5433)->size(0));
    for (int _5461 = _9380; _5461 < _9381; ++_5461)
    {
      {
        int _5462 = ((*_5433)(_5461))->inst((int)0,_5455,(int)0,_5456);
        int _9382 = (int)0;
        int _9383 = _5462;
        for (int _5463 = _9382; _5463 < _9383; ++_5463)
        {
          {
            _ptr__5452[_ptr__5451[_ptr__5455[_5463]]] = _ptr__5456[_5463];
            ++ _ptr__5451[_ptr__5455[_5463]];
          }
        }
      }
    }
    int _9384 = (int)0;
    int _9385 = _5445;
    for (int _5464 = _9384; _5464 < _9385; ++_5464)
    {
      {
        _ptr__5451[(_5445 - _5464)] = _ptr__5451[((_5445 - _5464) - (int)1)];
      }
    }
    _ptr__5451[(int)0] = (int)0;
  }
  std::vector<double> _9386;
  for (int _5465 = (int)0, _9387 = _5445; _5465 < _9387 ; ++_5465)
  {
    _9386.push_back(0.0);
  }
  auto _9388 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9386.size()),_9386.begin(),_9386.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5451,_5452,_5453,_9388,_5443,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5466,double _5467,monty::rc_ptr< ::mosek::fusion::Expression > _5468,double _5469){
  int _5470 = _5466->getND();
  int _5471 = _5468->getND();
  if ((_5470 == _5471))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5466,_5468,_5467,_5469)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9389;
      bool _9390 = (_5470 > _5471);
      if (_9390)
      {
        _9389 = _5470;
      }
      else
      {
        _9389 = _5471;
      }
      int _5472 = _9389;
      std::shared_ptr< monty::ndarray< int,1 > > _5473 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5472)));
      _checked_ptr_1<int> _ptr__5473(_5473 ? _5473->raw() : nullptr,_5473 ? _5473->size(0) : 0);
      if ((_5470 < _5471))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5474 = _5466->getShape();
          _checked_ptr_1<int> _ptr__5474(_5474 ? _5474->raw() : nullptr,_5474 ? _5474->size(0) : 0);
          int _9391 = (int)0;
          int _9392 = _5470;
          for (int _5475 = _9391; _5475 < _9392; ++_5475)
          {
            {
              _ptr__5473[_5475] = _ptr__5474[_5475];
            }
          }
          int _9393 = _5470;
          int _9394 = _5472;
          for (int _5476 = _9393; _5476 < _9394; ++_5476)
          {
            {
              _ptr__5473[_5476] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5473,_5466)).as<::mosek::fusion::Expression>(),_5468,_5467,_5469)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5477 = _5468->getShape();
          _checked_ptr_1<int> _ptr__5477(_5477 ? _5477->raw() : nullptr,_5477 ? _5477->size(0) : 0);
          int _9395 = (int)0;
          int _9396 = _5471;
          for (int _5478 = _9395; _5478 < _9396; ++_5478)
          {
            {
              _ptr__5473[_5478] = _ptr__5477[_5478];
            }
          }
          int _9397 = _5471;
          int _9398 = _5472;
          for (int _5479 = _9397; _5479 < _9398; ++_5479)
          {
            {
              _ptr__5473[_5479] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5466,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5473,_5468)).as<::mosek::fusion::Expression>(),_5467,_5469)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5480) { return mosek::fusion::p_Expr::transpose(_5480); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5480){
  if ((_5480->getND() == (int)0))
  {
    {
      return _5480;
    }
  }
  else if((_5480->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5480->getDim((int)0))}),_5480)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5480->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5480)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5481,    monty::rc_ptr< ::mosek::fusion::Expression > _5482) { return mosek::fusion::p_Expr::mulElm(_5481,_5482); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5481,monty::rc_ptr< ::mosek::fusion::Expression > _5482){
  return ::mosek::fusion::p_Expr::mulElm_(_5481,_5482);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5483,    monty::rc_ptr< ::mosek::fusion::Expression > _5484) { return mosek::fusion::p_Expr::mulElm(_5483,_5484); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5483,monty::rc_ptr< ::mosek::fusion::Expression > _5484){
  return ::mosek::fusion::p_Expr::mulElm_(_5483,_5484);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5485,    monty::rc_ptr< ::mosek::fusion::Expression > _5486) { return mosek::fusion::p_Expr::mulElm(_5485,_5486); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5485,monty::rc_ptr< ::mosek::fusion::Expression > _5486){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5485),_5486);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5487,    monty::rc_ptr< ::mosek::fusion::Expression > _5488) { return mosek::fusion::p_Expr::mulElm(_5487,_5488); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5487,monty::rc_ptr< ::mosek::fusion::Expression > _5488){
  _checked_ptr_1<double> _ptr__5487(_5487 ? _5487->raw() : nullptr, _5487 ? _5487->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5487,_5488);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5489,    monty::rc_ptr< ::mosek::fusion::Matrix > _5490) { return mosek::fusion::p_Expr::mulElm(_5489,_5490); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5489,monty::rc_ptr< ::mosek::fusion::Matrix > _5490){
  return ::mosek::fusion::p_Expr::mulElm_(_5490,_5489);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5491,    std::shared_ptr< monty::ndarray< double,2 > > _5492) { return mosek::fusion::p_Expr::mulElm(_5491,_5492); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5491,std::shared_ptr< monty::ndarray< double,2 > > _5492){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5492),_5491);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5493,    std::shared_ptr< monty::ndarray< double,1 > > _5494) { return mosek::fusion::p_Expr::mulElm(_5493,_5494); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5493,std::shared_ptr< monty::ndarray< double,1 > > _5494){
  _checked_ptr_1<double> _ptr__5494(_5494 ? _5494->raw() : nullptr, _5494 ? _5494->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5494,_5493);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5495,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5496) { return mosek::fusion::p_Expr::mulElm(_5495,_5496); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5495,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5496){
  return ::mosek::fusion::p_Expr::mulElm_(_5496,_5495);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5497,    monty::rc_ptr< ::mosek::fusion::Expression > _5498) { return mosek::fusion::p_Expr::sub(_5497,_5498); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5497,monty::rc_ptr< ::mosek::fusion::Expression > _5498){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5497),1.0,_5498,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5499,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5500) { return mosek::fusion::p_Expr::sub(_5499,_5500); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5499,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5500){
  return ::mosek::fusion::p_Expr::add_(_5499,1.0,::mosek::fusion::p_Expr::constTerm(_5500),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5501,    monty::rc_ptr< ::mosek::fusion::Expression > _5502) { return mosek::fusion::p_Expr::sub(_5501,_5502); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5501,monty::rc_ptr< ::mosek::fusion::Expression > _5502){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5501),1.0,_5502,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5503,    monty::rc_ptr< ::mosek::fusion::Matrix > _5504) { return mosek::fusion::p_Expr::sub(_5503,_5504); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5503,monty::rc_ptr< ::mosek::fusion::Matrix > _5504){
  return ::mosek::fusion::p_Expr::add_(_5503,1.0,::mosek::fusion::p_Expr::constTerm(_5504),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5505,    monty::rc_ptr< ::mosek::fusion::Expression > _5506) { return mosek::fusion::p_Expr::sub(_5505,_5506); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5505,monty::rc_ptr< ::mosek::fusion::Expression > _5506){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5506->getShape(),_5505),1.0,_5506,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5507,    double _5508) { return mosek::fusion::p_Expr::sub(_5507,_5508); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5507,double _5508){
  return ::mosek::fusion::p_Expr::add_(_5507,1.0,::mosek::fusion::p_Expr::constTerm(_5507->getShape(),_5508),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5509,    monty::rc_ptr< ::mosek::fusion::Expression > _5510) { return mosek::fusion::p_Expr::sub(_5509,_5510); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5509,monty::rc_ptr< ::mosek::fusion::Expression > _5510){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5509),1.0,_5510,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5511,    monty::rc_ptr< ::mosek::fusion::Expression > _5512) { return mosek::fusion::p_Expr::sub(_5511,_5512); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5511,monty::rc_ptr< ::mosek::fusion::Expression > _5512){
  _checked_ptr_1<double> _ptr__5511(_5511 ? _5511->raw() : nullptr, _5511 ? _5511->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5511),1.0,_5512,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5513,    std::shared_ptr< monty::ndarray< double,2 > > _5514) { return mosek::fusion::p_Expr::sub(_5513,_5514); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5513,std::shared_ptr< monty::ndarray< double,2 > > _5514){
  return ::mosek::fusion::p_Expr::add_(_5513,1.0,::mosek::fusion::p_Expr::constTerm(_5514),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5515,    std::shared_ptr< monty::ndarray< double,1 > > _5516) { return mosek::fusion::p_Expr::sub(_5515,_5516); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5515,std::shared_ptr< monty::ndarray< double,1 > > _5516){
  _checked_ptr_1<double> _ptr__5516(_5516 ? _5516->raw() : nullptr, _5516 ? _5516->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5515,1.0,::mosek::fusion::p_Expr::constTerm(_5516),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5517,    monty::rc_ptr< ::mosek::fusion::Expression > _5518) { return mosek::fusion::p_Expr::sub(_5517,_5518); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5517,monty::rc_ptr< ::mosek::fusion::Expression > _5518){
  return ::mosek::fusion::p_Expr::add_(_5517,1.0,_5518,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5519,    monty::rc_ptr< ::mosek::fusion::Expression > _5520) { return mosek::fusion::p_Expr::add(_5519,_5520); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5519,monty::rc_ptr< ::mosek::fusion::Expression > _5520){
  return ::mosek::fusion::p_Expr::add_(_5520,1.0,::mosek::fusion::p_Expr::constTerm(_5519),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5521,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5522) { return mosek::fusion::p_Expr::add(_5521,_5522); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5521,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5522){
  return ::mosek::fusion::p_Expr::add_(_5521,1.0,::mosek::fusion::p_Expr::constTerm(_5522),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5523,    monty::rc_ptr< ::mosek::fusion::Expression > _5524) { return mosek::fusion::p_Expr::add(_5523,_5524); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5523,monty::rc_ptr< ::mosek::fusion::Expression > _5524){
  return ::mosek::fusion::p_Expr::add_(_5524,1.0,::mosek::fusion::p_Expr::constTerm(_5523),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5525,    monty::rc_ptr< ::mosek::fusion::Matrix > _5526) { return mosek::fusion::p_Expr::add(_5525,_5526); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5525,monty::rc_ptr< ::mosek::fusion::Matrix > _5526){
  return ::mosek::fusion::p_Expr::add_(_5525,1.0,::mosek::fusion::p_Expr::constTerm(_5526),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5527,    monty::rc_ptr< ::mosek::fusion::Expression > _5528) { return mosek::fusion::p_Expr::add(_5527,_5528); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5527,monty::rc_ptr< ::mosek::fusion::Expression > _5528){
  return ::mosek::fusion::p_Expr::add_(_5528,1.0,::mosek::fusion::p_Expr::constTerm(_5528->getShape(),_5527),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5529,    double _5530) { return mosek::fusion::p_Expr::add(_5529,_5530); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5529,double _5530){
  return ::mosek::fusion::p_Expr::add_(_5529,1.0,::mosek::fusion::p_Expr::constTerm(_5529->getShape(),_5530),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5531,    monty::rc_ptr< ::mosek::fusion::Expression > _5532) { return mosek::fusion::p_Expr::add(_5531,_5532); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5531,monty::rc_ptr< ::mosek::fusion::Expression > _5532){
  return ::mosek::fusion::p_Expr::add_(_5532,1.0,::mosek::fusion::p_Expr::constTerm(_5531),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5533,    monty::rc_ptr< ::mosek::fusion::Expression > _5534) { return mosek::fusion::p_Expr::add(_5533,_5534); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5533,monty::rc_ptr< ::mosek::fusion::Expression > _5534){
  _checked_ptr_1<double> _ptr__5533(_5533 ? _5533->raw() : nullptr, _5533 ? _5533->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5534,1.0,::mosek::fusion::p_Expr::constTerm(_5533),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5535,    std::shared_ptr< monty::ndarray< double,2 > > _5536) { return mosek::fusion::p_Expr::add(_5535,_5536); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5535,std::shared_ptr< monty::ndarray< double,2 > > _5536){
  return ::mosek::fusion::p_Expr::add_(_5535,1.0,::mosek::fusion::p_Expr::constTerm(_5536),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5537,    std::shared_ptr< monty::ndarray< double,1 > > _5538) { return mosek::fusion::p_Expr::add(_5537,_5538); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5537,std::shared_ptr< monty::ndarray< double,1 > > _5538){
  _checked_ptr_1<double> _ptr__5538(_5538 ? _5538->raw() : nullptr, _5538 ? _5538->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5537,1.0,::mosek::fusion::p_Expr::constTerm(_5538),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5539,    monty::rc_ptr< ::mosek::fusion::Expression > _5540) { return mosek::fusion::p_Expr::add(_5539,_5540); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5539,monty::rc_ptr< ::mosek::fusion::Expression > _5540){
  return ::mosek::fusion::p_Expr::add_(_5539,1.0,_5540,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5541,monty::rc_ptr< ::mosek::fusion::WorkStack > _5542,monty::rc_ptr< ::mosek::fusion::WorkStack > _5543) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5541,_5542,_5543); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5541,monty::rc_ptr< ::mosek::fusion::WorkStack > _5542,monty::rc_ptr< ::mosek::fusion::WorkStack > _5543){
  std::vector<int> _9399;
  for (int _5544 = (int)0, _9400 = (int)((ptrb)->size(0)); _5544 < _9400 ; ++_5544)
  {
    _9399.push_back((int)((*ptrb)(_5544)));
  }
  auto _9401 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9399.size()),_9399.begin(),_9399.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5541,shape,_9401,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5545,std::shared_ptr< monty::ndarray< long long,1 > > _5546,std::shared_ptr< monty::ndarray< double,1 > > _5547,std::shared_ptr< monty::ndarray< double,1 > > _5548,std::shared_ptr< monty::ndarray< int,1 > > _5549,std::shared_ptr< monty::ndarray< long long,1 > > _5550){
  _checked_ptr_1<long long> _ptr__5545(_5545 ? _5545->raw() : nullptr, _5545 ? _5545->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5546(_5546 ? _5546->raw() : nullptr, _5546 ? _5546->size(0) : 0);
  _checked_ptr_1<double> _ptr__5547(_5547 ? _5547->raw() : nullptr, _5547 ? _5547->size(0) : 0);
  _checked_ptr_1<double> _ptr__5548(_5548 ? _5548->raw() : nullptr, _5548 ? _5548->size(0) : 0);
  _checked_ptr_1<int> _ptr__5549(_5549 ? _5549->raw() : nullptr, _5549 ? _5549->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5550(_5550 ? _5550->raw() : nullptr, _5550 ? _5550->size(0) : 0);
  if ((NULL == _5549.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5551 = ((int)((_5545)->size(0)) - (int)1);
  long long _5552 = _ptr__5545[((int)((_5545)->size(0)) - (int)1)];
  int _5553 = (int)((_5549)->size(0));
  long long _5554 = (long long)1;
  int _9402 = (int)0;
  int _9403 = _5553;
  for (int _5555 = _9402; _5555 < _9403; ++_5555)
  {
    {
      _5554 *= _ptr__5549[_5555];
    }
  }
  if (((int)((_5545)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5552 != (int)((_5546)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5552 != (int)((_5547)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5548.get()) || (_5551 != (int)((_5548)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5550.get()) && ((int)((_5550)->size(0)) < _5554)))
  {
    {
      if (((int)((_5550)->size(0)) != ((int)((_5545)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5550)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5550[(int)0] < (int)0) || (_ptr__5550[(int)0] >= _5554)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5556 = true;
          long long _5557 = _5554;
          int _9404 = (int)1;
          int _9405 = (int)((_5550)->size(0));
          for (int _5558 = _9404; _5558 < _9405; ++_5558)
          {
            {
              _5556 = (_5556 && ((_ptr__5550[_5558] >= (int)0) && ((_ptr__5550[_5558] < _5557) && (_ptr__5550[_5558] > _ptr__5550[(_5558 - (int)1)]))));
            }
          }
          if ((!_5556))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5554 != ((long long)((_5545)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5559 = false;
  bool _5560 = false;
  if ((_ptr__5545[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5561 = true;
  int _9406 = (int)0;
  int _9407 = _5551;
  for (int _5562 = _9406; _5562 < _9407; ++_5562)
  {
    {
      _5561 = (_5561 && (_ptr__5545[_5562] <= _ptr__5545[safe_add( _5562,(int)1 )]));
    }
  }
  if ((!_5561))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5563){
  monty::rc_ptr< ::mosek::fusion::Model > _9408;
  bool _9409 = ((NULL == _5563.get()) || ((int)((_5563)->size(0)) == (int)0));
  if (_9409)
  {
    _9408 = nullptr;
  }
  else
  {
    _9408 = ((*_5563)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9408;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5564) { return __mosek_2fusion_2Expression__pick(_5564); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5565) { return __mosek_2fusion_2Expression__pick(_5565); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5566) { return __mosek_2fusion_2Expression__index(_5566); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5567) { return __mosek_2fusion_2Expression__index(_5567); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5568,std::shared_ptr< monty::ndarray< int,1 > > _5569) { return __mosek_2fusion_2Expression__slice(_5568,_5569); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5570,int _5571) { return __mosek_2fusion_2Expression__slice(_5570,_5571); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5576){ return new mosek::fusion::FlatExpr(_5576); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5576) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5576); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5576){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5576)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5576)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5576)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5576)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5576)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5576)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5576)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578,    std::shared_ptr< monty::ndarray< long long,1 > > _5579,    std::shared_ptr< monty::ndarray< double,1 > > _5580,    std::shared_ptr< monty::ndarray< int,1 > > _5581,    std::shared_ptr< monty::ndarray< long long,1 > > _5582){ return new mosek::fusion::FlatExpr(_5577,_5578,_5579,_5580,_5581,_5582); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578,    std::shared_ptr< monty::ndarray< long long,1 > > _5579,    std::shared_ptr< monty::ndarray< double,1 > > _5580,    std::shared_ptr< monty::ndarray< int,1 > > _5581,    std::shared_ptr< monty::ndarray< long long,1 > > _5582) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5577,_5578,_5579,_5580,_5581,_5582); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578,    std::shared_ptr< monty::ndarray< long long,1 > > _5579,    std::shared_ptr< monty::ndarray< double,1 > > _5580,    std::shared_ptr< monty::ndarray< int,1 > > _5581,    std::shared_ptr< monty::ndarray< long long,1 > > _5582){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5577(_5577 ? _5577->raw() : nullptr, _5577 ? _5577->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5578(_5578 ? _5578->raw() : nullptr, _5578 ? _5578->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5579(_5579 ? _5579->raw() : nullptr, _5579 ? _5579->size(0) : 0);
    _checked_ptr_1<double> _ptr__5580(_5580 ? _5580->raw() : nullptr, _5580 ? _5580->size(0) : 0);
    _checked_ptr_1<int> _ptr__5581(_5581 ? _5581->raw() : nullptr, _5581 ? _5581->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5582(_5582 ? _5582->raw() : nullptr, _5582 ? _5582->size(0) : 0);
    if (((NULL != _5577.get()) && ((int)((_5577)->size(0)) != ((int)((_5578)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5580.get()) || ((NULL == _5579.get()) || ((int)((_5579)->size(0)) != (int)((_5580)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5581.get()))
    {
      {
        if ((NULL != _5582.get()))
        {
          {
            if (((int)((_5582)->size(0)) != ((int)((_5578)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5581) != ((long long)((_5578)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5577;
    ptrb = _5578;
    subj = _5579;
    cof = _5580;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5581;
    inst = _5582;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5583 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5583->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5583->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5583->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5583->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5583->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5583->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5584,    int _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< int,1 > > _5587,    std::shared_ptr< monty::ndarray< double,1 > > _5588,    std::shared_ptr< monty::ndarray< int,1 > > _5589,    std::shared_ptr< monty::ndarray< int,1 > > _5590,    std::shared_ptr< monty::ndarray< double,1 > > _5591,    double _5592){ return new mosek::fusion::SymmetricMatrix(_5584,_5585,_5586,_5587,_5588,_5589,_5590,_5591,_5592); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5584,    int _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< int,1 > > _5587,    std::shared_ptr< monty::ndarray< double,1 > > _5588,    std::shared_ptr< monty::ndarray< int,1 > > _5589,    std::shared_ptr< monty::ndarray< int,1 > > _5590,    std::shared_ptr< monty::ndarray< double,1 > > _5591,    double _5592) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5584,_5585,_5586,_5587,_5588,_5589,_5590,_5591,_5592); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5584,    int _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< int,1 > > _5587,    std::shared_ptr< monty::ndarray< double,1 > > _5588,    std::shared_ptr< monty::ndarray< int,1 > > _5589,    std::shared_ptr< monty::ndarray< int,1 > > _5590,    std::shared_ptr< monty::ndarray< double,1 > > _5591,    double _5592){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5586(_5586 ? _5586->raw() : nullptr, _5586 ? _5586->size(0) : 0);
    _checked_ptr_1<int> _ptr__5587(_5587 ? _5587->raw() : nullptr, _5587 ? _5587->size(0) : 0);
    _checked_ptr_1<double> _ptr__5588(_5588 ? _5588->raw() : nullptr, _5588 ? _5588->size(0) : 0);
    _checked_ptr_1<int> _ptr__5589(_5589 ? _5589->raw() : nullptr, _5589 ? _5589->size(0) : 0);
    _checked_ptr_1<int> _ptr__5590(_5590 ? _5590->raw() : nullptr, _5590 ? _5590->size(0) : 0);
    _checked_ptr_1<double> _ptr__5591(_5591 ? _5591->raw() : nullptr, _5591 ? _5591->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5584;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5585;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5586;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5587;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5588;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5589;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5590;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5591;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5592;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5593,    std::shared_ptr< monty::ndarray< int,1 > > _5594,    std::shared_ptr< monty::ndarray< double,1 > > _5595) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5593,_5594,_5595); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5593,std::shared_ptr< monty::ndarray< int,1 > > _5594,std::shared_ptr< monty::ndarray< double,1 > > _5595){
  _checked_ptr_1<int> _ptr__5594(_5594 ? _5594->raw() : nullptr, _5594 ? _5594->size(0) : 0);
  _checked_ptr_1<double> _ptr__5595(_5595 ? _5595->raw() : nullptr, _5595 ? _5595->size(0) : 0);
  if (((int)((_5594)->size(0)) != (int)((_5595)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9410 = (int)0;
  int _9411 = (int)((_5594)->size(0));
  for (int _5596 = _9410; _5596 < _9411; ++_5596)
  {
    {
      if (((_ptr__5594[_5596] < (int)0) || (_ptr__5594[_5596] >= _5593)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9412;
  for (int _5598 = (int)0, _9413 = (int)((_5594)->size(0)); _5598 < _9413 ; ++_5598)
  {
    _9412.push_back(_ptr__5594[_5598]);
  }
  auto _9414 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9412.size()),_9412.begin(),_9412.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5597 = _9414;
  _checked_ptr_1<int> _ptr__5597(_5597 ? _5597->raw() : nullptr,_5597 ? _5597->size(0) : 0);
  std::vector<int> _9415;
  for (int _5600 = (int)0, _9416 = (int)((_5594)->size(0)); _5600 < _9416 ; ++_5600)
  {
    _9415.push_back((int)1);
  }
  auto _9417 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9415.size()),_9415.begin(),_9415.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5599 = _9417;
  _checked_ptr_1<int> _ptr__5599(_5599 ? _5599->raw() : nullptr,_5599 ? _5599->size(0) : 0);
  std::vector<double> _9418;
  for (int _5602 = (int)0, _9419 = (int)((_5595)->size(0)); _5602 < _9419 ; ++_5602)
  {
    _9418.push_back(_ptr__5595[_5602]);
  }
  auto _9420 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9418.size()),_9418.begin(),_9418.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5601 = _9420;
  _checked_ptr_1<double> _ptr__5601(_5601 ? _5601->raw() : nullptr,_5601 ? _5601->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5593,(int)1,_5597,_5599,_5601,_5597,_5599,_5601,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5603) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5603); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5603){
  _checked_ptr_1<double> _ptr__5603(_5603 ? _5603->raw() : nullptr, _5603 ? _5603->size(0) : 0);
  int _5604 = (int)((_5603)->size(0));
  std::vector<int> _9421;
  for (int _5606 = (int)0, _9422 = _5604; _5606 < _9422 ; ++_5606)
  {
    _9421.push_back(_5606);
  }
  auto _9423 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9421.size()),_9421.begin(),_9421.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5605 = _9423;
  _checked_ptr_1<int> _ptr__5605(_5605 ? _5605->raw() : nullptr,_5605 ? _5605->size(0) : 0);
  std::vector<int> _9424;
  for (int _5608 = (int)0, _9425 = _5604; _5608 < _9425 ; ++_5608)
  {
    _9424.push_back((int)1);
  }
  auto _9426 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9424.size()),_9424.begin(),_9424.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5607 = _9426;
  _checked_ptr_1<int> _ptr__5607(_5607 ? _5607->raw() : nullptr,_5607 ? _5607->size(0) : 0);
  std::vector<double> _9427;
  for (int _5610 = (int)0, _9428 = _5604; _5610 < _9428 ; ++_5610)
  {
    _9427.push_back(_ptr__5603[_5610]);
  }
  auto _9429 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9427.size()),_9427.begin(),_9427.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5609 = _9429;
  _checked_ptr_1<double> _ptr__5609(_5609 ? _5609->raw() : nullptr,_5609 ? _5609->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5604,(int)1,_5605,_5607,_5609,_5605,_5607,_5609,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5611) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5611); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5611){
  _checked_ptr_1<double> _ptr__5611(_5611 ? _5611->raw() : nullptr, _5611 ? _5611->size(0) : 0);
  int _5612 = (int)((_5611)->size(0));
  std::vector<int> _9430;
  for (int _5614 = (int)0, _9431 = _5612; _5614 < _9431 ; ++_5614)
  {
    _9430.push_back(_5614);
  }
  auto _9432 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9430.size()),_9430.begin(),_9430.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5613 = _9432;
  _checked_ptr_1<int> _ptr__5613(_5613 ? _5613->raw() : nullptr,_5613 ? _5613->size(0) : 0);
  std::vector<int> _9433;
  for (int _5615 = (int)0, _9434 = _5612; _5615 < _9434 ; ++_5615)
  {
    _9433.push_back((_5612 - _5615));
  }
  auto _9435 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9433.size()),_9433.begin(),_9433.end()));
  std::vector<double> _9436;
  for (int _5616 = (int)0, _9437 = _5612; _5616 < _9437 ; ++_5616)
  {
    _9436.push_back(_ptr__5611[_5616]);
  }
  auto _9438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9436.size()),_9436.begin(),_9436.end()));
  std::vector<double> _9439;
  for (int _5617 = (int)0, _9440 = _5612; _5617 < _9440 ; ++_5617)
  {
    _9439.push_back(1.0);
  }
  auto _9441 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9439.size()),_9439.begin(),_9439.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5612,_5612,_5613,_9435,_9438,_5613,_5613,_9441,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5618) { return mosek::fusion::p_SymmetricMatrix::diag(_5618); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5618){
  _checked_ptr_1<double> _ptr__5618(_5618 ? _5618->raw() : nullptr, _5618 ? _5618->size(0) : 0);
  int _5619 = (int)((_5618)->size(0));
  std::vector<int> _9442;
  for (int _5621 = (int)0, _9443 = _5619; _5621 < _9443 ; ++_5621)
  {
    _9442.push_back(_5621);
  }
  auto _9444 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9442.size()),_9442.begin(),_9442.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5620 = _9444;
  _checked_ptr_1<int> _ptr__5620(_5620 ? _5620->raw() : nullptr,_5620 ? _5620->size(0) : 0);
  std::vector<double> _9445;
  for (int _5622 = (int)0, _9446 = _5619; _5622 < _9446 ; ++_5622)
  {
    _9445.push_back(_ptr__5618[_5622]);
  }
  auto _9447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9445.size()),_9445.begin(),_9445.end()));
  std::vector<double> _9448;
  for (int _5623 = (int)0, _9449 = _5619; _5623 < _9449 ; ++_5623)
  {
    _9448.push_back(1.0);
  }
  auto _9450 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9448.size()),_9448.begin(),_9448.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5619,_5619,_5620,_5620,_9447,_5620,_5620,_9450,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5624) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5624); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5624) { return __mosek_2fusion_2SymmetricMatrix__add(_5624); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5624){
  int _5625 = _pubthis->getdim();
  if ((_5624->getdim() != _5625))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5626 = (int)((usubi)->size(0));
  int _5627 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->usubi)->size(0));
  int _5628 = safe_add( _5626,_5627 );
  int _5629 = (int)((vsubi)->size(0));
  int _5630 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->vsubi)->size(0));
  int _5631 = safe_add( _5629,_5630 );
  std::shared_ptr< monty::ndarray< double,1 > > _5632 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5631)));
  _checked_ptr_1<double> _ptr__5632(_5632 ? _5632->raw() : nullptr,_5632 ? _5632->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5633 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5631)));
  _checked_ptr_1<int> _ptr__5633(_5633 ? _5633->raw() : nullptr,_5633 ? _5633->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5634 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5631)));
  _checked_ptr_1<int> _ptr__5634(_5634 ? _5634->raw() : nullptr,_5634 ? _5634->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5635 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5628)));
  _checked_ptr_1<double> _ptr__5635(_5635 ? _5635->raw() : nullptr,_5635 ? _5635->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5636 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5628)));
  _checked_ptr_1<int> _ptr__5636(_5636 ? _5636->raw() : nullptr,_5636 ? _5636->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5637 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5628)));
  _checked_ptr_1<int> _ptr__5637(_5637 ? _5637->raw() : nullptr,_5637 ? _5637->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5637,(int)0,_5626);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->usubi,(int)0,_5637,_5626,_5627);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5636,(int)0,_5626);
  int _9451 = (int)0;
  int _9452 = _5627;
  for (int _5638 = _9451; _5638 < _9452; ++_5638)
  {
    {
      _ptr__5636[safe_add( _5638,_5626 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->usubj)(_5638)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5635,(int)0,_5626);
    }
  }
  else
  {
    {
      int _9453 = (int)0;
      int _9454 = _5626;
      for (int _5639 = _9453; _5639 < _9454; ++_5639)
      {
        {
          _ptr__5635[_5639] = (scale * ((*uval)(_5639)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->uval,(int)0,_5635,_5626,_5627);
    }
  }
  else
  {
    {
      int _9455 = (int)0;
      int _9456 = _5627;
      for (int _5640 = _9455; _5640 < _9456; ++_5640)
      {
        {
          _ptr__5635[safe_add( _5640,_5626 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->uval)(_5640)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5637,(int)0,_5626);
  int _9457 = (int)0;
  int _9458 = _5630;
  for (int _5641 = _9457; _5641 < _9458; ++_5641)
  {
    {
      _ptr__5634[safe_add( _5641,_5629 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->vsubi)(_5641)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5633,(int)0,_5629);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->vsubj,_5629,_5633,_5629,_5630);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5632,(int)0,_5629);
    }
  }
  else
  {
    {
      int _9459 = (int)0;
      int _9460 = _5629;
      for (int _5642 = _9459; _5642 < _9460; ++_5642)
      {
        {
          _ptr__5632[_5642] = (scale * ((*vval)(_5642)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->vval,(int)0,_5632,_5629,_5630);
    }
  }
  else
  {
    {
      int _9461 = (int)0;
      int _9462 = _5630;
      for (int _5643 = _9461; _5643 < _9462; ++_5643)
      {
        {
          _ptr__5632[safe_add( _5643,_5629 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->vval)(_5643)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5624)->d1 ),_5637,_5636,_5635,_5634,_5633,_5632,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5644) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5644); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5644) { return __mosek_2fusion_2SymmetricMatrix__sub(_5644); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5644){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5644->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5645) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5645); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5645) { return __mosek_2fusion_2SymmetricMatrix__mul(_5645); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5645){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5645));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5646,    std::shared_ptr< monty::ndarray< int,2 > > _5647,    std::shared_ptr< monty::ndarray< double,1 > > _5648){ return new mosek::fusion::NDSparseArray(_5646,_5647,_5648); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5646,    std::shared_ptr< monty::ndarray< int,2 > > _5647,    std::shared_ptr< monty::ndarray< double,1 > > _5648) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5646,_5647,_5648); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5646,    std::shared_ptr< monty::ndarray< int,2 > > _5647,    std::shared_ptr< monty::ndarray< double,1 > > _5648){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5646(_5646 ? _5646->raw() : nullptr, _5646 ? _5646->size(0) : 0);
    _checked_ptr_1<double> _ptr__5648(_5648 ? _5648->raw() : nullptr, _5648 ? _5648->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5649 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5647)->size(0)))));
    _checked_ptr_1<long long> _ptr__5649(_5649 ? _5649->raw() : nullptr,_5649 ? _5649->size(0) : 0);
    size = (long long)1;
    int _9463 = (int)0;
    int _9464 = (int)((_5646)->size(0));
    for (int _5650 = _9463; _5650 < _9464; ++_5650)
    {
      {
        size = safe_mul( size,_ptr__5646[_5650] );
      }
    }
    int _5651 = (int)((_5646)->size(0));
    if (((int)((_5647)->size(0)) != (int)((_5648)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5647)->size(1)) != _5651))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    int _9465 = (int)0;
    int _9466 = (int)((_5647)->size(0));
    for (int _5652 = _9465; _5652 < _9466; ++_5652)
    {
      {
        int _9467 = (int)0;
        int _9468 = (int)((_5647)->size(1));
        for (int _5653 = _9467; _5653 < _9468; ++_5653)
        {
          {
            if (((((*_5647)(_5652,_5653)) < (int)0) || (((*_5647)(_5652,_5653)) >= _ptr__5646[_5653])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    int _9469 = (int)0;
    int _9470 = (int)((_5647)->size(0));
    for (int _5654 = _9469; _5654 < _9470; ++_5654)
    {
      {
        long long _5655 = (long long)0;
        int _9471 = (int)0;
        int _9472 = (int)((_5647)->size(1));
        for (int _5656 = _9471; _5656 < _9472; ++_5656)
        {
          {
            _5655 = safe_add( safe_mul( _5655,_ptr__5646[((_5651 - _5656) - (int)1)] ),((*_5647)(_5654,_5656)) );
          }
        }
        _ptr__5649[_5654] = _5655;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5646);
    bool _5657 = true;
    int _9473 = (int)1;
    int _9474 = (int)((_5649)->size(0));
    for (int _5658 = _9473; _5658 < _9474; ++_5658)
    {
      {
        _5657 = (_5657 && (_ptr__5649[_5658] >= _ptr__5649[(_5658 - (int)1)]));
      }
    }
    if (_5657)
    {
      {
        int _5659 = (int)1;
        int _9475 = (int)1;
        int _9476 = (int)((_5649)->size(0));
        for (int _5660 = _9475; _5660 < _9476; ++_5660)
        {
          {
            if ((_ptr__5649[(_5660 - (int)1)] > _ptr__5649[_5660]))
            {
              {
                ++ _5659;
              }
            }
            {}
          }
        }
        if ((_5659 == (int)((_5649)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5649);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5648);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5659)));
            ((*inst)((int)0)) = _ptr__5649[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5659)));
            ((*cof)((int)0)) = _ptr__5648[(int)0];
            int _5661 = (int)0;
            int _9477 = (int)1;
            int _9478 = (int)((_5649)->size(0));
            for (int _5662 = _9477; _5662 < _9478; ++_5662)
            {
              {
                if ((_ptr__5649[_5662] > _ptr__5649[(_5662 - (int)1)]))
                {
                  {
                    ++ _5661;
                    ((*inst)(_5661)) = _ptr__5649[_5662];
                    ((*cof)(_5661)) = _ptr__5648[_5662];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5661)) = (((*cof)(_5661)) + _ptr__5648[_5662]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5663 = ::mosek::fusion::Utils::Tools::range((long long)((_5649)->size(0)));
        _checked_ptr_1<long long> _ptr__5663(_5663 ? _5663->raw() : nullptr,_5663 ? _5663->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5663,_5649,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5649)->size(0)));
        int _5664 = (int)1;
        int _9479 = (int)1;
        int _9480 = (int)((_5649)->size(0));
        for (int _5665 = _9479; _5665 < _9480; ++_5665)
        {
          {
            if ((_ptr__5649[_ptr__5663[(_5665 - (int)1)]] < _ptr__5649[_ptr__5663[_5665]]))
            {
              {
                ++ _5664;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5664)));
        ((*inst)((int)0)) = _ptr__5649[_ptr__5663[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5664)));
        ((*cof)((int)0)) = _ptr__5648[_ptr__5663[(int)0]];
        int _5666 = (int)0;
        int _9481 = (int)1;
        int _9482 = (int)((_5649)->size(0));
        for (int _5667 = _9481; _5667 < _9482; ++_5667)
        {
          {
            if ((_ptr__5649[_ptr__5663[_5667]] > _ptr__5649[_ptr__5663[(_5667 - (int)1)]]))
            {
              {
                ++ _5666;
                ((*inst)(_5666)) = _ptr__5649[_ptr__5663[_5667]];
                ((*cof)(_5666)) = _ptr__5648[_ptr__5663[_5667]];
              }
            }
            else
            {
              {
                ((*cof)(_5666)) = (((*cof)(_5666)) + _ptr__5648[_ptr__5663[_5667]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< long long,1 > > _5669,    std::shared_ptr< monty::ndarray< double,1 > > _5670){ return new mosek::fusion::NDSparseArray(_5668,_5669,_5670); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< long long,1 > > _5669,    std::shared_ptr< monty::ndarray< double,1 > > _5670) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5668,_5669,_5670); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5668,    std::shared_ptr< monty::ndarray< long long,1 > > _5669,    std::shared_ptr< monty::ndarray< double,1 > > _5670){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5668(_5668 ? _5668->raw() : nullptr, _5668 ? _5668->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5669(_5669 ? _5669->raw() : nullptr, _5669 ? _5669->size(0) : 0);
    _checked_ptr_1<double> _ptr__5670(_5670 ? _5670->raw() : nullptr, _5670 ? _5670->size(0) : 0);
    size = (long long)1;
    int _9483 = (int)0;
    int _9484 = (int)((_5668)->size(0));
    for (int _5671 = _9483; _5671 < _9484; ++_5671)
    {
      {
        size = safe_mul( size,_ptr__5668[_5671] );
      }
    }
    if (((int)((_5669)->size(0)) != (int)((_5670)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    int _9485 = (int)0;
    int _9486 = (int)((_5669)->size(0));
    for (int _5672 = _9485; _5672 < _9486; ++_5672)
    {
      {
        if (((_ptr__5669[_5672] < (int)0) || (_ptr__5669[_5672] >= size)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
          }
        }
        {}
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5668);
    bool _5673 = true;
    int _9487 = (int)1;
    int _9488 = (int)((_5669)->size(0));
    for (int _5674 = _9487; _5674 < _9488; ++_5674)
    {
      {
        _5673 = (_5673 && (_ptr__5669[_5674] >= _ptr__5669[(_5674 - (int)1)]));
      }
    }
    if (_5673)
    {
      {
        int _5675 = (int)1;
        int _9489 = (int)1;
        int _9490 = (int)((_5669)->size(0));
        for (int _5676 = _9489; _5676 < _9490; ++_5676)
        {
          {
            if ((_ptr__5669[(_5676 - (int)1)] > _ptr__5669[_5676]))
            {
              {
                ++ _5675;
              }
            }
            {}
          }
        }
        if ((_5675 == (int)((_5669)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5669);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5670);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5675)));
            ((*inst)((int)0)) = _ptr__5669[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5675)));
            ((*cof)((int)0)) = _ptr__5670[(int)0];
            int _5677 = (int)0;
            int _9491 = (int)1;
            int _9492 = (int)((_5669)->size(0));
            for (int _5678 = _9491; _5678 < _9492; ++_5678)
            {
              {
                if ((_ptr__5669[_5678] > _ptr__5669[(_5678 - (int)1)]))
                {
                  {
                    ++ _5677;
                    ((*inst)(_5677)) = _ptr__5669[_5678];
                    ((*cof)(_5677)) = _ptr__5670[_5678];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5677)) = (((*cof)(_5677)) + _ptr__5670[_5678]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5679 = ::mosek::fusion::Utils::Tools::range((long long)((_5669)->size(0)));
        _checked_ptr_1<long long> _ptr__5679(_5679 ? _5679->raw() : nullptr,_5679 ? _5679->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5679,_5669,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5669)->size(0)));
        int _5680 = (int)1;
        int _9493 = (int)1;
        int _9494 = (int)((_5669)->size(0));
        for (int _5681 = _9493; _5681 < _9494; ++_5681)
        {
          {
            if ((_ptr__5669[_ptr__5679[(_5681 - (int)1)]] < _ptr__5669[_ptr__5679[_5681]]))
            {
              {
                ++ _5680;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5680)));
        ((*inst)((int)0)) = _ptr__5669[_ptr__5679[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5680)));
        ((*cof)((int)0)) = _ptr__5670[_ptr__5679[(int)0]];
        int _5682 = (int)0;
        int _9495 = (int)1;
        int _9496 = (int)((_5669)->size(0));
        for (int _5683 = _9495; _5683 < _9496; ++_5683)
        {
          {
            if ((_ptr__5669[_ptr__5679[_5683]] > ((*inst)(_ptr__5679[(_5683 - (int)1)]))))
            {
              {
                ++ _5682;
                ((*inst)(_5682)) = _ptr__5669[_ptr__5679[_5683]];
                ((*cof)(_5682)) = _ptr__5670[_ptr__5679[_5683]];
              }
            }
            else
            {
              {
                ((*cof)(_5682)) = (((*cof)(_5682)) + _ptr__5670[_ptr__5679[_5683]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5684){ return new mosek::fusion::NDSparseArray(_5684); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5684) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5684); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5684){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5685 = _5684->numNonzeros();
    int _5686 = _5684->numColumns();
    int _5687 = _5684->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5688 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5685)));
    _checked_ptr_1<double> _ptr__5688(_5688 ? _5688->raw() : nullptr,_5688 ? _5688->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5689 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5685)));
    _checked_ptr_1<int> _ptr__5689(_5689 ? _5689->raw() : nullptr,_5689 ? _5689->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5690 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5685)));
    _checked_ptr_1<int> _ptr__5690(_5690 ? _5690->raw() : nullptr,_5690 ? _5690->size(0) : 0);
    _5684->getDataAsTriplets(_5690,_5689,_5688);
    size = safe_mul( (long long)_5684->numRows(),(long long)_5684->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5687),(int)(_5686)});
    std::vector<long long> _9497;
    for (long long _5691 = (long long)0, _9498 = _5685; _5691 < _9498 ; ++_5691)
    {
      _9497.push_back(safe_add( safe_mul( (long long)_ptr__5690[_5691],_5686 ),(long long)_ptr__5689[_5691] ));
    }
    auto _9499 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9497.size()),_9497.begin(),_9497.end()));
    inst = _9499;
    cof = _5688;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5692) { return mosek::fusion::p_NDSparseArray::make(_5692); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5692){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5692);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5693,    std::shared_ptr< monty::ndarray< long long,1 > > _5694,    std::shared_ptr< monty::ndarray< double,1 > > _5695) { return mosek::fusion::p_NDSparseArray::make(_5693,_5694,_5695); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5693,std::shared_ptr< monty::ndarray< long long,1 > > _5694,std::shared_ptr< monty::ndarray< double,1 > > _5695){
  _checked_ptr_1<int> _ptr__5693(_5693 ? _5693->raw() : nullptr, _5693 ? _5693->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5694(_5694 ? _5694->raw() : nullptr, _5694 ? _5694->size(0) : 0);
  _checked_ptr_1<double> _ptr__5695(_5695 ? _5695->raw() : nullptr, _5695 ? _5695->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5693,_5694,_5695);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5696,    std::shared_ptr< monty::ndarray< int,2 > > _5697,    std::shared_ptr< monty::ndarray< double,1 > > _5698) { return mosek::fusion::p_NDSparseArray::make(_5696,_5697,_5698); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5696,std::shared_ptr< monty::ndarray< int,2 > > _5697,std::shared_ptr< monty::ndarray< double,1 > > _5698){
  _checked_ptr_1<int> _ptr__5696(_5696 ? _5696->raw() : nullptr, _5696 ? _5696->size(0) : 0);
  _checked_ptr_1<double> _ptr__5698(_5698 ? _5698->raw() : nullptr, _5698 ? _5698->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5696,_5697,_5698);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5699,    int _5700,    std::shared_ptr< monty::ndarray< double,1 > > _5701){ return new mosek::fusion::DenseMatrix(_5699,_5700,_5701); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5699,    int _5700,    std::shared_ptr< monty::ndarray< double,1 > > _5701) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5699,_5700,_5701); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5699,    int _5700,    std::shared_ptr< monty::ndarray< double,1 > > _5701){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5701(_5701 ? _5701->raw() : nullptr, _5701 ? _5701->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5699,_5700);
    nnz = (long long)safe_mul( _5699,_5700 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5699,_5700 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5701,(int)0,data,(int)0,safe_mul( _5699,_5700 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5702){ return new mosek::fusion::DenseMatrix(_5702); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5702) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5702); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5702){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5702)->dimi,mosek::fusion::p_Matrix::_get_impl(_5702)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9500 = _5702;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9500.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5703 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9500.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5703)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9500.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5704 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9500.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5704)->dimi,mosek::fusion::p_Matrix::_get_impl(_5704)->dimj ));
        long long _9501 = (long long)0;
        long long _9502 = mosek::fusion::p_SparseMatrix::_get_impl(_5704)->nnz;
        for (long long _5706 = _9501; _5706 < _9502; ++_5706)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5704)->subi)(_5706)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5704)->subj)(_5706)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5704)->val)(_5706));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5705 = _9500;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5707){ return new mosek::fusion::DenseMatrix(_5707); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5707) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5707); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5707){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5707)->size(0)),(int)((_5707)->size(1)));
    std::vector<double> _9503;
    for (int _5708 = (int)0, _9504 = dimi; _5708 < _9504 ; ++_5708)
    {
      for (int _5709 = (int)0, _9505 = dimj; _5709 < _9505 ; ++_5709)
      {
        _9503.push_back(((*_5707)(_5708,_5709)));
      }
    }
    auto _9506 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9503.size()),_9503.begin(),_9503.end()));
    data = _9506;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5710,    int _5711,    double _5712){ return new mosek::fusion::DenseMatrix(_5710,_5711,_5712); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5710,    int _5711,    double _5712) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5710,_5711,_5712); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5710,    int _5711,    double _5712){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5710,_5711);
    std::vector<double> _9507;
    for (int _5713 = (int)0, _9508 = _5710; _5713 < _9508 ; ++_5713)
    {
      for (int _5714 = (int)0, _9509 = _5711; _5714 < _9509 ; ++_5714)
      {
        _9507.push_back(_5712);
      }
    }
    auto _9510 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9507.size()),_9507.begin(),_9507.end()));
    data = _9510;
    nnz = (long long)safe_mul( _5710,_5711 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5715 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5716 = (int)0;
  {
    int _5717 = (int)0;
    for(;(_5717 < dimi);++ _5717)
    {
      {
        if ((_5717 > (int)0))
        {
          {
            _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5715->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5716)));
        ++ _5716;
        {
          int _5718 = (int)1;
          for(;(_5718 < dimj);++ _5718)
          {
            {
              _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5715->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5716)));
              ++ _5716;
            }
          }
        }
        _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5715->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5715->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5719 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5719(_5719 ? _5719->raw() : nullptr,_5719 ? _5719->size(0) : 0);
  int _5720 = (int)0;
  int _5721 = dimi;
  int _9511 = (int)0;
  int _9512 = dimi;
  for (int _5722 = _9511; _5722 < _9512; ++_5722)
  {
    {
      int _5723 = _5722;
      int _9513 = (int)0;
      int _9514 = dimj;
      for (int _5724 = _9513; _5724 < _9514; ++_5724)
      {
        {
          _ptr__5719[_5723] = ((*data)(_5720));
          _5723 = safe_add( _5723,_5721 );
          ++ _5720;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5719)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5725,std::shared_ptr< monty::ndarray< int,1 > > _5726,std::shared_ptr< monty::ndarray< double,1 > > _5727) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5725,_5726,_5727); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5725,std::shared_ptr< monty::ndarray< int,1 > > _5726,std::shared_ptr< monty::ndarray< double,1 > > _5727){
  _checked_ptr_1<int> _ptr__5725(_5725 ? _5725->raw() : nullptr, _5725 ? _5725->size(0) : 0);
  _checked_ptr_1<int> _ptr__5726(_5726 ? _5726->raw() : nullptr, _5726 ? _5726->size(0) : 0);
  _checked_ptr_1<double> _ptr__5727(_5727 ? _5727->raw() : nullptr, _5727 ? _5727->size(0) : 0);
  if ((((int)((_5725)->size(0)) < nnz) || (((int)((_5726)->size(0)) < nnz) || ((int)((_5727)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5727,(int)0,(int)((data)->size(0)));
  int _5728 = (int)0;
  int _9515 = (int)0;
  int _9516 = dimi;
  for (int _5729 = _9515; _5729 < _9516; ++_5729)
  {
    {
      int _9517 = (int)0;
      int _9518 = dimj;
      for (int _5730 = _9517; _5730 < _9518; ++_5730)
      {
        {
          _ptr__5725[_5728] = _5729;
          _ptr__5726[_5728] = _5730;
          ++ _5728;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5731,int _5732) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5731,_5732); }double mosek::fusion::p_DenseMatrix::get(int _5731,int _5732){
  return ((*data)(safe_add( safe_mul( _5731,dimj ),_5732 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5733,    int _5734,    std::shared_ptr< monty::ndarray< int,1 > > _5735,    std::shared_ptr< monty::ndarray< int,1 > > _5736,    std::shared_ptr< monty::ndarray< double,1 > > _5737,    long long _5738){ return new mosek::fusion::SparseMatrix(_5733,_5734,_5735,_5736,_5737,_5738); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5733,    int _5734,    std::shared_ptr< monty::ndarray< int,1 > > _5735,    std::shared_ptr< monty::ndarray< int,1 > > _5736,    std::shared_ptr< monty::ndarray< double,1 > > _5737,    long long _5738) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5733,_5734,_5735,_5736,_5737,_5738); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5733,    int _5734,    std::shared_ptr< monty::ndarray< int,1 > > _5735,    std::shared_ptr< monty::ndarray< int,1 > > _5736,    std::shared_ptr< monty::ndarray< double,1 > > _5737,    long long _5738){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5735(_5735 ? _5735->raw() : nullptr, _5735 ? _5735->size(0) : 0);
    _checked_ptr_1<int> _ptr__5736(_5736 ? _5736->raw() : nullptr, _5736 ? _5736->size(0) : 0);
    _checked_ptr_1<double> _ptr__5737(_5737 ? _5737->raw() : nullptr, _5737 ? _5737->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5733,_5734);
    if ((_5738 > (int)0))
    {
      {
        if ((((int)((_5735)->size(0)) < _5738) || (((int)((_5736)->size(0)) < _5738) || ((int)((_5737)->size(0)) < _5738))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        long long _9519 = (long long)0;
        long long _9520 = _5738;
        for (long long _5739 = _9519; _5739 < _9520; ++_5739)
        {
          {
            if (((_ptr__5735[_5739] < (int)0) || ((_ptr__5735[_5739] >= dimi) || ((_ptr__5736[_5739] < (int)0) || (_ptr__5736[_5739] >= dimj)))))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
              }
            }
            {}
          }
        }
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5740 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5741 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5742 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5735,_5736,_5737,_5740,_5741,_5742,_5738,dimi,dimj);
        subi = ((*_5740)((int)0));
        subj = ((*_5741)((int)0));
        val = ((*_5742)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5743,    int _5744,    std::shared_ptr< monty::ndarray< int,1 > > _5745,    std::shared_ptr< monty::ndarray< int,1 > > _5746,    std::shared_ptr< monty::ndarray< double,1 > > _5747){ return new mosek::fusion::SparseMatrix(_5743,_5744,_5745,_5746,_5747); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5743,    int _5744,    std::shared_ptr< monty::ndarray< int,1 > > _5745,    std::shared_ptr< monty::ndarray< int,1 > > _5746,    std::shared_ptr< monty::ndarray< double,1 > > _5747) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5743,_5744,_5745,_5746,_5747); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5743,    int _5744,    std::shared_ptr< monty::ndarray< int,1 > > _5745,    std::shared_ptr< monty::ndarray< int,1 > > _5746,    std::shared_ptr< monty::ndarray< double,1 > > _5747){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5745(_5745 ? _5745->raw() : nullptr, _5745 ? _5745->size(0) : 0);
    _checked_ptr_1<int> _ptr__5746(_5746 ? _5746->raw() : nullptr, _5746 ? _5746->size(0) : 0);
    _checked_ptr_1<double> _ptr__5747(_5747 ? _5747->raw() : nullptr, _5747 ? _5747->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5743,_5744);
    int _5748 = (int)0;
    int _9521 = (int)0;
    int _9522 = (int)((_5747)->size(0));
    for (int _5749 = _9521; _5749 < _9522; ++_5749)
    {
      {
        if (((_ptr__5747[_5749] > (int)0) || (_ptr__5747[_5749] < (int)0)))
        {
          {
            ++ _5748;
          }
        }
        {}
      }
    }
    if (((_5748 > (int)0) && (_5748 < (int)((_5745)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5748)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5748)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5748)));
        nnz = _5748;
        int _5750 = (int)0;
        int _9523 = (int)0;
        int _9524 = (int)((_5747)->size(0));
        for (int _5751 = _9523; _5751 < _9524; ++_5751)
        {
          {
            if (((_ptr__5747[_5751] < (int)0) || (_ptr__5747[_5751] > (int)0)))
            {
              {
                ((*val)(_5750)) = _ptr__5747[_5751];
                ((*subj)(_5750)) = _ptr__5746[_5751];
                ((*subi)(_5750)) = _ptr__5745[_5751];
                ++ _5750;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5745;
        subj = _5746;
        val = _5747;
        if ((NULL == _5745.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5752 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5752(_5752 ? _5752->raw() : nullptr,_5752 ? _5752->size(0) : 0);
  long long _5753 = (long long)0;
  int _9525 = (int)0;
  int _9526 = dimi;
  for (int _5754 = _9525; _5754 < _9526; ++_5754)
  {
    {
      _ptr__5752[_5754] = _5753;
      {
        for(;((_5753 < nnz) && (((*subi)(_5753)) == _5754));++ _5753)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5752[dimi] = _5753;
  return _5752;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5755 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5755->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5755->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9527 = (int)1;
      int _9528 = (int)((subi)->size(0));
      for (int _5756 = _9527; _5756 < _9528; ++_5756)
      {
        {
          _5755->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5756)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5756)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5756)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5755->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5755->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5757 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5757(_5757 ? _5757->raw() : nullptr,_5757 ? _5757->size(0) : 0);
  int _9529 = (int)0;
  int _9530 = (int)((subi)->size(0));
  for (int _5758 = _9529; _5758 < _9530; ++_5758)
  {
    {
      _ptr__5757[safe_add( safe_mul( ((*subi)(_5758)),dimj ),((*subj)(_5758)) )] = ((*val)(_5758));
    }
  }
  return _5757;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< int,1 > > _5760,std::shared_ptr< monty::ndarray< double,1 > > _5761) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5759,_5760,_5761); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< int,1 > > _5760,std::shared_ptr< monty::ndarray< double,1 > > _5761){
  _checked_ptr_1<int> _ptr__5759(_5759 ? _5759->raw() : nullptr, _5759 ? _5759->size(0) : 0);
  _checked_ptr_1<int> _ptr__5760(_5760 ? _5760->raw() : nullptr, _5760 ? _5760->size(0) : 0);
  _checked_ptr_1<double> _ptr__5761(_5761 ? _5761->raw() : nullptr, _5761 ? _5761->size(0) : 0);
  if ((((long long)((_5759)->size(0)) < nnz) || (((long long)((_5760)->size(0)) < nnz) || ((long long)((_5761)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5759,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5760,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5761,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5762,int _5763) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5762,_5763); }double mosek::fusion::p_SparseMatrix::get(int _5762,int _5763){
  if (((_5762 < (int)0) || ((_5762 >= dimi) || ((_5763 < (int)0) || (_5763 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5764 = (int)((subi)->size(0));
  int _5765 = (int)0;
  while ( ((_5764 - _5765) > (int)1) )
  {
    {
      int _5766 = (safe_add( _5765,_5764 ) / (int)2);
      if (((((*subi)(_5766)) < _5762) || ((((*subi)(_5766)) == _5762) && (((*subj)(_5766)) < _5763))))
      {
        {
          _5765 = _5766;
        }
      }
      else if(((((*subi)(_5766)) > _5762) || ((((*subi)(_5766)) == _5762) && (((*subj)(_5766)) > _5763))))
      {
        {
          _5764 = _5766;
        }
      }
      else
      {
        {
          return ((*val)(_5766));
        }
      }
    }
  }
  if (((((*subi)(_5765)) == _5762) && (((*subj)(_5765)) == _5763)))
  {
    {
      return ((*val)(_5765));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5767,    int _5768){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5767 < (int)0) || (_5768 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5767;
    dimj = _5768;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5769 = dimi;
  dimi = dimj;
  dimj = _5769;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5770,    monty::rc_ptr< ::mosek::fusion::Matrix > _5771) { return mosek::fusion::p_Matrix::diag(_5770,_5771); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5770,monty::rc_ptr< ::mosek::fusion::Matrix > _5771){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9531;
  for (int _5772 = (int)0, _9532 = _5770; _5772 < _9532 ; ++_5772)
  {
    _9531.push_back(_5771);
  }
  auto _9533 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9531.size()),_9531.begin(),_9531.end()));
  return ::mosek::fusion::p_Matrix::diag(_9533);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5773) { return mosek::fusion::p_Matrix::diag(_5773); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5773){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5774 = _5773;
  long long _5775 = (long long)0;
  int _5776 = (int)0;
  int _5777 = (int)0;
  int _9534 = (int)0;
  int _9535 = (int)((_5773)->size(0));
  for (int _5778 = _9534; _5778 < _9535; ++_5778)
  {
    {
      _5777 = safe_add( _5777,mosek::fusion::p_Matrix::_get_impl(((*_5773)(_5778)))->dimi );
      _5776 = safe_add( _5776,mosek::fusion::p_Matrix::_get_impl(((*_5773)(_5778)))->dimj );
      _5775 = safe_add( _5775,((*_5773)(_5778))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5779 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5775)));
  _checked_ptr_1<int> _ptr__5779(_5779 ? _5779->raw() : nullptr,_5779 ? _5779->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5780 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5775)));
  _checked_ptr_1<int> _ptr__5780(_5780 ? _5780->raw() : nullptr,_5780 ? _5780->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5781 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5775)));
  _checked_ptr_1<double> _ptr__5781(_5781 ? _5781->raw() : nullptr,_5781 ? _5781->size(0) : 0);
  {
    int _5782 = (int)0;
    int _5783 = (int)0;
    long long _5784 = (long long)0;
    int _9536 = (int)0;
    int _9537 = (int)((_5773)->size(0));
    for (int _5785 = _9536; _5785 < _9537; ++_5785)
    {
      {
        long long _5786 = ((*_5773)(_5785))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5787 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5786)));
        _checked_ptr_1<double> _ptr__5787(_5787 ? _5787->raw() : nullptr,_5787 ? _5787->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5788 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5786)));
        _checked_ptr_1<int> _ptr__5788(_5788 ? _5788->raw() : nullptr,_5788 ? _5788->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5789 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5786)));
        _checked_ptr_1<int> _ptr__5789(_5789 ? _5789->raw() : nullptr,_5789 ? _5789->size(0) : 0);
        ((*_5773)(_5785))->getDataAsTriplets(_5789,_5788,_5787);
        ::mosek::fusion::Utils::Tools::arraycopy(_5787,(long long)0,_5781,_5784,_5786);
        long long _9538 = (long long)0;
        long long _9539 = _5786;
        for (long long _5790 = _9538; _5790 < _9539; ++_5790)
        {
          {
            _ptr__5779[safe_add( _5784,_5790 )] = safe_add( _ptr__5789[_5790],_5783 );
            _ptr__5780[safe_add( _5784,_5790 )] = safe_add( _ptr__5789[_5790],_5782 );
          }
        }
        _5784 = safe_add( _5784,_5786 );
        _5783 = safe_add( _5783,mosek::fusion::p_Matrix::_get_impl(((*_5773)(_5785)))->dimi );
        _5782 = safe_add( _5782,mosek::fusion::p_Matrix::_get_impl(((*_5773)(_5785)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5777,_5776,_5779,_5780,_5781)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5791,    double _5792,    int _5793) { return mosek::fusion::p_Matrix::antidiag(_5791,_5792,_5793); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5791,double _5792,int _5793){
  if (((_5793 < _5791) && (_5793 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5792,(_5791 - _5793)),_5793);
    }
  }
  else if(((_5793 > (-_5791)) && (_5793 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5792,safe_add( _5791,_5793 )),_5793);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5794,    double _5795) { return mosek::fusion::p_Matrix::antidiag(_5794,_5795); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5794,double _5795){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5795,_5794),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5796,    double _5797,    int _5798) { return mosek::fusion::p_Matrix::diag(_5796,_5797,_5798); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5796,double _5797,int _5798){
  if (((_5798 < _5796) && (_5798 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5797,(_5796 - _5798)),_5798);
    }
  }
  else if(((_5798 > (-_5796)) && (_5798 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5797,safe_add( _5796,_5798 )),_5798);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5799,    double _5800) { return mosek::fusion::p_Matrix::diag(_5799,_5800); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5799,double _5800){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5800,_5799),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5801,    int _5802) { return mosek::fusion::p_Matrix::antidiag(_5801,_5802); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5801,int _5802){
  _checked_ptr_1<double> _ptr__5801(_5801 ? _5801->raw() : nullptr, _5801 ? _5801->size(0) : 0);
  int _9540;
  bool _9541 = (_5802 > (int)0);
  if (_9541)
  {
    _9540 = _5802;
  }
  else
  {
    _9540 = (-_5802);
  }
  int _5803 = _9540;
  int _5804 = safe_add( (int)((_5801)->size(0)),_5803 );
  int _5805 = (int)((_5801)->size(0));
  if ((_5802 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5806 = ::mosek::fusion::Utils::Tools::range(_5802,safe_add( _5805,_5802 ));
      _checked_ptr_1<int> _ptr__5806(_5806 ? _5806->raw() : nullptr,_5806 ? _5806->size(0) : 0);
      std::vector<int> _9542;
      for (int _5808 = (int)1, _9543 = safe_add( _5805,(int)1 ); _5808 < _9543 ; ++_5808)
      {
        _9542.push_back((safe_add( _5805,_5802 ) - _5808));
      }
      auto _9544 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9542.size()),_9542.begin(),_9542.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5807 = _9544;
      _checked_ptr_1<int> _ptr__5807(_5807 ? _5807->raw() : nullptr,_5807 ? _5807->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5804,_5804,_5806,_5807,_5801)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5809 = ::mosek::fusion::Utils::Tools::range((int)0,_5805);
      _checked_ptr_1<int> _ptr__5809(_5809 ? _5809->raw() : nullptr,_5809 ? _5809->size(0) : 0);
      std::vector<int> _9545;
      for (int _5811 = (int)1, _9546 = safe_add( _5805,(int)1 ); _5811 < _9546 ; ++_5811)
      {
        _9545.push_back((_5805 - _5811));
      }
      auto _9547 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9545.size()),_9545.begin(),_9545.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5810 = _9547;
      _checked_ptr_1<int> _ptr__5810(_5810 ? _5810->raw() : nullptr,_5810 ? _5810->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5804,_5804,_5809,_5810,_5801)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5812) { return mosek::fusion::p_Matrix::antidiag(_5812); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5812){
  _checked_ptr_1<double> _ptr__5812(_5812 ? _5812->raw() : nullptr, _5812 ? _5812->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5812,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5813,    int _5814) { return mosek::fusion::p_Matrix::diag(_5813,_5814); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5813,int _5814){
  _checked_ptr_1<double> _ptr__5813(_5813 ? _5813->raw() : nullptr, _5813 ? _5813->size(0) : 0);
  int _9548;
  bool _9549 = (_5814 > (int)0);
  if (_9549)
  {
    _9548 = _5814;
  }
  else
  {
    _9548 = (-_5814);
  }
  int _5815 = _9548;
  int _5816 = safe_add( (int)((_5813)->size(0)),_5815 );
  int _5817 = (int)((_5813)->size(0));
  if ((_5814 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5818 = ::mosek::fusion::Utils::Tools::range((int)0,_5817);
      _checked_ptr_1<int> _ptr__5818(_5818 ? _5818->raw() : nullptr,_5818 ? _5818->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5819 = ::mosek::fusion::Utils::Tools::range(_5815,safe_add( _5817,_5815 ));
      _checked_ptr_1<int> _ptr__5819(_5819 ? _5819->raw() : nullptr,_5819 ? _5819->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5816,_5816,_5818,_5819,_5813)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5820 = ::mosek::fusion::Utils::Tools::range(_5815,safe_add( _5817,_5815 ));
      _checked_ptr_1<int> _ptr__5820(_5820 ? _5820->raw() : nullptr,_5820 ? _5820->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5821 = ::mosek::fusion::Utils::Tools::range((int)0,_5817);
      _checked_ptr_1<int> _ptr__5821(_5821 ? _5821->raw() : nullptr,_5821 ? _5821->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5816,_5816,_5820,_5821,_5813)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5822) { return mosek::fusion::p_Matrix::diag(_5822); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5822){
  _checked_ptr_1<double> _ptr__5822(_5822 ? _5822->raw() : nullptr, _5822 ? _5822->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5822,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5823,    int _5824) { return mosek::fusion::p_Matrix::ones(_5823,_5824); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5823,int _5824){
  return ::mosek::fusion::p_Matrix::dense(_5823,_5824,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5825) { return mosek::fusion::p_Matrix::eye(_5825); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5825){
  std::vector<double> _9550;
  for (int _5826 = (int)0, _9551 = _5825; _5826 < _9551 ; ++_5826)
  {
    _9550.push_back(1.0);
  }
  auto _9552 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9550.size()),_9550.begin(),_9550.end()));
  return ::mosek::fusion::p_Matrix::diag(_9552);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5827) { return mosek::fusion::p_Matrix::dense(_5827); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5827){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5827)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5828,    int _5829,    double _5830) { return mosek::fusion::p_Matrix::dense(_5828,_5829,_5830); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5828,int _5829,double _5830){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5828,_5829,_5830)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5831,    int _5832,    std::shared_ptr< monty::ndarray< double,1 > > _5833) { return mosek::fusion::p_Matrix::dense(_5831,_5832,_5833); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5831,int _5832,std::shared_ptr< monty::ndarray< double,1 > > _5833){
  _checked_ptr_1<double> _ptr__5833(_5833 ? _5833->raw() : nullptr, _5833 ? _5833->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5831,_5832,_5833)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5834) { return mosek::fusion::p_Matrix::dense(_5834); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5834){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5834)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5835) { return mosek::fusion::p_Matrix::sparse(_5835); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5835){
  std::shared_ptr< monty::ndarray< int,1 > > _5836 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5835->numNonzeros())));
  _checked_ptr_1<int> _ptr__5836(_5836 ? _5836->raw() : nullptr,_5836 ? _5836->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5837 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5835->numNonzeros())));
  _checked_ptr_1<int> _ptr__5837(_5837 ? _5837->raw() : nullptr,_5837 ? _5837->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5838 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5835->numNonzeros())));
  _checked_ptr_1<double> _ptr__5838(_5838 ? _5838->raw() : nullptr,_5838 ? _5838->size(0) : 0);
  _5835->getDataAsTriplets(_5836,_5837,_5838);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5835->numRows(),_5835->numColumns(),_5836,_5837,_5838)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5839) { return mosek::fusion::p_Matrix::sparse(_5839); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5839){
  int _5840 = (int)((_5839)->size(0));
  int _5841 = (int)((((*_5839)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5842 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5840)));
  _checked_ptr_1<int> _ptr__5842(_5842 ? _5842->raw() : nullptr,_5842 ? _5842->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5843 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5841)));
  _checked_ptr_1<int> _ptr__5843(_5843 ? _5843->raw() : nullptr,_5843 ? _5843->size(0) : 0);
  long long _5844 = (long long)0;
  int _5845 = (int)0;
  {
    int _5846 = (int)0;
    for(;(_5846 < _5840);++ _5846)
    {
      {
        {
          int _5847 = (int)0;
          for(;(_5847 < _5841);++ _5847)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5848 = ((*((*_5839)(_5846)))(_5847));
              if ((NULL != _5848.get()))
              {
                {
                  if ((_ptr__5843[_5847] == (int)0))
                  {
                    {
                      _ptr__5843[_5847] = mosek::fusion::p_Matrix::_get_impl(_5848)->dimj;
                    }
                  }
                  else if((_ptr__5843[_5847] != mosek::fusion::p_Matrix::_get_impl(_5848)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5842[_5846] == (int)0))
                  {
                    {
                      _ptr__5842[_5846] = mosek::fusion::p_Matrix::_get_impl(_5848)->dimi;
                    }
                  }
                  else if((_ptr__5842[_5846] != mosek::fusion::p_Matrix::_get_impl(_5848)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5844 = safe_add( _5844,_5848->numNonzeros() );
                }
              }
              {}
              ++ _5845;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5849 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5844)));
  _checked_ptr_1<double> _ptr__5849(_5849 ? _5849->raw() : nullptr,_5849 ? _5849->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5850 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5844)));
  _checked_ptr_1<int> _ptr__5850(_5850 ? _5850->raw() : nullptr,_5850 ? _5850->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5844)));
  _checked_ptr_1<int> _ptr__5851(_5851 ? _5851->raw() : nullptr,_5851 ? _5851->size(0) : 0);
  int _5852 = (int)0;
  int _5853 = (int)0;
  {
    int _5854 = (int)0;
    for(;(_5854 < _5840);++ _5854)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5855 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5841)));
        _checked_ptr_1<int> _ptr__5855(_5855 ? _5855->raw() : nullptr,_5855 ? _5855->size(0) : 0);
        {
          int _5856 = (int)0;
          for(;(_5856 < _ptr__5842[_5854]);++ _5856)
          {
            {
              int _5857 = (int)0;
              {
                int _5858 = (int)0;
                for(;(_5858 < _5841);++ _5858)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5859 = ((*((*_5839)(_5854)))(_5858));
                    if ((NULL != _5859.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9553 = _5859;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9553.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5860 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9553.get()));
                          {
                            int _5863 = _ptr__5855[_5858];
                            {
                              int _5864 = (int)0;
                              for(;(_5864 < mosek::fusion::p_Matrix::_get_impl(_5860)->dimj);++ _5864)
                              {
                                {
                                  _ptr__5849[_5852] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5860)->data)(_5863));
                                  _ptr__5850[_5852] = safe_add( _5853,_5856 );
                                  _ptr__5851[_5852] = safe_add( _5857,_5864 );
                                  ++ _5863;
                                  ++ _5852;
                                }
                              }
                            }
                            _ptr__5855[_5858] = _5863;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9553.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5861 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9553.get()));
                          {
                            int _5865;
                            {
                              _5865 = _ptr__5855[_5858];
                              for(;((_5865 < mosek::fusion::p_SparseMatrix::_get_impl(_5861)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5861)->subi)(_5865)) == _5856));++ _5865)
                              {
                                {
                                  _ptr__5849[_5852] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5861)->val)(_5865));
                                  _ptr__5851[_5852] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5861)->subj)(_5865)),_5857 );
                                  _ptr__5850[_5852] = safe_add( _5853,_5856 );
                                  ++ _5852;
                                }
                              }
                            }
                            _ptr__5855[_5858] = _5865;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5862 = _9553;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5857 = safe_add( _5857,_ptr__5843[_5858] );
                  }
                }
              }
            }
          }
        }
        _5853 = safe_add( _5853,_ptr__5842[_5854] );
      }
    }
  }
  int _5866 = (int)0;
  int _5867 = (int)0;
  {
    int _5868 = (int)0;
    for(;(_5868 < _5840);++ _5868)
    {
      {
        _5866 = safe_add( _5866,_ptr__5842[_5868] );
      }
    }
  }
  {
    int _5869 = (int)0;
    for(;(_5869 < _5841);++ _5869)
    {
      {
        _5867 = safe_add( _5867,_ptr__5843[_5869] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5866,_5867,_5850,_5851,_5849)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5870) { return mosek::fusion::p_Matrix::sparse(_5870); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5870){
  int _5871 = (int)((_5870)->size(0));
  int _5872 = (int)((_5870)->size(1));
  long long _5873 = (long long)safe_mul( _5871,_5872 );
  std::vector<int> _9554;
  for (int _5875 = (int)0, _9555 = _5871; _5875 < _9555 ; ++_5875)
  {
    for (int _5876 = (int)0, _9556 = _5872; _5876 < _9556 ; ++_5876)
    {
      _9554.push_back(_5875);
    }
  }
  auto _9557 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9554.size()),_9554.begin(),_9554.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5874 = _9557;
  _checked_ptr_1<int> _ptr__5874(_5874 ? _5874->raw() : nullptr,_5874 ? _5874->size(0) : 0);
  std::vector<int> _9558;
  for (int _5878 = (int)0, _9559 = _5871; _5878 < _9559 ; ++_5878)
  {
    for (int _5879 = (int)0, _9560 = _5872; _5879 < _9560 ; ++_5879)
    {
      _9558.push_back(_5879);
    }
  }
  auto _9561 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9558.size()),_9558.begin(),_9558.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5877 = _9561;
  _checked_ptr_1<int> _ptr__5877(_5877 ? _5877->raw() : nullptr,_5877 ? _5877->size(0) : 0);
  std::vector<double> _9562;
  for (int _5881 = (int)0, _9563 = _5871; _5881 < _9563 ; ++_5881)
  {
    for (int _5882 = (int)0, _9564 = _5872; _5882 < _9564 ; ++_5882)
    {
      _9562.push_back(((*_5870)(_5881,_5882)));
    }
  }
  auto _9565 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9562.size()),_9562.begin(),_9562.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5880 = _9565;
  _checked_ptr_1<double> _ptr__5880(_5880 ? _5880->raw() : nullptr,_5880 ? _5880->size(0) : 0);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5871,_5872,_5874,_5877,_5880)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5883,    int _5884) { return mosek::fusion::p_Matrix::sparse(_5883,_5884); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5883,int _5884){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5883,_5884,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5885,    int _5886,    std::shared_ptr< monty::ndarray< int,1 > > _5887,    std::shared_ptr< monty::ndarray< int,1 > > _5888,    double _5889) { return mosek::fusion::p_Matrix::sparse(_5885,_5886,_5887,_5888,_5889); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5885,int _5886,std::shared_ptr< monty::ndarray< int,1 > > _5887,std::shared_ptr< monty::ndarray< int,1 > > _5888,double _5889){
  _checked_ptr_1<int> _ptr__5887(_5887 ? _5887->raw() : nullptr, _5887 ? _5887->size(0) : 0);
  _checked_ptr_1<int> _ptr__5888(_5888 ? _5888->raw() : nullptr, _5888 ? _5888->size(0) : 0);
  int _5890 = (int)0;
  if ((NULL != _5887.get()))
  {
    {
      _5890 = (int)((_5887)->size(0));
    }
  }
  else if((NULL != _5888.get()))
  {
    {
      _5890 = (int)((_5888)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_5885,_5886,_5887,_5888,::mosek::fusion::Utils::Tools::makevector(_5889,_5890));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5891,    std::shared_ptr< monty::ndarray< int,1 > > _5892,    double _5893) { return mosek::fusion::p_Matrix::sparse(_5891,_5892,_5893); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5891,std::shared_ptr< monty::ndarray< int,1 > > _5892,double _5893){
  _checked_ptr_1<int> _ptr__5891(_5891 ? _5891->raw() : nullptr, _5891 ? _5891->size(0) : 0);
  _checked_ptr_1<int> _ptr__5892(_5892 ? _5892->raw() : nullptr, _5892 ? _5892->size(0) : 0);
  int _5894 = (int)0;
  int _5895 = (int)0;
  int _5896 = (int)((_5891)->size(0));
  if ((_5896 > (int)((_5892)->size(0))))
  {
    {
      _5896 = (int)((_5892)->size(0));
    }
  }
  {}
  int _9566 = (int)0;
  int _9567 = _5896;
  for (int _5897 = _9566; _5897 < _9567; ++_5897)
  {
    {
      if ((_5895 < _ptr__5891[_5897]))
      {
        {
          _5895 = _ptr__5891[_5897];
        }
      }
      {}
      if ((_5894 < _ptr__5892[_5897]))
      {
        {
          _5894 = _ptr__5892[_5897];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5895,(int)1 ),safe_add( _5894,(int)1 ),_5891,_5892,_5893);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5898,    std::shared_ptr< monty::ndarray< int,1 > > _5899,    std::shared_ptr< monty::ndarray< double,1 > > _5900) { return mosek::fusion::p_Matrix::sparse(_5898,_5899,_5900); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5898,std::shared_ptr< monty::ndarray< int,1 > > _5899,std::shared_ptr< monty::ndarray< double,1 > > _5900){
  _checked_ptr_1<int> _ptr__5898(_5898 ? _5898->raw() : nullptr, _5898 ? _5898->size(0) : 0);
  _checked_ptr_1<int> _ptr__5899(_5899 ? _5899->raw() : nullptr, _5899 ? _5899->size(0) : 0);
  _checked_ptr_1<double> _ptr__5900(_5900 ? _5900->raw() : nullptr, _5900 ? _5900->size(0) : 0);
  int _5901 = (int)0;
  int _5902 = (int)0;
  int _5903 = (int)((_5898)->size(0));
  if ((_5903 > (int)((_5899)->size(0))))
  {
    {
      _5903 = (int)((_5899)->size(0));
    }
  }
  {}
  if ((_5903 > (int)((_5900)->size(0))))
  {
    {
      _5903 = (int)((_5900)->size(0));
    }
  }
  {}
  int _9568 = (int)0;
  int _9569 = _5903;
  for (int _5904 = _9568; _5904 < _9569; ++_5904)
  {
    {
      if ((_5902 < _ptr__5898[_5904]))
      {
        {
          _5902 = _ptr__5898[_5904];
        }
      }
      {}
      if ((_5901 < _ptr__5899[_5904]))
      {
        {
          _5901 = _ptr__5899[_5904];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5902,(int)1 ),safe_add( _5901,(int)1 ),_5898,_5899,_5900);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5905,    int _5906,    std::shared_ptr< monty::ndarray< int,1 > > _5907,    std::shared_ptr< monty::ndarray< int,1 > > _5908,    std::shared_ptr< monty::ndarray< double,1 > > _5909) { return mosek::fusion::p_Matrix::sparse(_5905,_5906,_5907,_5908,_5909); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5905,int _5906,std::shared_ptr< monty::ndarray< int,1 > > _5907,std::shared_ptr< monty::ndarray< int,1 > > _5908,std::shared_ptr< monty::ndarray< double,1 > > _5909){
  _checked_ptr_1<int> _ptr__5907(_5907 ? _5907->raw() : nullptr, _5907 ? _5907->size(0) : 0);
  _checked_ptr_1<int> _ptr__5908(_5908 ? _5908->raw() : nullptr, _5908 ? _5908->size(0) : 0);
  _checked_ptr_1<double> _ptr__5909(_5909 ? _5909->raw() : nullptr, _5909 ? _5909->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9570;
  bool _9571 = (NULL != _5909.get());
  if (_9571)
  {
    _9570 = _5909;
  }
  else
  {
    _9570 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5910 = _9570;
  _checked_ptr_1<double> _ptr__5910(_5910 ? _5910->raw() : nullptr,_5910 ? _5910->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9572;
  bool _9573 = (NULL != _5908.get());
  if (_9573)
  {
    _9572 = _5908;
  }
  else
  {
    _9572 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5911 = _9572;
  _checked_ptr_1<int> _ptr__5911(_5911 ? _5911->raw() : nullptr,_5911 ? _5911->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9574;
  bool _9575 = (NULL != _5907.get());
  if (_9575)
  {
    _9574 = _5907;
  }
  else
  {
    _9574 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5912 = _9574;
  _checked_ptr_1<int> _ptr__5912(_5912 ? _5912->raw() : nullptr,_5912 ? _5912->size(0) : 0);
  long long _5913 = (long long)((_5912)->size(0));
  if ((((long long)((_5911)->size(0)) != _5913) || ((long long)((_5910)->size(0)) != _5913)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5905,_5906,_5912,_5911,_5910,_5913)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _5919) : RuntimeException(_5919)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _5920) : RuntimeException(_5920)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _5921) : RuntimeException(_5921.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _5922) : RuntimeException(_5922)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _5923) : mosek::fusion::FusionRuntimeException(_5923)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _5924) : mosek::fusion::FusionException(_5924)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _5925) : mosek::fusion::FusionRuntimeException(_5925)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _5926) : mosek::fusion::FusionRuntimeException(_5926)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _5927) : mosek::fusion::FusionRuntimeException(_5927)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _5928) : mosek::fusion::FusionRuntimeException(_5928)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _5929) : mosek::fusion::FusionRuntimeException(_5929)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _5930) : mosek::fusion::FusionRuntimeException(_5930)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _5931) : mosek::fusion::FusionRuntimeException(_5931)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _5932) : mosek::fusion::FusionRuntimeException(_5932)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _5933) : mosek::fusion::FusionRuntimeException(_5933)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _5934) : mosek::fusion::FusionRuntimeException(_5934)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _5935) : mosek::fusion::FusionRuntimeException(_5935)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _5936) : mosek::fusion::FusionRuntimeException(_5936)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _5937) : mosek::fusion::FusionRuntimeException(_5937)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _5938) : mosek::fusion::FusionRuntimeException(_5938)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _5939) : mosek::fusion::FusionRuntimeException(_5939)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _5940) : RuntimeException(_5940)  {
    msg = _5940;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _5941) : Exception(_5941)  {
    msg = _5941;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _5942){ return new mosek::fusion::LinkedBlocks(_5942); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _5942) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5942); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _5942){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_5942);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5943){ return new mosek::fusion::LinkedBlocks(_5943); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5943) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5943); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5943){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5943)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5943)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5943)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5943)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _5944) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_5944); }void mosek::fusion::p_LinkedBlocks::free(int _5944){
  int _5945 = ((*bfirst)(_5944));
  ints->free(_5944,((*bsize)(_5944)));
  ((*bsize)(_5944)) = (-(int)1);
  ((*bfirst)(_5944)) = (-(int)1);
  blocks->free(_5945,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _5946) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_5946); }int mosek::fusion::p_LinkedBlocks::alloc(int _5946){
  int _9576;
  bool _9577 = (_5946 > (int)0);
  if (_9577)
  {
    _9576 = ints->alloc(_5946);
  }
  else
  {
    _9576 = (-(int)1);
  }
  int _5947 = _9576;
  int _5948 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5949 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5949(_5949 ? _5949->raw() : nullptr,_5949 ? _5949->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5950 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5950(_5950 ? _5950->raw() : nullptr,_5950 ? _5950->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_5949,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_5950,(int)0,(int)((bfirst)->size(0)));
      bsize = _5949;
      bfirst = _5950;
    }
  }
  {}
  ((*bfirst)(_5948)) = _5947;
  ((*bsize)(_5948)) = _5946;
  return _5948;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _5951) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_5951); }int mosek::fusion::p_LinkedBlocks::maxidx(int _5951){
  return ints->maxidx(((*bfirst)(_5951)),((*bsize)(_5951)));
}
void mosek::fusion::LinkedBlocks :: get(int _5952,std::shared_ptr< monty::ndarray< int,1 > > _5953,int _5954) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_5952,_5953,_5954); }void mosek::fusion::p_LinkedBlocks::get(int _5952,std::shared_ptr< monty::ndarray< int,1 > > _5953,int _5954){
  _checked_ptr_1<int> _ptr__5953(_5953 ? _5953->raw() : nullptr, _5953 ? _5953->size(0) : 0);
  ints->get(((*bfirst)(_5952)),((*bsize)(_5952)),_5953,_5954);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _5955) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_5955); }int mosek::fusion::p_LinkedBlocks::blocksize(int _5955){
  return ((*bsize)(_5955));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _5956){ return new mosek::fusion::LinkedInts(_5956); }mosek::fusion::LinkedInts::LinkedInts  (int _5956) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5956); }void mosek::fusion::p_LinkedInts::_initialize  (int _5956){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9578;
    bool _9579 = (_5956 > (int)0);
    if (_9579)
    {
      _9578 = _5956;
    }
    else
    {
      _9578 = (int)128;
    }
    int _5957 = _9578;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5957)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5957)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_5957 - (int)1);
    int _9580 = (int)1;
    int _9581 = _5957;
    for (int _5958 = _9580; _5958 < _9581; ++_5958)
    {
      {
        ((*prev)(_5958)) = (_5958 - (int)1);
        ((*next)((_5958 - (int)1))) = _5958;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_5957 - (int)1))) = (-(int)1);
    nfree = _5957;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5959){ return new mosek::fusion::LinkedInts(_5959); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5959) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5959); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5959){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5959)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5959)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_5959)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_5959)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_5959)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_5959)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _5960,int _5961) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_5960,_5961); }void mosek::fusion::p_LinkedInts::free(int _5960,int _5961){
  int _5962 = _5960;
  int _5963 = _5962;
  int _9582 = (int)0;
  int _9583 = (_5961 - (int)1);
  for (int _5964 = _9582; _5964 < _9583; ++_5964)
  {
    {
      _5963 = ((*next)(_5963));
    }
  }
  int _5965 = ((*prev)(_5962));
  int _5966 = ((*next)(_5963));
  if ((_5965 >= (int)0))
  {
    {
      ((*next)(_5965)) = _5966;
    }
  }
  {}
  if ((_5966 >= (int)0))
  {
    {
      ((*prev)(_5966)) = _5965;
    }
  }
  {}
  ((*prev)(_5962)) = (-(int)1);
  ((*next)(_5963)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _5963;
    }
  }
  {}
  first_free = _5962;
  nfree += _5961;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _5967) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_5967); }int mosek::fusion::p_LinkedInts::alloc(int _5967){
  return allocblock(_5967);
}
void mosek::fusion::LinkedInts :: alloc(int _5968,std::shared_ptr< monty::ndarray< int,1 > > _5969,int _5970) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_5968,_5969,_5970); }void mosek::fusion::p_LinkedInts::alloc(int _5968,std::shared_ptr< monty::ndarray< int,1 > > _5969,int _5970){
  _checked_ptr_1<int> _ptr__5969(_5969 ? _5969->raw() : nullptr, _5969 ? _5969->size(0) : 0);
  int _5971 = allocblock(_5968);
  int _9584 = (int)0;
  int _9585 = _5968;
  for (int _5972 = _9584; _5972 < _9585; ++_5972)
  {
    {
      _ptr__5969[safe_add( _5972,_5970 )] = _5971;
      _5971 = ((*next)(_5971));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _5973,int _5974,std::shared_ptr< monty::ndarray< int,1 > > _5975,int _5976) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_5973,_5974,_5975,_5976); }void mosek::fusion::p_LinkedInts::get(int _5973,int _5974,std::shared_ptr< monty::ndarray< int,1 > > _5975,int _5976){
  _checked_ptr_1<int> _ptr__5975(_5975 ? _5975->raw() : nullptr, _5975 ? _5975->size(0) : 0);
  int _5977 = _5973;
  int _9586 = (int)0;
  int _9587 = _5974;
  for (int _5978 = _9586; _5978 < _9587; ++_5978)
  {
    {
      _ptr__5975[safe_add( _5978,_5976 )] = _5977;
      _5977 = ((*next)(_5977));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _5979,int _5980) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_5979,_5980); }int mosek::fusion::p_LinkedInts::maxidx(int _5979,int _5980){
  int _5981 = _5979;
  int _5982 = _5979;
  int _9588 = (int)1;
  int _9589 = _5980;
  for (int _5983 = _9588; _5983 < _9589; ++_5983)
  {
    {
      _5982 = ((*next)(_5982));
      if ((_5981 < _5982))
      {
        {
          _5981 = _5982;
        }
      }
      {}
    }
  }
  return _5981;
}
int mosek::fusion::p_LinkedInts::allocblock(int _5984){
  int _5985 = (int)((next)->size(0));
  if ((nfree < _5984))
  {
    {
      int _5986 = (_5984 - nfree);
      if ((_5986 < _5985))
      {
        {
          _5986 = _5985;
        }
      }
      {}
      recap(safe_add( _5986,_5985 ));
    }
  }
  {}
  int _5987 = first_free;
  int _5988 = _5987;
  int _9590 = (int)0;
  int _9591 = (_5984 - (int)1);
  for (int _5989 = _9590; _5989 < _9591; ++_5989)
  {
    {
      _5988 = ((*next)(_5988));
    }
  }
  first_free = ((*next)(_5988));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_5988)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _5988;
    }
  }
  {}
  first_used = _5987;
  nfree -= _5984;
  return _5987;
}
void mosek::fusion::p_LinkedInts::recap(int _5990){
  int _5991 = (int)((next)->size(0));
  if ((_5990 > _5991))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_5990);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_5990);
      int _9592 = _5991;
      int _9593 = (_5990 - (int)1);
      for (int _5992 = _9592; _5992 < _9593; ++_5992)
      {
        {
          ((*next)(_5992)) = safe_add( _5992,(int)1 );
          ((*prev)(safe_add( _5992,(int)1 ))) = _5992;
        }
      }
      ((*next)((_5990 - (int)1))) = (-(int)1);
      ((*prev)(_5991)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _5991;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _5991;
        }
      }
      last_free = (_5990 - (int)1);
      nfree += (_5990 - _5991);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _5993 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _5994 = first_used;
  while ( (_5994 >= (int)0) )
  {
    {
      ((*_5993)(_5994)) = true;
      _5994 = ((*next)(_5994));
      if (((_5994 >= (int)0) && ((*_5993)(_5994))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _5994 = first_free;
  int _5995 = (int)0;
  while ( (_5994 >= (int)0) )
  {
    {
      ++ _5995;
      ((*_5993)(_5994)) = true;
      _5994 = ((*next)(_5994));
      if (((_5994 >= (int)0) && ((*_5993)(_5994))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_5995 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9594 = (int)0;
  int _9595 = (int)((_5993)->size(0));
  for (int _5996 = _9594; _5996 < _9595; ++_5996)
  {
    {
      if ((!((*_5993)(_5994))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9596 = (int)0;
  int _9597 = (int)((_5993)->size(0));
  for (int _5997 = _9596; _5997 < _9597; ++_5997)
  {
    {
      ((*_5993)(_5997)) = false;
    }
  }
  _5994 = last_free;
  int _5998 = (int)0;
  while ( (_5994 >= (int)0) )
  {
    {
      ++ _5998;
      ((*_5993)(_5994)) = true;
      _5994 = ((*prev)(_5994));
      if (((_5994 >= (int)0) && ((*_5993)(_5994))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_5998 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _5999,    const std::string & _6000,    double _6001) { mosek::fusion::p_Parameters::setParameter(_5999,_6000,_6001); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _5999,const std::string & _6000,double _6001){
  if (false)
  {
    {
    }
  }
  else if((_6000 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6000 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6000 == std::string ("numThreads")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6002 = _6001;
          if (((int)0 <= _6002))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6002);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6000 == std::string ("mtSpincount")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6003 = _6001;
          if ((((int)0 <= _6003) && (_6003 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6003);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6000 == std::string ("biMaxIterations")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6004 = _6001;
          if (((int)0 <= _6004))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6004);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6005 = _6001;
          if (((int)0 <= _6005))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6005);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6006 = _6001;
          if (((int)0 <= _6006))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6006);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logResponse")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6007 = _6001;
          if (((int)0 <= _6007))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6007);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logBi")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6008 = _6001;
          if (((int)0 <= _6008))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6008);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logBiFreq")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6009 = _6001;
          if (((int)0 <= _6009))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6009);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6000 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6000 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6000 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6000 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6000 == std::string ("logIntpnt")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6010 = _6001;
          if (((int)0 <= _6010))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6010);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6011 = _6001;
          if (((int)0 <= _6011))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6011);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6012 = _6001;
          if (((int)0 <= _6012))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6012);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_6000 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6000 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6000 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6000 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6013 = _6001;
          if (((-(int)1) <= _6013))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6013);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6000 == std::string ("presolveLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6014 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6014);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logPresolve")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6015 = _6001;
          if (((int)0 <= _6015))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6015);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6000 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6016 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6016);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6017 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6017);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6018 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6018);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simPrimalCrash")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6019 = _6001;
          if (((int)0 <= _6019))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6019);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logSim")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6020 = _6001;
          if (((int)0 <= _6020))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6020);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logSimMinor")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6021 = _6001;
          if (((int)0 <= _6021))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6021);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logSimFreq")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6022 = _6001;
          if (((int)0 <= _6022))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6022);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6023 = _6001;
          if ((((int)0 <= _6023) && (_6023 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6023);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6000 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6024 = _6001;
          if ((((int)0 <= _6024) && (_6024 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6024);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6000 == std::string ("simMaxIterations")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6025 = _6001;
          if (((int)0 <= _6025))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6025);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6000 == std::string ("simRefactorFreq")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6026 = _6001;
          if (((int)0 <= _6026))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6026);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simSeed")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6027 = _6001;
          if ((((int)0 <= _6027) && (_6027 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6027);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6000 == std::string ("logMio")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6028 = _6001;
          if (((int)0 <= _6028))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6028);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logMioFreq")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6029 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6029);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6030 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6030);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6031 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6031);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6032 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6032);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6000 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6033 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6033);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioProbingLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6034 = _6001;
          if ((((-(int)1) <= _6034) && (_6034 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6034);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6035 = _6001;
          if ((((-(int)1) <= _6035) && (_6035 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6035);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6036 = _6001;
          if ((((-(int)1) <= _6036) && (_6036 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6036);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6000 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6000 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6000 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6000 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6000 == std::string ("mioSeed")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6037 = _6001;
          if (((int)0 <= _6037))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6037);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6000 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6000 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6038 = _6001;
          if (((int)40 <= _6038))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6038);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6039 = _6001;
          if (((int)0 <= _6039))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6039);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6000 == std::string ("logInfeasAna")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6040 = _6001;
          if (((int)0 <= _6040))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6040);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6000 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6000 == std::string ("licensePauseTime")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6041 = _6001;
          if ((((int)0 <= _6041) && (_6041 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6041);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6000 == std::string ("log")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6042 = _6001;
          if (((int)0 <= _6042))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6042);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logExpand")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6043 = _6001;
          if (((int)0 <= _6043))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6043);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logFile")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6044 = _6001;
          if (((int)0 <= _6044))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6044);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("logOrder")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6045 = _6001;
          if (((int)0 <= _6045))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6045);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6000 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6000 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6046 = _6001;
          if ((((int)0 <= _6046) && (_6046 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6046);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6047 = _6001;
          if ((((int)0 <= _6047) && (_6047 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6047);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6048 = _6001;
          if (((int)0 <= _6048))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6048);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6000 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6000 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6000 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6000 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6000 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6000 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6000 == std::string ("simDualCrash")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6049 = _6001;
          if (((int)0 <= _6049))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6049);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6000 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6050 = _6001;
          if ((((-(int)1) <= _6050) && (_6050 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6050);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6000 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6000 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6000 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6000 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6000 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6051 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6051);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6052 = _6001;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6052);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6000 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6000 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6000 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6000 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_6001 - (int)_6001) == 0.0))
      {
        {
          double _6053 = _6001;
          if (((-(int)1) <= _6053))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6053);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("optimizerMaxTime")))
  {
    {
      double _6054 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6054);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("lowerObjCut")))
  {
    {
      double _6055 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6055);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("upperObjCut")))
  {
    {
      double _6056 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6056);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6057 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6057);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6058 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6058);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolRelGap")))
  {
    {
      double _6059 = _6001;
      if ((1.000000e-14 <= _6059))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6059);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolStepSize")))
  {
    {
      double _6060 = _6001;
      if (((0.000000e+00 <= _6060) && (_6060 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6060);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6061 = _6001;
      if (((1.000000e-06 <= _6061) && (_6061 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6061);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolRelStep")))
  {
    {
      double _6062 = _6001;
      if (((1.000000e-04 <= _6062) && (_6062 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6062);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolPath")))
  {
    {
      double _6063 = _6001;
      if (((0.000000e+00 <= _6063) && (_6063 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6063);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolPfeas")))
  {
    {
      double _6064 = _6001;
      if (((0.000000e+00 <= _6064) && (_6064 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6064);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolDfeas")))
  {
    {
      double _6065 = _6001;
      if (((0.000000e+00 <= _6065) && (_6065 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6065);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolMuRed")))
  {
    {
      double _6066 = _6001;
      if (((0.000000e+00 <= _6066) && (_6066 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6066);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolInfeas")))
  {
    {
      double _6067 = _6001;
      if (((0.000000e+00 <= _6067) && (_6067 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6067);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6068 = _6001;
      if (((0.000000e+00 <= _6068) && (_6068 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6068);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6069 = _6001;
      if (((0.000000e+00 <= _6069) && (_6069 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6069);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6070 = _6001;
      if (((0.000000e+00 <= _6070) && (_6070 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6070);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6071 = _6001;
      if (((0.000000e+00 <= _6071) && (_6071 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6071);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6072 = _6001;
      if ((1.000000e+00 <= _6072))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6072);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6073 = _6001;
      if (((0.000000e+00 <= _6073) && (_6073 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6073);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolPsafe")))
  {
    {
      double _6074 = _6001;
      if ((1.000000e-04 <= _6074))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6074);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("intpntTolDsafe")))
  {
    {
      double _6075 = _6001;
      if ((1.000000e-04 <= _6075))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6075);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioMaxTime")))
  {
    {
      double _6076 = _6001;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6076);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioRelGapConst")))
  {
    {
      double _6077 = _6001;
      if ((1.000000e-15 <= _6077))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6077);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioTolRelGap")))
  {
    {
      double _6078 = _6001;
      if ((0.000000e+00 <= _6078))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6078);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioTolAbsGap")))
  {
    {
      double _6079 = _6001;
      if ((0.000000e+00 <= _6079))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6079);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6080 = _6001;
      if ((1.000000e-09 <= _6080))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6080);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("basisTolX")))
  {
    {
      double _6081 = _6001;
      if ((1.000000e-09 <= _6081))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6081);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("basisTolS")))
  {
    {
      double _6082 = _6001;
      if ((1.000000e-09 <= _6082))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6082);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("basisRelTolS")))
  {
    {
      double _6083 = _6001;
      if ((0.000000e+00 <= _6083))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6083);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveTolX")))
  {
    {
      double _6084 = _6001;
      if ((0.000000e+00 <= _6084))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6084);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveTolS")))
  {
    {
      double _6085 = _6001;
      if ((0.000000e+00 <= _6085))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6085);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveTolAij")))
  {
    {
      double _6086 = _6001;
      if ((1.000000e-15 <= _6086))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6086);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6087 = _6001;
      if ((0.000000e+00 <= _6087))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6087);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6088 = _6001;
      if ((0.000000e+00 <= _6088))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6088);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6089 = _6001;
      if ((1.000000e-12 <= _6089))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6089);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioTolFeas")))
  {
    {
      double _6090 = _6001;
      if (((1.000000e-09 <= _6090) && (_6090 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6090);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6091 = _6001;
      if ((0.000000e+00 <= _6091))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6091);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6000 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6092 = _6001;
      if (((0.000000e+00 <= _6092) && (_6092 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5999.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6092);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6000 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6000 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6000 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6000 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6000 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6000 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6093,    const std::string & _6094,    int _6095) { mosek::fusion::p_Parameters::setParameter(_6093,_6094,_6095); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6093,const std::string & _6094,int _6095){
  if (false)
  {
    {
    }
  }
  else if((_6094 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6094 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6094 == std::string ("numThreads")))
  {
    {
      int _6096 = _6095;
      if (((int)0 <= _6096))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6096);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6094 == std::string ("mtSpincount")))
  {
    {
      int _6097 = _6095;
      if ((((int)0 <= _6097) && (_6097 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6097);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6094 == std::string ("biMaxIterations")))
  {
    {
      int _6098 = _6095;
      if (((int)0 <= _6098))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6098);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6099 = _6095;
      if (((int)0 <= _6099))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6099);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logCutSecondOpt")))
  {
    {
      int _6100 = _6095;
      if (((int)0 <= _6100))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6100);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logResponse")))
  {
    {
      int _6101 = _6095;
      if (((int)0 <= _6101))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6101);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logBi")))
  {
    {
      int _6102 = _6095;
      if (((int)0 <= _6102))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6102);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logBiFreq")))
  {
    {
      int _6103 = _6095;
      if (((int)0 <= _6103))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6103);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6094 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6094 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6094 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6094 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6094 == std::string ("logIntpnt")))
  {
    {
      int _6104 = _6095;
      if (((int)0 <= _6104))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6104);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntMaxIterations")))
  {
    {
      int _6105 = _6095;
      if (((int)0 <= _6105))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6105);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntOffColTrh")))
  {
    {
      int _6106 = _6095;
      if (((int)0 <= _6106))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6106);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_6094 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6094 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6094 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6094 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6107 = _6095;
      if (((-(int)1) <= _6107))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6107);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6094 == std::string ("presolveLevel")))
  {
    {
      int _6108 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6108);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logPresolve")))
  {
    {
      int _6109 = _6095;
      if (((int)0 <= _6109))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6109);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6094 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6110 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6110);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6111 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6111);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6112 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6112);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simPrimalCrash")))
  {
    {
      int _6113 = _6095;
      if (((int)0 <= _6113))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6113);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logSim")))
  {
    {
      int _6114 = _6095;
      if (((int)0 <= _6114))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6114);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logSimMinor")))
  {
    {
      int _6115 = _6095;
      if (((int)0 <= _6115))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6115);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logSimFreq")))
  {
    {
      int _6116 = _6095;
      if (((int)0 <= _6116))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6116);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6117 = _6095;
      if ((((int)0 <= _6117) && (_6117 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6117);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6094 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6118 = _6095;
      if ((((int)0 <= _6118) && (_6118 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6118);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6094 == std::string ("simMaxIterations")))
  {
    {
      int _6119 = _6095;
      if (((int)0 <= _6119))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6119);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6094 == std::string ("simRefactorFreq")))
  {
    {
      int _6120 = _6095;
      if (((int)0 <= _6120))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6120);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simSeed")))
  {
    {
      int _6121 = _6095;
      if ((((int)0 <= _6121) && (_6121 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6121);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6094 == std::string ("logMio")))
  {
    {
      int _6122 = _6095;
      if (((int)0 <= _6122))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6122);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logMioFreq")))
  {
    {
      int _6123 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6123);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6124 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6124);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6125 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6125);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6126 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6126);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6094 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6127 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6127);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioProbingLevel")))
  {
    {
      int _6128 = _6095;
      if ((((-(int)1) <= _6128) && (_6128 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6128);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6129 = _6095;
      if ((((-(int)1) <= _6129) && (_6129 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6129);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6130 = _6095;
      if ((((-(int)1) <= _6130) && (_6130 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6130);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6094 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6094 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6094 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6094 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6094 == std::string ("mioSeed")))
  {
    {
      int _6131 = _6095;
      if (((int)0 <= _6131))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6131);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6094 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6094 == std::string ("writeLpLineWidth")))
  {
    {
      int _6132 = _6095;
      if (((int)40 <= _6132))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6132);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6133 = _6095;
      if (((int)0 <= _6133))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6133);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6094 == std::string ("logInfeasAna")))
  {
    {
      int _6134 = _6095;
      if (((int)0 <= _6134))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6134);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6094 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6094 == std::string ("licensePauseTime")))
  {
    {
      int _6135 = _6095;
      if ((((int)0 <= _6135) && (_6135 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6094 == std::string ("log")))
  {
    {
      int _6136 = _6095;
      if (((int)0 <= _6136))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logExpand")))
  {
    {
      int _6137 = _6095;
      if (((int)0 <= _6137))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logFile")))
  {
    {
      int _6138 = _6095;
      if (((int)0 <= _6138))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("logOrder")))
  {
    {
      int _6139 = _6095;
      if (((int)0 <= _6139))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6094 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6094 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6140 = _6095;
      if ((((int)0 <= _6140) && (_6140 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6141 = _6095;
      if ((((int)0 <= _6141) && (_6141 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6142 = _6095;
      if (((int)0 <= _6142))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6094 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6094 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6094 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6094 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6094 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6094 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6094 == std::string ("simDualCrash")))
  {
    {
      int _6143 = _6095;
      if (((int)0 <= _6143))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6094 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6144 = _6095;
      if ((((-(int)1) <= _6144) && (_6144 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6094 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6094 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6094 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6094 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6094 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6145 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6146 = _6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6094 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6094 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6094 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6094 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6147 = _6095;
      if (((-(int)1) <= _6147))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("optimizerMaxTime")))
  {
    {
      double _6148 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("lowerObjCut")))
  {
    {
      double _6149 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("upperObjCut")))
  {
    {
      double _6150 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6151 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6152 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolRelGap")))
  {
    {
      double _6153 = (double)_6095;
      if ((1.000000e-14 <= _6153))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolStepSize")))
  {
    {
      double _6154 = (double)_6095;
      if (((0.000000e+00 <= _6154) && (_6154 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6155 = (double)_6095;
      if (((1.000000e-06 <= _6155) && (_6155 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolRelStep")))
  {
    {
      double _6156 = (double)_6095;
      if (((1.000000e-04 <= _6156) && (_6156 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolPath")))
  {
    {
      double _6157 = (double)_6095;
      if (((0.000000e+00 <= _6157) && (_6157 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolPfeas")))
  {
    {
      double _6158 = (double)_6095;
      if (((0.000000e+00 <= _6158) && (_6158 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolDfeas")))
  {
    {
      double _6159 = (double)_6095;
      if (((0.000000e+00 <= _6159) && (_6159 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolMuRed")))
  {
    {
      double _6160 = (double)_6095;
      if (((0.000000e+00 <= _6160) && (_6160 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolInfeas")))
  {
    {
      double _6161 = (double)_6095;
      if (((0.000000e+00 <= _6161) && (_6161 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6162 = (double)_6095;
      if (((0.000000e+00 <= _6162) && (_6162 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6163 = (double)_6095;
      if (((0.000000e+00 <= _6163) && (_6163 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6164 = (double)_6095;
      if (((0.000000e+00 <= _6164) && (_6164 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6165 = (double)_6095;
      if (((0.000000e+00 <= _6165) && (_6165 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6166 = (double)_6095;
      if ((1.000000e+00 <= _6166))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6167 = (double)_6095;
      if (((0.000000e+00 <= _6167) && (_6167 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolPsafe")))
  {
    {
      double _6168 = (double)_6095;
      if ((1.000000e-04 <= _6168))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("intpntTolDsafe")))
  {
    {
      double _6169 = (double)_6095;
      if ((1.000000e-04 <= _6169))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioMaxTime")))
  {
    {
      double _6170 = (double)_6095;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioRelGapConst")))
  {
    {
      double _6171 = (double)_6095;
      if ((1.000000e-15 <= _6171))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioTolRelGap")))
  {
    {
      double _6172 = (double)_6095;
      if ((0.000000e+00 <= _6172))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioTolAbsGap")))
  {
    {
      double _6173 = (double)_6095;
      if ((0.000000e+00 <= _6173))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6173);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6174 = (double)_6095;
      if ((1.000000e-09 <= _6174))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6174);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("basisTolX")))
  {
    {
      double _6175 = (double)_6095;
      if ((1.000000e-09 <= _6175))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6175);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("basisTolS")))
  {
    {
      double _6176 = (double)_6095;
      if ((1.000000e-09 <= _6176))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("basisRelTolS")))
  {
    {
      double _6177 = (double)_6095;
      if ((0.000000e+00 <= _6177))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveTolX")))
  {
    {
      double _6178 = (double)_6095;
      if ((0.000000e+00 <= _6178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveTolS")))
  {
    {
      double _6179 = (double)_6095;
      if ((0.000000e+00 <= _6179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveTolAij")))
  {
    {
      double _6180 = (double)_6095;
      if ((1.000000e-15 <= _6180))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6181 = (double)_6095;
      if ((0.000000e+00 <= _6181))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6182 = (double)_6095;
      if ((0.000000e+00 <= _6182))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6183 = (double)_6095;
      if ((1.000000e-12 <= _6183))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioTolFeas")))
  {
    {
      double _6184 = (double)_6095;
      if (((1.000000e-09 <= _6184) && (_6184 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6185 = (double)_6095;
      if ((0.000000e+00 <= _6185))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6094 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6186 = (double)_6095;
      if (((0.000000e+00 <= _6186) && (_6186 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6093.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6094 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6094 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6094 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6094 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6094 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6094 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6187,    const std::string & _6188,    const std::string & _6189) { mosek::fusion::p_Parameters::setParameter(_6187,_6188,_6189); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6187,const std::string & _6188,const std::string & _6189){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6188 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6190 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6190 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6190);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6191 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6191 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6191);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6193 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6193))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6193);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6192)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntMultiThread")))
  {
    {
      int _6194 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6194 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6194);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6196 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6196) && (_6196 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6196);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6195)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("optimizer")))
  {
    {
      int _6197 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6189);
      if ((_6197 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6197);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6199 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6199))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6199);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6198)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6201 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6201))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6201);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6200)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6203 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6203))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6203);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6202)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6205 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6205))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6205);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6204)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6207 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6207))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6207);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6206)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6209 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6209))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6209);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6208)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("biCleanOptimizer")))
  {
    {
      int _6210 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6189);
      if ((_6210 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6210);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntStartingPoint")))
  {
    {
      int _6211 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6189);
      if ((_6211 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6211);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntDiffStep")))
  {
    {
      int _6212 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6212 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6212);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntScaling")))
  {
    {
      int _6213 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6189);
      if ((_6213 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6213);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntSolveForm")))
  {
    {
      int _6214 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6189);
      if ((_6214 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6214);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6216 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6216))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6216);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6215)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6218 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6218))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6218);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6217)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6220 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6220))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6220);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6219)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntOrderMethod")))
  {
    {
      int _6221 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6189);
      if ((_6221 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6221);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntBasis")))
  {
    {
      int _6222 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6189);
      if ((_6222 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6222);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6223 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6223 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6223);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("biIgnoreNumError")))
  {
    {
      int _6224 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6224 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6224);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6226 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((-(int)1) <= _6226))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6226);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6225)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveUse")))
  {
    {
      int _6227 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6189);
      if ((_6227 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6227);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6229 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6229);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6228)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6231 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6231))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6231);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6230)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveLindepUse")))
  {
    {
      int _6232 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6232 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6232);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6234 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6234);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6233)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6236 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6236);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6235)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6238 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6238);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6237)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6240 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6240))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6240);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6239)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6242 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6242))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6242);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6241)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6244 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6244))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6244);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6243)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6246 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6246))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6246);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6245)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6248 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6248) && (_6248 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6248);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6247)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simPrimalSelection")))
  {
    {
      int _6249 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6189);
      if ((_6249 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6249);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6251 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6251) && (_6251 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6251);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6250)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simDualSelection")))
  {
    {
      int _6252 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6189);
      if ((_6252 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6252);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6254 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6254))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6254);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6253)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simHotstartLu")))
  {
    {
      int _6255 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6255 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6255);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6257 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6257))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6257);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6256)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6259 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6259) && (_6259 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6259);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6258)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioMode")))
  {
    {
      int _6260 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6189);
      if ((_6260 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6260);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6262 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6262))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6262);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6261)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6264 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6264);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6263)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6266 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6266);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6265)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6268 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6268);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6267)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6270 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6270);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6269)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioNodeSelection")))
  {
    {
      int _6271 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6189);
      if ((_6271 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6271);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6273 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6273);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6272)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6275 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((-(int)1) <= _6275) && (_6275 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6275);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6274)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6277 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((-(int)1) <= _6277) && (_6277 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6277);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6276)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6279 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((-(int)1) <= _6279) && (_6279 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6279);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6278)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioBranchDir")))
  {
    {
      int _6280 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6189);
      if ((_6280 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6280);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioRootOptimizer")))
  {
    {
      int _6281 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6189);
      if ((_6281 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6281);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6282 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6189);
      if ((_6282 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6282);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6283 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6283 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6283);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6284 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6284 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6284);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6286 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6286))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6286);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6285)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6287 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6287 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6287);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6288 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6288 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6288);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6290 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)40 <= _6290))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6290);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6289)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6292 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6292))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6292);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6291)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("writeLpFullObj")))
  {
    {
      int _6293 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6293);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6295 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6295))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6295);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6294)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("licenseWait")))
  {
    {
      int _6296 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6296 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6296);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6297 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6297 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6297);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6299 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6299) && (_6299 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6299);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6298)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("licenseDebug")))
  {
    {
      int _6300 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6300 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6300);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6302 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6302))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6302);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6301)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6304 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6304))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6304);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6303)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6306 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6306))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6306);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6305)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6308 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6308))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6308);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6307)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simScaling")))
  {
    {
      int _6309 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6189);
      if ((_6309 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6309);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simScalingMethod")))
  {
    {
      int _6310 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6189);
      if ((_6310 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6310);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6312 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6312) && (_6312 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6312);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6311)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6314 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((int)0 <= _6314) && (_6314 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6314);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6313)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6316 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6316))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6316);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6315)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simHotstart")))
  {
    {
      int _6317 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6189);
      if ((_6317 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6317);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simBasisFactorUse")))
  {
    {
      int _6318 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6318 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6318);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simDegen")))
  {
    {
      int _6319 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6189);
      if ((_6319 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6319);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simReformulation")))
  {
    {
      int _6320 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6189);
      if ((_6320 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6320);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simExploitDupvec")))
  {
    {
      int _6321 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6189);
      if ((_6321 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6321);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simSaveLu")))
  {
    {
      int _6322 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6322 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6322);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simNonSingular")))
  {
    {
      int _6323 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6323 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6323);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6325 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((int)0 <= _6325))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6325);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6324)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6326 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6326 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6326);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6328 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if ((((-(int)1) <= _6328) && (_6328 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6328);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6327)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioCutCmir")))
  {
    {
      int _6329 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6329 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6329);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioCutClique")))
  {
    {
      int _6330 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6330 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6330);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6331 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6331 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6331);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6332 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6332 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6332);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioCutGmi")))
  {
    {
      int _6333 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6333 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6333);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6335 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6335);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6334)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6337 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6337);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6336)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("cacheLicense")))
  {
    {
      int _6338 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6338 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6338);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6339 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6339 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6339);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simSolveForm")))
  {
    {
      int _6340 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6189);
      if ((_6340 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6340);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6341 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6189);
      if ((_6341 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6341);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6343 = ::mosek::fusion::Utils::Tools::toInt(_6189);
          if (((-(int)1) <= _6343))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6343);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6342)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6345 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6345);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6344)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6347 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6347);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6346)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6349 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6349);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6348)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6351 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6351);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6350)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6353 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6353);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6352)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6355 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-14 <= _6355))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6355);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6354)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6357 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6357) && (_6357 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6357);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6356)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6359 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((1.000000e-06 <= _6359) && (_6359 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6359);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6358)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6361 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((1.000000e-04 <= _6361) && (_6361 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6361);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6360)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6363 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6363) && (_6363 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6363);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6362)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6365 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6365) && (_6365 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6365);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6364)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6367 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6367) && (_6367 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6367);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6366)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6369 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6369) && (_6369 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6369);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6368)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6371 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6371) && (_6371 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6371);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6370)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6373 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6373) && (_6373 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6373);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6372)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6375 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6375) && (_6375 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6375);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6374)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6377 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6377) && (_6377 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6379 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6379) && (_6379 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6379);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6378)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6381 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e+00 <= _6381))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6381);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6380)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6383 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6383) && (_6383 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6383);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6382)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6385 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-04 <= _6385))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6385);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6384)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6387 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-04 <= _6387))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6387);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6386)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6389 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6391 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-15 <= _6391))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6393 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6393))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6395 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6395))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6397 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-09 <= _6397))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6399 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-09 <= _6399))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6401 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-09 <= _6401))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6403 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6403))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6405 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6405))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6405);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6404)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6407 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6407))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6407);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6406)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6409 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-15 <= _6409))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6409);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6408)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6411 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6411))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6411);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6410)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6413 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6413))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6413);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6412)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6415 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((1.000000e-12 <= _6415))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6417 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((1.000000e-09 <= _6417) && (_6417 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6417);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6416)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("anaSolInfeasTol")))
  {
    {
      try
      {
        {
          double _6419 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if ((0.000000e+00 <= _6419))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6419);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6418)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6421 = ::mosek::fusion::Utils::Tools::toDouble(_6189);
          if (((0.000000e+00 <= _6421) && (_6421 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6421);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6420)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6188 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6189);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6189);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6189);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6189);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6189);
      return;
    }
  }
  {}
  if ((_6188 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6187.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6189);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6422){
  if ((_6422 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6422 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6423){
  if ((_6423 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6423 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6424){
  if ((_6424 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6424 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6424 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6424 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6425){
  if ((_6425 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6425 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6425 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6425 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6426){
  if ((_6426 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6426 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6426 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6426 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6426 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6426 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6426 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6427){
  if ((_6427 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6427 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6427 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6427 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6427 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6427 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6427 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6427 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6427 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6427 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6427 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6427 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6427 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6427 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6427 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6427 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6427 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6427 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6427 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6427 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6427 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6427 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6427 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6427 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6428){
  if ((_6428 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6428 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6428 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6429){
  if ((_6429 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6429 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6429 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6430){
  if ((_6430 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6430 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6430 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6430 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6430 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6430 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6430 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6430 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6430 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6430 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6431){
  if ((_6431 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6431 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6431 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6431 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6431 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6431 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6431 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6431 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6432){
  if ((_6432 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6432 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6432 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6432 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6432 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6432 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6433){
  if ((_6433 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6434){
  if ((_6434 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6434 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6435){
  if ((_6435 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6435 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6435 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6435 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6436){
  if ((_6436 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6436 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6436 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6436 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6436 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6437){
  if ((_6437 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6437 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6437 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6437 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6437 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6437 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6437 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6437 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6437 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6437 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6437 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6437 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6437 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6437 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6437 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6437 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6437 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6437 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6437 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6437 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6437 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6437 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6437 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6437 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6437 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6437 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6437 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6437 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6437 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6437 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6437 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6437 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6437 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6437 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6437 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6437 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6437 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6437 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6437 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6437 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6437 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6437 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6437 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6437 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6437 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6437 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6437 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6437 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6437 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6437 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6437 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6437 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6437 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6437 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6437 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6437 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6437 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6437 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6437 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6437 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6437 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6437 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6437 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6437 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6437 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6437 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6437 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6437 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6437 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6437 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6437 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6437 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6437 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6437 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6437 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6437 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6437 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6437 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6437 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6437 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6437 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6437 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6437 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6437 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6437 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6437 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6437 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6437 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6437 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6437 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6437 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6437 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6437 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6437 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6437 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6437 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6437 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6437 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6437 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6437 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6437 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6437 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6437 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6437 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6437 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6437 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6437 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6437 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6437 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6437 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6437 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6437 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6437 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6437 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6437 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6437 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6437 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6437 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6437 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6437 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6437 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6437 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6437 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6437 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6437 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6437 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6437 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6437 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6437 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6437 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6437 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6437 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6437 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6437 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6437 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6437 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6437 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6437 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6437 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6437 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6437 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6437 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6437 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6437 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6437 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6437 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6437 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6437 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6437 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6437 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6437 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6437 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6437 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6437 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6437 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6437 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6437 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6437 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6437 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6437 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6437 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6437 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6437 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6437 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6437 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6437 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6437 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6437 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6437 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6437 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6437 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6437 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6437 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6437 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6437 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6437 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6437 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6437 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6437 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6437 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6437 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6437 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6437 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6437 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6437 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6437 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6437 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6437 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6437 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6437 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6437 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6437 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6437 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6437 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6437 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6437 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6437 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6437 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6437 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6437 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6437 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6437 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6437 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6437 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6437 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6437 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6437 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6437 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6437 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6437 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6437 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6437 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6437 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6437 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6437 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6437 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6437 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6437 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6437 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6437 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6437 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6437 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6437 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6437 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6437 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6437 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6437 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6437 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6437 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6437 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6437 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6437 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6437 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6437 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6437 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6437 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6437 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6437 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6437 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6437 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6437 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6437 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6437 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6437 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6437 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6437 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6437 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6437 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6437 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6437 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6437 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6437 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6437 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6437 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6437 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6437 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6437 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6437 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6437 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6437 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6437 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6437 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6437 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6437 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6437 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6437 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6437 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6437 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6437 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6437 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6437 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6437 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6437 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6437 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6437 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6437 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6437 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6437 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6437 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6437 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6437 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6437 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6437 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6437 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6437 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6437 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6437 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6437 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6437 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6437 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6437 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6437 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6437 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6437 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6437 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6437 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6437 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6437 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6437 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6437 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6437 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6437 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6437 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6437 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6437 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6437 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6437 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6437 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6437 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6437 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6438){
  if ((_6438 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6438 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6439){
  if ((_6439 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6439 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6439 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6439 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6439 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6439 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6439 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6439 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6439 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6440){
  if ((_6440 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6440 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6440 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6440 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6440 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6441){
  if ((_6441 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6441 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6441 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6442){
  if ((_6442 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6442 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6442 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6442 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6443){
  if ((_6443 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6443 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6443 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6444){
  if ((_6444 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6444 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6444 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6444 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6444 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6444 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6445){
  if ((_6445 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6445 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6445 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6445 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6445 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6445 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6445 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6446){
  if ((_6446 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6446 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6447){
  if ((_6447 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6447 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6448){
  if ((_6448 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6448 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6448 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6448 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6449){
  if ((_6449 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6449 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6449 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6449 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6450){
  if ((_6450 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6450 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6451){
  if ((_6451 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6451 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6451 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6451 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6452){
  if ((_6452 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6452 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6452 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6452 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6452 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6452 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6452 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6452 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6453){
  if ((_6453 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6453 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6453 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6453 == std::string ("intpntPurify")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6453 == std::string ("numThreads")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6453 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6453 == std::string ("timingLevel")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6453 == std::string ("mtSpincount")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6453 == std::string ("maxNumWarnings")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6453 == std::string ("optimizer")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6453 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6453 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6453 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6453 == std::string ("logAnaPro")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6453 == std::string ("logResponse")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6453 == std::string ("logBi")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6453 == std::string ("logBiFreq")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6453 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6453 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6453 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6453 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6453 == std::string ("intpntScaling")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6453 == std::string ("intpntSolveForm")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6453 == std::string ("logIntpnt")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6453 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6453 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6453 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6453 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6453 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6453 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6453 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6453 == std::string ("presolveUse")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6453 == std::string ("presolveLevel")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6453 == std::string ("logPresolve")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6453 == std::string ("presolveLindepUse")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6453 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6453 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6453 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6453 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6453 == std::string ("simStabilityPriority")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6453 == std::string ("simPrimalCrash")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6453 == std::string ("logSim")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6453 == std::string ("logSimMinor")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6453 == std::string ("logSimFreq")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6453 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6453 == std::string ("simPrimalSelection")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6453 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6453 == std::string ("simDualSelection")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6453 == std::string ("simMaxIterations")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6453 == std::string ("simHotstartLu")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6453 == std::string ("simRefactorFreq")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6453 == std::string ("simSeed")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6453 == std::string ("mioMode")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6453 == std::string ("logMio")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6453 == std::string ("logMioFreq")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6453 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6453 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6453 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6453 == std::string ("mioNodeSelection")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6453 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6453 == std::string ("mioProbingLevel")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6453 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6453 == std::string ("mioBranchDir")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6453 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6453 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6453 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6453 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6453 == std::string ("mioSeed")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6453 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6453 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6453 == std::string ("readMpsFormat")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6453 == std::string ("writeMpsFormat")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6453 == std::string ("readMpsWidth")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6453 == std::string ("readDebug")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6453 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6453 == std::string ("writeDataParam")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6453 == std::string ("writeFreeCon")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6453 == std::string ("writeGenericNames")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6453 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6453 == std::string ("writeCompression")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6453 == std::string ("writeMpsInt")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6453 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6453 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6453 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6453 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6453 == std::string ("writeLpFullObj")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6453 == std::string ("writePrecision")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6453 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6453 == std::string ("writeSolHead")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6453 == std::string ("writeSolConstraints")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6453 == std::string ("writeSolVariables")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6453 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6453 == std::string ("writeBasHead")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6453 == std::string ("writeBasConstraints")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6453 == std::string ("writeBasVariables")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6453 == std::string ("writeIntHead")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6453 == std::string ("writeIntConstraints")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6453 == std::string ("writeIntVariables")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6453 == std::string ("solReadNameWidth")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6453 == std::string ("solReadWidth")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6453 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6453 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6453 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6453 == std::string ("logInfeasAna")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6453 == std::string ("licenseWait")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6453 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6453 == std::string ("licensePauseTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6453 == std::string ("licenseDebug")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6453 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6453 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6453 == std::string ("log")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6453 == std::string ("logExpand")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6453 == std::string ("logFile")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6453 == std::string ("logOrder")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6453 == std::string ("logSensitivity")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6453 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6453 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6453 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6453 == std::string ("paramReadCaseName")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6453 == std::string ("paramReadIgnError")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6453 == std::string ("solutionCallback")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6453 == std::string ("simScaling")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6453 == std::string ("simScalingMethod")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6453 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6453 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6453 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6453 == std::string ("simHotstart")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6453 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6453 == std::string ("simDegen")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6453 == std::string ("simReformulation")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6453 == std::string ("simExploitDupvec")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6453 == std::string ("simSaveLu")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6453 == std::string ("simNonSingular")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6453 == std::string ("simDualCrash")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6453 == std::string ("logStorage")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6453 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6453 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteHints")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteParameters")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteProblem")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteHeader")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6453 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6453 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6453 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutCmir")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutClique")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6453 == std::string ("mioCutGmi")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6453 == std::string ("sensitivityType")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6453 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6453 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6453 == std::string ("sensitivityAll")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6453 == std::string ("logFeasRepair")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6453 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6453 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6453 == std::string ("simSolveForm")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6453 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6453 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6453 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6453 == std::string ("logCheckConvexity")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6453 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6453 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6453 == std::string ("writeXmlMode")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6453 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6453 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6453 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6453 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6453 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)76;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6454){
  if ((_6454 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6454 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6454 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6455){
  if ((_6455 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6455 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6455 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6455 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6455 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6455 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6455 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6455 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6455 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6455 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6455 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6455 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6455 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6455 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6455 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6455 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6455 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6455 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6455 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6455 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6455 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6455 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6455 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6455 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6455 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6455 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6455 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6455 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6455 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6455 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6455 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6455 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6455 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6455 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6455 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6455 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6455 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6455 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6455 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6456){
  if ((_6456 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6456 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6456 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6456 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6456 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6456 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6456 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6456 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6456 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6456 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6456 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6456 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6456 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6456 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6456 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6456 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6456 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6456 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6456 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6456 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6456 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6456 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6456 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6456 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6456 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6456 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6456 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6456 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6456 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6456 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6456 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6456 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6456 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6456 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6456 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6456 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6456 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6456 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6456 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6457){
  if ((_6457 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6457 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6457 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6458){
  if ((_6458 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6458 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6458 == std::string ("optimizeResponse")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6458 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6458 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6458 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6458 == std::string ("mioNodeDepth")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumvar")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumbin")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumcont")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumcon")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumcone")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumqcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumrqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6458 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6458 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6458 == std::string ("mioConstructSolution")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6458 == std::string ("mioConstructNumRoundings")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6458 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumRelax")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumBranch")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6458 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6458 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6458 == std::string ("mioInitialSolution")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6458 == std::string ("mioUserObjCut")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6458 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6458 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6458 == std::string ("rdProtype")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumvar")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumintvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumq")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6458 == std::string ("simDualDegIter")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6458 == std::string ("simDualInfIter")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6458 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6458 == std::string ("simPrimalIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6458 == std::string ("simDualIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6458 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6458 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6458 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6458 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6458 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6458 == std::string ("simDualHotstart")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6458 == std::string ("solItrProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6458 == std::string ("solItrSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6458 == std::string ("solBasProsta")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6458 == std::string ("solBasSolsta")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6458 == std::string ("solItgProsta")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6458 == std::string ("solItgSolsta")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6458 == std::string ("simNumcon")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6458 == std::string ("simNumvar")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6458 == std::string ("optNumcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6458 == std::string ("optNumvar")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6458 == std::string ("stoNumARealloc")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6458 == std::string ("rdNumcone")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6458 == std::string ("simSolveDual")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6458 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6458 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)68;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6459){
  if ((_6459 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6459 == std::string ("presolveStackSize")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6460){
  if ((_6460 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6460 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6460 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6460 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6460 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6460 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6460 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6460 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6460 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6460 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6460 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6460 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6460 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6461){
  if ((_6461 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6461 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6461 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6461 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6461 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6461 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6461 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6461 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6461 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6461 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6461 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6461 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6461 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6461 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6461 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6461 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6461 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6461 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6461 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6461 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6461 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6461 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6461 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6461 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6461 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6461 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6461 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6461 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6461 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6461 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6461 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6461 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6461 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6461 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6462){
  if ((_6462 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6462 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6463){
  if ((_6463 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6463 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6463 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6463 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6463 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6463 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6463 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6463 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6463 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6463 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6463 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6463 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6463 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6463 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6463 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6463 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6463 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6463 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6463 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6463 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6463 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6463 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6463 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6463 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6463 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6463 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6463 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6463 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6463 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6463 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6463 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6463 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6463 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6463 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6463 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6463 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6463 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6463 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6463 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6463 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6463 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6463 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6463 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6463 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6463 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6463 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6463 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6463 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6463 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6463 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6463 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6463 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6463 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6463 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6463 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6463 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6463 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6463 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6463 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6463 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6463 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6463 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6463 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6463 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6463 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6463 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6463 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6463 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6463 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6464){
  if ((_6464 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6464 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6464 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6464 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6464 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6464 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6464 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6464 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6464 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6465){
  if ((_6465 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6466){
  if ((_6466 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6466 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6466 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6466 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6466 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6467){
  if ((_6467 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6467 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6467 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6468){
  if ((_6468 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6468 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6468 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6468 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6468 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6468 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6468 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6469){
  if ((_6469 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6469 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6469 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6469 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6470){
  if ((_6470 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6470 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6470 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6471){
  if ((_6471 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6471 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6471 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6471 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6471 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6471 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6471 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6471 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6471 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6471 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6471 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6471 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6471 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6471 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6471 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6471 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6471 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6471 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6471 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6471 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6471 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6471 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6471 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6471 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6471 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6471 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6471 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6471 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6471 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6471 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6471 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6471 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6471 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6471 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6471 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6471 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6471 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6471 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6471 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6471 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6471 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6471 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6471 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6471 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6471 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6471 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6471 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6471 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6471 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6471 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6471 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6471 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6471 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6471 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6471 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6471 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6471 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6471 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6471 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6471 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6471 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6471 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6471 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6471 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6471 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6471 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6471 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6471 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6471 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6471 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6471 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6471 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6471 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6471 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6471 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6471 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6471 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6471 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6471 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6471 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6471 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6471 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6471 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6472){
  if ((_6472 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6472 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6472 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6472 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6472 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6473){
  if ((_6473 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6473 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6473 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6473 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6474){
  if ((_6474 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6474 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6474 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6475){
  if ((_6475 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6475 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6475 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6476){
  if ((_6476 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6476 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6476 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6476 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6477){
  if ((_6477 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6477 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6478){
  if ((_6478 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6478 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6479){
  if ((_6479 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6479 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6479 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6479 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6479 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6480){
  if ((_6480 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6480 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6481){
  if ((_6481 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6481 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6481 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6481 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6481 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6482){
  if ((_6482 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6482 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6482 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6482 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6482 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6483){
  if ((_6483 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6483 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }