#ifndef __FUSION_P_H__
#define __FUSION_P_H__
#include "monty.h"
#include "mosektask_p.h"
#include "list"
#include "vector"
#include "unordered_map"
#include "fusion.h"
namespace mosek
{
namespace fusion
{
// mosek.fusion.BaseModel from file 'src/fusion/cxx/BaseModel_p.h'
// namespace mosek::fusion
struct p_BaseModel
{
  p_BaseModel(BaseModel * _pubthis);

  void _initialize( monty::rc_ptr<BaseModel> m);
  void _initialize( const std::string & name,
                    const std::string & licpath);

  virtual ~p_BaseModel() { /* std::cout << "~p_BaseModel()" << std::endl;*/  }

  static p_BaseModel * _get_impl(Model * _inst) { return _inst->_impl; }

  //----------------------

  bool synched;
  std::string taskname;

  monty::rc_ptr<SolutionStruct> sol_itr;
  monty::rc_ptr<SolutionStruct> sol_itg;
  monty::rc_ptr<SolutionStruct> sol_bas;

  //---------------------

  std::unique_ptr<Task> task;

  //---------------------
  void task_setLogHandler (const msghandler_t & handler);
  void task_setDataCallbackHandler (const datacbhandler_t & handler);
  void task_setCallbackHandler (const cbhandler_t & handler);

  int task_append_barvar(int size, int num);

  void task_var_name   (int index, const std::string & name);
  void task_con_name   (int index, const std::string & name);
  void task_cone_name  (int index, const std::string & name);
  void task_barvar_name(int index, const std::string & name);
  void task_objectivename(         const std::string & name);

  void task_format_var_names(const std::shared_ptr<monty::ndarray<int,1>> subj, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_con_names(const std::shared_ptr<monty::ndarray<int,1>> subi, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_cone_names(const std::shared_ptr<monty::ndarray<int,1>> subk, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);

  void task_break_solve();

  //--------------------------

  int task_numvar();
  int task_numcon();
  int task_numcone();
  int task_numbarvar();

  //--------------------------

  void task_put_param(const std::string & name, const std::string & value);
  void task_put_param(const std::string & name, int    value);
  void task_put_param(const std::string & name, double value);
  
  double    task_get_dinf (const std::string & name);
  int       task_get_iinf (const std::string & name);
  long long task_get_liinf(const std::string & name);
  
  //--------------------------

  void task_con_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_con_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );

  void task_var_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_var_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );
  
  void task_var_putintlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_var_putcontlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs); 
 
  //--------------------------

  void task_putbararowlist(const std::shared_ptr<monty::ndarray<int,1>>       subi,
                           const std::shared_ptr<monty::ndarray<long long,1>> ptr,
                           const std::shared_ptr<monty::ndarray<int,1>>       subj,
                           const std::shared_ptr<monty::ndarray<long long,1>> matidx);

  void task_putbaraijlist(const std::shared_ptr<monty::ndarray<int,1>> subi,
                          const std::shared_ptr<monty::ndarray<int,1>> subj,
                          std::shared_ptr<monty::ndarray<long long,1>> matidx);
  
  void task_putbarc(const std::shared_ptr<monty::ndarray<int,1>> subj,
                    const std::shared_ptr<monty::ndarray<int,1>> subl,
                    const std::shared_ptr<monty::ndarray<int,1>> subk,
                    const std::shared_ptr<monty::ndarray<double,1>> val);
  
  std::shared_ptr<monty::ndarray<long long,1>> task_appendsymmatlist (const std::shared_ptr<monty::ndarray<int,1>>       & dim, 
                                                                      const std::shared_ptr<monty::ndarray<long long,1>> & nz, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subk, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subl, 
                                                                      const std::shared_ptr<monty::ndarray<double,1>>    & val);
  int  task_barvar_dim(int j);
  void task_putbaraij (int i, int j, int k);
  void task_putbaraij (int i, int j, const std::shared_ptr<monty::ndarray<int,1>> & k);
  void task_putbarcj  (int j, int k);
  void task_putbarcj  (int j,        const std::shared_ptr<monty::ndarray<int,1>> & k);
  int  task_barvardim (int index);

  int task_append_var(int num);
  int task_append_con(int num);

  void task_append_zerocones (int numcone);
  void task_clear_cones   ( const std::shared_ptr<monty::ndarray<int,1>> & idxs );
  void task_put_zerocones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_quadcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_rquadcones( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_pexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_ppowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );
  void task_put_dexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_dpowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );

  void task_putarowlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & idxs, 
    const std::shared_ptr<monty::ndarray<long long,1>> & ptrb, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof);
  void task_putaijlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & subi, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof, 
    long long                           num);

  void task_setnumvar(int num);
  void task_cleanup(int oldnum, int oldnumcon, int oldnumcone, int oldnumbarvar);
  void task_solve();

  void task_putobjective( 
    bool                             maximize,
    const std::shared_ptr<monty::ndarray<int,1>>    & subj    ,
    const std::shared_ptr<monty::ndarray<double,1>> & cof     ,
    double                           cfix    );

  void task_putclist(   
    const std::shared_ptr<monty::ndarray<int,1>>    & subj,
    const std::shared_ptr<monty::ndarray<double,1>> & cof);


  void task_putobjectivename(const std::string & name);

  void task_write(const std::string & filename);
  void task_dump (const std::string & filename);

  MSKtask_t task_get();
  MSKtask_t __mosek_2fusion_2BaseModel__task_get();
  
  void dispose();

  void task_putxx_slice(SolutionType which, int first, int last, std::shared_ptr<monty::ndarray<double,1>> & xx);

  static void env_syeig (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);
  static void env_potrf (int n, std::shared_ptr<monty::ndarray<double,1>> & a);                        
  static void env_syevd (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);

  static void env_putlicensecode(std::shared_ptr<monty::ndarray<int,1>> code);
  static void env_putlicensepath(const std::string &licfile);
  static void env_putlicensewait(int wait);

  void convertSolutionStatus(MSKsoltypee soltype, p_SolutionStruct * sol, MSKsolstae status, MSKprostae prosta);


};

// End of file 'src/fusion/cxx/BaseModel_p.h'
struct p_Model : public ::mosek::fusion::p_BaseModel
{
Model * _pubthis;
static mosek::fusion::p_Model* _get_impl(mosek::fusion::Model * _inst){ return static_cast< mosek::fusion::p_Model* >(mosek::fusion::p_BaseModel::_get_impl(_inst)); }
static mosek::fusion::p_Model * _get_impl(mosek::fusion::Model::t _inst) { return _get_impl(_inst.get()); }
p_Model(Model * _pubthis);
virtual ~p_Model() { /* std::cout << "~p_Model" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::WorkStack > xs{};monty::rc_ptr< ::mosek::fusion::WorkStack > ws{};monty::rc_ptr< ::mosek::fusion::WorkStack > rs{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > con_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > cons{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_type{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_ub{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_lb{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_efix{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_idx{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_slackidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconmap{};std::shared_ptr< monty::ndarray< bool,1 > > initsol_xx_flag{};std::shared_ptr< monty::ndarray< double,1 > > initsol_xx{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > var_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > barvars{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_ptr{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_num{};int natbarvarmap_nblock{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_dim{};std::shared_ptr< monty::ndarray< long long,1 > > natbarvar_ptr{};int natbarvar_numbarvarelm{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_j{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_i{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconemap_dim{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconemap{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > vars{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natvarmap{};mosek::fusion::SolutionType solutionptr{};mosek::fusion::AccSolutionStatus acceptable_sol{};std::string model_name{};virtual void destroy();
static Model::t _new_Model(monty::rc_ptr< ::mosek::fusion::Model > _464);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _464);
static Model::t _new_Model(const std::string &  _469);
void _initialize(const std::string &  _469);
static Model::t _new_Model();
void _initialize();
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474) ;
virtual void connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string &  _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478) ;
virtual void varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string &  _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482) ;
virtual void varname(int _483,const std::string &  _484) ;
virtual void natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486) ;
virtual void natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491) ;
virtual int natbarvarmap_alloc(int _498,int _499) ;
virtual int natvarmap_alloc(int _517) ;
virtual int natconmap_alloc(int _527) ;
virtual int natconemap_alloc(int _537) ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546) ;
static  void putlicensewait(bool _552);
static  void putlicensepath(const std::string &  _553);
static  void putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554);
virtual /* override */ void dispose() ;
virtual void nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558) ;
virtual MSKtask_t __mosek_2fusion_2Model__getTask() ;
virtual void getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) ;
virtual void getVariableDuals(bool _571,std::shared_ptr< monty::ndarray< long long,1 > > _572,std::shared_ptr< monty::ndarray< double,1 > > _573,int _574) ;
virtual void getVariableValues(bool _580,std::shared_ptr< monty::ndarray< long long,1 > > _581,std::shared_ptr< monty::ndarray< double,1 > > _582,int _583) ;
virtual void setVariableValues(bool _589,std::shared_ptr< monty::ndarray< long long,1 > > _590,std::shared_ptr< monty::ndarray< double,1 > > _591) ;
virtual void flushNames() ;
virtual void writeTask(const std::string &  _595) ;
virtual long long getSolverLIntInfo(const std::string &  _596) ;
virtual int getSolverIntInfo(const std::string &  _597) ;
virtual double getSolverDoubleInfo(const std::string &  _598) ;
virtual void setCallbackHandler(mosek::cbhandler_t  _599) ;
virtual void setDataCallbackHandler(mosek::datacbhandler_t  _600) ;
virtual void setLogHandler(mosek::msghandler_t  _601) ;
virtual void setSolverParam(const std::string &  _602,double _603) ;
virtual void setSolverParam(const std::string &  _604,int _605) ;
virtual void setSolverParam(const std::string &  _606,const std::string &  _607) ;
virtual void breakSolver() ;
virtual void solve() ;
virtual void flushSolutions() ;
virtual void flush_initsol(mosek::fusion::SolutionType _608) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus() ;
virtual mosek::fusion::ProblemStatus getProblemStatus() ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus() ;
virtual double dualObjValue() ;
virtual double primalObjValue() ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _614,bool _615,bool _616) ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _621,bool _622) ;
virtual void setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _623,std::shared_ptr< monty::ndarray< double,1 > > _624) ;
virtual void ensure_initsol_xx() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_bars(mosek::fusion::SolutionType _631) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_barx(mosek::fusion::SolutionType _632) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_y(mosek::fusion::SolutionType _633) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xc(mosek::fusion::SolutionType _634) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_snx(mosek::fusion::SolutionType _635) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_suc(mosek::fusion::SolutionType _636) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slc(mosek::fusion::SolutionType _637) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_sux(mosek::fusion::SolutionType _638) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slx(mosek::fusion::SolutionType _639) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_yx(mosek::fusion::SolutionType _640) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xx(mosek::fusion::SolutionType _641) ;
virtual void selectedSolution(mosek::fusion::SolutionType _642) ;
virtual mosek::fusion::AccSolutionStatus getAcceptedSolutionStatus() ;
virtual void acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _643) ;
virtual mosek::fusion::ProblemStatus getProblemStatus(mosek::fusion::SolutionType _644) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus(mosek::fusion::SolutionType _646) ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus(mosek::fusion::SolutionType _647) ;
virtual mosek::fusion::SolutionStatus getSolutionStatus(mosek::fusion::SolutionType _648,bool _649) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _652,monty::rc_ptr< ::mosek::fusion::Expression > _653) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _684,monty::rc_ptr< ::mosek::fusion::Expression > _685,std::shared_ptr< monty::ndarray< int,1 > > _686) ;
virtual void updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _714,monty::rc_ptr< ::mosek::fusion::Variable > _715) ;
virtual void objective_(const std::string &  _749,mosek::fusion::ObjectiveSense _750,monty::rc_ptr< ::mosek::fusion::Expression > _751) ;
virtual void objective(double _780) ;
virtual void objective(mosek::fusion::ObjectiveSense _781,double _782) ;
virtual void objective(mosek::fusion::ObjectiveSense _783,monty::rc_ptr< ::mosek::fusion::Expression > _784) ;
virtual void objective(const std::string &  _785,double _786) ;
virtual void objective(const std::string &  _787,mosek::fusion::ObjectiveSense _788,double _789) ;
virtual void objective(const std::string &  _790,mosek::fusion::ObjectiveSense _791,monty::rc_ptr< ::mosek::fusion::Expression > _792) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _863) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _870) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _886,std::shared_ptr< monty::ndarray< int,1 > > _887) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _897,int _898) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _899) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__ranged_variable(const std::string &  _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::RangeDomain > _902) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _923,std::shared_ptr< monty::ndarray< int,1 > > _924,monty::rc_ptr< ::mosek::fusion::ConeDomain > _925) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _953,std::shared_ptr< monty::ndarray< int,1 > > _954,monty::rc_ptr< ::mosek::fusion::LinearDomain > _955) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _995,std::shared_ptr< monty::ndarray< int,1 > > _996,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _997) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricVariable > __mosek_2fusion_2Model__variable_(const std::string &  _1019,std::shared_ptr< monty::ndarray< int,1 > > _1020,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1021) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1036,monty::rc_ptr< ::mosek::fusion::Expression > _1037,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1038) ;
virtual void update_constr_expr(std::shared_ptr< monty::ndarray< int,1 > > _1077,std::shared_ptr< monty::ndarray< double,1 > > _1078) ;
virtual void putarows(std::shared_ptr< monty::ndarray< int,1 > > _1085,monty::rc_ptr< ::mosek::fusion::WorkStack > _1086,int _1087,int _1088,int _1089,int _1090,int _1091) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1128,monty::rc_ptr< ::mosek::fusion::Expression > _1129,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1130) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1194,monty::rc_ptr< ::mosek::fusion::Expression > _1195,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1196) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1245,monty::rc_ptr< ::mosek::fusion::Expression > _1246,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1247) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1296,monty::rc_ptr< ::mosek::fusion::Expression > _1297,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1298) ;
virtual bool hasConstraint(const std::string &  _1337) ;
virtual bool hasVariable(const std::string &  _1338) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(int _1339) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(const std::string &  _1340) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(int _1341) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(const std::string &  _1342) ;
virtual std::string getName() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Model__clone() ;
}; // struct Model;

// mosek.fusion.Debug from file 'src/fusion/cxx/Debug_p.h'
// namespace mosek::fusion
struct p_Debug
{
  Debug * _pubthis;

  p_Debug(Debug * _pubthis) : _pubthis(_pubthis) {}

  static Debug::t o ()                 { return monty::rc_ptr<Debug>(new Debug()); }
  Debug::t p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (      int val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (long long val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (   double val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (     bool val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t lf()                        { std::cout << std::endl; return Debug::t(_pubthis); }

  static p_Debug * _get_impl(Debug * _inst) { return _inst->ptr; }

  template<typename T>
  Debug::t p(const std::shared_ptr<monty::ndarray<T,1>> & val)
  {
    if (val->size() > 0)
    {
      std::cout << (*val)[0];
      for (int i = 1; i < val->size(); ++i)
        std::cout << "," << (*val)[i];
    }
    return Debug::t(_pubthis);
  }

  Debug::t __mosek_2fusion_2Debug__p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }

  template<class C>
  Debug::t __mosek_2fusion_2Debug__p (C val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t __mosek_2fusion_2Debug__lf()      { std::cout << std::endl; return Debug::t(_pubthis); }
  
};
// End of file 'src/fusion/cxx/Debug_p.h'
struct p_Sort
{
Sort * _pubthis;
static mosek::fusion::p_Sort* _get_impl(mosek::fusion::Sort * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Sort * _get_impl(mosek::fusion::Sort::t _inst) { return _get_impl(_inst.get()); }
p_Sort(Sort * _pubthis);
virtual ~p_Sort() { /* std::cout << "~p_Sort" << std::endl;*/ };
virtual void destroy();
static  void argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274);
}; // struct Sort;

struct p_IndexCounter
{
IndexCounter * _pubthis;
static mosek::fusion::p_IndexCounter* _get_impl(mosek::fusion::IndexCounter * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_IndexCounter * _get_impl(mosek::fusion::IndexCounter::t _inst) { return _get_impl(_inst.get()); }
p_IndexCounter(IndexCounter * _pubthis);
virtual ~p_IndexCounter() { /* std::cout << "~p_IndexCounter" << std::endl;*/ };
long long start{};std::shared_ptr< monty::ndarray< int,1 > > dims{};std::shared_ptr< monty::ndarray< long long,1 > > strides{};std::shared_ptr< monty::ndarray< long long,1 > > st{};std::shared_ptr< monty::ndarray< int,1 > > ii{};int n{};virtual void destroy();
static IndexCounter::t _new_IndexCounter(std::shared_ptr< monty::ndarray< int,1 > > _276);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _276);
static IndexCounter::t _new_IndexCounter(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
void _initialize(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
static IndexCounter::t _new_IndexCounter(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
void _initialize(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
virtual bool atEnd() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getIndex() ;
virtual long long next() ;
virtual long long get() ;
virtual void inc() ;
virtual void reset() ;
}; // struct IndexCounter;

struct p_CommonTools
{
CommonTools * _pubthis;
static mosek::fusion::p_CommonTools* _get_impl(mosek::fusion::CommonTools * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_CommonTools * _get_impl(mosek::fusion::CommonTools::t _inst) { return _get_impl(_inst.get()); }
p_CommonTools(CommonTools * _pubthis);
virtual ~p_CommonTools() { /* std::cout << "~p_CommonTools" << std::endl;*/ };
virtual void destroy();
static  std::shared_ptr< monty::ndarray< long long,1 > > resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292);
static  std::shared_ptr< monty::ndarray< int,1 > > resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295);
static  std::shared_ptr< monty::ndarray< double,1 > > resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298);
static  int binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301);
static  int binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306);
static  int binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309);
static  int binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314);
static  void ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351);
static  void tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372);
static  void argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399);
static  void mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424);
}; // struct CommonTools;

struct p_SolutionStruct
{
SolutionStruct * _pubthis;
static mosek::fusion::p_SolutionStruct* _get_impl(mosek::fusion::SolutionStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SolutionStruct * _get_impl(mosek::fusion::SolutionStruct::t _inst) { return _get_impl(_inst.get()); }
p_SolutionStruct(SolutionStruct * _pubthis);
virtual ~p_SolutionStruct() { /* std::cout << "~p_SolutionStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > yx{};std::shared_ptr< monty::ndarray< double,1 > > snx{};std::shared_ptr< monty::ndarray< double,1 > > sux{};std::shared_ptr< monty::ndarray< double,1 > > slx{};std::shared_ptr< monty::ndarray< double,1 > > bars{};std::shared_ptr< monty::ndarray< double,1 > > barx{};std::shared_ptr< monty::ndarray< double,1 > > y{};std::shared_ptr< monty::ndarray< double,1 > > suc{};std::shared_ptr< monty::ndarray< double,1 > > slc{};std::shared_ptr< monty::ndarray< double,1 > > xx{};std::shared_ptr< monty::ndarray< double,1 > > xc{};double dobj{};double pobj{};mosek::fusion::ProblemStatus probstatus{};mosek::fusion::SolutionStatus dstatus{};mosek::fusion::SolutionStatus pstatus{};int sol_numbarvar{};int sol_numcone{};int sol_numvar{};int sol_numcon{};virtual void destroy();
static SolutionStruct::t _new_SolutionStruct(int _425,int _426,int _427,int _428);
void _initialize(int _425,int _426,int _427,int _428);
static SolutionStruct::t _new_SolutionStruct(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
void _initialize(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2SolutionStruct__clone() ;
virtual void resize(int _430,int _431,int _432,int _433) ;
virtual bool isDualAcceptable(mosek::fusion::AccSolutionStatus _453) ;
virtual bool isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) ;
virtual bool isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456) ;
}; // struct SolutionStruct;

struct p_ConNZStruct
{
ConNZStruct * _pubthis;
static mosek::fusion::p_ConNZStruct* _get_impl(mosek::fusion::ConNZStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConNZStruct * _get_impl(mosek::fusion::ConNZStruct::t _inst) { return _get_impl(_inst.get()); }
p_ConNZStruct(ConNZStruct * _pubthis);
virtual ~p_ConNZStruct() { /* std::cout << "~p_ConNZStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};virtual void destroy();
static ConNZStruct::t _new_ConNZStruct(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
}; // struct ConNZStruct;

struct p_BaseVariable : public /*implements*/ virtual ::mosek::fusion::Variable
{
BaseVariable * _pubthis;
static mosek::fusion::p_BaseVariable* _get_impl(mosek::fusion::BaseVariable * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseVariable * _get_impl(mosek::fusion::BaseVariable::t _inst) { return _get_impl(_inst.get()); }
p_BaseVariable(BaseVariable * _pubthis);
virtual ~p_BaseVariable() { /* std::cout << "~p_BaseVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};monty::rc_ptr< ::mosek::fusion::Model > model{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1581,monty::rc_ptr< ::mosek::fusion::Model > _1582);
void _initialize(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1581,monty::rc_ptr< ::mosek::fusion::Model > _1582);
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::Model > _1583,std::shared_ptr< monty::ndarray< int,1 > > _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585,std::shared_ptr< monty::ndarray< long long,1 > > _1586);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1583,std::shared_ptr< monty::ndarray< int,1 > > _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585,std::shared_ptr< monty::ndarray< long long,1 > > _1586);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseVariable__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1589,monty::rc_ptr< ::mosek::fusion::WorkStack > _1590,monty::rc_ptr< ::mosek::fusion::WorkStack > _1591) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1611) { return __mosek_2fusion_2BaseVariable__reshape(_1611); }
virtual void setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1615) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2BaseVariable__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
virtual int getND() ;
virtual int getDim(int _1618) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual long long getSize() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void makeContinuous() ;
virtual void makeInteger() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1639,int _1640,int _1641) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1639,int _1640,int _1641) { return __mosek_2fusion_2BaseVariable__index(_1639,_1640,_1641); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1642,int _1643) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1642,int _1643) { return __mosek_2fusion_2BaseVariable__index(_1642,_1643); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1644) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1644) { return __mosek_2fusion_2BaseVariable__index(_1644); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1647) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1647) { return __mosek_2fusion_2BaseVariable__index(_1647); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1648,std::shared_ptr< monty::ndarray< int,1 > > _1649,std::shared_ptr< monty::ndarray< int,1 > > _1650) { return __mosek_2fusion_2BaseVariable__pick(_1648,_1649,_1650); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1653,std::shared_ptr< monty::ndarray< int,1 > > _1654) { return __mosek_2fusion_2BaseVariable__pick(_1653,_1654); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1657) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1657) { return __mosek_2fusion_2BaseVariable__pick(_1657); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1678) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return __mosek_2fusion_2BaseVariable__pick(_1678); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _1688) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag(int _1688) { return __mosek_2fusion_2BaseVariable__antidiag(_1688); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _1689) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag(int _1689) { return __mosek_2fusion_2BaseVariable__diag(_1689); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1690,std::shared_ptr< monty::ndarray< int,1 > > _1691,int _1692) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1713,std::shared_ptr< monty::ndarray< int,1 > > _1714) { return __mosek_2fusion_2BaseVariable__slice(_1713,_1714); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1748,int _1749) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1748,int _1749) { return __mosek_2fusion_2BaseVariable__slice(_1748,_1749); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseVariable__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
virtual int inst(int _1758,std::shared_ptr< monty::ndarray< long long,1 > > _1759,int _1760,std::shared_ptr< monty::ndarray< long long,1 > > _1761) ;
virtual int numInst() ;
virtual void inst(int _1764,std::shared_ptr< monty::ndarray< long long,1 > > _1765) ;
virtual void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1772,bool _1773) ;
virtual void dual_lu(int _1778,std::shared_ptr< monty::ndarray< double,1 > > _1779,bool _1780) ;
virtual void values(int _1783,std::shared_ptr< monty::ndarray< double,1 > > _1784,bool _1785) ;
virtual void make_continuous() ;
virtual void make_integer() ;
}; // struct BaseVariable;

struct p_SliceVariable : public ::mosek::fusion::p_BaseVariable
{
SliceVariable * _pubthis;
static mosek::fusion::p_SliceVariable* _get_impl(mosek::fusion::SliceVariable * _inst){ return static_cast< mosek::fusion::p_SliceVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_SliceVariable * _get_impl(mosek::fusion::SliceVariable::t _inst) { return _get_impl(_inst.get()); }
p_SliceVariable(SliceVariable * _pubthis);
virtual ~p_SliceVariable() { /* std::cout << "~p_SliceVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};virtual void destroy();
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1344,std::shared_ptr< monty::ndarray< int,1 > > _1345,std::shared_ptr< monty::ndarray< long long,1 > > _1346,std::shared_ptr< monty::ndarray< long long,1 > > _1347);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1344,std::shared_ptr< monty::ndarray< int,1 > > _1345,std::shared_ptr< monty::ndarray< long long,1 > > _1346,std::shared_ptr< monty::ndarray< long long,1 > > _1347);
}; // struct SliceVariable;

struct p_ModelVariable : public ::mosek::fusion::p_BaseVariable
{
ModelVariable * _pubthis;
static mosek::fusion::p_ModelVariable* _get_impl(mosek::fusion::ModelVariable * _inst){ return static_cast< mosek::fusion::p_ModelVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_ModelVariable * _get_impl(mosek::fusion::ModelVariable::t _inst) { return _get_impl(_inst.get()); }
p_ModelVariable(ModelVariable * _pubthis);
virtual ~p_ModelVariable() { /* std::cout << "~p_ModelVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};long long varid{};std::string name{};virtual void destroy();
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1544,monty::rc_ptr< ::mosek::fusion::Model > _1545);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1544,monty::rc_ptr< ::mosek::fusion::Model > _1545);
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::Model > _1546,const std::string &  _1547,std::shared_ptr< monty::ndarray< int,1 > > _1548,long long _1549,std::shared_ptr< monty::ndarray< long long,1 > > _1550,std::shared_ptr< monty::ndarray< long long,1 > > _1551);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1546,const std::string &  _1547,std::shared_ptr< monty::ndarray< int,1 > > _1548,long long _1549,std::shared_ptr< monty::ndarray< long long,1 > > _1550,std::shared_ptr< monty::ndarray< long long,1 > > _1551);
virtual void flushNames() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void elementName(long long _1552,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1553) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1554) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelVariable;

struct p_SymRangedVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymRangedVariable * _pubthis;
static mosek::fusion::p_SymRangedVariable* _get_impl(mosek::fusion::SymRangedVariable * _inst){ return static_cast< mosek::fusion::p_SymRangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymRangedVariable * _get_impl(mosek::fusion::SymRangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymRangedVariable(SymRangedVariable * _pubthis);
virtual ~p_SymRangedVariable() { /* std::cout << "~p_SymRangedVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1348,monty::rc_ptr< ::mosek::fusion::Model > _1349);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1348,monty::rc_ptr< ::mosek::fusion::Model > _1349);
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1350,const std::string &  _1351,long long _1352,int _1353,std::shared_ptr< monty::ndarray< long long,1 > > _1354,std::shared_ptr< monty::ndarray< int,1 > > _1355);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1350,const std::string &  _1351,long long _1352,int _1353,std::shared_ptr< monty::ndarray< long long,1 > > _1354,std::shared_ptr< monty::ndarray< int,1 > > _1355);
virtual void dual_u(int _1356,std::shared_ptr< monty::ndarray< double,1 > > _1357) ;
virtual void dual_l(int _1358,std::shared_ptr< monty::ndarray< double,1 > > _1359) ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1363) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1363) { return __mosek_2fusion_2SymRangedVariable__clone(_1363); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1364,std::shared_ptr< monty::ndarray< long long,1 > > _1365,std::shared_ptr< monty::ndarray< int,1 > > _1366);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1382,std::shared_ptr< monty::ndarray< long long,1 > > _1383);
}; // struct SymRangedVariable;

struct p_RangedVariable : public ::mosek::fusion::p_ModelVariable
{
RangedVariable * _pubthis;
static mosek::fusion::p_RangedVariable* _get_impl(mosek::fusion::RangedVariable * _inst){ return static_cast< mosek::fusion::p_RangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_RangedVariable * _get_impl(mosek::fusion::RangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_RangedVariable(RangedVariable * _pubthis);
virtual ~p_RangedVariable() { /* std::cout << "~p_RangedVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};virtual void destroy();
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1394,monty::rc_ptr< ::mosek::fusion::Model > _1395);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1394,monty::rc_ptr< ::mosek::fusion::Model > _1395);
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1396,const std::string &  _1397,long long _1398,std::shared_ptr< monty::ndarray< int,1 > > _1399,std::shared_ptr< monty::ndarray< long long,1 > > _1400,std::shared_ptr< monty::ndarray< int,1 > > _1401);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1396,const std::string &  _1397,long long _1398,std::shared_ptr< monty::ndarray< int,1 > > _1399,std::shared_ptr< monty::ndarray< long long,1 > > _1400,std::shared_ptr< monty::ndarray< int,1 > > _1401);
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2RangedVariable__elementDesc(long long _1402,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1403) ;
virtual /* override */ void flushNames() ;
virtual void dual_u(int _1407,std::shared_ptr< monty::ndarray< double,1 > > _1408) ;
virtual void dual_l(int _1409,std::shared_ptr< monty::ndarray< double,1 > > _1410) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1411) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1411) { return __mosek_2fusion_2RangedVariable__clone(_1411); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1412);
}; // struct RangedVariable;

struct p_LinearPSDVariable : public ::mosek::fusion::p_ModelVariable
{
LinearPSDVariable * _pubthis;
static mosek::fusion::p_LinearPSDVariable* _get_impl(mosek::fusion::LinearPSDVariable * _inst){ return static_cast< mosek::fusion::p_LinearPSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDVariable * _get_impl(mosek::fusion::LinearPSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDVariable(LinearPSDVariable * _pubthis);
virtual ~p_LinearPSDVariable() { /* std::cout << "~p_LinearPSDVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};int varid{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int conedim{};virtual void destroy();
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1414,monty::rc_ptr< ::mosek::fusion::Model > _1415);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1414,monty::rc_ptr< ::mosek::fusion::Model > _1415);
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1416,const std::string &  _1417,int _1418,std::shared_ptr< monty::ndarray< int,1 > > _1419,int _1420,std::shared_ptr< monty::ndarray< long long,1 > > _1421);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1416,const std::string &  _1417,int _1418,std::shared_ptr< monty::ndarray< int,1 > > _1419,int _1420,std::shared_ptr< monty::ndarray< long long,1 > > _1421);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1424) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1425) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1426) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1426) { return __mosek_2fusion_2LinearPSDVariable__clone(_1426); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1427);
}; // struct LinearPSDVariable;

struct p_PSDVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
PSDVariable * _pubthis;
static mosek::fusion::p_PSDVariable* _get_impl(mosek::fusion::PSDVariable * _inst){ return static_cast< mosek::fusion::p_PSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_PSDVariable * _get_impl(mosek::fusion::PSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_PSDVariable(PSDVariable * _pubthis);
virtual ~p_PSDVariable() { /* std::cout << "~p_PSDVariable" << std::endl;*/ };
int conedim2{};int conedim1{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int varid{};virtual void destroy();
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1429,monty::rc_ptr< ::mosek::fusion::Model > _1430);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1429,monty::rc_ptr< ::mosek::fusion::Model > _1430);
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1431,const std::string &  _1432,int _1433,std::shared_ptr< monty::ndarray< int,1 > > _1434,int _1435,int _1436,std::shared_ptr< monty::ndarray< long long,1 > > _1437);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1431,const std::string &  _1432,int _1433,std::shared_ptr< monty::ndarray< int,1 > > _1434,int _1435,int _1436,std::shared_ptr< monty::ndarray< long long,1 > > _1437);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2PSDVariable__elementDesc(long long _1440,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1441) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1442) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1442) { return __mosek_2fusion_2PSDVariable__clone(_1442); }
static  std::shared_ptr< monty::ndarray< long long,1 > > fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1443,int _1444,int _1445,std::shared_ptr< monty::ndarray< long long,1 > > _1446);
}; // struct PSDVariable;

struct p_SymLinearVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymLinearVariable * _pubthis;
static mosek::fusion::p_SymLinearVariable* _get_impl(mosek::fusion::SymLinearVariable * _inst){ return static_cast< mosek::fusion::p_SymLinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymLinearVariable * _get_impl(mosek::fusion::SymLinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymLinearVariable(SymLinearVariable * _pubthis);
virtual ~p_SymLinearVariable() { /* std::cout << "~p_SymLinearVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1471,monty::rc_ptr< ::mosek::fusion::Model > _1472);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1471,monty::rc_ptr< ::mosek::fusion::Model > _1472);
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1473,const std::string &  _1474,long long _1475,int _1476,std::shared_ptr< monty::ndarray< long long,1 > > _1477,std::shared_ptr< monty::ndarray< int,1 > > _1478);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1473,const std::string &  _1474,long long _1475,int _1476,std::shared_ptr< monty::ndarray< long long,1 > > _1477,std::shared_ptr< monty::ndarray< int,1 > > _1478);
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1482) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1482) { return __mosek_2fusion_2SymLinearVariable__clone(_1482); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1483,std::shared_ptr< monty::ndarray< long long,1 > > _1484,std::shared_ptr< monty::ndarray< int,1 > > _1485);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1501,std::shared_ptr< monty::ndarray< long long,1 > > _1502);
}; // struct SymLinearVariable;

struct p_LinearVariable : public ::mosek::fusion::p_ModelVariable
{
LinearVariable * _pubthis;
static mosek::fusion::p_LinearVariable* _get_impl(mosek::fusion::LinearVariable * _inst){ return static_cast< mosek::fusion::p_LinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearVariable * _get_impl(mosek::fusion::LinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearVariable(LinearVariable * _pubthis);
virtual ~p_LinearVariable() { /* std::cout << "~p_LinearVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1513,monty::rc_ptr< ::mosek::fusion::Model > _1514);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1513,monty::rc_ptr< ::mosek::fusion::Model > _1514);
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1515,const std::string &  _1516,long long _1517,std::shared_ptr< monty::ndarray< int,1 > > _1518,std::shared_ptr< monty::ndarray< long long,1 > > _1519,std::shared_ptr< monty::ndarray< int,1 > > _1520);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1515,const std::string &  _1516,long long _1517,std::shared_ptr< monty::ndarray< int,1 > > _1518,std::shared_ptr< monty::ndarray< long long,1 > > _1519,std::shared_ptr< monty::ndarray< int,1 > > _1520);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1526) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1526) { return __mosek_2fusion_2LinearVariable__clone(_1526); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1527);
}; // struct LinearVariable;

struct p_ConicVariable : public ::mosek::fusion::p_ModelVariable
{
ConicVariable * _pubthis;
static mosek::fusion::p_ConicVariable* _get_impl(mosek::fusion::ConicVariable * _inst){ return static_cast< mosek::fusion::p_ConicVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_ConicVariable * _get_impl(mosek::fusion::ConicVariable::t _inst) { return _get_impl(_inst.get()); }
p_ConicVariable(ConicVariable * _pubthis);
virtual ~p_ConicVariable() { /* std::cout << "~p_ConicVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};int varid{};virtual void destroy();
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1529,monty::rc_ptr< ::mosek::fusion::Model > _1530);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1529,monty::rc_ptr< ::mosek::fusion::Model > _1530);
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::Model > _1531,const std::string &  _1532,int _1533,std::shared_ptr< monty::ndarray< int,1 > > _1534,std::shared_ptr< monty::ndarray< int,1 > > _1535);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1531,const std::string &  _1532,int _1533,std::shared_ptr< monty::ndarray< int,1 > > _1534,std::shared_ptr< monty::ndarray< int,1 > > _1535);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1541) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1541) { return __mosek_2fusion_2ConicVariable__clone(_1541); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1542);
}; // struct ConicVariable;

struct p_NilVariable : public ::mosek::fusion::p_BaseVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
NilVariable * _pubthis;
static mosek::fusion::p_NilVariable* _get_impl(mosek::fusion::NilVariable * _inst){ return static_cast< mosek::fusion::p_NilVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_NilVariable * _get_impl(mosek::fusion::NilVariable::t _inst) { return _get_impl(_inst.get()); }
p_NilVariable(NilVariable * _pubthis);
virtual ~p_NilVariable() { /* std::cout << "~p_NilVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static NilVariable::t _new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > > _1555);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _1555);
static NilVariable::t _new_NilVariable();
void _initialize();
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2NilVariable__elementDesc(long long _1557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1558) ;
virtual void elementName(long long _1559,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1560) ;
virtual /* override */ int numInst() ;
virtual int inst(int _1561,std::shared_ptr< monty::ndarray< long long,1 > > _1562,std::shared_ptr< monty::ndarray< long long,1 > > _1563) ;
virtual /* override */ void inst(int _1564,std::shared_ptr< monty::ndarray< long long,1 > > _1565) ;
virtual /* override */ void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1566,bool _1567) ;
virtual /* override */ void values(int _1568,std::shared_ptr< monty::ndarray< double,1 > > _1569,bool _1570) ;
virtual /* override */ void make_continuous() ;
virtual /* override */ void make_integer() ;
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return __mosek_2fusion_2NilVariable__index(_1571); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1571) { return __mosek_2fusion_2NilVariable__index(_1571); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(int _1573) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1573) { return __mosek_2fusion_2NilVariable__index(_1573); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1573) { return __mosek_2fusion_2NilVariable__index(_1573); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return __mosek_2fusion_2NilVariable__slice(_1575,_1576); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1575,std::shared_ptr< monty::ndarray< int,1 > > _1576) { return __mosek_2fusion_2NilVariable__slice(_1575,_1576); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(int _1579,int _1580) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1579,int _1580) { return __mosek_2fusion_2NilVariable__slice(_1579,_1580); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1579,int _1580) { return __mosek_2fusion_2NilVariable__slice(_1579,_1580); }
}; // struct NilVariable;

struct p_Var
{
Var * _pubthis;
static mosek::fusion::p_Var* _get_impl(mosek::fusion::Var * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Var * _get_impl(mosek::fusion::Var::t _inst) { return _get_impl(_inst.get()); }
p_Var(Var * _pubthis);
virtual ~p_Var() { /* std::cout << "~p_Var" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Variable > empty(std::shared_ptr< monty::ndarray< int,1 > > _1821);
static  monty::rc_ptr< ::mosek::fusion::Variable > compress(monty::rc_ptr< ::mosek::fusion::Variable > _1823);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1831,int _1832);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1833,int _1834,int _1835);
static  monty::rc_ptr< ::mosek::fusion::Variable > flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1836);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1837,std::shared_ptr< monty::ndarray< int,1 > > _1838);
static  monty::rc_ptr< ::mosek::fusion::Variable > index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1839,std::shared_ptr< monty::ndarray< int,1 > > _1840);
static  monty::rc_ptr< ::mosek::fusion::Variable > hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1869,int _1870);
static  monty::rc_ptr< ::mosek::fusion::Variable > vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1871,int _1872);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1873,int _1874);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1875,int _1876,int _1877);
static  monty::rc_ptr< ::mosek::fusion::Variable > drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1878,int _1879,int _1880);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1944);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1946,monty::rc_ptr< ::mosek::fusion::Variable > _1947,monty::rc_ptr< ::mosek::fusion::Variable > _1948);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1949,monty::rc_ptr< ::mosek::fusion::Variable > _1950);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1951);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1952,monty::rc_ptr< ::mosek::fusion::Variable > _1953,monty::rc_ptr< ::mosek::fusion::Variable > _1954);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1955,monty::rc_ptr< ::mosek::fusion::Variable > _1956);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1957);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1958,monty::rc_ptr< ::mosek::fusion::Variable > _1959,monty::rc_ptr< ::mosek::fusion::Variable > _1960,int _1961);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1962,monty::rc_ptr< ::mosek::fusion::Variable > _1963,int _1964);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1965,int _1966);
static  monty::rc_ptr< ::mosek::fusion::Variable > promote(monty::rc_ptr< ::mosek::fusion::Variable > _1969,int _1970);
static  monty::rc_ptr< ::mosek::fusion::Variable > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1975,int _1976);
}; // struct Var;

struct p_ConstraintCache
{
ConstraintCache * _pubthis;
static mosek::fusion::p_ConstraintCache* _get_impl(mosek::fusion::ConstraintCache * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConstraintCache * _get_impl(mosek::fusion::ConstraintCache::t _inst) { return _get_impl(_inst.get()); }
p_ConstraintCache(ConstraintCache * _pubthis);
virtual ~p_ConstraintCache() { /* std::cout << "~p_ConstraintCache" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmatidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};long long nbarnz{};long long nunordered{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subi{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subj{};std::shared_ptr< monty::ndarray< double,1 > > buffer_cof{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subi{};std::shared_ptr< monty::ndarray< int,1 > > subj{};long long nnz{};int nrows{};virtual void destroy();
static ConstraintCache::t _new_ConstraintCache(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2099);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2099);
static ConstraintCache::t _new_ConstraintCache(std::shared_ptr< monty::ndarray< long long,1 > > _2100,std::shared_ptr< monty::ndarray< double,1 > > _2101,std::shared_ptr< monty::ndarray< int,1 > > _2102,std::shared_ptr< monty::ndarray< double,1 > > _2103,std::shared_ptr< monty::ndarray< int,1 > > _2104,std::shared_ptr< monty::ndarray< int,1 > > _2105,std::shared_ptr< monty::ndarray< int,1 > > _2106);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _2100,std::shared_ptr< monty::ndarray< double,1 > > _2101,std::shared_ptr< monty::ndarray< int,1 > > _2102,std::shared_ptr< monty::ndarray< double,1 > > _2103,std::shared_ptr< monty::ndarray< int,1 > > _2104,std::shared_ptr< monty::ndarray< int,1 > > _2105,std::shared_ptr< monty::ndarray< int,1 > > _2106);
virtual void unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2109) ;
virtual long long order_barentries() ;
virtual void add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2119,std::shared_ptr< monty::ndarray< int,1 > > _2120,std::shared_ptr< monty::ndarray< int,1 > > _2121) ;
virtual void unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2127,std::shared_ptr< monty::ndarray< int,1 > > _2128,std::shared_ptr< monty::ndarray< double,1 > > _2129,std::shared_ptr< monty::ndarray< double,1 > > _2130) ;
virtual void add(std::shared_ptr< monty::ndarray< long long,1 > > _2139,std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< double,1 > > _2141,std::shared_ptr< monty::ndarray< double,1 > > _2142) ;
virtual long long flush(std::shared_ptr< monty::ndarray< int,1 > > _2143,std::shared_ptr< monty::ndarray< int,1 > > _2144,std::shared_ptr< monty::ndarray< double,1 > > _2145,std::shared_ptr< monty::ndarray< double,1 > > _2146) ;
virtual long long numUnsorted() ;
virtual monty::rc_ptr< ::mosek::fusion::ConstraintCache > __mosek_2fusion_2ConstraintCache__clone() ;
}; // struct ConstraintCache;

struct p_Constraint
{
Constraint * _pubthis;
static mosek::fusion::p_Constraint* _get_impl(mosek::fusion::Constraint * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Constraint * _get_impl(mosek::fusion::Constraint::t _inst) { return _get_impl(_inst.get()); }
p_Constraint(Constraint * _pubthis);
virtual ~p_Constraint() { /* std::cout << "~p_Constraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Constraint > _2220,monty::rc_ptr< ::mosek::fusion::Model > _2221);
void _initialize(monty::rc_ptr< ::mosek::fusion::Constraint > _2220,monty::rc_ptr< ::mosek::fusion::Model > _2221);
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Model > _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223,std::shared_ptr< monty::ndarray< int,1 > > _2224);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223,std::shared_ptr< monty::ndarray< int,1 > > _2224);
virtual /* override */ std::string toString() ;
virtual void toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2225,long long _2226,std::shared_ptr< monty::ndarray< std::string,1 > > _2227) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void values(bool _2230,int _2231,std::shared_ptr< monty::ndarray< double,1 > > _2232) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2233) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2237,monty::rc_ptr< ::mosek::fusion::Variable > _2238) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__get_model() ;
virtual int get_nd() ;
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2259,int _2260);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2261,monty::rc_ptr< ::mosek::fusion::Constraint > _2262,monty::rc_ptr< ::mosek::fusion::Constraint > _2263,int _2264);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2265,monty::rc_ptr< ::mosek::fusion::Constraint > _2266,int _2267);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2268);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2269);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2270,monty::rc_ptr< ::mosek::fusion::Constraint > _2271,monty::rc_ptr< ::mosek::fusion::Constraint > _2272);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2273,monty::rc_ptr< ::mosek::fusion::Constraint > _2274,monty::rc_ptr< ::mosek::fusion::Constraint > _2275);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2276,monty::rc_ptr< ::mosek::fusion::Constraint > _2277);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2278,monty::rc_ptr< ::mosek::fusion::Constraint > _2279);
static  monty::rc_ptr< ::mosek::fusion::Constraint > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2280,int _2281);
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2332) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2339) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2340,std::shared_ptr< monty::ndarray< int,1 > > _2341) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2360,int _2361) ;
virtual int getND() ;
virtual int getSize() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__getModel() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct Constraint;

struct p_SliceConstraint : public ::mosek::fusion::p_Constraint
{
SliceConstraint * _pubthis;
static mosek::fusion::p_SliceConstraint* _get_impl(mosek::fusion::SliceConstraint * _inst){ return static_cast< mosek::fusion::p_SliceConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_SliceConstraint * _get_impl(mosek::fusion::SliceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_SliceConstraint(SliceConstraint * _pubthis);
virtual ~p_SliceConstraint() { /* std::cout << "~p_SliceConstraint" << std::endl;*/ };
virtual void destroy();
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2169,std::shared_ptr< monty::ndarray< int,1 > > _2170,std::shared_ptr< monty::ndarray< int,1 > > _2171);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2169,std::shared_ptr< monty::ndarray< int,1 > > _2170,std::shared_ptr< monty::ndarray< int,1 > > _2171);
virtual /* override */ std::string toString() ;
}; // struct SliceConstraint;

struct p_ModelConstraint : public ::mosek::fusion::p_Constraint
{
ModelConstraint * _pubthis;
static mosek::fusion::p_ModelConstraint* _get_impl(mosek::fusion::ModelConstraint * _inst){ return static_cast< mosek::fusion::p_ModelConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_ModelConstraint * _get_impl(mosek::fusion::ModelConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ModelConstraint(ModelConstraint * _pubthis);
virtual ~p_ModelConstraint() { /* std::cout << "~p_ModelConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2209,monty::rc_ptr< ::mosek::fusion::Model > _2210);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2209,monty::rc_ptr< ::mosek::fusion::Model > _2210);
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2211,const std::string &  _2212,std::shared_ptr< monty::ndarray< int,1 > > _2213,std::shared_ptr< monty::ndarray< int,1 > > _2214);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2211,const std::string &  _2212,std::shared_ptr< monty::ndarray< int,1 > > _2213,std::shared_ptr< monty::ndarray< int,1 > > _2214);
virtual /* override */ std::string toString() ;
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2219) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelConstraint;

struct p_LinearPSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearPSDConstraint * _pubthis;
static mosek::fusion::p_LinearPSDConstraint* _get_impl(mosek::fusion::LinearPSDConstraint * _inst){ return static_cast< mosek::fusion::p_LinearPSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDConstraint * _get_impl(mosek::fusion::LinearPSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDConstraint(LinearPSDConstraint * _pubthis);
virtual ~p_LinearPSDConstraint() { /* std::cout << "~p_LinearPSDConstraint" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};int conid{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};virtual void destroy();
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2045,monty::rc_ptr< ::mosek::fusion::Model > _2046);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2045,monty::rc_ptr< ::mosek::fusion::Model > _2046);
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2047,const std::string &  _2048,int _2049,std::shared_ptr< monty::ndarray< int,1 > > _2050,int _2051,std::shared_ptr< monty::ndarray< int,1 > > _2052,std::shared_ptr< monty::ndarray< long long,1 > > _2053);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2047,const std::string &  _2048,int _2049,std::shared_ptr< monty::ndarray< int,1 > > _2050,int _2051,std::shared_ptr< monty::ndarray< int,1 > > _2052,std::shared_ptr< monty::ndarray< long long,1 > > _2053);
virtual void domainToString(long long _2054,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2055) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2059) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2059) { return __mosek_2fusion_2LinearPSDConstraint__clone(_2059); }
}; // struct LinearPSDConstraint;

struct p_PSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
PSDConstraint * _pubthis;
static mosek::fusion::p_PSDConstraint* _get_impl(mosek::fusion::PSDConstraint * _inst){ return static_cast< mosek::fusion::p_PSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_PSDConstraint * _get_impl(mosek::fusion::PSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_PSDConstraint(PSDConstraint * _pubthis);
virtual ~p_PSDConstraint() { /* std::cout << "~p_PSDConstraint" << std::endl;*/ };
bool names_flushed{};int conedim1{};int conedim0{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};int conid{};virtual void destroy();
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2060,monty::rc_ptr< ::mosek::fusion::Model > _2061);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2060,monty::rc_ptr< ::mosek::fusion::Model > _2061);
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2062,const std::string &  _2063,int _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065,int _2066,int _2067,std::shared_ptr< monty::ndarray< long long,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2062,const std::string &  _2063,int _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065,int _2066,int _2067,std::shared_ptr< monty::ndarray< long long,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2070) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2070) { return __mosek_2fusion_2PSDConstraint__clone(_2070); }
static  std::shared_ptr< monty::ndarray< int,1 > > computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2071,int _2072,int _2073,std::shared_ptr< monty::ndarray< int,1 > > _2074);
}; // struct PSDConstraint;

struct p_RangedConstraint : public ::mosek::fusion::p_ModelConstraint
{
RangedConstraint * _pubthis;
static mosek::fusion::p_RangedConstraint* _get_impl(mosek::fusion::RangedConstraint * _inst){ return static_cast< mosek::fusion::p_RangedConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_RangedConstraint * _get_impl(mosek::fusion::RangedConstraint::t _inst) { return _get_impl(_inst.get()); }
p_RangedConstraint(RangedConstraint * _pubthis);
virtual ~p_RangedConstraint() { /* std::cout << "~p_RangedConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2173,monty::rc_ptr< ::mosek::fusion::Model > _2174);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2173,monty::rc_ptr< ::mosek::fusion::Model > _2174);
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2175,const std::string &  _2176,std::shared_ptr< monty::ndarray< int,1 > > _2177,std::shared_ptr< monty::ndarray< int,1 > > _2178);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2175,const std::string &  _2176,std::shared_ptr< monty::ndarray< int,1 > > _2177,std::shared_ptr< monty::ndarray< int,1 > > _2178);
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2179) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2179) { return __mosek_2fusion_2RangedConstraint__clone(_2179); }
}; // struct RangedConstraint;

struct p_ConicConstraint : public ::mosek::fusion::p_ModelConstraint
{
ConicConstraint * _pubthis;
static mosek::fusion::p_ConicConstraint* _get_impl(mosek::fusion::ConicConstraint * _inst){ return static_cast< mosek::fusion::p_ConicConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_ConicConstraint * _get_impl(mosek::fusion::ConicConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ConicConstraint(ConicConstraint * _pubthis);
virtual ~p_ConicConstraint() { /* std::cout << "~p_ConicConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeslack{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::ConeDomain > dom{};int conid{};virtual void destroy();
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2180,monty::rc_ptr< ::mosek::fusion::Model > _2181);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2180,monty::rc_ptr< ::mosek::fusion::Model > _2181);
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2182,const std::string &  _2183,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2184,std::shared_ptr< monty::ndarray< int,1 > > _2185,int _2186,std::shared_ptr< monty::ndarray< int,1 > > _2187,std::shared_ptr< monty::ndarray< int,1 > > _2188);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2182,const std::string &  _2183,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2184,std::shared_ptr< monty::ndarray< int,1 > > _2185,int _2186,std::shared_ptr< monty::ndarray< int,1 > > _2187,std::shared_ptr< monty::ndarray< int,1 > > _2188);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2195,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2196) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2197) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2197) { return __mosek_2fusion_2ConicConstraint__clone(_2197); }
}; // struct ConicConstraint;

struct p_LinearConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearConstraint * _pubthis;
static mosek::fusion::p_LinearConstraint* _get_impl(mosek::fusion::LinearConstraint * _inst){ return static_cast< mosek::fusion::p_LinearConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearConstraint * _get_impl(mosek::fusion::LinearConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearConstraint(LinearConstraint * _pubthis);
virtual ~p_LinearConstraint() { /* std::cout << "~p_LinearConstraint" << std::endl;*/ };
std::string name{};int conid{};virtual void destroy();
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2198,monty::rc_ptr< ::mosek::fusion::Model > _2199);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2198,monty::rc_ptr< ::mosek::fusion::Model > _2199);
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2200,const std::string &  _2201,int _2202,std::shared_ptr< monty::ndarray< int,1 > > _2203,std::shared_ptr< monty::ndarray< int,1 > > _2204);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2200,const std::string &  _2201,int _2202,std::shared_ptr< monty::ndarray< int,1 > > _2203,std::shared_ptr< monty::ndarray< int,1 > > _2204);
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2206,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2207) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2208) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2208) { return __mosek_2fusion_2LinearConstraint__clone(_2208); }
}; // struct LinearConstraint;

struct p_Set
{
Set * _pubthis;
static mosek::fusion::p_Set* _get_impl(mosek::fusion::Set * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Set * _get_impl(mosek::fusion::Set::t _inst) { return _get_impl(_inst.get()); }
p_Set(Set * _pubthis);
virtual ~p_Set() { /* std::cout << "~p_Set" << std::endl;*/ };
virtual void destroy();
static  long long size(std::shared_ptr< monty::ndarray< int,1 > > _2366);
static  bool match(std::shared_ptr< monty::ndarray< int,1 > > _2369,std::shared_ptr< monty::ndarray< int,1 > > _2370);
static  long long linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2372,std::shared_ptr< monty::ndarray< int,1 > > _2373);
static  std::shared_ptr< monty::ndarray< int,1 > > idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2376,long long _2377);
static  void idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2379,long long _2380,std::shared_ptr< monty::ndarray< int,1 > > _2381);
static  std::string indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2385,long long _2386);
static  std::string keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2393);
static  void indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2396,long long _2397,std::shared_ptr< monty::ndarray< int,1 > > _2398);
static  std::shared_ptr< monty::ndarray< long long,1 > > strides(std::shared_ptr< monty::ndarray< int,1 > > _2402);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2406,std::shared_ptr< monty::ndarray< int,1 > > _2407);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2411);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2413,int _2414,int _2415);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2416,int _2417);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2418);
static  std::shared_ptr< monty::ndarray< int,1 > > scalar();
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< std::string,1 > > _2419);
}; // struct Set;

struct p_ConeDomain
{
ConeDomain * _pubthis;
static mosek::fusion::p_ConeDomain* _get_impl(mosek::fusion::ConeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConeDomain * _get_impl(mosek::fusion::ConeDomain::t _inst) { return _get_impl(_inst.get()); }
p_ConeDomain(ConeDomain * _pubthis);
virtual ~p_ConeDomain() { /* std::cout << "~p_ConeDomain" << std::endl;*/ };
double alpha{};std::shared_ptr< monty::ndarray< int,1 > > shape{};bool int_flag{};bool axisset{};int axisidx{};mosek::fusion::QConeKey key{};virtual void destroy();
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2420,double _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422);
void _initialize(mosek::fusion::QConeKey _2420,double _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422);
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2423,std::shared_ptr< monty::ndarray< int,1 > > _2424);
void _initialize(mosek::fusion::QConeKey _2423,std::shared_ptr< monty::ndarray< int,1 > > _2424);
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2425) ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__integral() ;
virtual bool axisIsSet() ;
virtual int getAxis() ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__axis(int _2426) ;
}; // struct ConeDomain;

struct p_LinPSDDomain
{
LinPSDDomain * _pubthis;
static mosek::fusion::p_LinPSDDomain* _get_impl(mosek::fusion::LinPSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinPSDDomain * _get_impl(mosek::fusion::LinPSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinPSDDomain(LinPSDDomain * _pubthis);
virtual ~p_LinPSDDomain() { /* std::cout << "~p_LinPSDDomain" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2427,int _2428);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2427,int _2428);
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2429);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2429);
static LinPSDDomain::t _new_LinPSDDomain();
void _initialize();
}; // struct LinPSDDomain;

struct p_PSDDomain
{
PSDDomain * _pubthis;
static mosek::fusion::p_PSDDomain* _get_impl(mosek::fusion::PSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_PSDDomain * _get_impl(mosek::fusion::PSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_PSDDomain(PSDDomain * _pubthis);
virtual ~p_PSDDomain() { /* std::cout << "~p_PSDDomain" << std::endl;*/ };
bool axisIsSet{};int conedim2{};int conedim1{};mosek::fusion::PSDKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2430,std::shared_ptr< monty::ndarray< int,1 > > _2431,int _2432,int _2433);
void _initialize(mosek::fusion::PSDKey _2430,std::shared_ptr< monty::ndarray< int,1 > > _2431,int _2432,int _2433);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2435,std::shared_ptr< monty::ndarray< int,1 > > _2436);
void _initialize(mosek::fusion::PSDKey _2435,std::shared_ptr< monty::ndarray< int,1 > > _2436);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2437);
void _initialize(mosek::fusion::PSDKey _2437);
virtual monty::rc_ptr< ::mosek::fusion::PSDDomain > __mosek_2fusion_2PSDDomain__axis(int _2438,int _2439) ;
}; // struct PSDDomain;

struct p_RangeDomain
{
RangeDomain * _pubthis;
static mosek::fusion::p_RangeDomain* _get_impl(mosek::fusion::RangeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_RangeDomain * _get_impl(mosek::fusion::RangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_RangeDomain(RangeDomain * _pubthis);
virtual ~p_RangeDomain() { /* std::cout << "~p_RangeDomain" << std::endl;*/ };
bool cardinal_flag{};bool scalable{};std::shared_ptr< monty::ndarray< double,1 > > ub{};std::shared_ptr< monty::ndarray< double,1 > > lb{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangeDomain::t _new_RangeDomain(bool _2441,std::shared_ptr< monty::ndarray< double,1 > > _2442,std::shared_ptr< monty::ndarray< double,1 > > _2443,std::shared_ptr< monty::ndarray< int,1 > > _2444);
void _initialize(bool _2441,std::shared_ptr< monty::ndarray< double,1 > > _2442,std::shared_ptr< monty::ndarray< double,1 > > _2443,std::shared_ptr< monty::ndarray< int,1 > > _2444);
static RangeDomain::t _new_RangeDomain(bool _2445,std::shared_ptr< monty::ndarray< double,1 > > _2446,std::shared_ptr< monty::ndarray< double,1 > > _2447,std::shared_ptr< monty::ndarray< int,1 > > _2448,std::shared_ptr< monty::ndarray< int,2 > > _2449);
void _initialize(bool _2445,std::shared_ptr< monty::ndarray< double,1 > > _2446,std::shared_ptr< monty::ndarray< double,1 > > _2447,std::shared_ptr< monty::ndarray< int,1 > > _2448,std::shared_ptr< monty::ndarray< int,2 > > _2449);
static RangeDomain::t _new_RangeDomain(bool _2450,std::shared_ptr< monty::ndarray< double,1 > > _2451,std::shared_ptr< monty::ndarray< double,1 > > _2452,std::shared_ptr< monty::ndarray< int,1 > > _2453,std::shared_ptr< monty::ndarray< int,2 > > _2454,int _2455);
void _initialize(bool _2450,std::shared_ptr< monty::ndarray< double,1 > > _2451,std::shared_ptr< monty::ndarray< double,1 > > _2452,std::shared_ptr< monty::ndarray< int,1 > > _2453,std::shared_ptr< monty::ndarray< int,2 > > _2454,int _2455);
static RangeDomain::t _new_RangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2456);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2456);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > __mosek_2fusion_2RangeDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2457) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2460) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2462) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2463) ;
}; // struct RangeDomain;

struct p_SymmetricRangeDomain : public ::mosek::fusion::p_RangeDomain
{
SymmetricRangeDomain * _pubthis;
static mosek::fusion::p_SymmetricRangeDomain* _get_impl(mosek::fusion::SymmetricRangeDomain * _inst){ return static_cast< mosek::fusion::p_SymmetricRangeDomain* >(mosek::fusion::p_RangeDomain::_get_impl(_inst)); }
static mosek::fusion::p_SymmetricRangeDomain * _get_impl(mosek::fusion::SymmetricRangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricRangeDomain(SymmetricRangeDomain * _pubthis);
virtual ~p_SymmetricRangeDomain() { /* std::cout << "~p_SymmetricRangeDomain" << std::endl;*/ };
int dim{};virtual void destroy();
static SymmetricRangeDomain::t _new_SymmetricRangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2440);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2440);
}; // struct SymmetricRangeDomain;

struct p_SymmetricLinearDomain
{
SymmetricLinearDomain * _pubthis;
static mosek::fusion::p_SymmetricLinearDomain* _get_impl(mosek::fusion::SymmetricLinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricLinearDomain * _get_impl(mosek::fusion::SymmetricLinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricLinearDomain(SymmetricLinearDomain * _pubthis);
virtual ~p_SymmetricLinearDomain() { /* std::cout << "~p_SymmetricLinearDomain" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::LinearDomain > dom{};int dim{};virtual void destroy();
static SymmetricLinearDomain::t _new_SymmetricLinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2465);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2465);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2466) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2469) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__integral() ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2471) ;
}; // struct SymmetricLinearDomain;

struct p_LinearDomain
{
LinearDomain * _pubthis;
static mosek::fusion::p_LinearDomain* _get_impl(mosek::fusion::LinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinearDomain * _get_impl(mosek::fusion::LinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinearDomain(LinearDomain * _pubthis);
virtual ~p_LinearDomain() { /* std::cout << "~p_LinearDomain" << std::endl;*/ };
bool scalable{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< double,1 > > bnd{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2473,bool _2474,std::shared_ptr< monty::ndarray< double,1 > > _2475,std::shared_ptr< monty::ndarray< int,1 > > _2476);
void _initialize(mosek::fusion::RelationKey _2473,bool _2474,std::shared_ptr< monty::ndarray< double,1 > > _2475,std::shared_ptr< monty::ndarray< int,1 > > _2476);
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2477,bool _2478,std::shared_ptr< monty::ndarray< double,1 > > _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,std::shared_ptr< monty::ndarray< int,2 > > _2481,int _2482);
void _initialize(mosek::fusion::RelationKey _2477,bool _2478,std::shared_ptr< monty::ndarray< double,1 > > _2479,std::shared_ptr< monty::ndarray< int,1 > > _2480,std::shared_ptr< monty::ndarray< int,2 > > _2481,int _2482);
static LinearDomain::t _new_LinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2483);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2483);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2LinearDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2484) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2487) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2489) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2490) ;
}; // struct LinearDomain;

struct p_Domain
{
Domain * _pubthis;
static mosek::fusion::p_Domain* _get_impl(mosek::fusion::Domain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Domain * _get_impl(mosek::fusion::Domain::t _inst) { return _get_impl(_inst.get()); }
p_Domain(Domain * _pubthis);
virtual ~p_Domain() { /* std::cout << "~p_Domain" << std::endl;*/ };
virtual void destroy();
static  long long dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2492);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > mkLinearDomain(mosek::fusion::RelationKey _2495,monty::rc_ptr< ::mosek::fusion::Matrix > _2496);
static  long long prod(std::shared_ptr< monty::ndarray< int,1 > > _2502);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(bool _2505,std::shared_ptr< monty::ndarray< double,1 > > _2506,std::shared_ptr< monty::ndarray< double,1 > > _2507,std::shared_ptr< monty::ndarray< int,2 > > _2508,std::shared_ptr< monty::ndarray< int,1 > > _2509);
static  monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2511);
static  monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2512);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2513,std::shared_ptr< monty::ndarray< int,2 > > _2514);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2515,std::shared_ptr< monty::ndarray< int,1 > > _2516);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2517,std::shared_ptr< monty::ndarray< int,2 > > _2518);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2519,std::shared_ptr< monty::ndarray< int,1 > > _2520);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2521);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2522);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2523);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2524,int _2525);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2526,std::shared_ptr< monty::ndarray< int,1 > > _2527);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2529,int _2530);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2531);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2532,std::shared_ptr< monty::ndarray< int,1 > > _2533);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2535,int _2536);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2537);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2538);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(int _2540);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2541);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(int _2543);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2544);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2546,int _2547);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2548);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2549);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2551,int _2552);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2553);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone();
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2554,int _2555);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2556);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2557,int _2558);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2559);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2560,int _2561);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2562);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(std::shared_ptr< monty::ndarray< int,1 > > _2563);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2564,int _2565);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2566);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2567,std::shared_ptr< monty::ndarray< double,1 > > _2568,std::shared_ptr< monty::ndarray< int,1 > > _2569);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2570,double _2571,std::shared_ptr< monty::ndarray< int,1 > > _2572);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2574,std::shared_ptr< monty::ndarray< double,1 > > _2575,std::shared_ptr< monty::ndarray< int,1 > > _2576);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2578,double _2579,std::shared_ptr< monty::ndarray< int,1 > > _2580);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2581,std::shared_ptr< monty::ndarray< double,1 > > _2582);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2583,double _2584);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2586,std::shared_ptr< monty::ndarray< double,1 > > _2587);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2589,double _2590);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2591);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2592,std::shared_ptr< monty::ndarray< int,1 > > _2593);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2594);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2597);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2598,std::shared_ptr< monty::ndarray< int,1 > > _2599);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2601,int _2602,int _2603);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2605,int _2606);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2608);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2609);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2610,std::shared_ptr< monty::ndarray< int,1 > > _2611);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2612);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2615);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2618,int _2619,int _2620);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2621,int _2622);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2623);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2624);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2625,std::shared_ptr< monty::ndarray< int,1 > > _2626);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2627);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2630);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2631,std::shared_ptr< monty::ndarray< int,1 > > _2632);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2633,int _2634,int _2635);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2636,int _2637);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2638);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2639);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2641,int _2642);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2643);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded();
}; // struct Domain;

struct p_BaseExpression : public /*implements*/ virtual ::mosek::fusion::Expression
{
BaseExpression * _pubthis;
static mosek::fusion::p_BaseExpression* _get_impl(mosek::fusion::BaseExpression * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseExpression * _get_impl(mosek::fusion::BaseExpression::t _inst) { return _get_impl(_inst.get()); }
p_BaseExpression(BaseExpression * _pubthis);
virtual ~p_BaseExpression() { /* std::cout << "~p_BaseExpression" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseExpression::t _new_BaseExpression(std::shared_ptr< monty::ndarray< int,1 > > _4787);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4787);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }
static  void storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4803,std::shared_ptr< monty::ndarray< int,1 > > _4804,std::shared_ptr< monty::ndarray< int,1 > > _4805,std::shared_ptr< monty::ndarray< long long,1 > > _4806,std::shared_ptr< monty::ndarray< long long,1 > > _4807,std::shared_ptr< monty::ndarray< double,1 > > _4808,std::shared_ptr< monty::ndarray< double,1 > > _4809);
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4820,monty::rc_ptr< ::mosek::fusion::WorkStack > _4821,monty::rc_ptr< ::mosek::fusion::WorkStack > _4822) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4823) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4823) { return __mosek_2fusion_2BaseExpression__pick(_4823); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4824) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4824) { return __mosek_2fusion_2BaseExpression__pick(_4824); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4827) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4827) { return __mosek_2fusion_2BaseExpression__index(_4827); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(int _4830) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _4830) { return __mosek_2fusion_2BaseExpression__index(_4830); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4832,std::shared_ptr< monty::ndarray< int,1 > > _4833) { return __mosek_2fusion_2BaseExpression__slice(_4832,_4833); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _4834,int _4835) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(int _4834,int _4835) { return __mosek_2fusion_2BaseExpression__slice(_4834,_4835); }
virtual long long getSize() ;
virtual int getND() ;
virtual int getDim(int _4836) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct BaseExpression;

struct p_ExprConst : public ::mosek::fusion::p_BaseExpression
{
ExprConst * _pubthis;
static mosek::fusion::p_ExprConst* _get_impl(mosek::fusion::ExprConst * _inst){ return static_cast< mosek::fusion::p_ExprConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprConst * _get_impl(mosek::fusion::ExprConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprConst(ExprConst * _pubthis);
virtual ~p_ExprConst() { /* std::cout << "~p_ExprConst" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2644,std::shared_ptr< monty::ndarray< long long,1 > > _2645,std::shared_ptr< monty::ndarray< double,1 > > _2646);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2644,std::shared_ptr< monty::ndarray< long long,1 > > _2645,std::shared_ptr< monty::ndarray< double,1 > > _2646);
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2647,std::shared_ptr< monty::ndarray< long long,1 > > _2648,double _2649);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2647,std::shared_ptr< monty::ndarray< long long,1 > > _2648,double _2649);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2652,monty::rc_ptr< ::mosek::fusion::WorkStack > _2653,monty::rc_ptr< ::mosek::fusion::WorkStack > _2654) ;
static  void validate(std::shared_ptr< monty::ndarray< int,1 > > _2668,std::shared_ptr< monty::ndarray< double,1 > > _2669,std::shared_ptr< monty::ndarray< long long,1 > > _2670);
virtual /* override */ std::string toString() ;
}; // struct ExprConst;

struct p_ExprPick : public ::mosek::fusion::p_BaseExpression
{
ExprPick * _pubthis;
static mosek::fusion::p_ExprPick* _get_impl(mosek::fusion::ExprPick * _inst){ return static_cast< mosek::fusion::p_ExprPick* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPick * _get_impl(mosek::fusion::ExprPick::t _inst) { return _get_impl(_inst.get()); }
p_ExprPick(ExprPick * _pubthis);
virtual ~p_ExprPick() { /* std::cout << "~p_ExprPick" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > idxs{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2673,std::shared_ptr< monty::ndarray< int,2 > > _2674);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2673,std::shared_ptr< monty::ndarray< int,2 > > _2674);
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2685,std::shared_ptr< monty::ndarray< long long,1 > > _2686);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2685,std::shared_ptr< monty::ndarray< long long,1 > > _2686);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2690,monty::rc_ptr< ::mosek::fusion::WorkStack > _2691,monty::rc_ptr< ::mosek::fusion::WorkStack > _2692) ;
virtual /* override */ std::string toString() ;
}; // struct ExprPick;

struct p_ExprSlice : public ::mosek::fusion::p_BaseExpression
{
ExprSlice * _pubthis;
static mosek::fusion::p_ExprSlice* _get_impl(mosek::fusion::ExprSlice * _inst){ return static_cast< mosek::fusion::p_ExprSlice* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSlice * _get_impl(mosek::fusion::ExprSlice::t _inst) { return _get_impl(_inst.get()); }
p_ExprSlice(ExprSlice * _pubthis);
virtual ~p_ExprSlice() { /* std::cout << "~p_ExprSlice" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > last{};std::shared_ptr< monty::ndarray< int,1 > > first{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSlice::t _new_ExprSlice(monty::rc_ptr< ::mosek::fusion::Expression > _2744,std::shared_ptr< monty::ndarray< int,1 > > _2745,std::shared_ptr< monty::ndarray< int,1 > > _2746);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2744,std::shared_ptr< monty::ndarray< int,1 > > _2745,std::shared_ptr< monty::ndarray< int,1 > > _2746);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2747,monty::rc_ptr< ::mosek::fusion::WorkStack > _2748,monty::rc_ptr< ::mosek::fusion::WorkStack > _2749) ;
static  std::shared_ptr< monty::ndarray< int,1 > > makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2803,std::shared_ptr< monty::ndarray< int,1 > > _2804,std::shared_ptr< monty::ndarray< int,1 > > _2805);
virtual /* override */ std::string toString() ;
}; // struct ExprSlice;

struct p_ExprPermuteDims : public ::mosek::fusion::p_BaseExpression
{
ExprPermuteDims * _pubthis;
static mosek::fusion::p_ExprPermuteDims* _get_impl(mosek::fusion::ExprPermuteDims * _inst){ return static_cast< mosek::fusion::p_ExprPermuteDims* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPermuteDims * _get_impl(mosek::fusion::ExprPermuteDims::t _inst) { return _get_impl(_inst.get()); }
p_ExprPermuteDims(ExprPermuteDims * _pubthis);
virtual ~p_ExprPermuteDims() { /* std::cout << "~p_ExprPermuteDims" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > dperm{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2810,monty::rc_ptr< ::mosek::fusion::Expression > _2811);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2810,monty::rc_ptr< ::mosek::fusion::Expression > _2811);
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2817,monty::rc_ptr< ::mosek::fusion::Expression > _2818,int _2819);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2817,monty::rc_ptr< ::mosek::fusion::Expression > _2818,int _2819);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2820,monty::rc_ptr< ::mosek::fusion::WorkStack > _2821,monty::rc_ptr< ::mosek::fusion::WorkStack > _2822) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2874,std::shared_ptr< monty::ndarray< int,1 > > _2875);
}; // struct ExprPermuteDims;

struct p_ExprTranspose : public ::mosek::fusion::p_BaseExpression
{
ExprTranspose * _pubthis;
static mosek::fusion::p_ExprTranspose* _get_impl(mosek::fusion::ExprTranspose * _inst){ return static_cast< mosek::fusion::p_ExprTranspose* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprTranspose * _get_impl(mosek::fusion::ExprTranspose::t _inst) { return _get_impl(_inst.get()); }
p_ExprTranspose(ExprTranspose * _pubthis);
virtual ~p_ExprTranspose() { /* std::cout << "~p_ExprTranspose" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprTranspose::t _new_ExprTranspose(monty::rc_ptr< ::mosek::fusion::Expression > _2877);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2877);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2878,monty::rc_ptr< ::mosek::fusion::WorkStack > _2879,monty::rc_ptr< ::mosek::fusion::WorkStack > _2880) ;
virtual /* override */ std::string toString() ;
static  std::shared_ptr< monty::ndarray< int,1 > > transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2924);
}; // struct ExprTranspose;

struct p_ExprStack : public ::mosek::fusion::p_BaseExpression
{
ExprStack * _pubthis;
static mosek::fusion::p_ExprStack* _get_impl(mosek::fusion::ExprStack * _inst){ return static_cast< mosek::fusion::p_ExprStack* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprStack * _get_impl(mosek::fusion::ExprStack::t _inst) { return _get_impl(_inst.get()); }
p_ExprStack(ExprStack * _pubthis);
virtual ~p_ExprStack() { /* std::cout << "~p_ExprStack" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > exprs{};virtual void destroy();
static ExprStack::t _new_ExprStack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2925,int _2926);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2925,int _2926);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2928,monty::rc_ptr< ::mosek::fusion::WorkStack > _2929,monty::rc_ptr< ::mosek::fusion::WorkStack > _2930) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3078,int _3079);
virtual /* override */ std::string toString() ;
}; // struct ExprStack;

struct p_ExprInner : public ::mosek::fusion::p_BaseExpression
{
ExprInner * _pubthis;
static mosek::fusion::p_ExprInner* _get_impl(mosek::fusion::ExprInner * _inst){ return static_cast< mosek::fusion::p_ExprInner* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprInner * _get_impl(mosek::fusion::ExprInner::t _inst) { return _get_impl(_inst.get()); }
p_ExprInner(ExprInner * _pubthis);
virtual ~p_ExprInner() { /* std::cout << "~p_ExprInner" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > vcof{};std::shared_ptr< monty::ndarray< long long,1 > > vsub{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3093,std::shared_ptr< monty::ndarray< long long,1 > > _3094,std::shared_ptr< monty::ndarray< double,1 > > _3095);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3093,std::shared_ptr< monty::ndarray< long long,1 > > _3094,std::shared_ptr< monty::ndarray< double,1 > > _3095);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3099,std::shared_ptr< monty::ndarray< double,1 > > _3100);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3099,std::shared_ptr< monty::ndarray< double,1 > > _3100);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3102,std::shared_ptr< monty::ndarray< int,2 > > _3103,std::shared_ptr< monty::ndarray< double,1 > > _3104);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3102,std::shared_ptr< monty::ndarray< int,2 > > _3103,std::shared_ptr< monty::ndarray< double,1 > > _3104);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3105,monty::rc_ptr< ::mosek::fusion::WorkStack > _3106,monty::rc_ptr< ::mosek::fusion::WorkStack > _3107) ;
static  std::shared_ptr< monty::ndarray< long long,1 > > range(int _3143);
static  std::shared_ptr< monty::ndarray< long long,1 > > convert(std::shared_ptr< monty::ndarray< int,1 > > _3145,std::shared_ptr< monty::ndarray< int,2 > > _3146);
virtual /* override */ std::string toString() ;
}; // struct ExprInner;

struct p_ExprMulDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagRight * _pubthis;
static mosek::fusion::p_ExprMulDiagRight* _get_impl(mosek::fusion::ExprMulDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagRight * _get_impl(mosek::fusion::ExprMulDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagRight(ExprMulDiagRight * _pubthis);
virtual ~p_ExprMulDiagRight() { /* std::cout << "~p_ExprMulDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3153,int _3154,std::shared_ptr< monty::ndarray< int,1 > > _3155,std::shared_ptr< monty::ndarray< int,1 > > _3156,std::shared_ptr< monty::ndarray< double,1 > > _3157,monty::rc_ptr< ::mosek::fusion::Expression > _3158,int _3159);
void _initialize(int _3153,int _3154,std::shared_ptr< monty::ndarray< int,1 > > _3155,std::shared_ptr< monty::ndarray< int,1 > > _3156,std::shared_ptr< monty::ndarray< double,1 > > _3157,monty::rc_ptr< ::mosek::fusion::Expression > _3158,int _3159);
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3160,int _3161,std::shared_ptr< monty::ndarray< int,1 > > _3162,std::shared_ptr< monty::ndarray< int,1 > > _3163,std::shared_ptr< monty::ndarray< double,1 > > _3164,monty::rc_ptr< ::mosek::fusion::Expression > _3165);
void _initialize(int _3160,int _3161,std::shared_ptr< monty::ndarray< int,1 > > _3162,std::shared_ptr< monty::ndarray< int,1 > > _3163,std::shared_ptr< monty::ndarray< double,1 > > _3164,monty::rc_ptr< ::mosek::fusion::Expression > _3165);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3166,monty::rc_ptr< ::mosek::fusion::WorkStack > _3167,monty::rc_ptr< ::mosek::fusion::WorkStack > _3168) ;
static  int validate(int _3260,int _3261,std::shared_ptr< monty::ndarray< int,1 > > _3262,std::shared_ptr< monty::ndarray< int,1 > > _3263,std::shared_ptr< monty::ndarray< double,1 > > _3264,monty::rc_ptr< ::mosek::fusion::Expression > _3265);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagRight;

struct p_ExprMulDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulDiagLeft* _get_impl(mosek::fusion::ExprMulDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagLeft * _get_impl(mosek::fusion::ExprMulDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagLeft(ExprMulDiagLeft * _pubthis);
virtual ~p_ExprMulDiagLeft() { /* std::cout << "~p_ExprMulDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3273,int _3274,std::shared_ptr< monty::ndarray< int,1 > > _3275,std::shared_ptr< monty::ndarray< int,1 > > _3276,std::shared_ptr< monty::ndarray< double,1 > > _3277,monty::rc_ptr< ::mosek::fusion::Expression > _3278,int _3279);
void _initialize(int _3273,int _3274,std::shared_ptr< monty::ndarray< int,1 > > _3275,std::shared_ptr< monty::ndarray< int,1 > > _3276,std::shared_ptr< monty::ndarray< double,1 > > _3277,monty::rc_ptr< ::mosek::fusion::Expression > _3278,int _3279);
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3280,int _3281,std::shared_ptr< monty::ndarray< int,1 > > _3282,std::shared_ptr< monty::ndarray< int,1 > > _3283,std::shared_ptr< monty::ndarray< double,1 > > _3284,monty::rc_ptr< ::mosek::fusion::Expression > _3285);
void _initialize(int _3280,int _3281,std::shared_ptr< monty::ndarray< int,1 > > _3282,std::shared_ptr< monty::ndarray< int,1 > > _3283,std::shared_ptr< monty::ndarray< double,1 > > _3284,monty::rc_ptr< ::mosek::fusion::Expression > _3285);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3286,monty::rc_ptr< ::mosek::fusion::WorkStack > _3287,monty::rc_ptr< ::mosek::fusion::WorkStack > _3288) ;
static  int validate(int _3373,int _3374,std::shared_ptr< monty::ndarray< int,1 > > _3375,std::shared_ptr< monty::ndarray< int,1 > > _3376,std::shared_ptr< monty::ndarray< double,1 > > _3377,monty::rc_ptr< ::mosek::fusion::Expression > _3378);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagLeft;

struct p_ExprMulElement : public ::mosek::fusion::p_BaseExpression
{
ExprMulElement * _pubthis;
static mosek::fusion::p_ExprMulElement* _get_impl(mosek::fusion::ExprMulElement * _inst){ return static_cast< mosek::fusion::p_ExprMulElement* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulElement * _get_impl(mosek::fusion::ExprMulElement::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulElement(ExprMulElement * _pubthis);
virtual ~p_ExprMulElement() { /* std::cout << "~p_ExprMulElement" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< long long,1 > > msp{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};virtual void destroy();
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3386,std::shared_ptr< monty::ndarray< long long,1 > > _3387,monty::rc_ptr< ::mosek::fusion::Expression > _3388);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3386,std::shared_ptr< monty::ndarray< long long,1 > > _3387,monty::rc_ptr< ::mosek::fusion::Expression > _3388);
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3393,std::shared_ptr< monty::ndarray< long long,1 > > _3394,monty::rc_ptr< ::mosek::fusion::Expression > _3395,int _3396);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3393,std::shared_ptr< monty::ndarray< long long,1 > > _3394,monty::rc_ptr< ::mosek::fusion::Expression > _3395,int _3396);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3397,monty::rc_ptr< ::mosek::fusion::WorkStack > _3398,monty::rc_ptr< ::mosek::fusion::WorkStack > _3399) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulElement;

struct p_ExprMulScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarConst * _pubthis;
static mosek::fusion::p_ExprMulScalarConst* _get_impl(mosek::fusion::ExprMulScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarConst * _get_impl(mosek::fusion::ExprMulScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarConst(ExprMulScalarConst * _pubthis);
virtual ~p_ExprMulScalarConst() { /* std::cout << "~p_ExprMulScalarConst" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};double c{};virtual void destroy();
static ExprMulScalarConst::t _new_ExprMulScalarConst(double _3446,monty::rc_ptr< ::mosek::fusion::Expression > _3447);
void _initialize(double _3446,monty::rc_ptr< ::mosek::fusion::Expression > _3447);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3448,monty::rc_ptr< ::mosek::fusion::WorkStack > _3449,monty::rc_ptr< ::mosek::fusion::WorkStack > _3450) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarConst;

struct p_ExprScalarMul : public ::mosek::fusion::p_BaseExpression
{
ExprScalarMul * _pubthis;
static mosek::fusion::p_ExprScalarMul* _get_impl(mosek::fusion::ExprScalarMul * _inst){ return static_cast< mosek::fusion::p_ExprScalarMul* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprScalarMul * _get_impl(mosek::fusion::ExprScalarMul::t _inst) { return _get_impl(_inst.get()); }
p_ExprScalarMul(ExprScalarMul * _pubthis);
virtual ~p_ExprScalarMul() { /* std::cout << "~p_ExprScalarMul" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprScalarMul::t _new_ExprScalarMul(int _3458,int _3459,std::shared_ptr< monty::ndarray< int,1 > > _3460,std::shared_ptr< monty::ndarray< int,1 > > _3461,std::shared_ptr< monty::ndarray< double,1 > > _3462,monty::rc_ptr< ::mosek::fusion::Expression > _3463,int _3464);
void _initialize(int _3458,int _3459,std::shared_ptr< monty::ndarray< int,1 > > _3460,std::shared_ptr< monty::ndarray< int,1 > > _3461,std::shared_ptr< monty::ndarray< double,1 > > _3462,monty::rc_ptr< ::mosek::fusion::Expression > _3463,int _3464);
static ExprScalarMul::t _new_ExprScalarMul(int _3465,int _3466,std::shared_ptr< monty::ndarray< int,1 > > _3467,std::shared_ptr< monty::ndarray< int,1 > > _3468,std::shared_ptr< monty::ndarray< double,1 > > _3469,monty::rc_ptr< ::mosek::fusion::Expression > _3470);
void _initialize(int _3465,int _3466,std::shared_ptr< monty::ndarray< int,1 > > _3467,std::shared_ptr< monty::ndarray< int,1 > > _3468,std::shared_ptr< monty::ndarray< double,1 > > _3469,monty::rc_ptr< ::mosek::fusion::Expression > _3470);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3471,monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473) ;
static  int validate(int _3498,int _3499,std::shared_ptr< monty::ndarray< int,1 > > _3500,std::shared_ptr< monty::ndarray< int,1 > > _3501,std::shared_ptr< monty::ndarray< double,1 > > _3502,monty::rc_ptr< ::mosek::fusion::Expression > _3503);
virtual /* override */ std::string toString() ;
}; // struct ExprScalarMul;

struct p_ExprMulRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulRight * _pubthis;
static mosek::fusion::p_ExprMulRight* _get_impl(mosek::fusion::ExprMulRight * _inst){ return static_cast< mosek::fusion::p_ExprMulRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulRight * _get_impl(mosek::fusion::ExprMulRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulRight(ExprMulRight * _pubthis);
virtual ~p_ExprMulRight() { /* std::cout << "~p_ExprMulRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulRight::t _new_ExprMulRight(int _3509,int _3510,std::shared_ptr< monty::ndarray< int,1 > > _3511,std::shared_ptr< monty::ndarray< int,1 > > _3512,std::shared_ptr< monty::ndarray< double,1 > > _3513,monty::rc_ptr< ::mosek::fusion::Expression > _3514,int _3515);
void _initialize(int _3509,int _3510,std::shared_ptr< monty::ndarray< int,1 > > _3511,std::shared_ptr< monty::ndarray< int,1 > > _3512,std::shared_ptr< monty::ndarray< double,1 > > _3513,monty::rc_ptr< ::mosek::fusion::Expression > _3514,int _3515);
static ExprMulRight::t _new_ExprMulRight(int _3516,int _3517,std::shared_ptr< monty::ndarray< int,1 > > _3518,std::shared_ptr< monty::ndarray< int,1 > > _3519,std::shared_ptr< monty::ndarray< double,1 > > _3520,monty::rc_ptr< ::mosek::fusion::Expression > _3521);
void _initialize(int _3516,int _3517,std::shared_ptr< monty::ndarray< int,1 > > _3518,std::shared_ptr< monty::ndarray< int,1 > > _3519,std::shared_ptr< monty::ndarray< double,1 > > _3520,monty::rc_ptr< ::mosek::fusion::Expression > _3521);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3522,monty::rc_ptr< ::mosek::fusion::WorkStack > _3523,monty::rc_ptr< ::mosek::fusion::WorkStack > _3524) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3665,std::shared_ptr< monty::ndarray< int,1 > > _3666);
static  int validate(int _3667,int _3668,std::shared_ptr< monty::ndarray< int,1 > > _3669,std::shared_ptr< monty::ndarray< int,1 > > _3670,std::shared_ptr< monty::ndarray< double,1 > > _3671,monty::rc_ptr< ::mosek::fusion::Expression > _3672);
virtual /* override */ std::string toString() ;
}; // struct ExprMulRight;

struct p_ExprMulLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulLeft * _pubthis;
static mosek::fusion::p_ExprMulLeft* _get_impl(mosek::fusion::ExprMulLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulLeft * _get_impl(mosek::fusion::ExprMulLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulLeft(ExprMulLeft * _pubthis);
virtual ~p_ExprMulLeft() { /* std::cout << "~p_ExprMulLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulLeft::t _new_ExprMulLeft(int _3680,int _3681,std::shared_ptr< monty::ndarray< int,1 > > _3682,std::shared_ptr< monty::ndarray< int,1 > > _3683,std::shared_ptr< monty::ndarray< double,1 > > _3684,monty::rc_ptr< ::mosek::fusion::Expression > _3685,int _3686);
void _initialize(int _3680,int _3681,std::shared_ptr< monty::ndarray< int,1 > > _3682,std::shared_ptr< monty::ndarray< int,1 > > _3683,std::shared_ptr< monty::ndarray< double,1 > > _3684,monty::rc_ptr< ::mosek::fusion::Expression > _3685,int _3686);
static ExprMulLeft::t _new_ExprMulLeft(int _3687,int _3688,std::shared_ptr< monty::ndarray< int,1 > > _3689,std::shared_ptr< monty::ndarray< int,1 > > _3690,std::shared_ptr< monty::ndarray< double,1 > > _3691,monty::rc_ptr< ::mosek::fusion::Expression > _3692);
void _initialize(int _3687,int _3688,std::shared_ptr< monty::ndarray< int,1 > > _3689,std::shared_ptr< monty::ndarray< int,1 > > _3690,std::shared_ptr< monty::ndarray< double,1 > > _3691,monty::rc_ptr< ::mosek::fusion::Expression > _3692);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3693,monty::rc_ptr< ::mosek::fusion::WorkStack > _3694,monty::rc_ptr< ::mosek::fusion::WorkStack > _3695) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3793,int _3794,std::shared_ptr< monty::ndarray< int,1 > > _3795);
static  int validate(int _3796,int _3797,std::shared_ptr< monty::ndarray< int,1 > > _3798,std::shared_ptr< monty::ndarray< int,1 > > _3799,std::shared_ptr< monty::ndarray< double,1 > > _3800,monty::rc_ptr< ::mosek::fusion::Expression > _3801);
virtual /* override */ std::string toString() ;
}; // struct ExprMulLeft;

struct p_ExprMulVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulVar * _pubthis;
static mosek::fusion::p_ExprMulVar* _get_impl(mosek::fusion::ExprMulVar * _inst){ return static_cast< mosek::fusion::p_ExprMulVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVar * _get_impl(mosek::fusion::ExprMulVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVar(ExprMulVar * _pubthis);
virtual ~p_ExprMulVar() { /* std::cout << "~p_ExprMulVar" << std::endl;*/ };
bool left{};monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulVar::t _new_ExprMulVar(bool _3808,int _3809,int _3810,std::shared_ptr< monty::ndarray< int,1 > > _3811,std::shared_ptr< monty::ndarray< int,1 > > _3812,std::shared_ptr< monty::ndarray< double,1 > > _3813,monty::rc_ptr< ::mosek::fusion::Variable > _3814);
void _initialize(bool _3808,int _3809,int _3810,std::shared_ptr< monty::ndarray< int,1 > > _3811,std::shared_ptr< monty::ndarray< int,1 > > _3812,std::shared_ptr< monty::ndarray< double,1 > > _3813,monty::rc_ptr< ::mosek::fusion::Variable > _3814);
static ExprMulVar::t _new_ExprMulVar(bool _3817,int _3818,int _3819,std::shared_ptr< monty::ndarray< int,1 > > _3820,std::shared_ptr< monty::ndarray< int,1 > > _3821,std::shared_ptr< monty::ndarray< double,1 > > _3822,monty::rc_ptr< ::mosek::fusion::Variable > _3823,int _3824);
void _initialize(bool _3817,int _3818,int _3819,std::shared_ptr< monty::ndarray< int,1 > > _3820,std::shared_ptr< monty::ndarray< int,1 > > _3821,std::shared_ptr< monty::ndarray< double,1 > > _3822,monty::rc_ptr< ::mosek::fusion::Variable > _3823,int _3824);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3825,monty::rc_ptr< ::mosek::fusion::WorkStack > _3826,monty::rc_ptr< ::mosek::fusion::WorkStack > _3827) ;
virtual void eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3828,monty::rc_ptr< ::mosek::fusion::WorkStack > _3829,monty::rc_ptr< ::mosek::fusion::WorkStack > _3830) ;
virtual void eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3936,monty::rc_ptr< ::mosek::fusion::WorkStack > _3937,monty::rc_ptr< ::mosek::fusion::WorkStack > _3938) ;
virtual void validate(int _4004,int _4005,std::shared_ptr< monty::ndarray< int,1 > > _4006,std::shared_ptr< monty::ndarray< int,1 > > _4007,std::shared_ptr< monty::ndarray< double,1 > > _4008) ;
static  std::shared_ptr< monty::ndarray< int,1 > > resshape(int _4012,int _4013,std::shared_ptr< monty::ndarray< int,1 > > _4014,bool _4015);
virtual /* override */ std::string toString() ;
}; // struct ExprMulVar;

struct p_ExprMulScalarVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarVar * _pubthis;
static mosek::fusion::p_ExprMulScalarVar* _get_impl(mosek::fusion::ExprMulScalarVar * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarVar * _get_impl(mosek::fusion::ExprMulScalarVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarVar(ExprMulScalarVar * _pubthis);
virtual ~p_ExprMulScalarVar() { /* std::cout << "~p_ExprMulScalarVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4016,int _4017,std::shared_ptr< monty::ndarray< int,1 > > _4018,std::shared_ptr< monty::ndarray< int,1 > > _4019,std::shared_ptr< monty::ndarray< double,1 > > _4020,monty::rc_ptr< ::mosek::fusion::Variable > _4021);
void _initialize(int _4016,int _4017,std::shared_ptr< monty::ndarray< int,1 > > _4018,std::shared_ptr< monty::ndarray< int,1 > > _4019,std::shared_ptr< monty::ndarray< double,1 > > _4020,monty::rc_ptr< ::mosek::fusion::Variable > _4021);
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4024,int _4025,std::shared_ptr< monty::ndarray< int,1 > > _4026,std::shared_ptr< monty::ndarray< int,1 > > _4027,std::shared_ptr< monty::ndarray< double,1 > > _4028,monty::rc_ptr< ::mosek::fusion::Variable > _4029,int _4030);
void _initialize(int _4024,int _4025,std::shared_ptr< monty::ndarray< int,1 > > _4026,std::shared_ptr< monty::ndarray< int,1 > > _4027,std::shared_ptr< monty::ndarray< double,1 > > _4028,monty::rc_ptr< ::mosek::fusion::Variable > _4029,int _4030);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4031,monty::rc_ptr< ::mosek::fusion::WorkStack > _4032,monty::rc_ptr< ::mosek::fusion::WorkStack > _4033) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarVar;

struct p_ExprMulVarScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulVarScalarConst * _pubthis;
static mosek::fusion::p_ExprMulVarScalarConst* _get_impl(mosek::fusion::ExprMulVarScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulVarScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVarScalarConst * _get_impl(mosek::fusion::ExprMulVarScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVarScalarConst(ExprMulVarScalarConst * _pubthis);
virtual ~p_ExprMulVarScalarConst() { /* std::cout << "~p_ExprMulVarScalarConst" << std::endl;*/ };
double c{};monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprMulVarScalarConst::t _new_ExprMulVarScalarConst(monty::rc_ptr< ::mosek::fusion::Variable > _4052,double _4053);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4052,double _4053);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4054,monty::rc_ptr< ::mosek::fusion::WorkStack > _4055,monty::rc_ptr< ::mosek::fusion::WorkStack > _4056) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulVarScalarConst;

struct p_ExprAdd : public ::mosek::fusion::p_BaseExpression
{
ExprAdd * _pubthis;
static mosek::fusion::p_ExprAdd* _get_impl(mosek::fusion::ExprAdd * _inst){ return static_cast< mosek::fusion::p_ExprAdd* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprAdd * _get_impl(mosek::fusion::ExprAdd::t _inst) { return _get_impl(_inst.get()); }
p_ExprAdd(ExprAdd * _pubthis);
virtual ~p_ExprAdd() { /* std::cout << "~p_ExprAdd" << std::endl;*/ };
double m2{};double m1{};monty::rc_ptr< ::mosek::fusion::Expression > e2{};monty::rc_ptr< ::mosek::fusion::Expression > e1{};virtual void destroy();
static ExprAdd::t _new_ExprAdd(monty::rc_ptr< ::mosek::fusion::Expression > _4074,monty::rc_ptr< ::mosek::fusion::Expression > _4075,double _4076,double _4077);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4074,monty::rc_ptr< ::mosek::fusion::Expression > _4075,double _4076,double _4077);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4079,monty::rc_ptr< ::mosek::fusion::WorkStack > _4080,monty::rc_ptr< ::mosek::fusion::WorkStack > _4081) ;
virtual /* override */ std::string toString() ;
}; // struct ExprAdd;

struct p_ExprWSum : public ::mosek::fusion::p_BaseExpression
{
ExprWSum * _pubthis;
static mosek::fusion::p_ExprWSum* _get_impl(mosek::fusion::ExprWSum * _inst){ return static_cast< mosek::fusion::p_ExprWSum* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprWSum * _get_impl(mosek::fusion::ExprWSum::t _inst) { return _get_impl(_inst.get()); }
p_ExprWSum(ExprWSum * _pubthis);
virtual ~p_ExprWSum() { /* std::cout << "~p_ExprWSum" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > w{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > es{};virtual void destroy();
static ExprWSum::t _new_ExprWSum(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4191,std::shared_ptr< monty::ndarray< double,1 > > _4192);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4191,std::shared_ptr< monty::ndarray< double,1 > > _4192);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4199,monty::rc_ptr< ::mosek::fusion::WorkStack > _4200,monty::rc_ptr< ::mosek::fusion::WorkStack > _4201) ;
virtual /* override */ std::string toString() ;
}; // struct ExprWSum;

struct p_ExprSumReduce : public ::mosek::fusion::p_BaseExpression
{
ExprSumReduce * _pubthis;
static mosek::fusion::p_ExprSumReduce* _get_impl(mosek::fusion::ExprSumReduce * _inst){ return static_cast< mosek::fusion::p_ExprSumReduce* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSumReduce * _get_impl(mosek::fusion::ExprSumReduce::t _inst) { return _get_impl(_inst.get()); }
p_ExprSumReduce(ExprSumReduce * _pubthis);
virtual ~p_ExprSumReduce() { /* std::cout << "~p_ExprSumReduce" << std::endl;*/ };
int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSumReduce::t _new_ExprSumReduce(int _4268,monty::rc_ptr< ::mosek::fusion::Expression > _4269);
void _initialize(int _4268,monty::rc_ptr< ::mosek::fusion::Expression > _4269);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4271,monty::rc_ptr< ::mosek::fusion::WorkStack > _4272,monty::rc_ptr< ::mosek::fusion::WorkStack > _4273) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeShape(int _4377,std::shared_ptr< monty::ndarray< int,1 > > _4378);
virtual /* override */ std::string toString() ;
}; // struct ExprSumReduce;

struct p_ExprDenseTril : public ::mosek::fusion::p_BaseExpression
{
ExprDenseTril * _pubthis;
static mosek::fusion::p_ExprDenseTril* _get_impl(mosek::fusion::ExprDenseTril * _inst){ return static_cast< mosek::fusion::p_ExprDenseTril* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDenseTril * _get_impl(mosek::fusion::ExprDenseTril::t _inst) { return _get_impl(_inst.get()); }
p_ExprDenseTril(ExprDenseTril * _pubthis);
virtual ~p_ExprDenseTril() { /* std::cout << "~p_ExprDenseTril" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDenseTril::t _new_ExprDenseTril(int _4382,int _4383,monty::rc_ptr< ::mosek::fusion::Expression > _4384,int _4385);
void _initialize(int _4382,int _4383,monty::rc_ptr< ::mosek::fusion::Expression > _4384,int _4385);
static ExprDenseTril::t _new_ExprDenseTril(int _4386,int _4387,monty::rc_ptr< ::mosek::fusion::Expression > _4388);
void _initialize(int _4386,int _4387,monty::rc_ptr< ::mosek::fusion::Expression > _4388);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4390,monty::rc_ptr< ::mosek::fusion::WorkStack > _4391,monty::rc_ptr< ::mosek::fusion::WorkStack > _4392) ;
}; // struct ExprDenseTril;

struct p_ExprDense : public ::mosek::fusion::p_BaseExpression
{
ExprDense * _pubthis;
static mosek::fusion::p_ExprDense* _get_impl(mosek::fusion::ExprDense * _inst){ return static_cast< mosek::fusion::p_ExprDense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDense * _get_impl(mosek::fusion::ExprDense::t _inst) { return _get_impl(_inst.get()); }
p_ExprDense(ExprDense * _pubthis);
virtual ~p_ExprDense() { /* std::cout << "~p_ExprDense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDense::t _new_ExprDense(monty::rc_ptr< ::mosek::fusion::Expression > _4465);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4465);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4466,monty::rc_ptr< ::mosek::fusion::WorkStack > _4467,monty::rc_ptr< ::mosek::fusion::WorkStack > _4468) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDense;

struct p_ExprSymmetrize : public ::mosek::fusion::p_BaseExpression
{
ExprSymmetrize * _pubthis;
static mosek::fusion::p_ExprSymmetrize* _get_impl(mosek::fusion::ExprSymmetrize * _inst){ return static_cast< mosek::fusion::p_ExprSymmetrize* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSymmetrize * _get_impl(mosek::fusion::ExprSymmetrize::t _inst) { return _get_impl(_inst.get()); }
p_ExprSymmetrize(ExprSymmetrize * _pubthis);
virtual ~p_ExprSymmetrize() { /* std::cout << "~p_ExprSymmetrize" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSymmetrize::t _new_ExprSymmetrize(int _4491,int _4492,monty::rc_ptr< ::mosek::fusion::Expression > _4493,int _4494);
void _initialize(int _4491,int _4492,monty::rc_ptr< ::mosek::fusion::Expression > _4493,int _4494);
static ExprSymmetrize::t _new_ExprSymmetrize(int _4495,int _4496,monty::rc_ptr< ::mosek::fusion::Expression > _4497);
void _initialize(int _4495,int _4496,monty::rc_ptr< ::mosek::fusion::Expression > _4497);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) ;
}; // struct ExprSymmetrize;

struct p_ExprCompress : public ::mosek::fusion::p_BaseExpression
{
ExprCompress * _pubthis;
static mosek::fusion::p_ExprCompress* _get_impl(mosek::fusion::ExprCompress * _inst){ return static_cast< mosek::fusion::p_ExprCompress* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCompress * _get_impl(mosek::fusion::ExprCompress::t _inst) { return _get_impl(_inst.get()); }
p_ExprCompress(ExprCompress * _pubthis);
virtual ~p_ExprCompress() { /* std::cout << "~p_ExprCompress" << std::endl;*/ };
double eps{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4600);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4600);
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4601,double _4602);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4601,double _4602);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4603,monty::rc_ptr< ::mosek::fusion::WorkStack > _4604,monty::rc_ptr< ::mosek::fusion::WorkStack > _4605) ;
static  void arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4671,monty::rc_ptr< ::mosek::fusion::WorkStack > _4672,int _4673,int _4674,int _4675,int _4676,int _4677);
static  void merge_sort(int _4713,int _4714,int _4715,int _4716,int _4717,int _4718,std::shared_ptr< monty::ndarray< int,1 > > _4719,std::shared_ptr< monty::ndarray< long long,1 > > _4720);
virtual /* override */ std::string toString() ;
}; // struct ExprCompress;

struct p_ExprCondense : public ::mosek::fusion::p_BaseExpression
{
ExprCondense * _pubthis;
static mosek::fusion::p_ExprCondense* _get_impl(mosek::fusion::ExprCondense * _inst){ return static_cast< mosek::fusion::p_ExprCondense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCondense * _get_impl(mosek::fusion::ExprCondense::t _inst) { return _get_impl(_inst.get()); }
p_ExprCondense(ExprCondense * _pubthis);
virtual ~p_ExprCondense() { /* std::cout << "~p_ExprCondense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCondense::t _new_ExprCondense(monty::rc_ptr< ::mosek::fusion::Expression > _4743);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4743);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4744,monty::rc_ptr< ::mosek::fusion::WorkStack > _4745,monty::rc_ptr< ::mosek::fusion::WorkStack > _4746) ;
}; // struct ExprCondense;

struct p_ExprFromVar : public ::mosek::fusion::p_BaseExpression
{
ExprFromVar * _pubthis;
static mosek::fusion::p_ExprFromVar* _get_impl(mosek::fusion::ExprFromVar * _inst){ return static_cast< mosek::fusion::p_ExprFromVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprFromVar * _get_impl(mosek::fusion::ExprFromVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprFromVar(ExprFromVar * _pubthis);
virtual ~p_ExprFromVar() { /* std::cout << "~p_ExprFromVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprFromVar::t _new_ExprFromVar(monty::rc_ptr< ::mosek::fusion::Variable > _4753);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4753);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4754,monty::rc_ptr< ::mosek::fusion::WorkStack > _4755,monty::rc_ptr< ::mosek::fusion::WorkStack > _4756) ;
virtual /* override */ std::string toString() ;
}; // struct ExprFromVar;

struct p_ExprReshape : public ::mosek::fusion::p_BaseExpression
{
ExprReshape * _pubthis;
static mosek::fusion::p_ExprReshape* _get_impl(mosek::fusion::ExprReshape * _inst){ return static_cast< mosek::fusion::p_ExprReshape* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprReshape * _get_impl(mosek::fusion::ExprReshape::t _inst) { return _get_impl(_inst.get()); }
p_ExprReshape(ExprReshape * _pubthis);
virtual ~p_ExprReshape() { /* std::cout << "~p_ExprReshape" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};virtual void destroy();
static ExprReshape::t _new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > > _4774,monty::rc_ptr< ::mosek::fusion::Expression > _4775);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4774,monty::rc_ptr< ::mosek::fusion::Expression > _4775);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779) ;
virtual /* override */ std::string toString() ;
}; // struct ExprReshape;

struct p_Expr : public ::mosek::fusion::p_BaseExpression
{
Expr * _pubthis;
static mosek::fusion::p_Expr* _get_impl(mosek::fusion::Expr * _inst){ return static_cast< mosek::fusion::p_Expr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_Expr * _get_impl(mosek::fusion::Expr::t _inst) { return _get_impl(_inst.get()); }
p_Expr(Expr * _pubthis);
virtual ~p_Expr() { /* std::cout << "~p_Expr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< double,1 > > cof_v{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4914,std::shared_ptr< monty::ndarray< long long,1 > > _4915,std::shared_ptr< monty::ndarray< double,1 > > _4916,std::shared_ptr< monty::ndarray< double,1 > > _4917,std::shared_ptr< monty::ndarray< int,1 > > _4918,std::shared_ptr< monty::ndarray< long long,1 > > _4919);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4914,std::shared_ptr< monty::ndarray< long long,1 > > _4915,std::shared_ptr< monty::ndarray< double,1 > > _4916,std::shared_ptr< monty::ndarray< double,1 > > _4917,std::shared_ptr< monty::ndarray< int,1 > > _4918,std::shared_ptr< monty::ndarray< long long,1 > > _4919);
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4930,std::shared_ptr< monty::ndarray< long long,1 > > _4931,std::shared_ptr< monty::ndarray< double,1 > > _4932,std::shared_ptr< monty::ndarray< double,1 > > _4933,std::shared_ptr< monty::ndarray< int,1 > > _4934,std::shared_ptr< monty::ndarray< long long,1 > > _4935,int _4936);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4930,std::shared_ptr< monty::ndarray< long long,1 > > _4931,std::shared_ptr< monty::ndarray< double,1 > > _4932,std::shared_ptr< monty::ndarray< double,1 > > _4933,std::shared_ptr< monty::ndarray< int,1 > > _4934,std::shared_ptr< monty::ndarray< long long,1 > > _4935,int _4936);
static Expr::t _new_Expr(monty::rc_ptr< ::mosek::fusion::Expression > _4937);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4937);
virtual long long prod(std::shared_ptr< monty::ndarray< int,1 > > _4962) ;
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _4965);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4968,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4969);
static  monty::rc_ptr< ::mosek::fusion::Expression > condense(monty::rc_ptr< ::mosek::fusion::Expression > _4973);
static  monty::rc_ptr< ::mosek::fusion::Expression > flatten(monty::rc_ptr< ::mosek::fusion::Expression > _4974);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4975,int _4976,int _4977);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4978,int _4979);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4980,std::shared_ptr< monty::ndarray< int,1 > > _4981);
virtual long long size() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expr__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(std::shared_ptr< monty::ndarray< int,1 > > _4984);
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(int _4985);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones();
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _4986,std::shared_ptr< monty::ndarray< int,2 > > _4987);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _4988);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(int _4989);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _4990);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _4991);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(double _5000);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5001,std::shared_ptr< monty::ndarray< int,2 > > _5002,double _5003);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5011,std::shared_ptr< monty::ndarray< int,2 > > _5012,std::shared_ptr< monty::ndarray< double,1 > > _5013);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5021,double _5022);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(int _5023,double _5024);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5026);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5029);
virtual long long numNonzeros() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5030,int _5031);
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5032);
static  monty::rc_ptr< ::mosek::fusion::Expression > neg(monty::rc_ptr< ::mosek::fusion::Expression > _5033);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(bool _5034,monty::rc_ptr< ::mosek::fusion::Matrix > _5035,monty::rc_ptr< ::mosek::fusion::Expression > _5036);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5043,monty::rc_ptr< ::mosek::fusion::Matrix > _5044);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5045,monty::rc_ptr< ::mosek::fusion::Variable > _5046);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5047,monty::rc_ptr< ::mosek::fusion::Matrix > _5048);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5049,monty::rc_ptr< ::mosek::fusion::Expression > _5050);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5051,std::shared_ptr< monty::ndarray< double,2 > > _5052);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5059,std::shared_ptr< monty::ndarray< double,2 > > _5060);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5067,monty::rc_ptr< ::mosek::fusion::Variable > _5068);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5075,monty::rc_ptr< ::mosek::fusion::Expression > _5076);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5083,monty::rc_ptr< ::mosek::fusion::Expression > _5084);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5093,monty::rc_ptr< ::mosek::fusion::Expression > _5094);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5096,monty::rc_ptr< ::mosek::fusion::Expression > _5097);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5100,double _5101);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(double _5102,monty::rc_ptr< ::mosek::fusion::Expression > _5103);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5104,std::shared_ptr< monty::ndarray< double,1 > > _5105);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,1 > > _5106,monty::rc_ptr< ::mosek::fusion::Expression > _5107);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5108,std::shared_ptr< monty::ndarray< double,2 > > _5109);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,2 > > _5110,monty::rc_ptr< ::mosek::fusion::Expression > _5111);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5112,monty::rc_ptr< ::mosek::fusion::Matrix > _5113);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5114,monty::rc_ptr< ::mosek::fusion::Expression > _5115);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5116,std::shared_ptr< monty::ndarray< double,1 > > _5117,monty::rc_ptr< ::mosek::fusion::Expression > _5118);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5133,std::shared_ptr< monty::ndarray< double,2 > > _5134,monty::rc_ptr< ::mosek::fusion::Expression > _5135);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5150,monty::rc_ptr< ::mosek::fusion::Matrix > _5151,monty::rc_ptr< ::mosek::fusion::Expression > _5152);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Variable > _5161,monty::rc_ptr< ::mosek::fusion::Matrix > _5162);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5168,monty::rc_ptr< ::mosek::fusion::Variable > _5169);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5175,int _5176,int _5177,std::shared_ptr< monty::ndarray< int,1 > > _5178,std::shared_ptr< monty::ndarray< int,1 > > _5179,std::shared_ptr< monty::ndarray< double,1 > > _5180,monty::rc_ptr< ::mosek::fusion::Variable > _5181);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5183,monty::rc_ptr< ::mosek::fusion::Matrix > _5184);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5192,std::shared_ptr< monty::ndarray< double,2 > > _5193);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5197,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5198);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5199,std::shared_ptr< monty::ndarray< double,1 > > _5200);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5205,monty::rc_ptr< ::mosek::fusion::Expression > _5206);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5207,monty::rc_ptr< ::mosek::fusion::Expression > _5208);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,2 > > _5209,monty::rc_ptr< ::mosek::fusion::Expression > _5210);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,1 > > _5211,monty::rc_ptr< ::mosek::fusion::Expression > _5212);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5213,monty::rc_ptr< ::mosek::fusion::Expression > _5214);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Expression > _5218,std::shared_ptr< monty::ndarray< double,1 > > _5219);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5222,monty::rc_ptr< ::mosek::fusion::Variable > _5223);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5230,monty::rc_ptr< ::mosek::fusion::Matrix > _5231);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5238,monty::rc_ptr< ::mosek::fusion::Variable > _5239);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5241,std::shared_ptr< monty::ndarray< double,1 > > _5242);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(int _5244,std::shared_ptr< monty::ndarray< long long,1 > > _5245,std::shared_ptr< monty::ndarray< long long,1 > > _5246,std::shared_ptr< monty::ndarray< double,1 > > _5247,std::shared_ptr< monty::ndarray< double,1 > > _5248,std::shared_ptr< monty::ndarray< long long,1 > > _5249,std::shared_ptr< monty::ndarray< double,1 > > _5250,std::shared_ptr< monty::ndarray< int,1 > > _5251,int _5252,bool _5253);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5283,int _5284,std::shared_ptr< monty::ndarray< double,1 > > _5285,std::shared_ptr< monty::ndarray< int,1 > > _5286,int _5287,bool _5288);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5305);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5311,double _5312,double _5313);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5314,double _5315,monty::rc_ptr< ::mosek::fusion::Expression > _5316);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5317,monty::rc_ptr< ::mosek::fusion::Expression > _5318,double _5319);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5320,monty::rc_ptr< ::mosek::fusion::Expression > _5321,monty::rc_ptr< ::mosek::fusion::Expression > _5322);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5323,double _5324,double _5325);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5326,double _5327,monty::rc_ptr< ::mosek::fusion::Expression > _5328);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5329,monty::rc_ptr< ::mosek::fusion::Expression > _5330,double _5331);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5332,monty::rc_ptr< ::mosek::fusion::Expression > _5333,monty::rc_ptr< ::mosek::fusion::Expression > _5334);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5335,monty::rc_ptr< ::mosek::fusion::Expression > _5336);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5337,double _5338);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5339,monty::rc_ptr< ::mosek::fusion::Expression > _5340);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5341);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5343,monty::rc_ptr< ::mosek::fusion::Expression > _5344,monty::rc_ptr< ::mosek::fusion::Expression > _5345);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5346,monty::rc_ptr< ::mosek::fusion::Expression > _5347,double _5348);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5349,double _5350,monty::rc_ptr< ::mosek::fusion::Expression > _5351);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5352,double _5353,double _5354);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5355,monty::rc_ptr< ::mosek::fusion::Expression > _5356,monty::rc_ptr< ::mosek::fusion::Expression > _5357);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5358,monty::rc_ptr< ::mosek::fusion::Expression > _5359,double _5360);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5361,double _5362,monty::rc_ptr< ::mosek::fusion::Expression > _5363);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5364,monty::rc_ptr< ::mosek::fusion::Expression > _5365);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5366,double _5367);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5368,monty::rc_ptr< ::mosek::fusion::Expression > _5369);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5370);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373,monty::rc_ptr< ::mosek::fusion::Expression > _5374,monty::rc_ptr< ::mosek::fusion::Expression > _5375);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377,monty::rc_ptr< ::mosek::fusion::Expression > _5378,double _5379);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5380,monty::rc_ptr< ::mosek::fusion::Expression > _5381,double _5382,monty::rc_ptr< ::mosek::fusion::Expression > _5383);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5384,monty::rc_ptr< ::mosek::fusion::Expression > _5385,double _5386,double _5387);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5388,double _5389,monty::rc_ptr< ::mosek::fusion::Expression > _5390,monty::rc_ptr< ::mosek::fusion::Expression > _5391);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5392,double _5393,monty::rc_ptr< ::mosek::fusion::Expression > _5394,double _5395);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5396,double _5397,double _5398,monty::rc_ptr< ::mosek::fusion::Expression > _5399);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5400,double _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5403,monty::rc_ptr< ::mosek::fusion::Expression > _5404,double _5405);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5406,monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5409,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5410);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5411,int _5412);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5413,int _5414);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5427,int _5428,int _5429);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5431);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5433);
static  monty::rc_ptr< ::mosek::fusion::Expression > add_(monty::rc_ptr< ::mosek::fusion::Expression > _5466,double _5467,monty::rc_ptr< ::mosek::fusion::Expression > _5468,double _5469);
static  monty::rc_ptr< ::mosek::fusion::Expression > transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5480);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5481,monty::rc_ptr< ::mosek::fusion::Expression > _5482);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5483,monty::rc_ptr< ::mosek::fusion::Expression > _5484);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5485,monty::rc_ptr< ::mosek::fusion::Expression > _5486);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5487,monty::rc_ptr< ::mosek::fusion::Expression > _5488);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5489,monty::rc_ptr< ::mosek::fusion::Matrix > _5490);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5491,std::shared_ptr< monty::ndarray< double,2 > > _5492);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5493,std::shared_ptr< monty::ndarray< double,1 > > _5494);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5495,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5496);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5497,monty::rc_ptr< ::mosek::fusion::Expression > _5498);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5499,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5500);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5501,monty::rc_ptr< ::mosek::fusion::Expression > _5502);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5503,monty::rc_ptr< ::mosek::fusion::Matrix > _5504);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(double _5505,monty::rc_ptr< ::mosek::fusion::Expression > _5506);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5507,double _5508);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,2 > > _5509,monty::rc_ptr< ::mosek::fusion::Expression > _5510);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,1 > > _5511,monty::rc_ptr< ::mosek::fusion::Expression > _5512);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5513,std::shared_ptr< monty::ndarray< double,2 > > _5514);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5515,std::shared_ptr< monty::ndarray< double,1 > > _5516);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5517,monty::rc_ptr< ::mosek::fusion::Expression > _5518);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5519,monty::rc_ptr< ::mosek::fusion::Expression > _5520);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5521,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5522);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Matrix > _5523,monty::rc_ptr< ::mosek::fusion::Expression > _5524);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5525,monty::rc_ptr< ::mosek::fusion::Matrix > _5526);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(double _5527,monty::rc_ptr< ::mosek::fusion::Expression > _5528);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5529,double _5530);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,2 > > _5531,monty::rc_ptr< ::mosek::fusion::Expression > _5532);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,1 > > _5533,monty::rc_ptr< ::mosek::fusion::Expression > _5534);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5535,std::shared_ptr< monty::ndarray< double,2 > > _5536);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5537,std::shared_ptr< monty::ndarray< double,1 > > _5538);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5539,monty::rc_ptr< ::mosek::fusion::Expression > _5540);
virtual /* override */ int getND() ;
virtual /* override */ std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5541,monty::rc_ptr< ::mosek::fusion::WorkStack > _5542,monty::rc_ptr< ::mosek::fusion::WorkStack > _5543) ;
static  void validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5545,std::shared_ptr< monty::ndarray< long long,1 > > _5546,std::shared_ptr< monty::ndarray< double,1 > > _5547,std::shared_ptr< monty::ndarray< double,1 > > _5548,std::shared_ptr< monty::ndarray< int,1 > > _5549,std::shared_ptr< monty::ndarray< long long,1 > > _5550);
static  monty::rc_ptr< ::mosek::fusion::Model > extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5563);
}; // struct Expr;

struct p_WorkStack
{
WorkStack * _pubthis;
static mosek::fusion::p_WorkStack* _get_impl(mosek::fusion::WorkStack * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_WorkStack * _get_impl(mosek::fusion::WorkStack::t _inst) { return _get_impl(_inst.get()); }
p_WorkStack(WorkStack * _pubthis);
virtual ~p_WorkStack() { /* std::cout << "~p_WorkStack" << std::endl;*/ };
int cof_base{};int bfix_base{};int nidxs_base{};int sp_base{};int shape_base{};int ptr_base{};bool hassp{};int nelem{};int nnz{};int nd{};int pf64{};int pi64{};int pi32{};std::shared_ptr< monty::ndarray< double,1 > > f64{};std::shared_ptr< monty::ndarray< long long,1 > > i64{};std::shared_ptr< monty::ndarray< int,1 > > i32{};virtual void destroy();
static WorkStack::t _new_WorkStack();
void _initialize();
virtual bool peek_hassp() ;
virtual int peek_nnz() ;
virtual int peek_nelem() ;
virtual int peek_dim(int _4837) ;
virtual int peek_nd() ;
virtual void alloc_expr(int _4838,int _4839,int _4840,bool _4841) ;
virtual void move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4842) ;
virtual void peek_expr() ;
virtual void pop_expr() ;
virtual void ensure_sparsity() ;
virtual void clear() ;
virtual int allocf64(int _4857) ;
virtual int alloci64(int _4860) ;
virtual int alloci32(int _4863) ;
virtual void pushf64(double _4866) ;
virtual void pushi64(long long _4867) ;
virtual void pushi32(int _4868) ;
virtual void ensuref64(int _4869) ;
virtual void ensurei64(int _4872) ;
virtual void ensurei32(int _4875) ;
virtual int popf64(int _4878) ;
virtual int popi64(int _4879) ;
virtual int popi32(int _4880) ;
virtual void popf64(int _4881,std::shared_ptr< monty::ndarray< double,1 > > _4882,int _4883) ;
virtual void popi64(int _4884,std::shared_ptr< monty::ndarray< long long,1 > > _4885,int _4886) ;
virtual void popi32(int _4887,std::shared_ptr< monty::ndarray< int,1 > > _4888,int _4889) ;
virtual double popf64() ;
virtual long long popi64() ;
virtual int popi32() ;
virtual double peekf64() ;
virtual long long peeki64() ;
virtual int peeki32() ;
virtual double peekf64(int _4890) ;
virtual long long peeki64(int _4891) ;
virtual int peeki32(int _4892) ;
}; // struct WorkStack;

struct p_SymmetricExpr
{
SymmetricExpr * _pubthis;
static mosek::fusion::p_SymmetricExpr* _get_impl(mosek::fusion::SymmetricExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricExpr * _get_impl(mosek::fusion::SymmetricExpr::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricExpr(SymmetricExpr * _pubthis);
virtual ~p_SymmetricExpr() { /* std::cout << "~p_SymmetricExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > xs{};monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > b{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > Ms{};int n{};virtual void destroy();
static SymmetricExpr::t _new_SymmetricExpr(int _4893,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4894,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4895,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4896);
void _initialize(int _4893,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4894,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4895,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4896);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4897,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4898);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4899,double _4900);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4902,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4903);
virtual /* override */ std::string toString() ;
}; // struct SymmetricExpr;

struct p_FlatExpr
{
FlatExpr * _pubthis;
static mosek::fusion::p_FlatExpr* _get_impl(mosek::fusion::FlatExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_FlatExpr * _get_impl(mosek::fusion::FlatExpr::t _inst) { return _get_impl(_inst.get()); }
p_FlatExpr(FlatExpr * _pubthis);
virtual ~p_FlatExpr() { /* std::cout << "~p_FlatExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > shape{};long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static FlatExpr::t _new_FlatExpr(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5576);
void _initialize(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5576);
static FlatExpr::t _new_FlatExpr(std::shared_ptr< monty::ndarray< double,1 > > _5577,std::shared_ptr< monty::ndarray< long long,1 > > _5578,std::shared_ptr< monty::ndarray< long long,1 > > _5579,std::shared_ptr< monty::ndarray< double,1 > > _5580,std::shared_ptr< monty::ndarray< int,1 > > _5581,std::shared_ptr< monty::ndarray< long long,1 > > _5582);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5577,std::shared_ptr< monty::ndarray< long long,1 > > _5578,std::shared_ptr< monty::ndarray< long long,1 > > _5579,std::shared_ptr< monty::ndarray< double,1 > > _5580,std::shared_ptr< monty::ndarray< int,1 > > _5581,std::shared_ptr< monty::ndarray< long long,1 > > _5582);
virtual /* override */ std::string toString() ;
virtual int size() ;
}; // struct FlatExpr;

struct p_SymmetricMatrix
{
SymmetricMatrix * _pubthis;
static mosek::fusion::p_SymmetricMatrix* _get_impl(mosek::fusion::SymmetricMatrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricMatrix * _get_impl(mosek::fusion::SymmetricMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricMatrix(SymmetricMatrix * _pubthis);
virtual ~p_SymmetricMatrix() { /* std::cout << "~p_SymmetricMatrix" << std::endl;*/ };
int nnz{};double scale{};std::shared_ptr< monty::ndarray< double,1 > > vval{};std::shared_ptr< monty::ndarray< int,1 > > vsubj{};std::shared_ptr< monty::ndarray< int,1 > > vsubi{};std::shared_ptr< monty::ndarray< double,1 > > uval{};std::shared_ptr< monty::ndarray< int,1 > > usubj{};std::shared_ptr< monty::ndarray< int,1 > > usubi{};int d1{};int d0{};virtual void destroy();
static SymmetricMatrix::t _new_SymmetricMatrix(int _5584,int _5585,std::shared_ptr< monty::ndarray< int,1 > > _5586,std::shared_ptr< monty::ndarray< int,1 > > _5587,std::shared_ptr< monty::ndarray< double,1 > > _5588,std::shared_ptr< monty::ndarray< int,1 > > _5589,std::shared_ptr< monty::ndarray< int,1 > > _5590,std::shared_ptr< monty::ndarray< double,1 > > _5591,double _5592);
void _initialize(int _5584,int _5585,std::shared_ptr< monty::ndarray< int,1 > > _5586,std::shared_ptr< monty::ndarray< int,1 > > _5587,std::shared_ptr< monty::ndarray< double,1 > > _5588,std::shared_ptr< monty::ndarray< int,1 > > _5589,std::shared_ptr< monty::ndarray< int,1 > > _5590,std::shared_ptr< monty::ndarray< double,1 > > _5591,double _5592);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(int _5593,std::shared_ptr< monty::ndarray< int,1 > > _5594,std::shared_ptr< monty::ndarray< double,1 > > _5595);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5603);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5611);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5618);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5624) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5644) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__mul(double _5645) ;
virtual int getdim() ;
}; // struct SymmetricMatrix;

struct p_NDSparseArray
{
NDSparseArray * _pubthis;
static mosek::fusion::p_NDSparseArray* _get_impl(mosek::fusion::NDSparseArray * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_NDSparseArray * _get_impl(mosek::fusion::NDSparseArray::t _inst) { return _get_impl(_inst.get()); }
p_NDSparseArray(NDSparseArray * _pubthis);
virtual ~p_NDSparseArray() { /* std::cout << "~p_NDSparseArray" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > dims{};long long size{};virtual void destroy();
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5646,std::shared_ptr< monty::ndarray< int,2 > > _5647,std::shared_ptr< monty::ndarray< double,1 > > _5648);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5646,std::shared_ptr< monty::ndarray< int,2 > > _5647,std::shared_ptr< monty::ndarray< double,1 > > _5648);
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5668,std::shared_ptr< monty::ndarray< long long,1 > > _5669,std::shared_ptr< monty::ndarray< double,1 > > _5670);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5668,std::shared_ptr< monty::ndarray< long long,1 > > _5669,std::shared_ptr< monty::ndarray< double,1 > > _5670);
static NDSparseArray::t _new_NDSparseArray(monty::rc_ptr< ::mosek::fusion::Matrix > _5684);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5684);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(monty::rc_ptr< ::mosek::fusion::Matrix > _5692);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5693,std::shared_ptr< monty::ndarray< long long,1 > > _5694,std::shared_ptr< monty::ndarray< double,1 > > _5695);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5696,std::shared_ptr< monty::ndarray< int,2 > > _5697,std::shared_ptr< monty::ndarray< double,1 > > _5698);
}; // struct NDSparseArray;

struct p_Matrix
{
Matrix * _pubthis;
static mosek::fusion::p_Matrix* _get_impl(mosek::fusion::Matrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Matrix * _get_impl(mosek::fusion::Matrix::t _inst) { return _get_impl(_inst.get()); }
p_Matrix(Matrix * _pubthis);
virtual ~p_Matrix() { /* std::cout << "~p_Matrix" << std::endl;*/ };
int dimj{};int dimi{};virtual void destroy();
static Matrix::t _new_Matrix(int _5767,int _5768);
void _initialize(int _5767,int _5768);
virtual /* override */ std::string toString() ;
virtual void switchDims() ;
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5770,monty::rc_ptr< ::mosek::fusion::Matrix > _5771);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5773);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5791,double _5792,int _5793);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5794,double _5795);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5796,double _5797,int _5798);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5799,double _5800);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5801,int _5802);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5812);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5813,int _5814);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5822);
static  monty::rc_ptr< ::mosek::fusion::Matrix > ones(int _5823,int _5824);
static  monty::rc_ptr< ::mosek::fusion::Matrix > eye(int _5825);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5827);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5828,int _5829,double _5830);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5831,int _5832,std::shared_ptr< monty::ndarray< double,1 > > _5833);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(std::shared_ptr< monty::ndarray< double,2 > > _5834);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5835);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5839);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< double,2 > > _5870);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5883,int _5884);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5885,int _5886,std::shared_ptr< monty::ndarray< int,1 > > _5887,std::shared_ptr< monty::ndarray< int,1 > > _5888,double _5889);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5891,std::shared_ptr< monty::ndarray< int,1 > > _5892,double _5893);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5898,std::shared_ptr< monty::ndarray< int,1 > > _5899,std::shared_ptr< monty::ndarray< double,1 > > _5900);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5905,int _5906,std::shared_ptr< monty::ndarray< int,1 > > _5907,std::shared_ptr< monty::ndarray< int,1 > > _5908,std::shared_ptr< monty::ndarray< double,1 > > _5909);
virtual double get(int _5914,int _5915) { throw monty::AbstractClassError("Call to abstract method"); }
virtual bool isSparse() { throw monty::AbstractClassError("Call to abstract method"); }
virtual std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5916,std::shared_ptr< monty::ndarray< int,1 > > _5917,std::shared_ptr< monty::ndarray< double,1 > > _5918) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { throw monty::AbstractClassError("Call to abstract method"); }
virtual long long numNonzeros() { throw monty::AbstractClassError("Call to abstract method"); }
virtual int numColumns() ;
virtual int numRows() ;
}; // struct Matrix;

struct p_DenseMatrix : public ::mosek::fusion::p_Matrix
{
DenseMatrix * _pubthis;
static mosek::fusion::p_DenseMatrix* _get_impl(mosek::fusion::DenseMatrix * _inst){ return static_cast< mosek::fusion::p_DenseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_DenseMatrix * _get_impl(mosek::fusion::DenseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_DenseMatrix(DenseMatrix * _pubthis);
virtual ~p_DenseMatrix() { /* std::cout << "~p_DenseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > data{};virtual void destroy();
static DenseMatrix::t _new_DenseMatrix(int _5699,int _5700,std::shared_ptr< monty::ndarray< double,1 > > _5701);
void _initialize(int _5699,int _5700,std::shared_ptr< monty::ndarray< double,1 > > _5701);
static DenseMatrix::t _new_DenseMatrix(monty::rc_ptr< ::mosek::fusion::Matrix > _5702);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5702);
static DenseMatrix::t _new_DenseMatrix(std::shared_ptr< monty::ndarray< double,2 > > _5707);
void _initialize(std::shared_ptr< monty::ndarray< double,2 > > _5707);
static DenseMatrix::t _new_DenseMatrix(int _5710,int _5711,double _5712);
void _initialize(int _5710,int _5711,double _5712);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2DenseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5725,std::shared_ptr< monty::ndarray< int,1 > > _5726,std::shared_ptr< monty::ndarray< double,1 > > _5727) ;
virtual /* override */ double get(int _5731,int _5732) ;
virtual /* override */ long long numNonzeros() ;
}; // struct DenseMatrix;

struct p_SparseMatrix : public ::mosek::fusion::p_Matrix
{
SparseMatrix * _pubthis;
static mosek::fusion::p_SparseMatrix* _get_impl(mosek::fusion::SparseMatrix * _inst){ return static_cast< mosek::fusion::p_SparseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_SparseMatrix * _get_impl(mosek::fusion::SparseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SparseMatrix(SparseMatrix * _pubthis);
virtual ~p_SparseMatrix() { /* std::cout << "~p_SparseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > val{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< int,1 > > subi{};virtual void destroy();
static SparseMatrix::t _new_SparseMatrix(int _5733,int _5734,std::shared_ptr< monty::ndarray< int,1 > > _5735,std::shared_ptr< monty::ndarray< int,1 > > _5736,std::shared_ptr< monty::ndarray< double,1 > > _5737,long long _5738);
void _initialize(int _5733,int _5734,std::shared_ptr< monty::ndarray< int,1 > > _5735,std::shared_ptr< monty::ndarray< int,1 > > _5736,std::shared_ptr< monty::ndarray< double,1 > > _5737,long long _5738);
static SparseMatrix::t _new_SparseMatrix(int _5743,int _5744,std::shared_ptr< monty::ndarray< int,1 > > _5745,std::shared_ptr< monty::ndarray< int,1 > > _5746,std::shared_ptr< monty::ndarray< double,1 > > _5747);
void _initialize(int _5743,int _5744,std::shared_ptr< monty::ndarray< int,1 > > _5745,std::shared_ptr< monty::ndarray< int,1 > > _5746,std::shared_ptr< monty::ndarray< double,1 > > _5747);
virtual std::shared_ptr< monty::ndarray< long long,1 > > formPtrb() ;
virtual /* override */ std::string toString() ;
virtual /* override */ long long numNonzeros() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2SparseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< int,1 > > _5760,std::shared_ptr< monty::ndarray< double,1 > > _5761) ;
virtual /* override */ double get(int _5762,int _5763) ;
}; // struct SparseMatrix;

struct p_LinkedBlocks
{
LinkedBlocks * _pubthis;
static mosek::fusion::p_LinkedBlocks* _get_impl(mosek::fusion::LinkedBlocks * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedBlocks * _get_impl(mosek::fusion::LinkedBlocks::t _inst) { return _get_impl(_inst.get()); }
p_LinkedBlocks(LinkedBlocks * _pubthis);
virtual ~p_LinkedBlocks() { /* std::cout << "~p_LinkedBlocks" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > bfirst{};std::shared_ptr< monty::ndarray< int,1 > > bsize{};monty::rc_ptr< ::mosek::fusion::LinkedInts > blocks{};monty::rc_ptr< ::mosek::fusion::LinkedInts > ints{};virtual void destroy();
static LinkedBlocks::t _new_LinkedBlocks();
void _initialize();
static LinkedBlocks::t _new_LinkedBlocks(int _5942);
void _initialize(int _5942);
static LinkedBlocks::t _new_LinkedBlocks(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5943);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5943);
virtual void free(int _5944) ;
virtual int alloc(int _5946) ;
virtual int maxidx(int _5951) ;
virtual void get(int _5952,std::shared_ptr< monty::ndarray< int,1 > > _5953,int _5954) ;
virtual int numblocks() ;
virtual int blocksize(int _5955) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedBlocks;

struct p_LinkedInts
{
LinkedInts * _pubthis;
static mosek::fusion::p_LinkedInts* _get_impl(mosek::fusion::LinkedInts * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedInts * _get_impl(mosek::fusion::LinkedInts::t _inst) { return _get_impl(_inst.get()); }
p_LinkedInts(LinkedInts * _pubthis);
virtual ~p_LinkedInts() { /* std::cout << "~p_LinkedInts" << std::endl;*/ };
int nfree{};int last_free{};int first_free{};int first_used{};std::shared_ptr< monty::ndarray< int,1 > > prev{};std::shared_ptr< monty::ndarray< int,1 > > next{};virtual void destroy();
static LinkedInts::t _new_LinkedInts(int _5956);
void _initialize(int _5956);
static LinkedInts::t _new_LinkedInts();
void _initialize();
static LinkedInts::t _new_LinkedInts(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5959);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5959);
virtual void free(int _5960,int _5961) ;
virtual int alloc() ;
virtual int alloc(int _5967) ;
virtual void alloc(int _5968,std::shared_ptr< monty::ndarray< int,1 > > _5969,int _5970) ;
virtual void get(int _5973,int _5974,std::shared_ptr< monty::ndarray< int,1 > > _5975,int _5976) ;
virtual int maxidx(int _5979,int _5980) ;
virtual int allocblock(int _5984) ;
virtual void recap(int _5990) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedInts;

struct p_Parameters
{
Parameters * _pubthis;
static mosek::fusion::p_Parameters* _get_impl(mosek::fusion::Parameters * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Parameters * _get_impl(mosek::fusion::Parameters::t _inst) { return _get_impl(_inst.get()); }
p_Parameters(Parameters * _pubthis);
virtual ~p_Parameters() { /* std::cout << "~p_Parameters" << std::endl;*/ };
virtual void destroy();
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _5999,const std::string &  _6000,double _6001);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6093,const std::string &  _6094,int _6095);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6187,const std::string &  _6188,const std::string &  _6189);
static  int string_to_variabletype_value(const std::string &  _6422);
static  int string_to_value_value(const std::string &  _6423);
static  int string_to_streamtype_value(const std::string &  _6424);
static  int string_to_startpointtype_value(const std::string &  _6425);
static  int string_to_stakey_value(const std::string &  _6426);
static  int string_to_sparam_value(const std::string &  _6427);
static  int string_to_solveform_value(const std::string &  _6428);
static  int string_to_soltype_value(const std::string &  _6429);
static  int string_to_solsta_value(const std::string &  _6430);
static  int string_to_solitem_value(const std::string &  _6431);
static  int string_to_simseltype_value(const std::string &  _6432);
static  int string_to_sensitivitytype_value(const std::string &  _6433);
static  int string_to_scalingmethod_value(const std::string &  _6434);
static  int string_to_scalingtype_value(const std::string &  _6435);
static  int string_to_rescodetype_value(const std::string &  _6436);
static  int string_to_rescode_value(const std::string &  _6437);
static  int string_to_xmlwriteroutputtype_value(const std::string &  _6438);
static  int string_to_prosta_value(const std::string &  _6439);
static  int string_to_problemtype_value(const std::string &  _6440);
static  int string_to_problemitem_value(const std::string &  _6441);
static  int string_to_parametertype_value(const std::string &  _6442);
static  int string_to_presolvemode_value(const std::string &  _6443);
static  int string_to_orderingtype_value(const std::string &  _6444);
static  int string_to_optimizertype_value(const std::string &  _6445);
static  int string_to_onoffkey_value(const std::string &  _6446);
static  int string_to_objsense_value(const std::string &  _6447);
static  int string_to_mpsformat_value(const std::string &  _6448);
static  int string_to_mionodeseltype_value(const std::string &  _6449);
static  int string_to_miomode_value(const std::string &  _6450);
static  int string_to_miocontsoltype_value(const std::string &  _6451);
static  int string_to_branchdir_value(const std::string &  _6452);
static  int string_to_iparam_value(const std::string &  _6453);
static  int string_to_iomode_value(const std::string &  _6454);
static  int string_to_internal_iinf_value(const std::string &  _6455);
static  int string_to_internal_dinf_value(const std::string &  _6456);
static  int string_to_inftype_value(const std::string &  _6457);
static  int string_to_iinfitem_value(const std::string &  _6458);
static  int string_to_internal_liinf_value(const std::string &  _6459);
static  int string_to_liinfitem_value(const std::string &  _6460);
static  int string_to_dparam_value(const std::string &  _6461);
static  int string_to_feature_value(const std::string &  _6462);
static  int string_to_dinfitem_value(const std::string &  _6463);
static  int string_to_dataformat_value(const std::string &  _6464);
static  int string_to_symmattype_value(const std::string &  _6465);
static  int string_to_scopr_value(const std::string &  _6466);
static  int string_to_nametype_value(const std::string &  _6467);
static  int string_to_conetype_value(const std::string &  _6468);
static  int string_to_compresstype_value(const std::string &  _6469);
static  int string_to_checkconvexitytype_value(const std::string &  _6470);
static  int string_to_callbackcode_value(const std::string &  _6471);
static  int string_to_purify_value(const std::string &  _6472);
static  int string_to_intpnthotstart_value(const std::string &  _6473);
static  int string_to_simhotstart_value(const std::string &  _6474);
static  int string_to_simdupvec_value(const std::string &  _6475);
static  int string_to_simreform_value(const std::string &  _6476);
static  int string_to_uplo_value(const std::string &  _6477);
static  int string_to_transpose_value(const std::string &  _6478);
static  int string_to_simdegen_value(const std::string &  _6479);
static  int string_to_mark_value(const std::string &  _6480);
static  int string_to_boundkey_value(const std::string &  _6481);
static  int string_to_basindtype_value(const std::string &  _6482);
static  int string_to_language_value(const std::string &  _6483);
}; // struct Parameters;

}
}
namespace mosek
{
namespace fusion
{
namespace Utils
{
// mosek.fusion.Utils.IntMap from file 'src/fusion/cxx/IntMap_p.h'
struct p_IntMap 
{
  IntMap * _pubself;

  static p_IntMap * _get_impl(IntMap * _inst) { return _inst->_impl.get(); }

  p_IntMap(IntMap * _pubself) : _pubself(_pubself) {}

  static IntMap::t _new_IntMap() { return new IntMap(); }

  ::std::unordered_map<long long,int> m;

  bool hasItem (long long key) { return m.find(key) != m.end(); }
  int  getItem (long long key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (long long key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<long long,1>> keys()
  { 
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<long long,1>>(new monty::ndarray<long long,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;    
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  IntMap::t clone();
  IntMap::t __mosek_2fusion_2Utils_2IntMap__clone();
};



struct p_StringIntMap
{
  StringIntMap * _pubself;

  static p_StringIntMap * _get_impl(StringIntMap * _inst) { return _inst->_impl.get(); }

  p_StringIntMap(StringIntMap * _pubself) : _pubself(_pubself) {}

  static StringIntMap::t _new_StringIntMap() { return new StringIntMap(); }

  ::std::unordered_map<std::string,int> m;

  bool hasItem (const std::string & key) { return m.find(key) != m.end(); }
  int  getItem (const std::string & key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (const std::string & key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<std::string,1>> keys()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<std::string,1>>(new monty::ndarray<std::string,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  StringIntMap::t clone();
  StringIntMap::t __mosek_2fusion_2Utils_2StringIntMap__clone();
};
// End of file 'src/fusion/cxx/IntMap_p.h'
// mosek.fusion.Utils.StringBuffer from file 'src/fusion/cxx/StringBuffer_p.h'
// namespace mosek::fusion::Utils
struct p_StringBuffer
{
  StringBuffer * _pubthis; 
  std::stringstream ss;

  p_StringBuffer(StringBuffer * _pubthis) : _pubthis(_pubthis) {}

  static p_StringBuffer * _get_impl(StringBuffer::t ptr) { return ptr->_impl.get(); }
  static p_StringBuffer * _get_impl(StringBuffer * ptr) { return ptr->_impl.get(); }

  static StringBuffer::t _new_StringBuffer() { return new StringBuffer(); }

  StringBuffer::t clear ();
  
  StringBuffer::t a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t a (const monty::ndarray<int,1> & val);
  StringBuffer::t a (const monty::ndarray<long long,1> & val);
  StringBuffer::t a (const monty::ndarray<double,1> & val);
  

  StringBuffer::t a (const int & val);
  StringBuffer::t a (const long long & val);
  StringBuffer::t a (const double & val);
  StringBuffer::t a (const bool & val);
  StringBuffer::t a (const std::string & val);

  StringBuffer::t lf ();
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__clear ();

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<int,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<long long,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<double,1> & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const int & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const long long & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const double & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const bool & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const std::string & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__lf ();

  std::string toString () const;
};
// End of file 'src/fusion/cxx/StringBuffer_p.h'
}
}
}
#endif
